use chrono::DateTime;
use chrono::Utc;
use phf::phf_map;
use phf::Map;
use serde::{Deserialize, Serialize};
use strum::Display;
use strum::EnumString;
use uuid::Uuid;

use crate::errors::ThothError;
use crate::errors::ThothResult;
#[cfg(feature = "backend")]
use crate::schema::subject;
#[cfg(feature = "backend")]
use crate::schema::subject_history;

#[cfg_attr(feature = "backend", derive(DbEnum, juniper::GraphQLEnum))]
#[cfg_attr(feature = "backend", DieselType = "Subject_type")]
#[derive(Debug, Clone, PartialEq, Deserialize, Serialize, EnumString, Display)]
#[serde(rename_all = "SCREAMING_SNAKE_CASE")]
pub enum SubjectType {
    #[strum(serialize = "BIC")]
    Bic,
    #[strum(serialize = "BISAC")]
    Bisac,
    Thema,
    #[strum(serialize = "LCC")]
    Lcc,
    Custom,
    Keyword,
}

#[cfg_attr(
    feature = "backend",
    derive(juniper::GraphQLEnum),
    graphql(description = "Field to use when sorting subjects list")
)]
pub enum SubjectField {
    SubjectId,
    WorkId,
    SubjectType,
    SubjectCode,
    SubjectOrdinal,
    CreatedAt,
    UpdatedAt,
}

#[cfg_attr(feature = "backend", derive(Queryable))]
#[derive(Debug, Clone, Serialize, Deserialize, PartialEq)]
#[serde(rename_all = "camelCase")]
pub struct Subject {
    pub subject_id: Uuid,
    pub work_id: Uuid,
    pub subject_type: SubjectType,
    pub subject_code: String,
    pub subject_ordinal: i32,
    pub created_at: DateTime<Utc>,
    pub updated_at: DateTime<Utc>,
}

#[cfg_attr(
    feature = "backend",
    derive(juniper::GraphQLInputObject, Insertable),
    table_name = "subject"
)]
pub struct NewSubject {
    pub work_id: Uuid,
    pub subject_type: SubjectType,
    pub subject_code: String,
    pub subject_ordinal: i32,
}

#[cfg_attr(
    feature = "backend",
    derive(juniper::GraphQLInputObject, AsChangeset),
    changeset_options(treat_none_as_null = "true"),
    table_name = "subject"
)]
pub struct PatchSubject {
    pub subject_id: Uuid,
    pub work_id: Uuid,
    pub subject_type: SubjectType,
    pub subject_code: String,
    pub subject_ordinal: i32,
}

#[cfg_attr(feature = "backend", derive(Queryable))]
pub struct SubjectHistory {
    pub subject_history_id: Uuid,
    pub subject_id: Uuid,
    pub account_id: Uuid,
    pub data: serde_json::Value,
    pub timestamp: DateTime<Utc>,
}

#[cfg_attr(
    feature = "backend",
    derive(Insertable),
    table_name = "subject_history"
)]
pub struct NewSubjectHistory {
    pub subject_id: Uuid,
    pub account_id: Uuid,
    pub data: serde_json::Value,
}

pub fn check_subject(subject_type: &SubjectType, code: &str) -> ThothResult<()> {
    let valid = match &subject_type {
        SubjectType::Bic => true,
        SubjectType::Bisac => true,
        SubjectType::Thema => THEMA_CODES.contains_key::<str>(&code),
        SubjectType::Lcc => true,
        SubjectType::Custom => true,
        SubjectType::Keyword => true,
    };
    if valid {
        Ok(())
    } else {
        Err(ThothError::InvalidSubjectCode(
            code.to_string(),
            subject_type.to_string(),
        ))
    }
}

impl Default for SubjectType {
    fn default() -> SubjectType {
        SubjectType::Keyword
    }
}

impl Default for Subject {
    fn default() -> Subject {
        Subject {
            subject_id: Default::default(),
            work_id: Default::default(),
            subject_type: Default::default(),
            subject_code: "".to_string(),
            subject_ordinal: 1,
            created_at: chrono::TimeZone::timestamp(&Utc, 0, 0),
            updated_at: chrono::TimeZone::timestamp(&Utc, 0, 0),
        }
    }
}

#[test]
fn test_subjecttype_default() {
    let subjecttype: SubjectType = Default::default();
    assert_eq!(subjecttype, SubjectType::Keyword);
}

#[test]
fn test_subjecttype_display() {
    assert_eq!(format!("{}", SubjectType::Bic), "BIC");
    assert_eq!(format!("{}", SubjectType::Bisac), "BISAC");
    assert_eq!(format!("{}", SubjectType::Thema), "Thema");
    assert_eq!(format!("{}", SubjectType::Lcc), "LCC");
    assert_eq!(format!("{}", SubjectType::Custom), "Custom");
    assert_eq!(format!("{}", SubjectType::Keyword), "Keyword");
}

#[test]
fn test_subjecttype_fromstr() {
    use std::str::FromStr;
    assert_eq!(SubjectType::from_str("BIC").unwrap(), SubjectType::Bic);
    assert_eq!(SubjectType::from_str("BISAC").unwrap(), SubjectType::Bisac);
    assert_eq!(SubjectType::from_str("Thema").unwrap(), SubjectType::Thema);
    assert_eq!(SubjectType::from_str("LCC").unwrap(), SubjectType::Lcc);
    assert_eq!(
        SubjectType::from_str("Custom").unwrap(),
        SubjectType::Custom
    );
    assert_eq!(
        SubjectType::from_str("Keyword").unwrap(),
        SubjectType::Keyword
    );

    assert!(SubjectType::from_str("bic").is_err());
    assert!(SubjectType::from_str("Library of Congress Subject Code").is_err());
}

#[test]
fn test_check_subject() {
    // Valid codes for specific schemas
    assert!(check_subject(&SubjectType::Bic, "HRQX9").is_ok());
    assert!(check_subject(&SubjectType::Bisac, "BIB004060").is_ok());
    assert!(check_subject(&SubjectType::Thema, "ATXZ1").is_ok());

    // Custom fields: no validity restrictions
    assert!(check_subject(&SubjectType::Custom, "A custom subject").is_ok());
    assert!(check_subject(&SubjectType::Keyword, "keyword").is_ok());

    // Invalid codes for specific schemas: only validate Thema
    assert!(check_subject(&SubjectType::Bic, "ABCD0").is_ok());
    assert!(check_subject(&SubjectType::Bisac, "BLA123456").is_ok());
    assert!(check_subject(&SubjectType::Thema, "AHBW").is_err());
}

static THEMA_CODES: Map<&'static str, &'static str> = phf_map! {
    "A" => "The Arts",
    "AB" => "The arts: general issues",
    "ABA" => "Theory of art",
    "ABC" => "Conservation, restoration & care of artworks",
    "ABK" => "Forgery, falsification & theft of artworks",
    "ABQ" => "Art: financial aspects",
    "AF" => "Fine arts: art forms",
    "AFC" => "Painting & paintings",
    "AFCC" => "Paintings & painting in watercolours",
    "AFCL" => "Paintings & painting in oils",
    "AFCM" => "Murals & wall paintings",
    "AFF" => "Drawing & drawings",
    "AFH" => "Prints & printmaking",
    "AFJ" => "Other graphic art forms",
    "AFK" => "Non-graphic art forms",
    "AFKB" => "Sculpture",
    "AFKC" => "Carvings: artworks",
    "AFKG" => "Precious metal, precious stones & jewellery: artworks & design",
    "AFKN" => "Installation art",
    "AFKP" => "Performance art",
    "AFKV" => "Electronic, holographic & video art",
    "AFP" => "Ceramic & glass: artworks",
    "AFT" => "Decorative arts",
    "AFW" => "Textile artworks",
    "AG" => "Fine arts: treatments & subjects",
    "AGA" => "History of art",
    "AGB" => "Individual artists, art monographs",
    "AGC" => "Exhibition catalogues & specific collections",
    "AGH" => "Human figures depicted in art",
    "AGHF" => "Portraits & self-portraiture in art",
    "AGHN" => "Nudes depicted in art",
    "AGHX" => "Erotic art",
    "AGK" => "Small-scale, secular & domestic scenes in art",
    "AGN" => "Nature in art",
    "AGNA" => "Animals in art",
    "AGNB" => "Botanical art",
    "AGNL" => "Landscapes / seascapes",
    "AGNS" => "Still life",
    "AGP" => "Man-made objects depicted in art (cityscapes, machines, etc)",
    "AGR" => "Religious art",
    "AGZ" => "Art techniques & principles",
    "AJ" => "Photography & photographs",
    "AJC" => "Photographs: collections",
    "AJCD" => "Individual photographers",
    "AJCP" => "Photography: portraits & self-portraiture",
    "AJCX" => "Erotic & nude photography",
    "AJF" => "Photojournalism",
    "AJT" => "Photographic equipment & techniques: general",
    "AJTA" => "Camera-specific manuals",
    "AJTF" => "Photography: specific techniques",
    "AJTV" => "Video photography / videography",
    "AK" => "Industrial / commercial art & design",
    "AKB" => "Individual designers",
    "AKC" => "Graphic design",
    "AKD" => "Typography & lettering",
    "AKH" => "Book design",
    "AKHM" => "Manuscripts and illumination",
    "AKL" => "Illustration & commercial art",
    "AKLB" => "Illustration",
    "AKLC" => "Comic book & cartoon art",
    "AKLC1" => "Graphic novel & Manga artwork",
    "AKLF" => "Computer game art",
    "AKLP" => "Poster art",
    "AKP" => "Product design",
    "AKR" => "Furniture design",
    "AKT" => "Fashion & textiles",
    "AKTR" => "National or regional costume",
    "AM" => "Architecture",
    "AMA" => "Theory of architecture",
    "AMB" => "Individual architects & architectural firms",
    "AMC" => "Architectural structure & design",
    "AMCD" => "Architectural details, components and motifs",
    "AMCR" => "Environmentally-friendly (‘green’) architecture & design",
    "AMD" => "Architecture: professional practice",
    "AMG" => "Architecture: public buildings",
    "AMK" => "Architecture: residential buildings, domestic buildings",
    "AMKH" => "Architecture: holiday homes & cabins",
    "AMKL" => "Architecture: castles & fortifications",
    "AMKS" => "Architecture: palaces, stately homes & mansions",
    "AMN" => "Architecture: religious buildings",
    "AMR" => "Architecture: interior design",
    "AMV" => "Landscape architecture & design",
    "AMVD" => "City & town planning: architectural aspects",
    "AMX" => "History of architecture",
    "AT" => "Performing arts",
    "ATC" => "Individual actors & performers",
    "ATD" => "Theatre studies",
    "ATDC" => "Acting techniques",
    "ATDF" => "Theatre direction & production",
    "ATDH" => "Theatre: technical & background skills",
    "ATDS" => "Theatre management",
    "ATF" => "Films, cinema",
    "ATFA" => "Film history, theory & criticism",
    "ATFB" => "Individual film directors, film-makers",
    "ATFD" => "Film scripts & screenplays",
    "ATFG" => "Film guides & reviews",
    "ATFN" => "Film: styles & genres",
    "ATFR" => "Documentary films",
    "ATFV" => "Animated films",
    "ATFV1" => "Anime",
    "ATFX" => "Film production: technical & background skills",
    "ATJ" => "Television",
    "ATJD" => "Television screenplays, scripts & performances",
    "ATJS" => "Television drama",
    "ATJX" => "Television production: technical & background skills",
    "ATL" => "Radio",
    "ATLD" => "Radio plays, scripts & performances",
    "ATN" => "Internet & digital media: arts & performance",
    "ATQ" => "Dance",
    "ATQC" => "Choreography",
    "ATQL" => "Ballet",
    "ATQR" => "Ballroom dancing",
    "ATQT" => "Contemporary dance",
    "ATQV" => "Dancers / choreographers",
    "ATQZ" => "Folk dancing",
    "ATX" => "Other performing arts",
    "ATXC" => "Circus & circus skills",
    "ATXD" => "Comedy & stand-up",
    "ATXF" => "Conjuring & magic",
    "ATXM" => "Puppetry, miniature & toy theatre",
    "ATXP" => "Pageants, parades, festivals",
    "ATXZ" => "Animal spectacles, performing animals",
    "ATXZ1" => "Bullfighting",
    "AV" => "Music",
    "AVA" => "Theory of music & musicology",
    "AVC" => "Music reviews & criticism",
    "AVD" => "Discographies & buyer’s guides",
    "AVL" => "Music: styles & genres",
    "AVLA" => "Art music, orchestral & formal music",
    "AVLC" => "Choral music",
    "AVLF" => "Opera",
    "AVLK" => "Sacred & religious music",
    "AVLM" => "Music of film & stage",
    "AVLP" => "Popular music",
    "AVLT" => "Traditional & folk music",
    "AVLW" => "World music & regional styles",
    "AVLX" => "Electronic music",
    "AVM" => "History of music",
    "AVN" => "Composers & songwriters",
    "AVP" => "Musicians, singers, bands & groups",
    "AVQ" => "Musical scores, lyrics & libretti",
    "AVQS" => "Songbooks",
    "AVR" => "Musical instruments",
    "AVRG" => "Keyboard instruments",
    "AVRG1" => "Piano",
    "AVRJ" => "Percussion instruments",
    "AVRL" => "String instruments",
    "AVRL1" => "Guitar",
    "AVRL2" => "Plucked instruments",
    "AVRL3" => "Violin",
    "AVRN" => "Wind instruments",
    "AVRQ" => "Mechanical musical instruments",
    "AVRS" => "Electronic musical instruments",
    "AVS" => "Techniques of music / music tutorials / teaching of music",
    "AVSA" => "Singing: techniques",
    "AVX" => "Music recording & reproduction",
    "C" => "Language & Linguistics",
    "CB" => "Language: reference & general",
    "CBD" => "Dictionaries",
    "CBDX" => "Bilingual & multilingual dictionaries",
    "CBF" => "Thesauri",
    "CBG" => "Usage & grammar guides",
    "CBP" => "Speaking in public: advice & guides",
    "CBV" => "Creative writing & creative writing guides",
    "CBVS" => "Screenwriting techniques",
    "CBW" => "Writing & editing guides",
    "CBX" => "Language: history & general works",
    "CF" => "Linguistics",
    "CFA" => "Philosophy of language",
    "CFB" => "Sociolinguistics",
    "CFC" => "Literacy",
    "CFD" => "Psycholinguistics & cognitive linguistics",
    "CFDC" => "Language acquisition",
    "CFDM" => "Bilingualism & multilingualism",
    "CFF" => "Historical & comparative linguistics",
    "CFFD" => "Dialect, slang & jargon",
    "CFG" => "Semantics, discourse analysis, stylistics",
    "CFH" => "Phonetics, phonology",
    "CFK" => "Grammar, syntax & morphology",
    "CFL" => "Palaeography",
    "CFLA" => "Writing systems, alphabets",
    "CFM" => "Lexicography",
    "CFP" => "Translation & interpretation",
    "CFX" => "Computational & corpus linguistics",
    "CFZ" => "Sign languages, Braille & other linguistic communication",
    "CJ" => "Language teaching & learning",
    "CJA" => "Language teaching theory & methods",
    "CJB" => "Language teaching & learning material & coursework",
    "CJBG" => "Language learning: grammar, vocabulary & pronunciation",
    "CJBR" => "Language readers",
    "CJBT" => "Language self-study",
    "CJC" => "Language learning: specific skills",
    "CJCK" => "Language learning: speaking skills",
    "CJCL" => "Language learning: listening skills",
    "CJCR" => "Language learning: reading skills",
    "CJCW" => "Language learning: writing skills",
    "CJP" => "Language learning for specific purposes",
    "CJPD" => "Language learning for business",
    "CJPG" => "Language learning for technical & scientific purposes",
    "D" => "Biography, Literature & Literary studies",
    "DB" => "Ancient, classical & mediaeval texts",
    "DBS" => "Sagas & epics",
    "DBSG" => "Ancient Greek & Roman legends",
    "DBSN" => "Icelandic & Old Norse sagas",
    "DC" => "Poetry",
    "DCA" => "Classic & pre-20th century poetry",
    "DCC" => "Modern & contemporary poetry (c 1900 onwards)",
    "DCF" => "Poetry by individual poets",
    "DCQ" => "Poetry anthologies (various poets)",
    "DD" => "Plays, playscripts",
    "DDA" => "Classic & pre-20th century plays",
    "DDC" => "Modern & contemporary plays (c 1900 onwards)",
    "DDL" => "Comedic plays",
    "DDT" => "Tragic plays",
    "DN" => "Biography & non-fiction prose",
    "DNB" => "Biography: general",
    "DNBA" => "Autobiography: general",
    "DNBB" => "Biography: business & industry",
    "DNBB1" => "Autobiography: business & industry",
    "DNBF" => "Biography: arts & entertainment",
    "DNBF1" => "Autobiography: arts & entertainment",
    "DNBH" => "Biography: historical, political & military",
    "DNBH1" => "Autobiography: historical, political & military",
    "DNBL" => "Biography: literary",
    "DNBL1" => "Autobiography: literary",
    "DNBM" => "Biography: philosophy & social sciences",
    "DNBM1" => "Autobiography: philosophy & social sciences",
    "DNBP" => "Biography: adventurers & explorers",
    "DNBP1" => "Autobiography: adventurers & explorers",
    "DNBR" => "Biography: royalty",
    "DNBR1" => "Autobiography: royalty",
    "DNBS" => "Biography: sport",
    "DNBS1" => "Autobiography: sport",
    "DNBT" => "Biography: science, technology & medicine",
    "DNBT1" => "Autobiography: science, technology & medicine",
    "DNBX" => "Biography: religious & spiritual",
    "DNBX1" => "Autobiography: religious & spiritual",
    "DNBZ" => "Collected biographies",
    "DNC" => "Memoirs",
    "DND" => "Diaries, letters & journals",
    "DNG" => "Animal life stories",
    "DNL" => "Literary essays",
    "DNP" => "Reportage & collected journalism",
    "DNS" => "Speeches",
    "DNT" => "Anthologies: general",
    "DNX" => "True stories: general",
    "DNXC" => "True crime",
    "DNXC3" => "True crime: serial killers & murderers",
    "DNXH" => "True stories of discovery",
    "DNXM" => "True war & combat stories",
    "DNXP" => "True stories of heroism, endurance & survival",
    "DNXR" => "True stories of survival of abuse & injustice",
    "DNXZ" => "Erotic confessions & true stories",
    "DS" => "Literature: history & criticism",
    "DSA" => "Literary theory",
    "DSB" => "Literary studies: general",
    "DSBB" => "Literary studies: ancient, classical & mediaeval",
    "DSBC" => "Literary studies: c 1400 to c 1600",
    "DSBD" => "Literary studies: c 1600 to c 1800",
    "DSBF" => "Literary studies: c 1800 to c 1900",
    "DSBH" => "Literary studies: c 1900 to c 2000",
    "DSBH5" => "Literary studies: post-colonial literature",
    "DSBJ" => "Literary studies: from c 2000",
    "DSC" => "Literary studies: poetry & poets",
    "DSG" => "Literary studies: plays & playwrights",
    "DSK" => "Literary studies: fiction, novelists & prose writers",
    "DSM" => "Comparative literature",
    "DSR" => "Literary reference works",
    "DSRC" => "Literary companions, book reviews & guides",
    "DSY" => "Children’s & teenage literature studies: general",
    "DSYC" => "Children’s & teenage book reviews & guides",
    "F" => "Fiction & Related items",
    "FB" => "Fiction: general & literary",
    "FBA" => "Modern & contemporary fiction",
    "FBAN" => "‘Street’ fiction",
    "FBC" => "Classic fiction",
    "FC" => "Biographical fiction",
    "FD" => "Speculative fiction",
    "FDB" => "Dystopian & utopian fiction",
    "FDK" => "Alternative history fiction",
    "FF" => "Crime & mystery fiction",
    "FFC" => "Classic crime & mystery fiction",
    "FFD" => "Crime & mystery: private investigator / amateur detectives",
    "FFH" => "Historical crime & mysteries",
    "FFJ" => "Crime & mystery: cosy mystery",
    "FFK" => "Comic (humorous) crime & mystery",
    "FFL" => "Crime & mystery: hard-boiled crime, noir fiction",
    "FFP" => "Crime & mystery: police procedural",
    "FFS" => "Crime & mystery: women sleuths",
    "FG" => "Sports fiction",
    "FH" => "Thriller / suspense fiction",
    "FHD" => "Espionage & spy thriller",
    "FHK" => "Technothriller",
    "FHP" => "Political / legal thriller",
    "FHQ" => "Esoteric thriller",
    "FHX" => "Psychological thriller",
    "FJ" => "Adventure fiction",
    "FJH" => "Historical adventure fiction",
    "FJM" => "War, combat & military fiction",
    "FJMC" => "Napoleonic War fiction",
    "FJMF" => "First World War fiction",
    "FJMS" => "Second World War fiction",
    "FJMV" => "Vietnam War fiction",
    "FJN" => "Sea stories",
    "FJW" => "Adventure fiction: Westerns",
    "FK" => "Horror & supernatural fiction",
    "FKC" => "Classic horror & ghost stories",
    "FKM" => "Contemporary horror & ghost stories",
    "FKW" => "Occult fiction",
    "FL" => "Science fiction",
    "FLC" => "Classic science fiction",
    "FLG" => "Science fiction: time travel",
    "FLM" => "Science fiction: steampunk",
    "FLP" => "Science fiction: near-future",
    "FLPB" => "Science fiction: cyberpunk / biopunk",
    "FLQ" => "Science fiction: apocalyptic & post-apocalyptic",
    "FLR" => "Science fiction: military",
    "FLS" => "Science fiction: space opera",
    "FLU" => "Science fiction: aliens / UFOs",
    "FLW" => "Science fiction: space exploration",
    "FM" => "Fantasy",
    "FMB" => "Epic fantasy / heroic fantasy",
    "FMH" => "Historical fantasy",
    "FMK" => "Comic (humorous) fantasy",
    "FMM" => "Magical realism",
    "FMR" => "Fantasy romance",
    "FMT" => "Dark fantasy",
    "FMW" => "Contemporary fantasy",
    "FMX" => "Urban fantasy",
    "FN" => "Myths & fairy tales",
    "FP" => "Erotic fiction",
    "FQ" => "Contemporary lifestyle fiction",
    "FR" => "Romance",
    "FRD" => "Contemporary romance",
    "FRF" => "Romance: wholesome",
    "FRH" => "Historical romance",
    "FRJ" => "Romance: ‘western’, rural or ‘outback’",
    "FRM" => "Romantic suspense",
    "FRP" => "Romance in uniform",
    "FRQ" => "Romance: medical",
    "FRT" => "Romance: fantasy & paranormal",
    "FRU" => "Romance: time travel",
    "FRV" => "Dark romance",
    "FRX" => "Erotic romance",
    "FS" => "Family life fiction",
    "FT" => "Generational sagas",
    "FU" => "Humorous fiction",
    "FUP" => "Satirical fiction & parodies",
    "FV" => "Historical fiction",
    "FW" => "Religious & spiritual fiction",
    "FX" => "Fiction: narrative themes",
    "FXB" => "Narrative theme: Coming of age",
    "FXD" => "Narrative theme: Love & relationships",
    "FXE" => "Narrative theme: Environmental issues",
    "FXL" => "Narrative theme: Death, grief, loss",
    "FXM" => "Narrative theme: Interior life",
    "FXP" => "Narrative theme: Politics",
    "FXR" => "Narrative theme: Sense of place",
    "FXS" => "Narrative theme: Social issues",
    "FY" => "Fiction: special features",
    "FYB" => "Short stories",
    "FYD" => "Epistolary fiction",
    "FYH" => "Fiction: pastiche",
    "FYM" => "Fiction: mashup",
    "FYR" => "Category fiction",
    "FYT" => "Fiction in translation",
    "FYV" => "Fiction: inspired by or adapted from",
    "FZ" => "Fiction companions",
    "G" => "Reference, Information & Interdisciplinary subjects",
    "GB" => "Encyclopaedias & reference works",
    "GBA" => "General encyclopaedias",
    "GBC" => "Reference works",
    "GBCB" => "Dictionaries of biography",
    "GBCD" => "Subject dictionaries",
    "GBCQ" => "Quotations, proverbs & sayings",
    "GBCR" => "Bibliographies, catalogues",
    "GBCS" => "Serials, periodicals, abstracts, indexes",
    "GBCT" => "Directories",
    "GBCY" => "Yearbooks, annuals, almanacs",
    "GBD" => "Miscellanies & compendia",
    "GL" => "Library & information sciences / Museology",
    "GLC" => "Library, archive & information management",
    "GLCA" => "Information retrieval & access",
    "GLF" => "IT, Internet & electronic resources in libraries",
    "GLH" => "Acquisitions & collection development",
    "GLK" => "Bibliographic & subject control",
    "GLM" => "Library & information services",
    "GLP" => "Archiving, preservation & digitization",
    "GLZ" => "Museology & heritage studies",
    "GP" => "Research & information: general",
    "GPF" => "Information theory",
    "GPFC" => "Cybernetics & systems theory",
    "GPH" => "Data analysis: general",
    "GPJ" => "Coding theory & cryptology",
    "GPQ" => "Decision theory: general",
    "GPQD" => "Risk assessment",
    "GPS" => "Research methods: general",
    "GT" => "Interdisciplinary studies",
    "GTB" => "History of scholarship (principally of social sciences & humanities)",
    "GTC" => "Communication studies",
    "GTD" => "Semiotics / semiology",
    "GTK" => "Cognitive studies",
    "GTM" => "Regional studies",
    "GTP" => "Development studies",
    "GTQ" => "Globalization",
    "GTT" => "Flags, emblems, symbols, logos",
    "GTU" => "Peace studies & conflict resolution",
    "GTV" => "Institutions & learned societies: general",
    "GTZ" => "General studies",
    "J" => "Society & Social Sciences",
    "JB" => "Society & culture: general",
    "JBC" => "Cultural & media studies",
    "JBCC" => "Cultural studies",
    "JBCC1" => "Popular culture",
    "JBCC2" => "Material culture",
    "JBCC3" => "Cultural studies: fashion & society",
    "JBCC4" => "Cultural studies: food & society",
    "JBCC6" => "Cultural studies: customs & traditions",
    "JBCC9" => "History of ideas",
    "JBCT" => "Media studies",
    "JBCT1" => "Media studies: internet, digital media & society",
    "JBCT2" => "Media studies: TV & society",
    "JBCT3" => "Media studies: advertising & society",
    "JBCT4" => "Media studies: journalism",
    "JBF" => "Social & ethical issues",
    "JBFA" => "Social discrimination & equal treatment",
    "JBFB" => "Social Integration & assimilation",
    "JBFC" => "Poverty & precarity",
    "JBFD" => "Housing & homelessness",
    "JBFF" => "Social impact of disasters",
    "JBFG" => "Refugees & political asylum",
    "JBFG1" => "Aiding escape & evasion",
    "JBFH" => "Migration, immigration & emigration",
    "JBFJ" => "Human trafficking",
    "JBFK" => "Violence & abuse in society",
    "JBFK1" => "Child abuse",
    "JBFK2" => "Sexual abuse & harassment",
    "JBFK3" => "Domestic abuse",
    "JBFK4" => "Bullying & harassment",
    "JBFM" => "Disability: social aspects",
    "JBFN" => "Health, illness & addiction: social aspects",
    "JBFQ" => "Social mobility",
    "JBFS" => "Consumerism",
    "JBFU" => "Animals & society",
    "JBFV" => "Ethical issues & debates",
    "JBFV1" => "Ethical issues: abortion & birth control",
    "JBFV2" => "Ethical issues: capital punishment",
    "JBFV3" => "Ethical issues: censorship",
    "JBFV4" => "Ethical issues: euthanasia & right to die",
    "JBFV5" => "Ethical issues: scientific, technological & medical developments",
    "JBFW" => "Sex & sexuality, social aspects",
    "JBFX" => "Social attitudes",
    "JBFZ" => "Social forecasting, future studies",
    "JBG" => "Popular beliefs & controversial knowledge",
    "JBGB" => "Folklore, myths & legends",
    "JBGX" => "Conspiracy theories",
    "JBS" => "Social groups",
    "JBSA" => "Social classes",
    "JBSC" => "Rural communities",
    "JBSD" => "Urban communities",
    "JBSF" => "Gender studies, gender groups",
    "JBSF1" => "Gender studies: women & girls",
    "JBSF11" => "Feminism & feminist theory",
    "JBSF2" => "Gender studies: men & boys",
    "JBSF3" => "Gender studies: transgender, transsexual, intersex people",
    "JBSJ" => "Gay & Lesbian studies / LGBTQ studies",
    "JBSL" => "Ethnic studies",
    "JBSL1" => "Ethnic groups & multicultural studies",
    "JBSL11" => "Indigenous peoples",
    "JBSL13" => "Mixed heritage / mixed race groups or people",
    "JBSP" => "Age groups & generations",
    "JBSP1" => "Age groups: children",
    "JBSP2" => "Age groups: adolescents",
    "JBSP3" => "Age groups: adults",
    "JBSP4" => "Age groups: the elderly",
    "JBSR" => "Social groups: religious groups & communities",
    "JBSW" => "Social groups: alternative lifestyles",
    "JBSX" => "Secret societies",
    "JBSY" => "Social groups: clubs & societies",
    "JH" => "Sociology & anthropology",
    "JHB" => "Sociology",
    "JHBA" => "Social theory",
    "JHBC" => "Social research & statistics",
    "JHBD" => "Population & demography",
    "JHBK" => "Sociology: family & relationships",
    "JHBL" => "Sociology: work & labour",
    "JHBS" => "Sociology: sport & leisure",
    "JHBZ" => "Sociology: death & dying",
    "JHM" => "Anthropology",
    "JHMC" => "Social & cultural anthropology",
    "JK" => "Social services & welfare, criminology",
    "JKS" => "Social welfare & social services",
    "JKSB" => "Welfare & benefit systems",
    "JKSB1" => "Child welfare",
    "JKSF" => "Adoption & fostering",
    "JKSG" => "Care of the elderly",
    "JKSM" => "Care of the mentally ill",
    "JKSN" => "Social work",
    "JKSN1" => "Charities, voluntary services & philanthropy",
    "JKSN2" => "Social counselling & advice services",
    "JKSR" => "Aid & relief programmes",
    "JKSW" => "Emergency services",
    "JKSW1" => "Police & security services",
    "JKSW2" => "Fire services",
    "JKSW3" => "Ambulance & rescue services",
    "JKV" => "Crime & criminology",
    "JKVC" => "Causes & prevention of crime",
    "JKVF" => "Criminal investigation & detection",
    "JKVF1" => "Forensic science",
    "JKVG" => "Drugs trade / drug trafficking",
    "JKVJ" => "Street crime",
    "JKVK" => "Corporate crime / white-collar crime",
    "JKVM" => "Organized crime",
    "JKVP" => "Penology & punishment",
    "JKVQ" => "Offenders",
    "JKVQ1" => "Rehabilitation of offenders",
    "JKVQ2" => "Juvenile offenders",
    "JKVS" => "Probation services",
    "JKVV" => "Victimology & victims of crime",
    "JM" => "Psychology",
    "JMA" => "Psychological theory, systems, schools & viewpoints",
    "JMAF" => "Psychoanalytical & Freudian psychology",
    "JMAF1" => "Lacanian psychoanalysis",
    "JMAJ" => "Analytical & Jungian psychology",
    "JMAL" => "Behaviourism, Behavioural theory",
    "JMAN" => "Humanistic psychology",
    "JMAP" => "Positive psychology",
    "JMAQ" => "Cognitivism, cognitive theory",
    "JMB" => "Psychological methodology",
    "JMBT" => "Psychological testing & measurement",
    "JMC" => "Child, developmental & lifespan psychology",
    "JMD" => "Psychology of ageing",
    "JMF" => "Family psychology",
    "JMG" => "Psychology of gender",
    "JMH" => "Social, group or collective psychology",
    "JMHC" => "Interpersonal communication & skills",
    "JMJ" => "Occupational & industrial psychology",
    "JMK" => "Criminal or forensic psychology",
    "JML" => "Experimental psychology",
    "JMM" => "Physiological & neuro-psychology, biopsychology",
    "JMP" => "Abnormal psychology",
    "JMQ" => "Psychology: emotions",
    "JMR" => "Cognition & cognitive psychology",
    "JMS" => "Psychology: the self, ego, identity, personality",
    "JMT" => "Psychology: states of consciousness",
    "JMU" => "Psychology: sexual behaviour",
    "JMX" => "Parapsychological studies",
    "JN" => "Education",
    "JNA" => "Philosophy & theory of education",
    "JNAM" => "Moral & social purpose of education",
    "JNB" => "History of education",
    "JNC" => "Educational psychology",
    "JND" => "Educational systems & structures",
    "JNDG" => "Curriculum planning & development",
    "JNDH" => "Education: examinations & assessment",
    "JNE" => "Social pedagogy",
    "JNF" => "Educational strategies & policy",
    "JNFC" => "Counselling of students",
    "JNFK" => "Educational strategies & policy: inclusion",
    "JNG" => "Early childhood care & education",
    "JNH" => "Home schooling",
    "JNK" => "Educational administration & organization",
    "JNKG" => "Funding of education & student finance",
    "JNKH" => "Teaching staff",
    "JNL" => "Schools & pre-schools",
    "JNLA" => "Pre-school & kindergarten",
    "JNLB" => "Primary & middle schools",
    "JNLC" => "Secondary schools",
    "JNLP" => "Independent schools, private education",
    "JNLR" => "Faith (religious) schools",
    "JNLV" => "Outdoor schools / education",
    "JNM" => "Higher & further education, tertiary education",
    "JNMT" => "Teacher training",
    "JNP" => "Adult education, continuous learning",
    "JNQ" => "Open learning, distance education",
    "JNR" => "Careers guidance",
    "JNRD" => "Work experience, placements & internships",
    "JNRV" => "Industrial or vocational training",
    "JNS" => "Teaching of students with different educational needs",
    "JNSC" => "Teaching of students with physical impairment or disability",
    "JNSG" => "Teaching of students with learning difficulties",
    "JNSL" => "Teaching of students with social, emotional or behavioural difficulties",
    "JNSP" => "Teaching of gifted or talented students",
    "JNSR" => "Remedial education & teaching",
    "JNT" => "Teaching skills & techniques",
    "JNTC" => "Competence development",
    "JNTP" => "Project-based learning",
    "JNU" => "Teaching of a specific subject",
    "JNUM" => "Teachers’ classroom resources & material",
    "JNUM1" => "Lesson plans",
    "JNV" => "Educational equipment & technology, computer-aided learning (CAL)",
    "JNW" => "Extra-curricular activities",
    "JNZ" => "Study & learning skills: general",
    "JP" => "Politics & government",
    "JPA" => "Political science & theory",
    "JPB" => "Comparative politics",
    "JPF" => "Political ideologies",
    "JPFB" => "Anarchism",
    "JPFC" => "Marxism & Communism",
    "JPFF" => "Socialism & left-of-centre democratic ideologies",
    "JPFK" => "Liberalism & centre democratic ideologies",
    "JPFM" => "Conservatism & right-of-centre democratic ideologies",
    "JPFN" => "Nationalism",
    "JPFQ" => "Fascism & Nazism",
    "JPFR" => "Religious & theocratic ideologies",
    "JPH" => "Political structure & processes",
    "JPHC" => "Constitution: government & the state",
    "JPHF" => "Elections & referenda",
    "JPHL" => "Political leaders & leadership",
    "JPHV" => "Political structures: democracy",
    "JPHX" => "Political structures: totalitarianism & dictatorship",
    "JPL" => "Political parties",
    "JPN" => "Indigenous people: government",
    "JPP" => "Public administration",
    "JPQ" => "Central / national / federal government",
    "JPQB" => "Central / national / federal government policies",
    "JPR" => "Regional, state & other local government",
    "JPRB" => "Regional, state & other local government policies",
    "JPS" => "International relations",
    "JPSD" => "Diplomacy",
    "JPSF" => "Arms negotiation & control",
    "JPSH" => "Espionage & secret services",
    "JPSL" => "Geopolitics",
    "JPSN" => "International institutions",
    "JPT" => "Municipal / city government",
    "JPV" => "Political control & freedoms",
    "JPVC" => "Civics & citizenship",
    "JPVH" => "Human rights, civil rights",
    "JPVR" => "Political oppression & persecution",
    "JPW" => "Political activism",
    "JPWA" => "Public opinion & polls",
    "JPWC" => "Political campaigning & advertising",
    "JPWG" => "Pressure groups, protest movements & non-violent action",
    "JPWH" => "Non-governmental organizations (NGOs)",
    "JPWL" => "Terrorism, armed struggle",
    "JPWQ" => "Revolutionary groups & movements",
    "JPWS" => "Armed conflict",
    "JPZ" => "Political corruption",
    "JW" => "Warfare & defence",
    "JWA" => "Theory of warfare & military science",
    "JWC" => "Military forces & sectors",
    "JWCD" => "Land forces & warfare",
    "JWCG" => "Irregular or guerrilla forces & warfare",
    "JWCK" => "Naval forces & warfare",
    "JWCM" => "Air forces & warfare",
    "JWCS" => "Special & elite forces",
    "JWJ" => "Military administration",
    "JWK" => "Military & defence strategy",
    "JWKF" => "Military intelligence",
    "JWL" => "War & defence operations",
    "JWLF" => "Battles & campaigns",
    "JWLP" => "Peacekeeping operations",
    "JWM" => "Weapons & equipment",
    "JWMC" => "Chemical & biological weapons",
    "JWMN" => "Nuclear weapons",
    "JWMV" => "Military vehicles",
    "JWT" => "Military institutions",
    "JWTU" => "Military uniforms / insignia",
    "JWX" => "Other warfare & defence issues",
    "JWXF" => "Arms trade",
    "JWXK" => "War crimes",
    "JWXN" => "Mercenaries",
    "JWXR" => "Prisoners of war",
    "JWXT" => "Mutiny",
    "JWXV" => "Military veterans",
    "JWXZ" => "Combat / defence skills & manuals",
    "K" => "Economics, Finance, Business & Management",
    "KC" => "Economics",
    "KCA" => "Economic theory & philosophy",
    "KCB" => "Macroeconomics",
    "KCBM" => "Monetary economics",
    "KCC" => "Microeconomics",
    "KCD" => "Economics of industrial organization",
    "KCF" => "Labour / income economics",
    "KCG" => "Economic growth",
    "KCH" => "Econometrics & economic statistics",
    "KCJ" => "Economic forecasting",
    "KCK" => "Behavioural economics",
    "KCL" => "International economics",
    "KCM" => "Development economics & emerging economies",
    "KCLT" => "International trade & commerce",
    "KCP" => "Political economy",
    "KCS" => "Economic systems & structures",
    "KCSA" => "Capitalism",
    "KCSD" => "Mixed economic systems",
    "KCSG" => "Planned economic systems",
    "KCV" => "Economics of specific sectors",
    "KCVD" => "Agricultural economics",
    "KCVG" => "Environmental economics",
    "KCVJ" => "Health economics",
    "KCVK" => "Welfare economics",
    "KCVM" => "Digital or internet economics",
    "KCVP" => "Knowledge economics",
    "KCVS" => "Urban economics",
    "KCX" => "Economic & financial crises & disasters",
    "KCY" => "Popular economics",
    "KCZ" => "Economic history",
    "KF" => "Finance & accounting",
    "KFC" => "Accounting",
    "KFCC" => "Cost accounting",
    "KFCF" => "Financial accounting",
    "KFCM" => "Management accounting & bookkeeping",
    "KFCP" => "Public finance accounting",
    "KFCR" => "Financial reporting, financial statements",
    "KFCX" => "Accounting: study & revision guides",
    "KFF" => "Finance",
    "KFFD" => "Public finance & taxation",
    "KFFH" => "Corporate finance",
    "KFFJ" => "Currency / Foreign exchange",
    "KFFK" => "Banking",
    "KFFL" => "Credit & credit institutions",
    "KFFM" => "Investment & securities",
    "KFFN" => "Insurance & actuarial studies",
    "KFFP" => "Pensions",
    "KFFR" => "Property & real estate",
    "KFFX" => "Banking & finance: study & revision guides",
    "KJ" => "Business & Management",
    "KJB" => "Business studies: general",
    "KJBX" => "Business & management: study & revision guides",
    "KJC" => "Business strategy",
    "KJD" => "Business innovation",
    "KJDD" => "Disruptive innovation",
    "KJE" => "E-commerce: business aspects",
    "KJF" => "Business competition",
    "KJG" => "Business ethics & social responsibility",
    "KJH" => "Entrepreneurship",
    "KJJ" => "Business & the environment; ‘green’ approaches to business",
    "KJK" => "International business",
    "KJL" => "Consultancy",
    "KJM" => "Management & management techniques",
    "KJMB" => "Management: leadership & motivation",
    "KJMD" => "Management decision making",
    "KJMK" => "Knowledge management",
    "KJMP" => "Project management",
    "KJMQ" => "Quality Assurance (QA) & Total Quality Management (TQM)",
    "KJMT" => "Time management",
    "KJMV" => "Management of specific areas",
    "KJMV1" => "Budgeting & financial management",
    "KJMV2" => "Personnel & human resources management",
    "KJMV21" => "Performance management / appraisals",
    "KJMV22" => "Diversity, inclusivity in the workplace",
    "KJMV4" => "Management of real estate, property & plant",
    "KJMV5" => "Production & quality control management",
    "KJMV6" => "Research & development management",
    "KJMV7" => "Sales & marketing management",
    "KJMV8" => "Purchasing & supply management",
    "KJMV9" => "Distribution & logistics management",
    "KJN" => "Business negotiation",
    "KJP" => "Business communication & presentation",
    "KJQ" => "Business mathematics & systems",
    "KJR" => "Corporate governance: role & responsibilities of boards & directors",
    "KJS" => "Sales & marketing",
    "KJSA" => "Advertising",
    "KJSC" => "Brands & branding",
    "KJSG" => "Web-marketing",
    "KJSJ" => "Direct marketing / telemarketing",
    "KJSM" => "Market research",
    "KJSP" => "Public relations",
    "KJSU" => "Customer services",
    "KJT" => "Operational research",
    "KJU" => "Organizational theory & behaviour",
    "KJV" => "Ownership & organization of enterprises",
    "KJVB" => "Takeovers, mergers & buy-outs",
    "KJVD" => "Privatization",
    "KJVF" => "Franchises",
    "KJVG" => "Multinationals",
    "KJVN" => "Public ownership / nationalization",
    "KJVP" => "Monopolies",
    "KJVS" => "Small businesses & self-employment",
    "KJVT" => "Outsourcing",
    "KJVV" => "Joint ventures",
    "KJVW" => "Employee-ownership & co-operatives",
    "KJVX" => "Non-profitmaking organizations",
    "KJW" => "Office & workplace",
    "KJWB" => "Office management",
    "KJWF" => "Office systems & equipment",
    "KJWS" => "Secretarial, clerical & office skills",
    "KJWX" => "Working patterns & practices",
    "KJZ" => "History of specific companies / corporate history",
    "KN" => "Industry & industrial studies",
    "KNA" => "Agribusiness & primary industries",
    "KNAC" => "Agriculture, agribusiness & food production industries",
    "KNAF" => "Fisheries & related industries",
    "KNAL" => "Forestry industry",
    "KNAT" => "Extractive industries",
    "KNB" => "Energy industries & utilities",
    "KNBL" => "Electrical power generation & distribution industries",
    "KNBP" => "Petroleum, oil & gas industries",
    "KNBT" => "Alternative & renewable energy industries",
    "KNBW" => "Water industries",
    "KND" => "Manufacturing industries",
    "KNDC" => "Chemical, biotechnology & pharmaceutical industries",
    "KNDD" => "Apparel, garment & textile industries",
    "KNDR" => "Vehicle manufacturing industries",
    "KNG" => "Transport industries",
    "KNJ" => "Construction & heavy industry",
    "KNJC" => "Construction & building industry",
    "KNJH" => "Iron, steel & other metal industries",
    "KNP" => "Retail & wholesale industries",
    "KNS" => "Hospitality & service industries",
    "KNSB" => "Food & drink service industries",
    "KNSG" => "Hospitality, leisure & tourism industries",
    "KNSJ" => "Events management industry",
    "KNSX" => "Fashion & beauty industries",
    "KNT" => "Media, entertainment, information & communication industries",
    "KNTC" => "Film, TV & Radio industries",
    "KNTF" => "Music industry",
    "KNTP" => "Publishing industry & journalism",
    "KNTP1" => "Publishing & book trade",
    "KNTP2" => "News media & journalism",
    "KNTV" => "Computer & video game industry",
    "KNTX" => "Information technology industries",
    "KNV" => "Civil service & public sector",
    "KNX" => "Industrial relations, occupational health & safety",
    "KNXC" => "Health & safety in the workplace",
    "KNXN" => "Industrial arbitration & negotiation",
    "KNXU" => "Trade unions",
    "L" => "Law",
    "LA" => "Jurisprudence & general issues",
    "LAB" => "Methods, theory & philosophy of law",
    "LAF" => "Systems of law",
    "LAFC" => "Systems of law: common law",
    "LAFD" => "Systems of law: civil codes / civil law",
    "LAFR" => "Systems of law: Roman law",
    "LAFS" => "Systems of law: Islamic law",
    "LAFT" => "Systems of law: Jewish Law",
    "LAFX" => "Systems of law: ecclesiastical (canon) law",
    "LAM" => "Comparative law",
    "LAQ" => "Law & society, sociology of law",
    "LAQG" => "Law & society, gender issues",
    "LAR" => "Legal aspects of criminology",
    "LAS" => "Legal skills & practice",
    "LASD" => "Legal skills: advocacy",
    "LASH" => "Legal skills: drafting & legal writing",
    "LASK" => "Legal skills: negotiating and interviewing",
    "LASN" => "Legal skills: research methods",
    "LASP" => "Legal practice: paralegals & paralegalism",
    "LAT" => "Legal profession: general",
    "LATC" => "Legal ethics & professional conduct",
    "LAY" => "Law as it applies to other professions & disciplines",
    "LAZ" => "Legal history",
    "LB" => "International law",
    "LBB" => "Public international law",
    "LBBC" => "Public international law: treaties & other sources",
    "LBBC1" => "Public International law: customary law",
    "LBBD" => "Public international law: diplomatic law",
    "LBBF" => "Public international law: jurisdiction & immunities",
    "LBBJ" => "Public international law: territory & statehood",
    "LBBK" => "Public international law: law of the sea",
    "LBBL" => "Public International law: health",
    "LBBM" => "Public international law: economic & trade",
    "LBBM1" => "Public international law, economic & trade: tariffs",
    "LBBM3" => "Public international law, economic & trade: investment treaties & disputes",
    "LBBM5" => "Public international law: energy & natural resources",
    "LBBM7" => "Public international law, economic & trade: corporations",
    "LBBP" => "Public international law: environment",
    "LBBP1" => "Public international law, environment: agricultural law",
    "LBBQ" => "Public international law: administration",
    "LBBR" => "Public international law: human rights",
    "LBBR1" => "Public international law, human rights: labour & social",
    "LBBS" => "Public international law: humanitarian law",
    "LBBU" => "Public international law: international organizations & institutions",
    "LBBV" => "Public international law: responsibility of states & other entities",
    "LBBZ" => "Public international law: criminal law",
    "LBD" => "International law: transport, communications & commerce",
    "LBDA" => "International law, transport: space & aerospace law",
    "LBDK" => "International law: transnational commerce & international sale of goods law",
    "LBDM" => "International law, transport & commerce: maritime law",
    "LBDT" => "International law: communications, telecommunications & media",
    "LBG" => "Private international law & conflict of laws",
    "LBH" => "International law: international disputes & civil procedure",
    "LBHG" => "International law: courts & procedures",
    "LBHT" => "International law: arbitration",
    "LBJ" => "International law: intellectual property",
    "LBK" => "International law: sports",
    "LBL" => "International law reports",
    "LN" => "Laws of specific jurisdictions & specific areas of law",
    "LNA" => "Legal systems: general",
    "LNAA" => "Legal systems: courts & procedures",
    "LNAA1" => "Legal systems: judicial powers",
    "LNAA2" => "Legal systems: law of contempt",
    "LNAC" => "Legal systems: civil procedure, litigation & dispute resolution",
    "LNAC1" => "Civil remedies",
    "LNAC12" => "Restitution",
    "LNAC14" => "Damages & compensation",
    "LNAC16" => "Injunctions & other orders",
    "LNAC3" => "Civil procedure: law of evidence",
    "LNAC4" => "Civil procedure: investigation & specific proceedings",
    "LNAC5" => "Arbitration, mediation & alternative dispute resolution",
    "LNAF" => "Legal systems: costs & funding",
    "LNAL" => "Legal systems: regulation of legal profession",
    "LNB" => "Private or civil law: general",
    "LNBA" => "Legal entity (natural & legal persons)",
    "LNBB" => "Civil registration system",
    "LNC" => "Company, commercial & competition law: general",
    "LNCB" => "Commercial law",
    "LNCB1" => "Franchising law",
    "LNCB2" => "E-commerce law",
    "LNCB3" => "Sale of goods law",
    "LNCB4" => "Outsourcing law",
    "LNCB5" => "Shipping law",
    "LNCB6" => "Aviation law",
    "LNCB7" => "Catering, restaurants & crafts law",
    "LNCC" => "Regulatory compliance",
    "LNCD" => "Company law",
    "LNCD1" => "Mergers & acquisitions law",
    "LNCE" => "Registry & proceedings law",
    "LNCF" => "Partnership & cooperative law",
    "LNCG" => "Transformation law, change of corporate form",
    "LNCH" => "Competition law / Antitrust law",
    "LNCJ" => "Contract law",
    "LNCK" => "Company & business offences",
    "LNCL" => "Agency law",
    "LNCN" => "Procurement law",
    "LNCQ" => "Construction & engineering law",
    "LNCQ1" => "Private construction & engineering law",
    "LNCQ2" => "Public construction law",
    "LNCR" => "Energy & natural resources law",
    "LND" => "Constitutional & administrative law: general",
    "LNDA" => "Citizenship & nationality law",
    "LNDA1" => "Immigration law",
    "LNDA3" => "Asylum law",
    "LNDB" => "Administrative jurisdiction & public administration",
    "LNDB1" => "Administrative law, general",
    "LNDB2" => "Administrative procedure & courts",
    "LNDB3" => "State & public properties & assets",
    "LNDB4" => "Sanctioning power of the administration",
    "LNDB5" => "Compulsory expropriation, compulsory purchase, eminent domain",
    "LNDB6" => "Making of rules & administrative acts",
    "LNDB7" => "Regulation of public services",
    "LNDB8" => "Law of science & research, university college law",
    "LNDC" => "Law: Human rights & civil liberties",
    "LNDC1" => "Constitutional law & human rights",
    "LNDC2" => "Privacy law",
    "LNDC4" => "Freedom of expression law",
    "LNDC5" => "History of constitution & comparative constitutional law",
    "LNDE" => "Civil & Public Servants law",
    "LNDF" => "Freedom of information law",
    "LNDG" => "Religious law & concordats",
    "LNDH" => "Government powers",
    "LNDJ" => "State liability & compensation law",
    "LNDK" => "Military & defence law & civilian service law",
    "LNDL" => "Safety & police law, regulatory & weapons law",
    "LNDM" => "Judicial review",
    "LNDP" => "Parliamentary & legislative practice",
    "LNDS" => "Election law",
    "LNDU" => "Local government law",
    "LNDV" => "Regional government law",
    "LNDX" => "Constitution",
    "LNE" => "Economic administrative law & public commercial law",
    "LNEA" => "Financial administration & public finance law",
    "LNEB" => "Foreign economics & customs law",
    "LNEC" => "Law of allowances & subsidies",
    "LNEF" => "Public procurement, services & supplies",
    "LNF" => "Criminal law: procedure & offences",
    "LNFB" => "Criminal justice law",
    "LNFG" => "Criminal law: offences against the government",
    "LNFG1" => "Offences against the State, against public administration & the administration of justice",
    "LNFG2" => "Offences against land use & city planning, monument, land & environment protection",
    "LNFJ" => "Criminal law: offences against the person",
    "LNFJ1" => "Harassment & stalking",
    "LNFJ2" => "Gender violence",
    "LNFL" => "Criminal law: offences against property",
    "LNFN" => "Fraud",
    "LNFQ" => "Juvenile criminal law",
    "LNFR" => "Offences against public health, safety, order",
    "LNFS" => "Criminal law: additional penalty law",
    "LNFT" => "Road traffic law, motoring offences",
    "LNFU" => "Criminal law: fiscal offences",
    "LNFV" => "Criminal law: terrorism law",
    "LNFW" => "Corruption",
    "LNFX" => "Criminal procedure",
    "LNFX1" => "Sentencing & punishment",
    "LNFX3" => "Criminal procedure: law of evidence",
    "LNFX31" => "Criminal procedure: investigation & specific proceedings",
    "LNFX5" => "Police law & police procedures",
    "LNFX51" => "Police law: preliminary injunction",
    "LNFX7" => "Prison law",
    "LNFY" => "Jury trials",
    "LNH" => "Employment & labour law: general",
    "LNHD" => "Discrimination in employment & harassment law",
    "LNHH" => "Occupational health & safety law, working time law",
    "LNHJ" => "Labour rules violations & penalties",
    "LNHR" => "Industrial relations & trade unions law",
    "LNHU" => "Employment contracts",
    "LNHW" => "Law of professional training",
    "LNHX" => "Employment & labour law: procedure, dispute resolution",
    "LNJ" => "Entertainment & media law",
    "LNJD" => "Defamation law, slander & libel",
    "LNJS" => "Sport & the law",
    "LNJX" => "Advertising, marketing & sponsorship law",
    "LNK" => "Environment, transport & planning law: general",
    "LNKF" => "Agricultural law",
    "LNKG" => "Animal law",
    "LNKJ" => "Environment law",
    "LNKK" => "Disaster control & fire protection law",
    "LNKN" => "Nature conservation law",
    "LNKP" => "Water & wastewater law",
    "LNKT" => "Transport law",
    "LNKV" => "Ways & highways law",
    "LNKW" => "Planning law",
    "LNKX" => "Protection of historic buildings & cultural assets",
    "LNL" => "Law: equity & trusts, foundations",
    "LNM" => "Family law",
    "LNMB" => "Family law: marriage, separation & divorce",
    "LNMC" => "Family law: cohabitation",
    "LNMF" => "Family law: same-sex partnership",
    "LNMI" => "Family law: financial statement between spouses",
    "LNMK" => "Family law: children",
    "LNP" => "Financial law: general",
    "LNPA" => "Accounting & auditing law",
    "LNPB" => "Banking law",
    "LNPC" => "Bankruptcy & insolvency",
    "LNPC1" => "Bankruptcy law: extrajudicial procedures",
    "LNPD" => "Capital markets & securities law & regulation",
    "LNPF" => "Financial services law & regulation",
    "LNPN" => "Insurance law",
    "LNPP" => "Pensions, old-age provisions & private compensation",
    "LNQ" => "IT & Communications law / Postal laws & regulations",
    "LNQD" => "Data protection law",
    "LNQE" => "Computer crime, cybercrime",
    "LNR" => "Intellectual property law",
    "LNRC" => "Copyright law",
    "LNRD" => "Patents law",
    "LNRF" => "Trademarks law",
    "LNRL" => "Designs law",
    "LNRV" => "Confidential information law",
    "LNS" => "Property law: general",
    "LNSH" => "Land & real estate law",
    "LNSH1" => "Ownership & mortgage law",
    "LNSH3" => "Landlord & tenant law",
    "LNSH5" => "Conveyancing law",
    "LNSH7" => "Rating & valuation law",
    "LNSH9" => "Housing law",
    "LNSP" => "Personal property law",
    "LNT" => "Social law & Medical law",
    "LNTC" => "Charity law",
    "LNTD" => "Education law",
    "LNTH" => "Social security & welfare law",
    "LNTH1" => "Social insurance law",
    "LNTJ" => "Public health & safety law",
    "LNTM" => "Medical & healthcare law",
    "LNTM1" => "Mental health law",
    "LNTM2" => "Regulation of medicines & medical devices",
    "LNTN" => "Pharmaceutical law",
    "LNTQ" => "Disability & the law",
    "LNTS" => "Law & the elderly",
    "LNTU" => "Consumer protection law",
    "LNTV" => "Food law",
    "LNTX" => "Licensing, gaming & club law",
    "LNU" => "Taxation & duties law",
    "LNUC" => "Corporate & business tax",
    "LNUD" => "Local taxation, charges, public prices, excise duties",
    "LNUP" => "Personal tax",
    "LNUS" => "Sales tax, tariffs & customs duties",
    "LNUT" => "Trusts & estates taxation, gift tax",
    "LNUU" => "Real estate tax, property valuation",
    "LNUV" => "Excise taxes",
    "LNUW" => "Other transaction taxes",
    "LNUX" => "International taxation law",
    "LNUY" => "Taxation procedure",
    "LNV" => "Law of torts, damages & compensation",
    "LNVC" => "Negligence",
    "LNVF" => "Nuisance",
    "LNVJ" => "Personal injury",
    "LNW" => "Law: wills, probate, succession",
    "LNX" => "Public Law",
    "LNZ" => "Primary sources of law",
    "LNZC" => "Sources of law: case law, precedent",
    "LNZL" => "Sources of law: legislation",
    "LW" => "Shariah law",
    "LWF" => "Shariah law: four Schools of Fiqh",
    "LWFA" => "Shariah law: Al-Shafi’i School of Fiqh",
    "LWFB" => "Shariah law: Al-Hanbali School of Fiqh",
    "LWFC" => "Shariah law: Al-Maaliki School of Fiqh",
    "LWFD" => "Shariah law: Al-Hanafi School of Fiqh",
    "LWK" => "Shariah law: key topics & practice",
    "LWKF" => "Shariah law: family relations",
    "LWKG" => "Shariah law: crime & punishment",
    "LWKH" => "Shariah law: inheritance & disposal of property",
    "LWKL" => "Shariah law: economics & finance",
    "LWKM" => "Shariah law: dietary",
    "LWKN" => "Shariah law: alcohol & gambling",
    "LWKP" => "Shariah law: customs & behaviour",
    "LWKR" => "Shariah law: administration of justice (including penalties & apostasy)",
    "LWKT" => "Shariah law: Islamic rituals",
    "LWKT1" => "Shariah law: Islamic rituals: purification",
    "LWKT2" => "Shariah law: Islamic rituals: jihad",
    "LWKT3" => "Shariah law: Islamic rituals: prayer & funeral prayer",
    "LWKT4" => "Shariah law: Islamic rituals: zakat (alms)",
    "LWKT5" => "Shariah law: Islamic rituals: fasting",
    "LWKT6" => "Shariah law: Islamic rituals: pilgrimage",
    "LX" => "Law: study & revision guides",
    "M" => "Medicine & Nursing",
    "MB" => "Medicine: general issues",
    "MBD" => "Medical profession",
    "MBDC" => "Medical ethics & professional conduct",
    "MBDP" => "Doctor/patient relationship",
    "MBDS" => "Patient safety",
    "MBF" => "Medical & health informatics",
    "MBG" => "Medical equipment & techniques",
    "MBGL" => "Medical laboratory testing & techniques",
    "MBGR" => "Medical research",
    "MBGR1" => "Clinical trials",
    "MBGT" => "Telemedicine",
    "MBN" => "Public health & preventive medicine",
    "MBNC" => "Medical screening",
    "MBNH" => "Personal & public health / health education",
    "MBNH1" => "Hygiene",
    "MBNH2" => "Environmental factors",
    "MBNH3" => "Dietetics & nutrition",
    "MBNH4" => "Birth control, contraception, family planning",
    "MBNH9" => "Health psychology",
    "MBNK" => "Vaccination",
    "MBNS" => "Epidemiology & medical statistics",
    "MBP" => "Health systems & services",
    "MBPA" => "Primary care medicine, primary health care",
    "MBPC" => "General practice",
    "MBPK" => "Mental health services",
    "MBPM" => "Medical administration & management",
    "MBPN" => "Residential care",
    "MBPR" => "Medical insurance",
    "MBQ" => "Medicolegal issues",
    "MBS" => "Medical sociology",
    "MBX" => "History of medicine",
    "MF" => "Pre-clinical medicine: basic sciences",
    "MFC" => "Anatomy",
    "MFCC" => "Cytology",
    "MFCH" => "Histology",
    "MFCR" => "Regional anatomy",
    "MFCX" => "Dissection",
    "MFG" => "Physiology",
    "MFGC" => "Cellular physiology",
    "MFGG" => "Regional physiology",
    "MFGM" => "Metabolism",
    "MFGV" => "Biomechanics, human kinetics",
    "MFK" => "Human reproduction, growth & development",
    "MFKC" => "Reproductive medicine",
    "MFKC1" => "Infertility & fertilization",
    "MFKC3" => "Embryology",
    "MFKH" => "Human growth & development",
    "MFKH3" => "Maturation & ageing",
    "MFN" => "Medical genetics",
    "MJ" => "Clinical & internal medicine",
    "MJA" => "Medical diagnosis",
    "MJAD" => "Examination of patients",
    "MJC" => "Diseases & disorders",
    "MJCG" => "Congenital diseases & disorders",
    "MJCG1" => "Hereditary diseases & disorders",
    "MJCJ" => "Infectious & contagious diseases",
    "MJCJ1" => "Venereal diseases",
    "MJCJ2" => "HIV/AIDS",
    "MJCJ3" => "Hospital infections",
    "MJCL" => "Oncology",
    "MJCL1" => "Radiotherapy",
    "MJCL2" => "Chemotherapy",
    "MJCM" => "Immunology",
    "MJCM1" => "Allergies",
    "MJD" => "Cardiovascular medicine",
    "MJE" => "Musculoskeletal medicine",
    "MJF" => "Haematology",
    "MJG" => "Endocrinology",
    "MJGD" => "Diabetes",
    "MJH" => "Gastroenterology",
    "MJJ" => "Hepatology",
    "MJK" => "Dermatology",
    "MJL" => "Respiratory medicine",
    "MJM" => "Rheumatology",
    "MJP" => "Otorhinolaryngology (ENT)",
    "MJPD" => "Audiology & otology",
    "MJQ" => "Ophthalmology",
    "MJR" => "Renal medicine & nephrology",
    "MJRD" => "Haemodialysis",
    "MJS" => "Urology & urogenital medicine",
    "MK" => "Medical specialties, branches of medicine",
    "MKA" => "Anaesthetics",
    "MKAL" => "Pain & pain management",
    "MKB" => "Palliative medicine",
    "MKC" => "Gynaecology & obstetrics",
    "MKCM" => "Materno-foetal medicine / perinatology",
    "MKD" => "Paediatric medicine",
    "MKDN" => "Neonatal medicine",
    "MKE" => "Dentistry",
    "MKEP" => "Oral & maxillofacial surgery",
    "MKF" => "Pathology",
    "MKFC" => "Cytopathology",
    "MKFH" => "Histopathology",
    "MKFK" => "Chronic disease",
    "MKFM" => "Medical microbiology & virology",
    "MKFP" => "Medical parasitology",
    "MKFS" => "Psychosomatics",
    "MKG" => "Pharmacology",
    "MKGT" => "Medical toxicology",
    "MKGW" => "Psychopharmacology",
    "MKH" => "Regenerative medicine",
    "MKHC" => "Regenerative medicine: stem cells",
    "MKJ" => "Neurology & clinical neurophysiology",
    "MKJA" => "Autism & Asperger’s Syndrome",
    "MKJD" => "Alzheimer’s & dementia",
    "MKL" => "Psychiatry",
    "MKLD" => "Psychiatric & mental disorders",
    "MKM" => "Clinical psychology",
    "MKMT" => "Psychotherapy",
    "MKMT1" => "Psychotherapy: general",
    "MKMT2" => "Psychotherapy: group",
    "MKMT3" => "Psychotherapy: child & adolescent",
    "MKMT4" => "Psychotherapy: couples & families",
    "MKMT5" => "Psychotherapy: counselling",
    "MKMT6" => "Cognitive behavioural therapy",
    "MKN" => "Geriatric medicine",
    "MKP" => "Accident & emergency medicine",
    "MKPB" => "Trauma & shock",
    "MKPD" => "Burns",
    "MKPL" => "Intensive care medicine",
    "MKR" => "Nuclear medicine",
    "MKS" => "Medical imaging",
    "MKSF" => "Medical imaging: ultrasonics",
    "MKSG" => "Medical imaging: nuclear magnetic resonance (NMR / MRI)",
    "MKSH" => "Medical imaging: radiology",
    "MKSJ" => "Medical imaging: tomography",
    "MKT" => "Forensic medicine",
    "MKV" => "Environmental medicine",
    "MKVB" => "Aviation & space medicine",
    "MKVD" => "Diving & hyperbaric medicine",
    "MKVP" => "Occupational medicine",
    "MKVQ" => "Travel medicine / emporiatrics",
    "MKVT" => "Tropical medicine",
    "MKW" => "Sports injuries & medicine",
    "MKZ" => "Therapy & therapeutics",
    "MKZD" => "Eating disorders & therapy",
    "MKZF" => "Obesity: treatment & therapy",
    "MKZL" => "Speech & language disorders & therapy",
    "MKZR" => "Addiction & therapy",
    "MKZS" => "Sleep disorders & therapy",
    "MKZV" => "Gene therapy",
    "MN" => "Surgery",
    "MNB" => "Surgical techniques",
    "MNC" => "General surgery",
    "MND" => "Abdominal surgery",
    "MNG" => "Gastrointestinal & colorectal surgery",
    "MNH" => "Cardiothoracic surgery",
    "MNJ" => "Vascular surgery",
    "MNK" => "Surgical oncology",
    "MNL" => "Critical care surgery",
    "MNN" => "Neurosurgery",
    "MNP" => "Plastic & reconstructive surgery",
    "MNPC" => "Cosmetic surgery",
    "MNQ" => "Transplant surgery",
    "MNS" => "Surgical orthopaedics & fractures",
    "MNZ" => "Peri-operative care",
    "MQ" => "Nursing & ancillary services",
    "MQC" => "Nursing",
    "MQCA" => "Nursing fundamentals & skills",
    "MQCB" => "Nursing research & theory",
    "MQCH" => "Nurse/patient relationship",
    "MQCL" => "Nursing specialties",
    "MQCL1" => "Accident & emergency nursing",
    "MQCL2" => "Intensive care nursing",
    "MQCL3" => "Paediatric nursing",
    "MQCL4" => "Geriatric nursing",
    "MQCL5" => "Psychiatric nursing",
    "MQCL6" => "Surgical nursing",
    "MQCL9" => "Terminal care nursing",
    "MQCM" => "Nursing pharmacology",
    "MQCW" => "Nursing sociology",
    "MQCX" => "Community nursing",
    "MQCZ" => "Nursing management & leadership",
    "MQD" => "Midwifery",
    "MQDB" => "Birthing methods",
    "MQF" => "First aid & paramedical services",
    "MQG" => "Medical assistants",
    "MQH" => "Radiography",
    "MQK" => "Chiropody & podiatry",
    "MQP" => "Pharmacy / dispensing",
    "MQR" => "Optometry / opticians",
    "MQS" => "Physiotherapy",
    "MQT" => "Occupational therapy",
    "MQTC" => "Creative therapy (eg art, music, drama)",
    "MQU" => "Medical counselling",
    "MQV" => "Rehabilitation",
    "MQVB" => "Rehabilitation: brain & spinal injuries",
    "MQW" => "Biomedical engineering",
    "MQWB" => "Orthotics",
    "MQWP" => "Prosthetics",
    "MQZ" => "Mortuary practice",
    "MR" => "Medical study & revision guides & reference material",
    "MRG" => "Medical study & revision guides",
    "MRGD" => "Medical revision aids: MRCP",
    "MRGK" => "Medical revision aids: MRCS",
    "MRGL" => "Medical revision aids: PLAB",
    "MRT" => "Medical charts, colour atlases",
    "MX" => "Complementary medicine",
    "MXH" => "Chiropractic & osteopathy",
    "MZ" => "Veterinary medicine",
    "MZC" => "Veterinary medicine: small animals (pets)",
    "MZD" => "Veterinary medicine: large animals (domestic / farm)",
    "MZDH" => "Equine veterinary medicine",
    "MZF" => "Veterinary medicine: laboratory animals",
    "MZG" => "Veterinary medicine: exotic & zoo animals",
    "MZH" => "Veterinary anatomy & physiology",
    "MZK" => "Veterinary pathology & histology",
    "MZL" => "Veterinary nutrition",
    "MZM" => "Veterinary medicine: infectious diseases & therapeutics",
    "MZMP" => "Veterinary bacteriology, virology, parasitology",
    "MZP" => "Veterinary pharmacology",
    "MZR" => "Veterinary radiology",
    "MZS" => "Veterinary surgery",
    "MZSN" => "Veterinary anaesthetics",
    "MZT" => "Veterinary dentistry",
    "MZV" => "Veterinary nursing",
    "MZX" => "Complementary medicine for animals",
    "N" => "History & Archaeology",
    "NH" => "History",
    "NHA" => "History: theory & methods",
    "NHAH" => "Historiography",
    "NHAP" => "Historical research: source documents",
    "NHB" => "General & world history",
    "NHC" => "Ancient history",
    "NHD" => "European history",
    "NHDA" => "European history: the Romans",
    "NHDC" => "European history: the Celts",
    "NHDE" => "European history: the Vikings",
    "NHDG" => "European history: the Normans",
    "NHDJ" => "European history: mediaeval period, middle ages",
    "NHDL" => "European history: Renaissance",
    "NHDN" => "European history: Reformation",
    "NHF" => "Asian history",
    "NHG" => "Middle Eastern history",
    "NHH" => "African history",
    "NHHA" => "African history: pre-colonial period",
    "NHK" => "History of the Americas",
    "NHKA" => "History of the Americas: pre-Columbian period",
    "NHM" => "Australasian & Pacific history",
    "NHQ" => "History of specific lands",
    "NHT" => "History: specific events & topics",
    "NHTB" => "Social & cultural history",
    "NHTD" => "Oral history",
    "NHTF" => "History: plagues, diseases etc",
    "NHTG" => "Genealogy, heraldry, names & honours",
    "NHTK" => "Industrialization & industrial history",
    "NHTM" => "Maritime history",
    "NHTP" => "Historical geography",
    "NHTP1" => "Historical maps & atlases",
    "NHTQ" => "Colonialism & imperialism",
    "NHTR" => "National liberation & independence, post-colonialism",
    "NHTS" => "Slavery & abolition of slavery",
    "NHTT" => "Invasion & occupation",
    "NHTV" => "Revolutions, uprisings, rebellions",
    "NHTW" => "The Cold War",
    "NHTZ" => "Genocide & ethnic cleansing",
    "NHTZ1" => "The Holocaust",
    "NHW" => "Military history",
    "NHWA" => "Ancient warfare",
    "NHWF" => "Early modern warfare (including gunpowder warfare)",
    "NHWL" => "Modern warfare",
    "NHWR" => "Specific wars & campaigns",
    "NHWR1" => "Specific battles",
    "NHWR3" => "Civil wars",
    "NHWR5" => "First World War",
    "NHWR7" => "Second World War",
    "NHWR9" => "Military history: post-WW2 conflicts",
    "NK" => "Archaeology",
    "NKA" => "Archaeological theory",
    "NKD" => "Archaeology by period / region",
    "NKL" => "Landscape archaeology",
    "NKP" => "Environmental archaeology",
    "NKR" => "Underwater archaeology",
    "NKT" => "Industrial archaeology",
    "NKV" => "Battlefield archaeology",
    "NKX" => "Archaeological science, methodology & techniques",
    "P" => "Mathematics & Science",
    "PB" => "Mathematics",
    "PBB" => "Philosophy of mathematics",
    "PBC" => "Mathematical foundations",
    "PBCD" => "Mathematical logic",
    "PBCH" => "Set theory",
    "PBCN" => "Number systems",
    "PBD" => "Discrete mathematics",
    "PBF" => "Algebra",
    "PBG" => "Groups & group theory",
    "PBH" => "Number theory",
    "PBJ" => "Pre-calculus",
    "PBK" => "Calculus & mathematical analysis",
    "PBKA" => "Calculus",
    "PBKB" => "Real analysis, real variables",
    "PBKD" => "Complex analysis, complex variables",
    "PBKF" => "Functional analysis & transforms",
    "PBKJ" => "Differential calculus & equations",
    "PBKL" => "Integral calculus & equations",
    "PBKQ" => "Calculus of variations",
    "PBKS" => "Numerical analysis",
    "PBM" => "Geometry",
    "PBMB" => "Trigonometry",
    "PBMH" => "Euclidean geometry",
    "PBML" => "Non-Euclidean geometry",
    "PBMP" => "Differential & Riemannian geometry",
    "PBMS" => "Analytic geometry",
    "PBMW" => "Algebraic geometry",
    "PBMX" => "Fractal geometry",
    "PBP" => "Topology",
    "PBPD" => "Algebraic topology",
    "PBPH" => "Analytic topology",
    "PBT" => "Probability & statistics",
    "PBTB" => "Bayesian inference",
    "PBU" => "Optimization",
    "PBUD" => "Game theory",
    "PBUH" => "Linear programming",
    "PBV" => "Combinatorics & graph theory",
    "PBW" => "Applied mathematics",
    "PBWH" => "Mathematical modelling",
    "PBWL" => "Stochastics",
    "PBWR" => "Nonlinear science",
    "PBWS" => "Chaos theory",
    "PBWX" => "Fuzzy set theory",
    "PBX" => "History of mathematics",
    "PD" => "Science: general issues",
    "PDA" => "Philosophy of science",
    "PDC" => "Scientific nomenclature & classification",
    "PDD" => "Scientific standards, measurement etc",
    "PDE" => "Maths for scientists",
    "PDG" => "Industrial applications of scientific research & technological innovation",
    "PDJ" => "Regulation of science & experimentation",
    "PDK" => "Science funding & policy",
    "PDM" => "Scientific research",
    "PDN" => "Scientific equipment, experiments & techniques",
    "PDR" => "Impact of science & technology on society",
    "PDT" => "Nanosciences",
    "PDX" => "History of science",
    "PDZ" => "Popular science",
    "PDZM" => "Popular and recreational mathematics",
    "PG" => "Astronomy, space & time",
    "PGC" => "Theoretical & mathematical astronomy",
    "PGG" => "Astronomical observation: observatories, equipment & methods",
    "PGK" => "Cosmology & the universe",
    "PGM" => "Galaxies & stars",
    "PGS" => "Solar system: the Sun & planets",
    "PGT" => "Astronomical charts & atlases",
    "PGZ" => "Time (chronology), time systems & standards",
    "PH" => "Physics",
    "PHD" => "Classical mechanics",
    "PHDB" => "Elementary mechanics",
    "PHDD" => "Analytical mechanics",
    "PHDF" => "Physics: Fluid mechanics",
    "PHDS" => "Wave mechanics (vibration & acoustics)",
    "PHDT" => "Dynamics & statics",
    "PHDV" => "Gravity",
    "PHDY" => "Energy",
    "PHF" => "Materials / States of matter",
    "PHFB" => "Low temperature physics",
    "PHFC" => "Condensed matter physics (liquid state & solid state physics)",
    "PHFC1" => "Soft matter physics",
    "PHFC2" => "Mesoscopic physics",
    "PHFG" => "Physics of gases",
    "PHFP" => "Plasma physics",
    "PHH" => "Thermodynamics & heat",
    "PHJ" => "Optical physics",
    "PHJL" => "Laser physics",
    "PHK" => "Electricity, electromagnetism & magnetism",
    "PHM" => "Atomic & molecular physics",
    "PHN" => "Nuclear physics",
    "PHP" => "Particle & high-energy physics",
    "PHQ" => "Quantum physics (quantum mechanics & quantum field theory)",
    "PHR" => "Relativity physics",
    "PHS" => "Statistical physics",
    "PHU" => "Mathematical physics",
    "PHV" => "Applied physics",
    "PHVB" => "Astrophysics",
    "PHVD" => "Medical physics",
    "PHVG" => "Geophysics",
    "PHVJ" => "Atmospheric physics",
    "PHVN" => "Biophysics",
    "PHVQ" => "Chemical physics",
    "PHVS" => "Cryogenics",
    "PN" => "Chemistry",
    "PNB" => "Medicinal chemistry",
    "PNC" => "Environmental chemistry",
    "PND" => "Food chemistry",
    "PNF" => "Analytical chemistry",
    "PNFC" => "Chromatography",
    "PNFR" => "Magnetic resonance",
    "PNFS" => "Spectrum analysis, spectrochemistry, mass spectrometry",
    "PNK" => "Inorganic chemistry",
    "PNN" => "Organic chemistry",
    "PNND" => "Organometallic chemistry",
    "PNNP" => "Polymer chemistry",
    "PNR" => "Physical chemistry",
    "PNRA" => "Computational chemistry",
    "PNRC" => "Colloid chemistry",
    "PNRD" => "Catalysis",
    "PNRD1" => "Bio-catalysis",
    "PNRE" => "Experimental chemistry",
    "PNRH" => "Electrochemistry & magnetochemistry",
    "PNRL" => "Nuclear chemistry, photochemistry & radiation",
    "PNRP" => "Quantum & theoretical chemistry",
    "PNRR" => "Physical organic chemistry",
    "PNRS" => "Solid state chemistry",
    "PNRW" => "Thermochemistry & chemical thermodynamics",
    "PNRX" => "Surface chemistry & adsorption",
    "PNT" => "Crystallography",
    "PNV" => "Chemistry of minerals, crystals & gems",
    "PS" => "Biology, life sciences",
    "PSA" => "Life sciences: general issues",
    "PSAB" => "Taxonomy & systematics",
    "PSAD" => "Bioethics",
    "PSAF" => "Ecological science, the Biosphere",
    "PSAG" => "Xenobiotics",
    "PSAJ" => "Evolution",
    "PSAK" => "Genetics (non-medical)",
    "PSAN" => "Neurosciences",
    "PSAN1" => "Cellular & molecular neuroscience",
    "PSAN2" => "Developmental neuroscience",
    "PSAN3" => "Neuroimaging & neuroanatomy",
    "PSAN4" => "Sensory & motor systems",
    "PSAN5" => "Cognitive & behavioural neuroscience",
    "PSAX" => "Computational biology / bioinformatics",
    "PSB" => "Biochemistry",
    "PSC" => "Developmental biology",
    "PSD" => "Molecular biology",
    "PSE" => "Chemical biology",
    "PSF" => "Cellular biology (cytology)",
    "PSG" => "Microbiology (non-medical)",
    "PSGN" => "Protozoa",
    "PSP" => "Hydrobiology",
    "PSPA" => "Phycology (algae & seaweed)",
    "PSPF" => "Freshwater biology",
    "PSPM" => "Marine biology",
    "PSQ" => "Mycology, fungi",
    "PST" => "Botany & plant sciences",
    "PSTB" => "Plant biology",
    "PSTH" => "Flowering plants (angiosperms)",
    "PSTJ" => "Conifers & gymnosperms",
    "PSTM" => "Ferns, mosses & liverworts",
    "PSV" => "Zoology & animal sciences",
    "PSVA" => "Zoology: invertebrates",
    "PSVA2" => "Insects (entomology)",
    "PSVA4" => "Crustaceans (carcinology)",
    "PSVA6" => "Molluscs (malacology)",
    "PSVA8" => "Arachnids (arachnology)",
    "PSVC" => "Zoology: fishes (ichthyology)",
    "PSVF" => "Zoology: amphibians & reptiles (herpetology)",
    "PSVJ" => "Zoology: birds (ornithology)",
    "PSVM" => "Zoology: mammals (mammalogy)",
    "PSVM1" => "Zoology: marsupials & monotremes",
    "PSVM2" => "Zoology: marine & freshwater mammals",
    "PSVM3" => "Zoology: primates (primatology)",
    "PSVP" => "Ethology & animal behaviour",
    "PSX" => "Human biology",
    "PSXE" => "Evolutionary anthropology",
    "Q" => "Philosophy & Religion",
    "QD" => "Philosophy",
    "QDH" => "History of philosophy, philosophical traditions",
    "QDHA" => "Ancient philosophy",
    "QDHC" => "East Asian & Indian philosophy",
    "QDHC2" => "Yoga (as a philosophy)",
    "QDHF" => "Mediaeval philosophy",
    "QDHH" => "Humanist philosophy",
    "QDHK" => "Islamic & Arab philosophy",
    "QDHM" => "Western philosophy: Enlightenment",
    "QDHR" => "Modern philosophy: since c 1800",
    "QDHR1" => "Idealism",
    "QDHR3" => "Pragmatism",
    "QDHR5" => "Phenomenology & Existentialism",
    "QDHR7" => "Structuralism & Post-structuralism",
    "QDHR9" => "Analytical philosophy & Logical Positivism",
    "QDT" => "Topics in philosophy",
    "QDTJ" => "Philosophy: metaphysics & ontology",
    "QDTK" => "Philosophy: epistemology & theory of knowledge",
    "QDTL" => "Philosophy: logic",
    "QDTM" => "Philosophy of mind",
    "QDTN" => "Philosophy: aesthetics",
    "QDTQ" => "Ethics & moral philosophy",
    "QDTS" => "Social & political philosophy",
    "QDX" => "Popular philosophy",
    "QR" => "Religion & beliefs",
    "QRA" => "Religion: general",
    "QRAB" => "Philosophy of religion",
    "QRAB1" => "Nature & existence of God",
    "QRAC" => "Comparative religion",
    "QRAF" => "Interfaith relations",
    "QRAM" => "Religious issues & debates",
    "QRAM1" => "Religious ethics",
    "QRAM2" => "Religion & politics",
    "QRAM3" => "Religion & science",
    "QRAM6" => "Religious fundamentalism",
    "QRAM7" => "Blasphemy, heresy, apostasy",
    "QRAM9" => "Religious intolerance & persecution",
    "QRAX" => "History of religion",
    "QRD" => "Hinduism",
    "QRDB" => "Hinduism: branches & groups",
    "QRDF" => "Hindu sacred texts",
    "QRDF1" => "Hindu texts: Vedas, Upanishads",
    "QRDF2" => "Hindu texts: Bhagavad Gita",
    "QRDP" => "Hindu life & practice",
    "QRF" => "Buddhism",
    "QRFB" => "Buddhism: branches & groups",
    "QRFB1" => "Theravada Buddhism",
    "QRFB2" => "Mahayana Buddhism",
    "QRFB21" => "Tibetan Buddhism",
    "QRFB23" => "Zen Buddhism",
    "QRFF" => "Buddhist sacred texts",
    "QRFP" => "Buddhist life & practice",
    "QRJ" => "Judaism",
    "QRJB" => "Judaism: branches & groups",
    "QRJB1" => "Orthodox Judaism",
    "QRJB3" => "Liberal & Reform Judaism",
    "QRJF" => "Judaism: sacred texts",
    "QRJF1" => "Jewish texts: Tanakh, Torah, Nevi’im, Ketuvim",
    "QRJF5" => "Rabbinic literature",
    "QRJP" => "Judaism: life & practice",
    "QRM" => "Christianity",
    "QRMB" => "Christian Churches, denominations, groups",
    "QRMB1" => "Roman Catholicism, Roman Catholic Church",
    "QRMB2" => "Orthodox & Oriental Orthodox Churches",
    "QRMB3" => "Protestantism & Protestant Churches",
    "QRMB31" => "Anglican & Episcopalian Churches",
    "QRMB32" => "Baptist Churches",
    "QRMB33" => "Calvinist, Reformed & Presbyterian Churches",
    "QRMB34" => "Lutheran Churches",
    "QRMB35" => "Methodist Churches",
    "QRMB36" => "Pentecostal Churches",
    "QRMB37" => "Quakers (Religious Society of Friends)",
    "QRMB39" => "Other Nonconformist & Evangelical Churches",
    "QRMB5" => "Denominations of American origin",
    "QRMB8" => "Christian & quasi-Christian cults & sects",
    "QRMB9" => "Ecumenism",
    "QRMF" => "Christianity: sacred texts",
    "QRMF1" => "Bibles",
    "QRMF12" => "Old Testaments",
    "QRMF13" => "New Testaments",
    "QRMF19" => "Bible readings, selections & meditations",
    "QRMP" => "Christian life & practice",
    "QRMP1" => "Christian sacraments",
    "QRP" => "Islam",
    "QRPB" => "Islam: branches & groups",
    "QRPB1" => "Islamic groups: Sunni, Alsalaf",
    "QRPB2" => "Islamic groups: Khawarij, Kharijite",
    "QRPB3" => "Islamic groups: Shi’ah, Shi’ite",
    "QRPB4" => "Islamic groups: Sufis",
    "QRPF" => "Islamic sacred texts",
    "QRPF1" => "The Koran (Qur’an)",
    "QRPP" => "Islamic life & practice",
    "QRR" => "Other World religions",
    "QRRB" => "Baha’i",
    "QRRC" => "Jainism",
    "QRRD" => "Sikhism",
    "QRRF" => "Zoroastrianism",
    "QRRL" => "East Asian religions",
    "QRRL1" => "Confucianism",
    "QRRL3" => "Shintoism",
    "QRRL5" => "Taoism",
    "QRRL6" => "Chinese folk religion",
    "QRRM" => "Afro-American religions",
    "QRRN" => "Traditional African religions & mythologies",
    "QRRT" => "Tribal religions",
    "QRS" => "Ancient religions & mythologies",
    "QRSA" => "Ancient Egyptian religion & mythology",
    "QRSG" => "Ancient Greek religion & mythology",
    "QRSL" => "Roman religion & mythology",
    "QRST" => "Celtic religion & mythology",
    "QRSW" => "Norse religion & mythology",
    "QRV" => "Aspects of religion",
    "QRVA" => "Sacred texts",
    "QRVC" => "Criticism & exegesis of sacred texts",
    "QRVG" => "Theology",
    "QRVH" => "Sermons",
    "QRVJ" => "Prayers & liturgical material",
    "QRVJ1" => "Worship, rites & ceremonies",
    "QRVJ2" => "Prayer & prayerbooks",
    "QRVJ3" => "Devotional material",
    "QRVK" => "Spirituality & religious experience",
    "QRVK2" => "Mysticism",
    "QRVK4" => "Miracles, apparitions & religious phenomena",
    "QRVP" => "Religious life & practice",
    "QRVP1" => "Pilgrimage",
    "QRVP2" => "Religious Festivals",
    "QRVP3" => "Religious instruction",
    "QRVP4" => "Fasting & abstinence",
    "QRVP5" => "Religious counselling",
    "QRVP7" => "Religious aspects of sexuality, gender & relationships",
    "QRVS" => "Religious institutions & organizations",
    "QRVS1" => "Religious & spiritual figures",
    "QRVS2" => "Religious social & pastoral thought & activity",
    "QRVS3" => "Religious ministry",
    "QRVS4" => "Religious mission & conversion",
    "QRVS5" => "Religious communities & monasticism",
    "QRVX" => "Personal religious testimony & popular inspirational works",
    "QRY" => "Alternative belief systems",
    "QRYA" => "Humanist & secular alternatives to religion",
    "QRYA5" => "Agnosticism & atheism",
    "QRYC" => "Eclectic & esoteric religions & belief systems",
    "QRYC1" => "Gnosticism",
    "QRYC5" => "Theosophy & Anthroposophy",
    "QRYM" => "Contemporary non-Christian & para-Christian cults & sects",
    "QRYM2" => "Spiritualism",
    "QRYX" => "Occult studies",
    "QRYX2" => "Magic, alchemy & hermetic thought",
    "QRYX5" => "Witchcraft",
    "QRYX9" => "Satanism & demonology",
    "R" => "Earth Sciences, Geography, Environment, Planning",
    "RB" => "Earth sciences",
    "RBC" => "Volcanology & seismology",
    "RBG" => "Geology, geomorphology & the lithosphere",
    "RBGB" => "Sedimentology & pedology",
    "RBGD" => "Geomorphology & geological surface processes",
    "RBGF" => "Historical geology",
    "RBGG" => "Petrology, petrography & mineralogy",
    "RBGH" => "Stratigraphy",
    "RBGK" => "Geochemistry",
    "RBGL" => "Economic geology",
    "RBK" => "Hydrology & the hydrosphere",
    "RBKC" => "Oceanography (seas & oceans)",
    "RBKF" => "Limnology (inland waters)",
    "RBP" => "Meteorology & climatology",
    "RBX" => "Palaeontology",
    "RG" => "Geography",
    "RGB" => "Physical geography & topography",
    "RGBA" => "Arid zones, deserts",
    "RGBC" => "Plains & grasslands",
    "RGBC1" => "Prairies",
    "RGBC2" => "Savanna",
    "RGBD" => "Tundra",
    "RGBF" => "Wetlands, swamps, fens",
    "RGBG" => "Rivers & lakes",
    "RGBL" => "Forests & woodland",
    "RGBL1" => "Rainforest",
    "RGBL2" => "Mixed forest",
    "RGBL3" => "Broadleaf forest",
    "RGBL4" => "Boreal, coniferous forest",
    "RGBP" => "Coastlines",
    "RGBR" => "Coral reefs",
    "RGBS" => "Mountains",
    "RGBU" => "Glaciers & ice caps",
    "RGC" => "Human geography",
    "RGCD" => "Development & environmental geography",
    "RGCG" => "Population & migration geography",
    "RGCM" => "Economic geography",
    "RGCP" => "Political geography",
    "RGCS" => "Social geography",
    "RGCT" => "Tourism geography",
    "RGCU" => "Settlement, urban & rural geography",
    "RGL" => "Regional geography",
    "RGM" => "Biogeography",
    "RGR" => "Geographical discovery & exploration",
    "RGV" => "Cartography, map-making & projections",
    "RGW" => "Geographical information systems & remote sensing",
    "RGX" => "Geographical reference works",
    "RGXB" => "World atlases / world maps",
    "RGXH" => "Geographical maps (specialist)",
    "RGXM" => "Naval & marine charts",
    "RGXP" => "Place names & gazetteers",
    "RN" => "The environment",
    "RNA" => "Environmentalist thought & ideology",
    "RNB" => "Environmentalist, conservationist & Green organizations",
    "RNC" => "Applied ecology",
    "RNCB" => "Biodiversity",
    "RND" => "Environmental policy & protocols",
    "RNF" => "Environmental management",
    "RNFD" => "Drought & water supply",
    "RNFF" => "Food security & supply",
    "RNFY" => "Energy resources",
    "RNH" => "Waste management",
    "RNK" => "Conservation of the environment",
    "RNKH" => "Conservation of wildlife & habitats",
    "RNKH1" => "Endangered species & extinction of species",
    "RNP" => "Pollution & threats to the environment",
    "RNPD" => "Deforestation",
    "RNPG" => "Climate change",
    "RNQ" => "Nuclear issues",
    "RNR" => "Natural disasters",
    "RNT" => "Social impact of environmental issues",
    "RNU" => "Sustainability",
    "RP" => "Regional & area planning",
    "RPC" => "Urban & municipal planning",
    "RPG" => "Rural planning",
    "RPT" => "Transport planning & policy",
    "S" => "Sports & Active outdoor recreation",
    "SC" => "Sport: general",
    "SCB" => "Sporting events & management",
    "SCBB" => "Olympic & Paralympic games",
    "SCBG" => "Sports governing bodies",
    "SCBM" => "Sports management & facilities",
    "SCBT" => "Sports teams & clubs",
    "SCBV" => "Sporting venues",
    "SCG" => "Sports training & coaching",
    "SCGF" => "Sport science, physical education",
    "SCGP" => "Sports psychology",
    "SCK" => "Drug abuse in sport",
    "SCL" => "Parasport",
    "SCX" => "History of sport",
    "SF" => "Ball sports / ball games",
    "SFB" => "Football variants & related games",
    "SFBC" => "Association football (Soccer)",
    "SFBD" => "American football",
    "SFBF" => "Australian Rules football",
    "SFBH" => "Canadian football",
    "SFBK" => "Gaelic football",
    "SFBT" => "Rugby Union",
    "SFBV" => "Rugby League",
    "SFC" => "Baseball",
    "SFD" => "Cricket",
    "SFH" => "Golf",
    "SFJ" => "Field hockey",
    "SFK" => "Lacrosse",
    "SFL" => "Hurling",
    "SFM" => "Basketball",
    "SFN" => "Netball",
    "SFP" => "Volleyball",
    "SFQ" => "Handball",
    "SFT" => "Racket games",
    "SFTA" => "Tennis",
    "SFTB" => "Badminton",
    "SFTC" => "Squash & rackets (racquets)",
    "SFTD" => "Table tennis",
    "SFV" => "Bowls, bowling, petanque",
    "SFX" => "Snooker, billiards, pool",
    "SH" => "Athletics, gymnastics & related sports",
    "SHB" => "Track & field sports, athletics",
    "SHBF" => "Marathon & cross-country running",
    "SHBM" => "Multidiscipline sports",
    "SHG" => "Gymnastics",
    "SHP" => "Weightlifting",
    "SK" => "Equestrian & animal sports",
    "SKG" => "Horse racing",
    "SKL" => "Riding, showjumping & horsemanship",
    "SKR" => "Dog racing",
    "SM" => "Vehicle sports",
    "SMC" => "Air sports & recreations",
    "SMF" => "Motor sports",
    "SMFA" => "Car racing",
    "SMFC" => "Motor rallying / rally driving",
    "SMFF" => "Stock car & hot rod racing",
    "SMFK" => "Motorcycle racing",
    "SMQ" => "Cycle racing",
    "SMQB" => "BMX cycling",
    "SMX" => "Rollerblading, skateboarding, etc",
    "SP" => "Water sports & recreations",
    "SPC" => "Swimming & diving",
    "SPCA" => "Underwater (sub-aqua) swimming",
    "SPCA1" => "Scuba diving",
    "SPCA2" => "Snorkelling",
    "SPCD" => "Diving",
    "SPCS" => "Swimming",
    "SPG" => "Surfing, windsurfing, water skiing",
    "SPN" => "Boating: Sport & leisure",
    "SPND" => "Motor / power boating & cruising",
    "SPNG" => "Sailing / yachting",
    "SPNK" => "Canoeing & kayaking",
    "SPNL" => "Rowing & sculling",
    "SR" => "Combat sports & self-defence",
    "SRB" => "Boxing",
    "SRC" => "Wrestling",
    "SRF" => "Fencing",
    "SRM" => "Martial arts",
    "SRMA" => "Aikido",
    "SRMC" => "Capoeira",
    "SRMJ" => "Judo",
    "SRMK" => "Ju-jitsu",
    "SRML" => "Karate",
    "SRMM" => "Kendo",
    "SRMN" => "Chinese martial arts / Kung-fu",
    "SRMN1" => "Tai Chi",
    "SRMN2" => "Qigong",
    "SRMS" => "Sumo",
    "SRMT" => "Taekwondo",
    "SRMV" => "Mixed martial arts",
    "ST" => "Winter sports",
    "STA" => "Skiing",
    "STAA" => "Alpine skiing",
    "STAB" => "Biathlon",
    "STAN" => "Nordic skiing",
    "STAN1" => "Cross-country skiing",
    "STAN2" => "Ski jumping",
    "STC" => "Snowboarding",
    "STG" => "Ice-skating",
    "STH" => "Speed skating",
    "STJ" => "Figure skating",
    "STK" => "Ice hockey",
    "STL" => "Sledding",
    "STLN" => "Sled dog racing",
    "STP" => "Curling",
    "SV" => "Field sports: fishing, hunting, shooting",
    "SVF" => "Fishing, angling",
    "SVFF" => "Fly fishing",
    "SVFS" => "Sea fishing",
    "SVH" => "Hunting or shooting animals & game",
    "SVHH" => "Professional qualifications for hunting / shooting",
    "SVR" => "Archery",
    "SVS" => "Small firearms, guns & other equipment",
    "SVT" => "Target shooting",
    "SX" => "Other sports & competitive activities",
    "SXB" => "Bodybuilding",
    "SXD" => "Darts",
    "SXE" => "eSports / Professional video gaming",
    "SXQ" => "Extreme sports",
    "SZ" => "Active outdoor pursuits",
    "SZC" => "Walking, hiking, trekking",
    "SZD" => "Cycling: general & touring",
    "SZE" => "Running & jogging",
    "SZG" => "Climbing & mountaineering",
    "SZK" => "Orienteering",
    "SZN" => "Caving & potholing",
    "SZR" => "Camping",
    "SZV" => "Outdoor survival skills",
    "T" => "Technology, Engineering, Agriculture, Industrial processes",
    "TB" => "Technology: general issues",
    "TBC" => "Engineering: general",
    "TBD" => "Technical design",
    "TBDG" => "Ergonomics",
    "TBG" => "Engineering graphics & draughting / technical drawing",
    "TBJ" => "Maths for engineers",
    "TBM" => "Instruments & instrumentation engineering",
    "TBMM" => "Engineering measurement & calibration",
    "TBN" => "Nanotechnology",
    "TBR" => "Intermediate technology",
    "TBX" => "History of engineering & technology",
    "TBY" => "Inventions & inventors",
    "TC" => "Biochemical engineering",
    "TCB" => "Biotechnology",
    "TCBG" => "Genetic engineering",
    "TCBS" => "Biosensors",
    "TD" => "Industrial chemistry & manufacturing technologies",
    "TDC" => "Industrial chemistry & chemical engineering",
    "TDCA" => "Agrichemicals",
    "TDCF" => "Fuels & petrochemicals",
    "TDCJ" => "Dyestuffs, pigments & paint technology",
    "TDCP" => "Plastics & polymers",
    "TDCQ" => "Ceramic & glass technology",
    "TDCT" => "Food & beverage technology",
    "TDCT1" => "Food & beverage safety",
    "TDCT2" => "Food & beverage processing & engineering",
    "TDCW" => "Pharmaceutical chemistry & technology",
    "TDCX" => "Process engineering technology & techniques",
    "TDP" => "Other manufacturing technologies",
    "TDPF" => "Textiles & fibres",
    "TDPJ" => "Timber & wood processing",
    "TDPJ1" => "Paper & pulp manufacture & processing",
    "TDPM" => "Metals technology / metallurgy",
    "TDPP" => "Printing & reprographic technologies",
    "TDPT" => "3D Printing",
    "TG" => "Mechanical engineering & materials",
    "TGB" => "Mechanical engineering",
    "TGBF" => "Tribology (friction & lubrication)",
    "TGBN" => "Engines & power transmission",
    "TGM" => "Materials science",
    "TGMB" => "Engineering thermodynamics",
    "TGMD" => "Engineering: Mechanics of solids",
    "TGMF" => "Engineering: Mechanics of fluids",
    "TGMF1" => "Aerodynamics",
    "TGMF2" => "Hydraulics / Pneumatics",
    "TGML" => "Engineering applications of bio-materials",
    "TGMM" => "Engineering applications of electronic, magnetic, optical materials",
    "TGMP" => "Engineering applications of polymers & composites",
    "TGMS" => "Engineering applications of surface coatings & films",
    "TGMT" => "Testing of materials",
    "TGP" => "Production & industrial engineering",
    "TGPC" => "Computer aided manufacture (CAM)",
    "TGPQ" => "Industrial quality control",
    "TGPR" => "Reliability engineering",
    "TGX" => "Engineering skills & trades",
    "TH" => "Energy technology & engineering",
    "THF" => "Fossil fuel technologies",
    "THFG" => "Gas technology",
    "THFP" => "Petroleum technology",
    "THFS" => "Solid fuel technology",
    "THK" => "Nuclear power & engineering",
    "THN" => "Heat transfer processes",
    "THR" => "Electrical engineering",
    "THRM" => "Electric motors",
    "THRX" => "Electrician skills & trades",
    "THV" => "Alternative & renewable energy sources & technology",
    "THVB" => "Biofuels",
    "THVS" => "Solar power",
    "THVW" => "Wind power",
    "THY" => "Energy, power generation, distribution & storage",
    "THYC" => "Energy efficiency",
    "TJ" => "Electronics & communications engineering",
    "TJF" => "Electronics engineering",
    "TJFC" => "Electronics: circuits & components",
    "TJFD" => "Electronic devices & materials",
    "TJFM" => "Automatic control engineering",
    "TJFM1" => "Robotics",
    "TJFN" => "Microwave technology",
    "TJK" => "Communications engineering / telecommunications",
    "TJKD" => "Radar technology",
    "TJKR" => "Radio technology",
    "TJKS" => "Satellite communication technology",
    "TJKT" => "Telephone technology",
    "TJKT1" => "Mobile phone technology",
    "TJKV" => "Television technology",
    "TJKW" => "WAP (wireless) technology",
    "TJS" => "Sensors",
    "TN" => "Civil engineering, surveying & building",
    "TNC" => "Structural engineering",
    "TNCB" => "Surveying, quantity surveying",
    "TNCC" => "Soil & rock mechanics",
    "TNCE" => "Earthquake engineering",
    "TNCJ" => "Bridges",
    "TNF" => "Hydraulic engineering",
    "TNFL" => "Flood control",
    "TNH" => "Highway & traffic engineering",
    "TNK" => "Building construction & materials",
    "TNKA" => "Accessibility in buildings & building design",
    "TNKE" => "Building physics & energy-efficient construction",
    "TNKF" => "Fire protection & safety",
    "TNKH" => "Heating, lighting, ventilation",
    "TNKP" => "Construction planning",
    "TNKR" => "Building redevelopment",
    "TNKS" => "Security & fire alarm systems",
    "TNKX" => "Conservation of buildings & building materials",
    "TNT" => "Building skills & trades",
    "TQ" => "Environmental science, engineering & technology",
    "TQD" => "Environmental monitoring",
    "TQK" => "Pollution control",
    "TQS" => "Sanitary & municipal engineering",
    "TQSR" => "Waste treatment & disposal",
    "TQSW" => "Water supply & treatment",
    "TR" => "Transport technology & trades",
    "TRC" => "Automotive technology & trades",
    "TRCS" => "Automotive (motor mechanic) skills",
    "TRCT" => "Road transport & haulage trades",
    "TRF" => "Railway technology, engineering & trades",
    "TRFT" => "Railway trades",
    "TRL" => "Shipbuilding technology, engineering & trades",
    "TRLD" => "Ship design & naval architecture",
    "TRLN" => "Navigation & seamanship",
    "TRLT" => "Maritime & nautical trades",
    "TRP" => "Aerospace & aviation technology",
    "TRPS" => "Aviation skills & piloting",
    "TRT" => "Intelligent & automated transport system technology",
    "TT" => "Other technologies & applied sciences",
    "TTA" => "Acoustic & sound engineering",
    "TTB" => "Applied optics",
    "TTBF" => "Fibre optics",
    "TTBL" => "Laser technology & holography",
    "TTBM" => "Imaging systems & technology",
    "TTBS" => "Scanning systems & technology",
    "TTD" => "Space science",
    "TTDS" => "Astronautics",
    "TTDX" => "Space exploration",
    "TTM" => "Military engineering",
    "TTMW" => "Ordnance, weapons technology",
    "TTP" => "Explosives technology & pyrotechnics",
    "TTS" => "Marine engineering",
    "TTU" => "Mining technology & engineering",
    "TTV" => "Other vocational technologies & trades",
    "TTVC" => "Hotel, hospitality & catering trades",
    "TTVC2" => "Catering & food preparation skills & trades",
    "TTVH" => "Hairdressing, salon & beauty therapy skills",
    "TTVR" => "Traditional trades & skills",
    "TTVS" => "Security, safety & protection skills / professions",
    "TTVT" => "Caretakers, janitors, housekeepers, cleaners & related skills",
    "TTW" => "Assistive technology",
    "TTX" => "Taxidermy",
    "TV" => "Agriculture & farming",
    "TVB" => "Agricultural science",
    "TVBP" => "Soil science & management",
    "TVD" => "Agricultural engineering & machinery",
    "TVDR" => "Irrigation",
    "TVF" => "Sustainable agriculture",
    "TVG" => "Organic farming",
    "TVH" => "Animal husbandry",
    "TVHB" => "Animal breeding",
    "TVHF" => "Dairy farming",
    "TVHH" => "Apiculture (beekeeping)",
    "TVHP" => "Poultry farming",
    "TVK" => "Agronomy & crop production",
    "TVM" => "Smallholdings",
    "TVP" => "Pest control",
    "TVQ" => "Tropical agriculture: practice & techniques",
    "TVR" => "Forestry & silviculture: practice & techniques",
    "TVS" => "Commercial horticulture",
    "TVSH" => "Hydroponics / hydroculture",
    "TVSW" => "Viticulture",
    "TVT" => "Aquaculture & fish-farming: practice & techniques",
    "TVU" => "Urban farming / urban agriculture",
    "U" => "Computing & Information Technology",
    "UB" => "Information technology: general topics",
    "UBH" => "Health & safety aspects of IT",
    "UBJ" => "Ethical & social aspects of IT",
    "UBL" => "Legal aspects of IT",
    "UBM" => "Maker and hacker culture",
    "UBW" => "Internet: general works",
    "UD" => "Computing & IT: consumer and user guides",
    "UDA" => "Personal organization software & apps",
    "UDB" => "Internet guides & online services",
    "UDBA" => "Online shopping & auctions",
    "UDBD" => "Internet searching",
    "UDBG" => "Internet gambling",
    "UDBM" => "Online finance & investing",
    "UDBR" => "Internet browsers",
    "UDBS" => "Social media / social networking",
    "UDBV" => "Virtual worlds",
    "UDD" => "Online safety & behaviour",
    "UDF" => "Email: consumer / user guides",
    "UDH" => "E-book readers, tablets & other portable devices: consumer / user guides",
    "UDM" => "Digital music & audio: consumer / user guides",
    "UDQ" => "Digital video: consumer / user guides",
    "UDT" => "Mobile phones & smartphones: consumer / user guides",
    "UDV" => "Digital TV & media centres: consumer / user guides",
    "UDX" => "Computer games / online games: strategy guides",
    "UDY" => "Virtual assistants: consumer / guides",
    "UF" => "Business applications",
    "UFB" => "Integrated software packages",
    "UFC" => "Spreadsheet software",
    "UFD" => "Word processing software",
    "UFG" => "Presentation graphics software",
    "UFK" => "Accounting software",
    "UFL" => "Enterprise software",
    "UFLS" => "SAP (Systems, applications & products in databases)",
    "UFM" => "Mathematical & statistical software",
    "UFP" => "Project management software",
    "UFS" => "Collaboration & group software",
    "UG" => "Graphical & digital media applications",
    "UGB" => "Web graphics & design",
    "UGC" => "Computer-aided design (CAD)",
    "UGD" => "Desktop publishing",
    "UGG" => "Computer games design",
    "UGK" => "3D graphics & modelling",
    "UGL" => "Illustration & drawing software",
    "UGM" => "Digital music: professional",
    "UGN" => "Digital animation",
    "UGP" => "Photo & image editing",
    "UGV" => "Digital video: professional",
    "UK" => "Computer hardware",
    "UKC" => "Supercomputers",
    "UKD" => "Mainframes & minicomputers",
    "UKF" => "Servers",
    "UKG" => "Grid & parallel computing",
    "UKM" => "Embedded systems",
    "UKN" => "Network hardware",
    "UKP" => "Personal computers",
    "UKPC" => "PCs (IBM-compatible personal computers)",
    "UKPM" => "Macintosh",
    "UKR" => "Maintenance & repairs",
    "UKS" => "Storage media & peripherals",
    "UKX" => "Utilities & tools",
    "UL" => "Operating systems",
    "ULD" => "Microsoft (Windows) operating systems",
    "ULH" => "Apple operating systems",
    "ULJ" => "Open source & other operating systems",
    "ULJL" => "Linux",
    "ULP" => "Mobile & other handheld operating systems",
    "ULQ" => "IBM mainframe operating systems",
    "ULR" => "Real time operating systems",
    "UM" => "Computer programming / software engineering",
    "UMA" => "Programming techniques",
    "UMB" => "Algorithms & data structures",
    "UMC" => "Compilers & interpreters",
    "UMF" => "Agile programming",
    "UMG" => "Aspect programming / AOP",
    "UMH" => "Extreme programming",
    "UMJ" => "Functional programming",
    "UMK" => "Games development & programming",
    "UMKB" => "2D graphics: games programming",
    "UMKC" => "3D graphics: games programming",
    "UMKL" => "Level design: games programming",
    "UML" => "Graphics programming",
    "UMN" => "Object-oriented programming (OOP)",
    "UMP" => "Microsoft programming",
    "UMPN" => ".Net programming",
    "UMPW" => "Windows programming",
    "UMQ" => "Macintosh programming",
    "UMR" => "Network programming",
    "UMS" => "Mobile & handheld device programming / Apps programming",
    "UMT" => "Database programming",
    "UMW" => "Web programming",
    "UMWS" => "Web services",
    "UMX" => "Programming & scripting languages: general",
    "UMZ" => "Software Engineering",
    "UMZL" => "Unified Modeling Language (UML)",
    "UMZT" => "Software testing & verification",
    "UMZW" => "Object oriented software engineering",
    "UN" => "Databases",
    "UNA" => "Database design & theory",
    "UNAN" => "NoSQL databases",
    "UNAR" => "Relational databases",
    "UNC" => "Data capture & analysis",
    "UND" => "Data warehousing",
    "UNF" => "Data mining",
    "UNH" => "Information retrieval",
    "UNJ" => "Object-oriented databases",
    "UNK" => "Distributed databases",
    "UNKD" => "Distributed ledgers",
    "UNKP" => "Peer-to-peer networks",
    "UNN" => "Databases & the Web",
    "UNS" => "Database software",
    "UP" => "Practical applications of information technology",
    "UQ" => "Computer certification",
    "UQF" => "Computer certification: Microsoft",
    "UQJ" => "Computer certification: Cisco",
    "UQL" => "Computer certification: ECDL",
    "UQR" => "Computer certification: CompTIA",
    "UQT" => "Computer certification: CLAiT",
    "UR" => "Computer security",
    "URD" => "Privacy & data protection",
    "URH" => "Computer fraud & hacking",
    "URJ" => "Computer viruses, Trojans & worms",
    "URQ" => "Firewalls",
    "URS" => "Spam",
    "URW" => "Spyware",
    "URY" => "Data encryption",
    "UT" => "Computer networking & communications",
    "UTC" => "Cloud computing",
    "UTD" => "Client–Server networking",
    "UTE" => "System administration",
    "UTF" => "Network management",
    "UTFB" => "Computer systems back-up & data recovery",
    "UTG" => "Grid computing",
    "UTM" => "Electronic mail (email): professional",
    "UTN" => "Network security",
    "UTP" => "Networking standards & protocols",
    "UTR" => "Distributed systems",
    "UTS" => "Networking packages",
    "UTV" => "Virtualization",
    "UTW" => "WAP networking & applications",
    "UTX" => "EDI (electronic data interchange)",
    "UX" => "Applied computing",
    "UXA" => "Computer applications in the arts & humanities",
    "UXJ" => "Computer applications in the social & behavioural sciences",
    "UXT" => "Computer applications in industry & technology",
    "UY" => "Computer science",
    "UYA" => "Mathematical theory of computation",
    "UYAM" => "Maths for computer scientists",
    "UYD" => "Systems analysis & design",
    "UYF" => "Computer architecture & logic design",
    "UYFL" => "Assembly languages",
    "UYFP" => "Parallel processing",
    "UYM" => "Computer modelling & simulation",
    "UYQ" => "Artificial intelligence",
    "UYQE" => "Expert systems / knowledge-based systems",
    "UYQL" => "Natural language & machine translation",
    "UYQM" => "Machine learning",
    "UYQN" => "Neural networks & fuzzy systems",
    "UYQP" => "Pattern recognition",
    "UYQS" => "Speech recognition",
    "UYQV" => "Computer vision",
    "UYS" => "Signal processing",
    "UYT" => "Image processing",
    "UYU" => "Audio processing",
    "UYV" => "Virtual reality",
    "UYW" => "Augmented reality (AR)",
    "UYZ" => "Human–computer interaction",
    "UYZF" => "Information visualization",
    "UYZG" => "User interface design & usability",
    "UYZM" => "Information architecture",
    "V" => "Health, Relationships & Personal development",
    "VF" => "Family & health",
    "VFB" => "Personal safety",
    "VFD" => "Popular medicine & health",
    "VFDF" => "First aid for the home",
    "VFDJ" => "Children’s health",
    "VFDM" => "Men’s health",
    "VFDW" => "Women’s health",
    "VFDW2" => "Menopause",
    "VFG" => "Home nursing & caring",
    "VFJ" => "Coping with personal & health issues",
    "VFJB" => "Coping with illness & specific health conditions",
    "VFJB1" => "Coping with allergies, including food allergies",
    "VFJB2" => "Coping with back problems",
    "VFJB3" => "Coping with cancer",
    "VFJB4" => "Coping with heart conditions",
    "VFJB5" => "Coping with diabetes",
    "VFJB6" => "Coping with Alzheimer’s & dementia",
    "VFJD" => "Coping with disability",
    "VFJG" => "Coping with ageing",
    "VFJJ" => "Coping with eating disorders",
    "VFJK" => "Coping with drug & alcohol problems",
    "VFJL" => "Coping with addiction",
    "VFJM" => "Coping with abuse",
    "VFJP" => "Coping with anxiety & phobias",
    "VFJQ" => "Coping with mental health issues",
    "VFJQ1" => "Coping with depression & other mood disorders",
    "VFJR" => "Coping with neurodevelopmental issues",
    "VFJR1" => "Coping with autism / Asperger’s",
    "VFJR2" => "Coping with ADHD",
    "VFJR3" => "Coping with dyslexia & learning difficulties",
    "VFJR4" => "Coping with communication difficulties",
    "VFJS" => "Coping with stress",
    "VFJT" => "Coping with loneliness / solitude",
    "VFJV" => "Coping with sleep problems",
    "VFJX" => "Coping with death & bereavement",
    "VFJX1" => "Coping with suicide",
    "VFL" => "Giving up smoking",
    "VFM" => "Fitness & diet",
    "VFMD" => "Diets & dieting",
    "VFMG" => "Exercise & workout books",
    "VFMG1" => "Yoga for exercise",
    "VFMG2" => "Weight training",
    "VFMS" => "Massage",
    "VFV" => "Family & relationships: advice & issues",
    "VFVC" => "Sex & sexuality: advice & issues",
    "VFVG" => "Dating, relationships, living together & marriage: advice",
    "VFVJ" => "Involuntary childlessness: advice & issues",
    "VFVK" => "Adoption & fostering: advice & issues",
    "VFVM" => "Solo lifestyles: advice & issues",
    "VFVS" => "Separation & divorce: advice & issues",
    "VFVX" => "Intergenerational relationships: advice & issues",
    "VFX" => "Parenting: advice & issues",
    "VFXB" => "Pregnancy, birth & baby care: advice & issues",
    "VFXB1" => "Baby names: guides for parents",
    "VFXC" => "Child care & upbringing: advice for parents",
    "VFXC1" => "Teenagers: advice for parents",
    "VS" => "Self-help, personal development & practical advice",
    "VSB" => "Personal finance",
    "VSC" => "Advice on careers & achieving success",
    "VSCB" => "Job hunting / changing careers",
    "VSD" => "Law, citizenship & rights for the lay person",
    "VSF" => "Roadcraft & driving",
    "VSG" => "Consumer advice",
    "VSH" => "Housing & property for the individual: buying/selling & legal aspects",
    "VSK" => "Advice on education",
    "VSKB" => "Student life",
    "VSL" => "Adult literacy guides & handbooks",
    "VSN" => "Adult numeracy guides & handbooks",
    "VSP" => "Popular psychology",
    "VSPD" => "Mindfulness",
    "VSPM" => "Assertiveness, motivation, self-esteem & positive mental attitude",
    "VSPT" => "Memory improvement & thinking techniques",
    "VSPX" => "Neuro Linguistic Programming (NLP)",
    "VSR" => "Retirement",
    "VSS" => "Soft skills & dealing with other people",
    "VSW" => "Living & working in other countries: practical advice",
    "VSZ" => "Self-sufficiency & ‘green’ lifestyle",
    "VX" => "Mind, body, spirit",
    "VXA" => "Mind, body, spirit: thought & practice",
    "VXF" => "Fortune-telling & divination",
    "VXFA" => "Astrology",
    "VXFA1" => "Star signs & horoscopes",
    "VXFC" => "Fortune-telling by cards (cartomancy)",
    "VXFC1" => "Tarot",
    "VXFD" => "The I Ching",
    "VXFG" => "Graphology",
    "VXFJ" => "Divination from physical attributes",
    "VXFJ1" => "Palmistry, chiromancy",
    "VXFJ2" => "Phrenology & physiognomy",
    "VXFN" => "Numerology",
    "VXFT" => "Clairvoyance & precognition",
    "VXH" => "Complementary therapies, healing & health",
    "VXHA" => "Acupuncture",
    "VXHC" => "Aromatherapy & essential oils",
    "VXHF" => "Nature therapy",
    "VXHH" => "Homoeopathy",
    "VXHJ" => "Reflexology",
    "VXHK" => "Reiki",
    "VXHT" => "Traditional medicine & herbal remedies",
    "VXK" => "Earth energies",
    "VXM" => "Mind, body, spirit: meditation & visualization",
    "VXN" => "Dreams & their interpretation",
    "VXP" => "Psychic powers & psychic phenomena",
    "VXPC" => "Crystals & colour-healing",
    "VXPH" => "Chakras, auras & spiritual energy",
    "VXPJ" => "Astral projection & out-of-body experiences",
    "VXPR" => "The afterlife, reincarnation & past lives",
    "VXPS" => "Spirit guides, angels & channelling",
    "VXQ" => "Unexplained phenomena / the paranormal",
    "VXQB" => "UFOs & extraterrestrial beings",
    "VXQG" => "Ghosts & poltergeists",
    "VXQM" => "Monsters, mythical & legendary beings",
    "VXQM1" => "Mythical creatures: Dragons",
    "VXQM2" => "Mythical creatures: Vampires, werewolves & other shapeshifters",
    "VXQM3" => "Mythical creatures: Zombies & the undead",
    "VXV" => "Feng Shui & approaches to living space design & style",
    "VXW" => "Mysticism, magic & occult interests",
    "VXWK" => "Kabbalah: popular works",
    "VXWM" => "Magic, spells & alchemy",
    "VXWS" => "Shamanism, paganism & druidry",
    "VXWT" => "Witchcraft & wicca",
    "W" => "Lifestyle, Hobbies & Leisure",
    "WB" => "Cookery / food & drink etc",
    "WBA" => "General cookery & recipes",
    "WBAC" => "Comfort food and food nostalgia",
    "WBB" => "TV / celebrity chef cookbooks",
    "WBC" => "Cooking for one",
    "WBD" => "Budget cookery",
    "WBF" => "Quick & easy cookery",
    "WBH" => "Health & wholefood cookery",
    "WBHS" => "Cookery for specific diets & conditions",
    "WBJ" => "Vegetarian cookery",
    "WBJK" => "Vegan cookery",
    "WBK" => "Organic food / organic cookery",
    "WBN" => "National, regional & ethnic cuisine",
    "WBNB" => "Street food",
    "WBQ" => "Cookery for/with children",
    "WBR" => "Cooking for parties & special occasions",
    "WBS" => "Cooking with specific gadgets",
    "WBT" => "Cookery / food by ingredient",
    "WBTB" => "Cookery / food by ingredient: meat & game",
    "WBTC" => "Cookery / food by ingredient: chicken & other poultry",
    "WBTF" => "Cookery / food by ingredient: fish & seafood",
    "WBTH" => "Cookery / food by ingredient: herbs, spices, oils & vinegars",
    "WBTJ" => "Cookery / food by ingredient: rice, grains, pulses, nuts & seeds",
    "WBTM" => "Cookery / food by ingredient: fruit & vegetables",
    "WBTP" => "Cookery / food by ingredient: pasta & noodles",
    "WBTR" => "Cookery / food by ingredient: egg, cheese & dairy products",
    "WBTX" => "Cookery / food by ingredient: chocolate",
    "WBV" => "Cookery dishes & courses",
    "WBVD" => "Cookery dishes & courses: soups & starters",
    "WBVG" => "Cookery dishes & courses: salads & vegetables",
    "WBVH" => "Cookery dishes & courses: sauces",
    "WBVM" => "Cookery dishes & courses: main courses",
    "WBVQ" => "Cookery dishes & courses: desserts",
    "WBVS" => "Baking, bread, cakes & pastry",
    "WBVS1" => "Cakes & cake decoration, icing & sugarcraft",
    "WBW" => "Cookery: preserving & freezing",
    "WBX" => "Food & drink: beverages",
    "WBXD" => "Food & drink: alcoholic beverages",
    "WBXD1" => "Food & drink: wines",
    "WBXD2" => "Food & drink: beers & ciders",
    "WBXD3" => "Food & drink: spirits, liqueurs & cocktails",
    "WBXN" => "Food & drink: non-alcoholic beverages",
    "WBXN1" => "Tea & coffee",
    "WBXN3" => "Juices & smoothies",
    "WBZ" => "Cigars & smoking",
    "WC" => "Antiques & collectables",
    "WCB" => "Antiques & collectables: buyer’s guides",
    "WCC" => "Care & restoration of antiques",
    "WCF" => "Collecting coins, banknotes, medals & other related items",
    "WCG" => "Collecting stamps, philately",
    "WCJ" => "Antique clocks, watches, musical boxes & automata",
    "WCK" => "Militaria, arms & armour",
    "WCL" => "Antique furniture / furniture collecting",
    "WCN" => "Antiques & collectables: ceramics, glass & other related items",
    "WCNC" => "Antiques & collectables: ceramics, porcelain & pottery",
    "WCNG" => "Antiques & collectables: glass",
    "WCP" => "Antiques & collectables: jewellery",
    "WCR" => "Antiques & collectables: gold, silver & other metals (other than jewellery)",
    "WCRB" => "Antiques & collectables: buttons, badges, pins & related small items",
    "WCS" => "Antiques & collectables: books, manuscripts, ephemera & printed matter",
    "WCT" => "Antiques & collectables: sports memorabilia",
    "WCU" => "Antiques & collectables: pictures, prints & maps",
    "WCV" => "Antiques & collectables: carpets, rugs & textiles",
    "WCW" => "Antiques & collectables: toys, games, dolls & models",
    "WCX" => "Antiques & collectables: instruments, implements & tools",
    "WCXM" => "Antiques & collectables: musical instruments",
    "WCXS" => "Antiques & collectables: scientific instruments",
    "WD" => "Hobbies, quizzes & games",
    "WDH" => "Hobbies",
    "WDHB" => "Model-making & construction",
    "WDHM" => "Model railways",
    "WDHR" => "Radio-controlled models",
    "WDHW" => "Role-playing, war games & fantasy sports",
    "WDJ" => "3D images & optical illusions",
    "WDK" => "Puzzles & quizzes",
    "WDKC" => "Crosswords & word games",
    "WDKN" => "Sudoku & number puzzles",
    "WDKX" => "Trivia & quiz question books",
    "WDM" => "Indoor games",
    "WDMC" => "Card games",
    "WDMC1" => "Card games: Bridge",
    "WDMC2" => "Card games: Poker",
    "WDMG" => "Board games",
    "WDMG1" => "Board games: Chess",
    "WDP" => "Gambling: theories & methods",
    "WF" => "Handicrafts, decorative arts & crafts",
    "WFA" => "Painting & art manuals",
    "WFB" => "Needlework & fabric crafts",
    "WFBC" => "Embroidery crafts",
    "WFBL" => "Lace & lacemaking",
    "WFBQ" => "Quiltmaking, patchwork & applique",
    "WFBS" => "Knitting & crochet",
    "WFBS1" => "Knitting",
    "WFBS2" => "Crochet",
    "WFBV" => "Fabric dyeing",
    "WFBW" => "Sewing",
    "WFC" => "Ropework, knots & macramé",
    "WFF" => "Rug & carpetmaking",
    "WFG" => "Spinning & weaving",
    "WFH" => "Toys: making & decorating",
    "WFJ" => "Jewellery & beadcraft",
    "WFK" => "Decorative finishes & surfaces",
    "WFN" => "Pottery, ceramics & glass crafts",
    "WFP" => "Decorative metalwork",
    "WFQ" => "Decorative woodwork",
    "WFS" => "Carving & modelling, moulding & casting",
    "WFT" => "Book & paper crafts",
    "WFTM" => "Origami & paper engineering",
    "WFU" => "Calligraphy & hand-lettering",
    "WFV" => "Rural crafts",
    "WFW" => "Flower arranging & floral crafts",
    "WFX" => "Adult colouring & activity books",
    "WG" => "Transport: general interest",
    "WGC" => "Road & motor vehicles: general interest",
    "WGCB" => "Motor cars: general interest",
    "WGCF" => "Buses, trams & commercial vehicles: general interest",
    "WGCK" => "Motorcycles: general interest",
    "WGCQ" => "Road & motor vehicles: Camper vans, Recreational vehicles",
    "WGCT" => "Tractors & farm vehicles: general interest",
    "WGCV" => "Vehicle maintenance & manuals",
    "WGD" => "Bicycles & non-motorised transport: general interest & maintenance",
    "WGF" => "Trains & railways: general interest",
    "WGFD" => "Locomotives & rolling stock",
    "WGFL" => "Urban rail transit systems",
    "WGG" => "Ships & boats: general interest",
    "WGGB" => "Boats",
    "WGGD" => "Ships: Liners & other ocean-going vessels",
    "WGGP" => "Ships & boats: certification and licences",
    "WGGV" => "Boatbuilding & maintenance",
    "WGM" => "Aircraft & aviation",
    "WH" => "Humour",
    "WHG" => "TV tie-in humour",
    "WHJ" => "Jokes & riddles",
    "WHL" => "Slang & dialect humour",
    "WHP" => "Parodies & spoofs: non-fiction",
    "WHX" => "Humour collections & anthologies",
    "WJ" => "Lifestyle & personal style guides",
    "WJF" => "Fashion & style guides",
    "WJH" => "Cosmetics, hair & beauty",
    "WJK" => "Interior design, decor & style guides",
    "WJS" => "Shopping guides",
    "WJW" => "Weddings, wedding planners",
    "WJX" => "Parties, etiquette & entertaining",
    "WJXC" => "Manners: guides & advice",
    "WJXF" => "Table settings & arts of the table",
    "WK" => "Home & house maintenance",
    "WKD" => "DIY: general",
    "WKDM" => "DIY: house maintenance manuals",
    "WKDW" => "DIY: carpentry & woodworking",
    "WKH" => "Household hints",
    "WKR" => "Home renovation & extension",
    "WKU" => "Outdoor & recreational areas: design & maintenance",
    "WM" => "Gardening",
    "WMB" => "Gardens (descriptions, history etc)",
    "WMD" => "Garden design & planning",
    "WMF" => "Greenhouses, conservatories, patios",
    "WMP" => "Gardening: plants & cultivation guides",
    "WMPC" => "Gardening: flowers & ornamental plants",
    "WMPF" => "Gardening: fruit & vegetable",
    "WMPS" => "Gardening: trees & shrubs",
    "WMPY" => "Gardening: pests & diseases",
    "WMQ" => "Specialized gardening methods",
    "WMQB" => "Bonsai",
    "WMQF" => "Organic gardening",
    "WMQL" => "Landscape gardening",
    "WMQN" => "Natural & wild gardening",
    "WMQP" => "Gardening with native plants",
    "WMQR" => "Container gardening",
    "WMQR1" => "Indoor gardening",
    "WMQW" => "Water gardens, pools",
    "WMT" => "Allotments / Community gardens",
    "WN" => "Nature & the natural world: general interest",
    "WNA" => "Dinosaurs & the prehistoric world: general interest",
    "WNC" => "Wildlife: general interest",
    "WNCB" => "Wildlife: birds & birdwatching: general interest",
    "WNCF" => "Wildlife: mammals: general interest",
    "WNCK" => "Wildlife: reptiles & amphibians: general interest",
    "WNCN" => "Wildlife: butterflies, other insects & spiders: general interest",
    "WNCS" => "Wildlife: aquatic creatures: general interest",
    "WNCS1" => "Sea life & the seashore: general interest",
    "WNCS2" => "Freshwater life: general interest",
    "WND" => "The countryside, country life: general interest",
    "WNF" => "Farm & working animals: general interest",
    "WNG" => "Domestic animals & pets",
    "WNGC" => "Cats as pets",
    "WNGD" => "Dogs as pets",
    "WNGD1" => "Dog obedience & training",
    "WNGF" => "Fishes as pets & aquaria",
    "WNGH" => "Horses & ponies: general interest",
    "WNGK" => "Birds, including cage birds, as pets",
    "WNGR" => "Rabbits & rodents as pets",
    "WNGS" => "Reptiles & amphibians as pets",
    "WNGX" => "Insects & spiders as pets",
    "WNH" => "Zoos & wildlife parks: general interest",
    "WNJ" => "National parks & nature reserves: general interest",
    "WNP" => "Trees, wildflowers & plants: general interest",
    "WNR" => "Rocks, minerals & fossils: general interest",
    "WNW" => "The Earth: natural history: general interest",
    "WNWM" => "Weather & climate: general interest",
    "WNX" => "Popular astronomy & space",
    "WQ" => "Local & family history, nostalgia",
    "WQH" => "Local history",
    "WQN" => "Nostalgia: general",
    "WQP" => "Places in old photographs",
    "WQY" => "Family history, tracing ancestors",
    "WT" => "Travel & holiday",
    "WTD" => "Travel tips & advice: general",
    "WTH" => "Travel & holiday guides",
    "WTHA" => "Travel guides: adventure holidays",
    "WTHB" => "Travel guides: business travel",
    "WTHC" => "Travel guides: eco-tourism, ‘green’ tourism",
    "WTHD" => "Travel guides: food & drink regions",
    "WTHE" => "Travel guides: activity holidays",
    "WTHF" => "Travel guides: holidays with children / family holidays",
    "WTHG" => "Travel guides: budget travel",
    "WTHH" => "Travel guides: hotel & holiday accommodation guides",
    "WTHH1" => "Travel guides: caravan & camp-site guides",
    "WTHK" => "Travel guides: beaches & coastal areas",
    "WTHM" => "Travel guides: museums, historic sites, galleries etc",
    "WTHR" => "Travel guides: restaurants & cafes",
    "WTHT" => "Travel guides: theme parks & funfairs",
    "WTHW" => "Travel guides: routes & ways",
    "WTHX" => "Travel guides: cruises",
    "WTK" => "Language phrasebooks",
    "WTL" => "Travel writing",
    "WTLC" => "Classic travel writing",
    "WTLP" => "Expeditions: popular accounts",
    "WTM" => "Places & peoples: general & pictorial works",
    "WTR" => "Travel maps & atlases",
    "WTRD" => "Road atlases & maps",
    "WTRM" => "Travel maps",
    "WTRS" => "Street maps & city plans",
    "WZ" => "Miscellaneous items",
    "WZG" => "Gift books",
    "WZS" => "Stationery items",
    "WZSN" => "Blank stationery items",
    "X" => "Graphic novels, Comic books, Cartoons",
    "XA" => "Graphic novel & Comic book: types",
    "XAB" => "European tradition graphic novels",
    "XAD" => "European tradition comic books, Bandes dessinées",
    "XADC" => "European comic books: general, classic, all ages",
    "XAK" => "American / British style comic books & graphic novels",
    "XAKC" => "American comic books: classic, Golden Age",
    "XAM" => "Manga & Asian style comics",
    "XAMC" => "Manga: Kodomo",
    "XAMF" => "Manga: Shōjo",
    "XAMG" => "Manga: Shōnen",
    "XAML" => "Manga: Seinen",
    "XAMR" => "Manga: Josei",
    "XAMT" => "Manga: Yaoi",
    "XAMV" => "Manga: Bara",
    "XAMX" => "Manga: adult (erotic, extreme violence)",
    "XAMX2" => "Manga: hentai manga",
    "XAMY" => "Manga: Yuri",
    "XQ" => "Graphic novel & Comic book: genres",
    "XQA" => "Graphic novel / Comic book: memoirs, true stories & non-fiction",
    "XQB" => "Graphic novel / Comic book: literary adaptations",
    "XQC" => "Graphic novel / Comic book: inspired by or adapted from",
    "XQD" => "Graphic novel / Comic book: crime, mystery & thrillers",
    "XQG" => "Graphic novel / Comic book: action & adventure",
    "XQGW" => "Graphic novel / Comic book: Westerns",
    "XQH" => "Graphic novel / Comic book: horror",
    "XQK" => "Graphic novel / Comic book: super-heroes & super-villains",
    "XQL" => "Graphic novel / Comic book: science fiction",
    "XQM" => "Graphic novel / Comic book: fantasy, esoteric",
    "XQN" => "Graphic novel / Comic book: anthropomorphic / animal stories",
    "XQR" => "Graphic novel / Comic book: romance",
    "XQS" => "Graphic novel / Comic book: school / college life",
    "XQT" => "Graphic novel / Comic book: humorous",
    "XQV" => "Graphic novel / Comic book: historical",
    "XQX" => "Graphic novel / Comic book: adult",
    "XQXE" => "Graphic novel / Comic book: adult – erotic",
    "XQXV" => "Graphic novel / Comic book: adult – extreme violence / gore",
    "XR" => "Graphic novel & comic books: guides & reviews",
    "XRM" => "Manga guides & reviews",
    "XY" => "Strip cartoons",
    "Y" => "Children’s, Teenage & Educational",
    "YB" => "Books for very young children, children’s picture books & activity books",
    "YBC" => "Children’s picture books",
    "YBCB" => "Baby books",
    "YBCH" => "Picture books: character books",
    "YBCS" => "Picture storybooks",
    "YBCS1" => "Picture storybooks: bedtime stories & dreams",
    "YBCS2" => "Picture storybooks: imagination & play",
    "YBG" => "Children’s interactive & activity books & packs",
    "YBGC" => "Colouring books",
    "YBGH" => "Children’s activity books: hidden object",
    "YBL" => "Early years / early learning concepts",
    "YBLA" => "Early years: letters & words",
    "YBLB" => "Early years: verse, rhymes & wordplay",
    "YBLC" => "Early years: numbers & counting",
    "YBLD" => "Early years: colours",
    "YBLF" => "Early years: opposites",
    "YBLH" => "Early years: size, shapes & patterns",
    "YBLJ" => "Early years: time & seasons",
    "YBLL" => "Early years: nature & animals",
    "YBLM" => "Early years: daily routine",
    "YBLN" => "Early years: first experiences",
    "YBLN1" => "Early years: the body & the senses",
    "YBLP" => "Early years: people who help us",
    "YBLQ" => "Early years: family",
    "YBLT" => "Early years: things that go",
    "YD" => "Children’s / Teenage poetry, anthologies, annuals",
    "YDA" => "Children’s / Teenage: Annuals",
    "YDC" => "Children’s / Teenage: Anthologies",
    "YDP" => "Children’s / Teenage: Poetry",
    "YF" => "Children’s / Teenage fiction & true stories",
    "YFA" => "Children’s / Teenage fiction: Classic fiction",
    "YFB" => "Children’s / Teenage fiction: General fiction",
    "YFC" => "Children’s / Teenage fiction: Action & adventure stories",
    "YFCA" => "Children’s / Teenage fiction: Interactive adventure stories",
    "YFCB" => "Children’s / Teenage fiction: Thrillers",
    "YFCF" => "Children’s / Teenage fiction: Crime & mystery fiction",
    "YFCW" => "Children’s / Teenage fiction: Military & war fiction",
    "YFD" => "Children’s / Teenage fiction: Horror & ghost stories, chillers",
    "YFE" => "Children’s / Teenage fiction: Speculative, dystopian & utopian fiction",
    "YFG" => "Children’s / Teenage fiction: Science fiction",
    "YFGS" => "Children’s / Teenage fiction: Steampunk",
    "YFH" => "Children’s / Teenage fiction: Fantasy",
    "YFHD" => "Children’s / Teenage fiction: Magical realism",
    "YFHR" => "Children’s / Teenage fiction: Fantasy romance",
    "YFJ" => "Children’s / Teenage fiction: Traditional stories",
    "YFK" => "Children’s / Teenage fiction: Religious fiction",
    "YFM" => "Children’s / Teenage fiction: Romance, love & relationships stories",
    "YFN" => "Children’s / Teenage fiction: Family & home stories",
    "YFP" => "Children’s / Teenage fiction: Nature & animal stories",
    "YFQ" => "Children’s / Teenage fiction: Humorous stories",
    "YFR" => "Children’s / Teenage fiction: Sporting stories",
    "YFS" => "Children’s / Teenage fiction: School stories",
    "YFT" => "Children’s / Teenage fiction: Historical fiction",
    "YFU" => "Children’s / Teenage fiction: Short stories",
    "YFV" => "Children’s / Teenage fiction: Stories in verse",
    "YFX" => "Children’s / Teenage fiction: Biographical fiction",
    "YFY" => "Children’s / Teenage: True stories told as fiction",
    "YFZ" => "Children’s / Teenage fiction: Special features & related items",
    "YFZR" => "Children’s / Teenage category fiction",
    "YFZV" => "Children’s / Teenage fiction: Inspired by or adapted from",
    "YFZZ" => "Children’s / Teenage fiction: Companion works",
    "YN" => "Children’s / Teenage: General interest",
    "YNA" => "Children’s / Teenage general interest: Art & artists",
    "YNB" => "Children’s / Teenage general interest: Biography & autobiography",
    "YNC" => "Children’s / Teenage general interest: Music",
    "YNCS" => "Songbooks for children",
    "YND" => "Children’s / Teenage general interest: Drama & performing",
    "YNDB" => "Children’s / Teenage general interest: Dance, ballet",
    "YNDS" => "Children’s / Teenage general interest: Playscripts",
    "YNF" => "Children’s / Teenage general interest: Television, video & film",
    "YNG" => "Children’s / Teenage general interest: General knowledge & interesting facts",
    "YNGL" => "Children’s / Teenage general interest: Information resources",
    "YNH" => "Children’s / Teenage general interest: History & the past",
    "YNHA" => "Children’s / Teenage general interest: Adventurers & outlaws",
    "YNHA1" => "Children’s / Teenage general interest: Pirates",
    "YNHD" => "Children’s / Teenage general interest: Discovery & exploration",
    "YNHP" => "Children’s / Teenage general interest: Lives of children in the past",
    "YNJ" => "Children’s / Teenage general interest: Warfare, battles, armed forces",
    "YNJC" => "Children’s / Teenage general interest: Castles & knights",
    "YNK" => "Children’s / Teenage general interest: Work & society",
    "YNKA" => "Children’s / Teenage general interest: Politics",
    "YNKC" => "Children’s / Teenage general interest: Law, police & crime",
    "YNL" => "Children’s / Teenage general interest: Literature, books & writers",
    "YNM" => "Children’s / Teenage general interest: Places & peoples",
    "YNMC" => "Children’s / Teenage general interest: Countries, cultures & national identity",
    "YNMD" => "Children’s / Teenage general interest: Celebrations, holidays, festivals & special events",
    "YNMF" => "Children’s / Teenage general interest: Girls & women",
    "YNMH" => "Children’s / Teenage general interest: Boys & men",
    "YNMK" => "Children’s / Teenage general interest: City & town life",
    "YNML" => "Children’s / Teenage general interest: Rural & farm life",
    "YNMW" => "Children’s / Teenage general interest: Queens, kings, princesses, princes etc",
    "YNN" => "Children’s / Teenage general interest: Nature, animals, the natural world",
    "YNNA" => "Children’s / Teenage general interest: Dinosaurs & prehistoric world",
    "YNNB" => "Children’s / Teenage general interest: Wildlife & habitats",
    "YNNB1" => "Children’s / Teenage general interest: Wildlife & habitats: Oceans & seas",
    "YNNB2" => "Children’s / Teenage general interest: Wildlife & habitats: Jungles & tropical forests",
    "YNNB3" => "Children’s / Teenage general interest: Wildlife & habitats: Deserts",
    "YNNB9" => "Children’s / Teenage general interest: Wildlife & habitats: Ice, snow & tundra",
    "YNNC" => "Children’s / Teenage general interest: Ecosystems",
    "YNNF" => "Children’s / Teenage general interest: Farm animals",
    "YNNH" => "Children’s / Teenage general interest: Pets & pet care",
    "YNNH1" => "Children’s / Teenage general interest: Pets & pet care: Dogs",
    "YNNH2" => "Children’s / Teenage general interest: Pets & pet care: Cats",
    "YNNH3" => "Children’s / Teenage general interest: Pets & pet care: Rabbits & rodents",
    "YNNH4" => "Children’s / Teenage general interest: Pets & pet care: Horses & ponies",
    "YNNH5" => "Children’s / Teenage general interest: Pets & pet care: Birds",
    "YNNJ" => "Children’s / Teenage general interest: Mammals",
    "YNNJ1" => "Children’s / Teenage general interest: Freshwater & marine mammals",
    "YNNJ14" => "Children’s / Teenage general interest: Whales, dolphins & porpoises",
    "YNNJ2" => "Children’s / Teenage general interest: Large land mammals",
    "YNNJ21" => "Children’s / Teenage general interest: Dogs & wolves",
    "YNNJ22" => "Children’s / Teenage general interest: Cats including big cats",
    "YNNJ23" => "Children’s / Teenage general interest: Bears",
    "YNNJ24" => "Children’s / Teenage general interest: Ponies & horses",
    "YNNJ25" => "Children’s / Teenage general interest: Cows & cattle",
    "YNNJ26" => "Children’s / Teenage general interest: Pigs, hogs & boars",
    "YNNJ27" => "Children’s / Teenage general interest: Sheep & goats",
    "YNNJ29" => "Children’s / Teenage general interest: Apes, monkeys & lemurs",
    "YNNJ3" => "Children’s / Teenage general interest: Small land mammals",
    "YNNJ31" => "Children’s / Teenage general interest: Rodents & rabbits",
    "YNNJ9" => "Children’s / Teenage general interest: Marsupials, platypuses & echidnas",
    "YNNK" => "Children’s / Teenage general interest: Birds",
    "YNNL" => "Children’s / Teenage general interest: Insects, spiders, minibeasts",
    "YNNM" => "Children’s / Teenage general interest: Reptiles & amphibians",
    "YNNS" => "Children’s / Teenage general interest: Fish & marine life",
    "YNNT" => "Children’s / Teenage general interest: Plants & trees",
    "YNNV" => "Children’s / Teenage general interest: Rocks, weather & physical world",
    "YNNZ" => "Children’s / Teenage general interest: Space, stars & the solar system",
    "YNP" => "Children’s / Teenage general interest: Practical interests",
    "YNPC" => "Children’s / Teenage general interest: Cooking & food",
    "YNPG" => "Children’s / Teenage general interest: Gardening",
    "YNPH" => "Children’s / Teenage general interest: Handicrafts",
    "YNPH1" => "Children’s / Teenage general interest: Woodworking, model-making",
    "YNPH2" => "Children’s / Teenage general interest: Needlecraft & fabric crafts",
    "YNPJ" => "Children’s / Teenage general interest: Clothing & fashion",
    "YNPK" => "Children’s / Teenage general interest: Money",
    "YNQ" => "Children’s / Teenage: Youth clubs, societies, groups & organisations",
    "YNR" => "Children’s / Teenage general interest: Religion & beliefs",
    "YNRD" => "Children’s / Teenage general interest: Hinduism",
    "YNRF" => "Children’s / Teenage general interest: Buddhism",
    "YNRJ" => "Children’s / Teenage general interest: Judaism",
    "YNRM" => "Children’s / Teenage general interest: Christianity",
    "YNRP" => "Children’s / Teenage general interest: Islam",
    "YNRR" => "Children’s / Teenage general interest: Other religions",
    "YNRU" => "Children’s / Teenage general interest: Ancient religions & mythologies",
    "YNRX" => "Children’s / Teenage general interest: Religious texts, prayers & devotional material",
    "YNT" => "Children’s / Teenage general interest: Science & technology",
    "YNTA" => "Children’s / Teenage general interest: Science: The human body",
    "YNTC" => "Children’s / Teenage general interest: Computing & Information Technology",
    "YNTC1" => "Children’s / Teenage general interest: Programming & scripting languages",
    "YNTC2" => "Children’s / Teenage general interest: Social media",
    "YNTD" => "Children’s / Teenage general interest: Inventors, inventions & experiments",
    "YNTG" => "Children’s / Teenage general interest: Machines & how things work",
    "YNTM" => "Children’s / Teenage general interest: Mathematics & numbers",
    "YNTP" => "Children’s / Teenage general interest: Buildings & construction",
    "YNTR" => "Children’s / Teenage general interest: Transport & vehicles",
    "YNTT" => "Children’s / Teenage general interest: Time travel",
    "YNU" => "Children’s / Teenage general interest: Humour & jokes",
    "YNUC" => "Children’s / Teenage general interest: Cartoons & comic strips",
    "YNV" => "Children’s / Teenage general interest: Hobbies, quizzes, toys & games",
    "YNVD" => "Children’s / Teenage general interest: Toys",
    "YNVD1" => "Children’s / Teenage general interest: Dolls, figures & similar toys",
    "YNVD2" => "Children’s / Teenage general interest: Stuffed or soft toys",
    "YNVD3" => "Children’s / Teenage general interest: Building bricks, blocks & construction toys",
    "YNVP" => "Children’s / Teenage general interest: Puzzle books",
    "YNVU" => "Children’s / Teenage general interest: Computer & video games",
    "YNW" => "Children’s / Teenage general interest: Sports & outdoor recreation",
    "YNWD" => "Children’s / Teenage general interest: Ball games & sports",
    "YNWD1" => "Children’s / Teenage general interest: Ball games & sports: Association football (Soccer)",
    "YNWD2" => "Children’s / Teenage general interest: Ball games & sports: American Football",
    "YNWD3" => "Children’s / Teenage general interest: Ball games & sports: Baseball & Softball",
    "YNWD4" => "Children’s / Teenage general interest: Ball games & sports: Basketball",
    "YNWD6" => "Children’s / Teenage general interest: Ball games & sports: Volleyball",
    "YNWD8" => "Children’s/Teenage general interest: Ball games & sports: Handball",
    "YNWG" => "Children’s / Teenage general interest: Athletics & gymnastics",
    "YNWM" => "Children’s / Teenage general interest: Winter sports",
    "YNWM1" => "Children’s / Teenage general interest: Winter sports: Skiing",
    "YNWM2" => "Children’s / Teenage general interest: Winter sports: Ice hockey",
    "YNWW" => "Children’s / Teenage general interest: Swimming & water sports",
    "YNWY" => "Children’s / Teenage general interest: Cycling, rollerskating & skateboarding",
    "YNWZ" => "Children’s / Teenage general interest: Sports teams & clubs",
    "YNX" => "Children’s / Teenage general interest: Mysteries & the unexplained",
    "YNXB" => "Children’s / Teenage general interest: Supernatural & mythological creatures",
    "YNXB1" => "Children’s / Teenage general interest: Dragons",
    "YNXB2" => "Children’s / Teenage general interest: Vampires, werewolves & shapeshifters",
    "YNXB3" => "Children’s / Teenage general interest: Zombies, ghosts & the undead",
    "YNXB4" => "Children’s / Teenage general interest: Fairies, elves, etc",
    "YNXF" => "Children’s / Teenage general interest: UFOs & extraterrestrial beings",
    "YNXW" => "Children’s / Teenage general interest: Witches, wizards & magicians",
    "YP" => "Educational material",
    "YPA" => "Educational: Arts, general",
    "YPAB" => "Educational: Art & design",
    "YPAD" => "Educational: Music",
    "YPAF" => "Educational: Drama & performance arts",
    "YPAG" => "Educational: Fashion & textile",
    "YPAK" => "Educational: Handicrafts",
    "YPC" => "Educational: Language, literature & literacy",
    "YPCA" => "Educational: First / native language",
    "YPCA1" => "Educational: First / native language: Basic literacy",
    "YPCA2" => "Educational: First / native language: Reading & writing skills",
    "YPCA21" => "Educational: First / native language: Readers & reading schemes",
    "YPCA22" => "Educational: First / native language: Handwriting skills",
    "YPCA23" => "Educational: First / native language: Spelling & vocabulary",
    "YPCA4" => "Educational: First / native language: Grammar & punctuation",
    "YPCA5" => "Educational: First / native language: Speaking skills",
    "YPCA9" => "Educational: First / native language: Literature studies",
    "YPCA91" => "Educational: First / native language: School editions of literature texts",
    "YPCK" => "Educational: Modern (non-native) languages",
    "YPCK2" => "Educational: Modern (non-native) languages: Language learning",
    "YPCK21" => "Educational: Modern (non-native) languages: Language learning: grammar, vocabulary and pronunciation",
    "YPCK22" => "Educational: Modern (non-native) languages: Language learning: readers",
    "YPCK9" => "Educational: Modern (non-native) languages: Literature studies",
    "YPCK91" => "Educational: Modern (non-native) languages: School editions of literature texts",
    "YPCS" => "Educational: Classical & ancient languages",
    "YPCS4" => "Educational: Classical & ancient languages: Language learning",
    "YPCS9" => "Educational: Classical & ancient languages: Literature studies",
    "YPCS91" => "Educational: Classical & ancient languages: School editions of classical texts",
    "YPJ" => "Educational: Humanities & social sciences, general",
    "YPJH" => "Educational: History",
    "YPJJ" => "Educational: Social sciences, social studies",
    "YPJJ1" => "Educational: Politics & constitution",
    "YPJJ3" => "Educational: Citizenship & social education",
    "YPJJ4" => "Educational: Local / integrated studies",
    "YPJJ5" => "Educational: Psychology",
    "YPJJ6" => "Educational: Personal & health education",
    "YPJK" => "Educational: Media studies",
    "YPJL" => "Educational: Philosophy & ethics",
    "YPJM" => "Educational: Law / legal studies",
    "YPJN" => "Educational: Religious studies",
    "YPJN1" => "Educational: Religious studies: Hinduism",
    "YPJN2" => "Educational: Religious studies: Buddhism",
    "YPJN3" => "Educational: Religious studies: Judaism",
    "YPJN4" => "Educational: Religious studies: Christianity",
    "YPJN5" => "Educational: Religious studies: Islam",
    "YPJN9" => "Educational: Religious studies: Other religions",
    "YPJT" => "Educational: Geography",
    "YPJV" => "Educational: Business studies & economics",
    "YPJV1" => "Educational: Economics",
    "YPJV2" => "Educational: Business administration & office skills",
    "YPJV3" => "Educational: Accounting",
    "YPM" => "Educational: Mathematics, science & technology, general",
    "YPMF" => "Educational: Mathematics & numeracy",
    "YPMF1" => "Educational: Mathematics & numeracy: arithmetic / times tables",
    "YPMP" => "Educational: Sciences, general science",
    "YPMP1" => "Educational: Biology",
    "YPMP3" => "Educational: Chemistry",
    "YPMP5" => "Educational: Physics",
    "YPMP51" => "Educational: Astronomy",
    "YPMP6" => "Educational: Environmental science",
    "YPMT" => "Educational: Technology",
    "YPMT2" => "Educational: Design & technology",
    "YPMT3" => "Educational: Engineering",
    "YPMT4" => "Educational: Food technology, cooking skills",
    "YPMT5" => "Educational: Electronics",
    "YPMT6" => "Educational: IT & computing, ICT",
    "YPMT7" => "Educational: Technical drawing",
    "YPMT8" => "Educational: Woodwork, metalwork, etc",
    "YPW" => "Educational: Vocational & other subjects",
    "YPWB" => "Education: Family & consumer sciences / domestic management",
    "YPWC" => "Educational: Other vocational education & training",
    "YPWC1" => "Educational: Health & social care",
    "YPWC2" => "Educational: Child care / Child development",
    "YPWC3" => "Educational: Sales & retail skills",
    "YPWC4" => "Educational: Hospitality",
    "YPWC5" => "Educational: Hairdressing, salon & beauty therapy skills",
    "YPWC9" => "Educational: Work experience / Careers",
    "YPWF" => "Educational: Physical education",
    "YPWL" => "Educational: General studies / study skills general",
    "YPZ" => "Educational: study & revision guides",
    "YPZN" => "Education: Non-Verbal reasoning",
    "YPZP" => "Education: Verbal reasoning",
    "YR" => "Children’s / Teenage reference material",
    "YRD" => "Children’s / Teenage reference: Dictionaries and language reference",
    "YRDC" => "Children’s / Teenage reference: Picture dictionaries",
    "YRDL" => "Children’s / Teenage reference: Bilingual / multilingual dictionaries",
    "YRDM" => "Children’s / Teenage reference: Non-native language study and reference",
    "YRE" => "Children’s / Teenage reference: Encyclopaedias, general reference",
    "YRG" => "Children’s / Teenage reference: Subject-specific reference",
    "YRW" => "Children’s / Teenage reference: Atlases & maps",
    "YX" => "Children’s / Teenage: Personal & social topics",
    "YXA" => "Children’s / Teenage personal & social topics: Body & health",
    "YXAB" => "Children’s / Teenage personal & social topics: Fitness, exercise & healthy eating",
    "YXAX" => "Children’s / Teenage personal & social topics: Sex education & the facts of life",
    "YXB" => "Children’s / Teenage personal & social topics: LGBT",
    "YXC" => "Children’s / Teenage personal & social topics: Gender identity",
    "YXD" => "Children’s / Teenage personal & social topics: Self-awareness & self-esteem",
    "YXE" => "Children’s / Teenage personal & social topics: Emotions, moods & feelings",
    "YXF" => "Children’s / Teenage personal & social topics: Families & family issues",
    "YXFD" => "Children’s / Teenage personal & social topics: Divorce, separation, family break-up",
    "YXFF" => "Children’s / Teenage personal & social topics: Adoption / fostering",
    "YXFS" => "Children’s / Teenage personal & social topics: New baby",
    "YXG" => "Children’s / Teenage personal & social topics: Death & bereavement",
    "YXGS" => "Children’s / Teenage personal & social topics: Suicide",
    "YXH" => "Children’s / Teenage personal & social topics: Relationships (non-family)",
    "YXHB" => "Children’s / Teenage personal & social topics: Friends & friendship issues",
    "YXHL" => "Children’s / Teenage personal & social topics: Dating, relationships & love",
    "YXHY" => "Children’s / Teenage personal & social topics: Teenage pregnancy",
    "YXJ" => "Children’s / Teenage personal & social topics: Drugs & addiction",
    "YXK" => "Children’s / Teenage personal & social topics: Disability & special needs",
    "YXL" => "Children’s / Teenage personal & social topics: Physical & mental health conditions",
    "YXLB" => "Children’s / Teenage personal & social topics: Illness & specific physical health conditions",
    "YXLB1" => "Children’s / Teenage personal & social topics: Cancer",
    "YXLD" => "Children’s / Teenage personal & social topics: Mental health",
    "YXLD1" => "Children’s / Teenage personal & social topics: Eating disorders",
    "YXLD2" => "Children’s / Teenage personal & social topics: Anxiety, depression & self-harm",
    "YXLD6" => "Children’s / Teenage personal & social topics: Positive / good mental health",
    "YXN" => "Children’s / Teenage personal & social topics: Racism & multiculturalism",
    "YXP" => "Children’s / Teenage personal & social topics: Diversity / inclusivity",
    "YXPB" => "Children’s / Teenage personal & social topics: Prejudice & intolerance",
    "YXQ" => "Children’s / Teenage personal & social topics: Bullying, violence, abuse & peer pressure",
    "YXQD" => "Children’s / Teenage personal & social topics: Abuse",
    "YXQF" => "Children’s / Teenage personal & social topics: Bullying & harassment",
    "YXR" => "Children’s / Teenage personal & social topics: Personal safety",
    "YXS" => "Children’s / Teenage personal & social topics: Runaways",
    "YXT" => "Children’s / Teenage personal & social topics: Truancy & school problems",
    "YXV" => "Teenage personal & social topics: Advice on careers & further education, leaving school",
    "YXW" => "Children’s / Teenage personal & social topics: First experiences & growing up",
    "YXZ" => "Children’s / Teenage: Social issues",
    "YXZG" => "Children’s / Teenage social issues: Environment & green issues",
    "YXZM" => "Children’s / Teenage social issues: Migration & refugees",
    "YXZR" => "Children’s / Teenage social issues: Religious issues",
    "YXZW" => "Children’s / Teenage social issues: War & conflict issues",
    "YZ" => "Children’s / Teenage stationery & miscellaneous items",
    "YZG" => "Children’s gift books",
    "YZS" => "Children’s stationery items",
    "YZSN" => "Blank children’s stationery items",
    "1A" => "World",
    "1D" => "Europe",
    "1DD" => "Western Europe",
    "1DDB" => "Belgium",
    "1DDB-BE-B" => "Brussels",
    "1DDB-BE-F" => "Flanders",
    "1DDB-BE-FA" => "Antwerp (Province)",
    "1DDB-BE-FAA" => "Antwerp",
    "1DDB-BE-FB" => "Flemish Brabant",
    "1DDB-BE-FBA" => "Leuven",
    "1DDB-BE-FC" => "Limburg (BE)",
    "1DDB-BE-FCA" => "Hasselt",
    "1DDB-BE-FD" => "East Flanders",
    "1DDB-BE-FDA" => "Ghent",
    "1DDB-BE-FE" => "West Flanders",
    "1DDB-BE-FEA" => "Bruges",
    "1DDB-BE-W" => "Wallonia / Wallonie",
    "1DDB-BE-WA" => "Wallonian Brabant",
    "1DDB-BE-WAA" => "Wavre",
    "1DDB-BE-WB" => "Hainaut",
    "1DDB-BE-WBA" => "Mons",
    "1DDB-BE-WBB" => "Charleroi",
    "1DDB-BE-WC" => "Liège (Province)",
    "1DDB-BE-WCA" => "Liège",
    "1DDB-BE-WD" => "Luxembourg (Province)",
    "1DDB-BE-WDA" => "Arlon / Arlen",
    "1DDB-BE-WE" => "Namur (Province)",
    "1DDB-BE-WEA" => "Namur",
    "1DDF" => "France",
    "1DDF-FR-X" => "Regions of France",
    "1DDF-FR-XA" => "Auvergne-Rhône-Alpes",
    "1DDF-FR-C" => "Auvergne",
    "1DDF-FR-CA" => "Allier",
    "1DDF-FR-CAA" => "Moulins",
    "1DDF-FR-CAB" => "Montluçon",
    "1DDF-FR-CAC" => "Vichy",
    "1DDF-FR-CB" => "Cantal",
    "1DDF-FR-CBA" => "Aurillac",
    "1DDF-FR-CBB" => "Mauriac",
    "1DDF-FR-CBC" => "Saint-Flour",
    "1DDF-FR-CC" => "Haute-Loire",
    "1DDF-FR-CCA" => "Le Puy-en-Velay",
    "1DDF-FR-CCB" => "Brioude",
    "1DDF-FR-CCC" => "Yssingeaux",
    "1DDF-FR-CD" => "Puy-de-Dôme",
    "1DDF-FR-CDA" => "Clermont-Ferrand",
    "1DDF-FR-CDB" => "Ambert",
    "1DDF-FR-CDC" => "Issoire",
    "1DDF-FR-CDD" => "Riom",
    "1DDF-FR-CDE" => "Thiers",
    "1DDF-FR-V" => "Rhône-Alpes",
    "1DDF-FR-VA" => "Ain",
    "1DDF-FR-VAA" => "Bourg-en-Bresse",
    "1DDF-FR-VAB" => "Belley",
    "1DDF-FR-VAC" => "Gex",
    "1DDF-FR-VAD" => "Nantua",
    "1DDF-FR-VB" => "Ardèche",
    "1DDF-FR-VBA" => "Privas",
    "1DDF-FR-VBB" => "Largentière",
    "1DDF-FR-VBC" => "Tournon-sur-Rhône",
    "1DDF-FR-VC" => "Drôme",
    "1DDF-FR-VCA" => "Valence",
    "1DDF-FR-VCB" => "Die",
    "1DDF-FR-VCC" => "Nyons",
    "1DDF-FR-VD" => "Isère",
    "1DDF-FR-VDA" => "Grenoble",
    "1DDF-FR-VDB" => "La Tour-du-Pin",
    "1DDF-FR-VDC" => "Vienne (Isère)",
    "1DDF-FR-VE" => "Loire",
    "1DDF-FR-VEA" => "Saint-Étienne",
    "1DDF-FR-VEB" => "Montbrison",
    "1DDF-FR-VEC" => "Roanne",
    "1DDF-FR-VF" => "Rhône",
    "1DDF-FR-VFA" => "Lyon",
    "1DDF-FR-VFB" => "Villefranche-sur-Saône",
    "1DDF-FR-VG" => "Savoy",
    "1DDF-FR-VGA" => "Chambéry",
    "1DDF-FR-VGB" => "Albertville",
    "1DDF-FR-VGC" => "Saint-Jean-de-Maurienne",
    "1DDF-FR-VH" => "Haute-Savoie",
    "1DDF-FR-VHA" => "Annecy",
    "1DDF-FR-VHB" => "Bonneville",
    "1DDF-FR-VHC" => "Chamonix",
    "1DDF-FR-VHD" => "Saint-Julien-en-Genevois",
    "1DDF-FR-VHE" => "Thonon-les-Bains",
    "1DDF-FR-XAZ" => "Auvergne-Rhône-Alpes: Places of interest",
    "1DDF-FR-XAZB" => "Bourbonnais",
    "1DDF-FR-XAZF" => "Forez / Livradois",
    "1DDF-FR-XAZG" => "Beaujolais",
    "1DDF-FR-XAZH" => "Dauphiné / Dauphiny",
    "1DDF-FR-XAZK" => "Chablais",
    "1DDF-FR-XB" => "Bourgogne-Franche-Comté",
    "1DDF-FR-E" => "Burgundy",
    "1DDF-FR-EA" => "Côte-d’Or",
    "1DDF-FR-EAA" => "Dijon",
    "1DDF-FR-EAB" => "Beaune",
    "1DDF-FR-EAC" => "Montbard",
    "1DDF-FR-EB" => "Nièvre",
    "1DDF-FR-EBA" => "Nevers",
    "1DDF-FR-EBB" => "Château-Chinon & the Morvan",
    "1DDF-FR-EBC" => "Clamecy",
    "1DDF-FR-EBD" => "Cosne-Cours-sur-Loire",
    "1DDF-FR-EC" => "Saône-et-Loire",
    "1DDF-FR-ECA" => "Mâcon & the Mâconnais",
    "1DDF-FR-ECB" => "Autun",
    "1DDF-FR-ECC" => "Chalon-sur-Saône & the Chalonnais",
    "1DDF-FR-ECD" => "Charolles & the Charolais",
    "1DDF-FR-ECE" => "Louhans",
    "1DDF-FR-ED" => "Yonne",
    "1DDF-FR-EDA" => "Auxerre",
    "1DDF-FR-EDB" => "Avallon",
    "1DDF-FR-J" => "Franche-Comté",
    "1DDF-FR-JA" => "Doubs",
    "1DDF-FR-JAA" => "Montbéliard",
    "1DDF-FR-JAB" => "Besançon",
    "1DDF-FR-JAC" => "Pontarlier",
    "1DDF-FR-JB" => "Jura (39)",
    "1DDF-FR-JBA" => "Lons-le-Saunier",
    "1DDF-FR-JBB" => "Dole",
    "1DDF-FR-JBC" => "Saint-Claude",
    "1DDF-FR-JC" => "Haute-Saône",
    "1DDF-FR-JCA" => "Vesoul",
    "1DDF-FR-JCB" => "Lure",
    "1DDF-FR-JD" => "Territoire de Belfort",
    "1DDF-FR-JDA" => "Belfort",
    "1DDF-FR-XC" => "Occitanie",
    "1DDF-FR-M" => "Languedoc-Roussillon",
    "1DDF-FR-MA" => "Aude",
    "1DDF-FR-MAA" => "Carcassonne",
    "1DDF-FR-MAB" => "Limoux",
    "1DDF-FR-MAC" => "Narbonne",
    "1DDF-FR-MAD" => "Rennes-le-Château",
    "1DDF-FR-MB" => "Gard",
    "1DDF-FR-MBA" => "Nîmes",
    "1DDF-FR-MBB" => "Alès",
    "1DDF-FR-MBC" => "Le Vigan",
    "1DDF-FR-MC" => "Hérault",
    "1DDF-FR-MCA" => "Montpellier",
    "1DDF-FR-MCB" => "Béziers",
    "1DDF-FR-MCC" => "Lodève",
    "1DDF-FR-MD" => "Lozère",
    "1DDF-FR-MDA" => "Mende",
    "1DDF-FR-MDB" => "Florac Trois Rivières",
    "1DDF-FR-ME" => "Pyrénées-Orientales",
    "1DDF-FR-MEA" => "Perpignan",
    "1DDF-FR-MEB" => "Céret",
    "1DDF-FR-MEC" => "Prades",
    "1DDF-FR-P" => "Midi-Pyrénées",
    "1DDF-FR-PA" => "Ariège",
    "1DDF-FR-PAA" => "Foix",
    "1DDF-FR-PAB" => "Pamiers",
    "1DDF-FR-PAC" => "Saint-Girons",
    "1DDF-FR-PB" => "Aveyron",
    "1DDF-FR-PBA" => "Rodez",
    "1DDF-FR-PBB" => "Millau",
    "1DDF-FR-PBC" => "Villefranche-de-Rouergue",
    "1DDF-FR-PC" => "Haute-Garonne",
    "1DDF-FR-PCA" => "Toulouse",
    "1DDF-FR-PCB" => "Muret",
    "1DDF-FR-PCC" => "Saint-Gaudens",
    "1DDF-FR-PD" => "Gers",
    "1DDF-FR-PDA" => "Auch",
    "1DDF-FR-PDB" => "Condom",
    "1DDF-FR-PDC" => "Mirande",
    "1DDF-FR-PE" => "Lot",
    "1DDF-FR-PEA" => "Cahors",
    "1DDF-FR-PEB" => "Figeac",
    "1DDF-FR-PEC" => "Gourdon",
    "1DDF-FR-PF" => "Hautes-Pyrénées",
    "1DDF-FR-PFA" => "Tarbes",
    "1DDF-FR-PFB" => "Argelès-Gazost",
    "1DDF-FR-PFC" => "Bagnères-de-Bigorre",
    "1DDF-FR-PFD" => "Lourdes",
    "1DDF-FR-PG" => "Tarn",
    "1DDF-FR-PGA" => "Albi",
    "1DDF-FR-PGB" => "Castres",
    "1DDF-FR-PH" => "Tarn-et-Garonne",
    "1DDF-FR-PHA" => "Montauban",
    "1DDF-FR-PHB" => "Castelsarrasin",
    "1DDF-FR-XCZ" => "Occitanie: Places of interest",
    "1DDF-FR-XCZA" => "Armagnac",
    "1DDF-FR-XCZB" => "Aubrac",
    "1DDF-FR-XCZC" => "Cévennes",
    "1DDF-FR-XCZG" => "Gévaudan",
    "1DDF-FR-XCZL" => "Languedoc",
    "1DDF-FR-XCZM" => "Canal du Midi",
    "1DDF-FR-XCZN" => "Causses",
    "1DDF-FR-XCZQ" => "Quercy",
    "1DDF-FR-XCZR" => "Roussillion",
    "1DDF-FR-XE" => "Grand-Est",
    "1DDF-FR-A" => "Alsace",
    "1DDF-FR-AA" => "Bas-Rhin",
    "1DDF-FR-AAA" => "Strasbourg",
    "1DDF-FR-AAB" => "Haguenau",
    "1DDF-FR-AAC" => "Molsheim",
    "1DDF-FR-AAD" => "Saverne",
    "1DDF-FR-AAE" => "Sélestat",
    "1DDF-FR-AB" => "Haut-Rhin",
    "1DDF-FR-ABA" => "Colmar",
    "1DDF-FR-ABB" => "Altkirch",
    "1DDF-FR-ABC" => "Mulhouse",
    "1DDF-FR-ABD" => "Thann",
    "1DDF-FR-H" => "Champagne-Ardenne",
    "1DDF-FR-HA" => "Ardennes",
    "1DDF-FR-HAA" => "Sedan",
    "1DDF-FR-HAB" => "Charleville-Mézières",
    "1DDF-FR-HAC" => "Rethel",
    "1DDF-FR-HAD" => "Vouziers",
    "1DDF-FR-HB" => "Aube",
    "1DDF-FR-HBA" => "Troyes",
    "1DDF-FR-HBB" => "Bar-sur-Aube",
    "1DDF-FR-HBC" => "Nogent-sur-Seine",
    "1DDF-FR-HC" => "Marne",
    "1DDF-FR-HCA" => "Châlons-en-Champagne",
    "1DDF-FR-HCB" => "Épernay",
    "1DDF-FR-HCC" => "Reims",
    "1DDF-FR-HCD" => "Sainte-Menehould",
    "1DDF-FR-HCE" => "Vitry-le-François",
    "1DDF-FR-HD" => "Haute-Marne",
    "1DDF-FR-HDA" => "Chaumont",
    "1DDF-FR-HDB" => "Langres",
    "1DDF-FR-HDC" => "Saint-Dizier",
    "1DDF-FR-O" => "Lorraine",
    "1DDF-FR-OA" => "Meurthe-et-Moselle",
    "1DDF-FR-OAA" => "Nancy",
    "1DDF-FR-OAB" => "Lunéville",
    "1DDF-FR-OAC" => "Toul",
    "1DDF-FR-OAD" => "Val-de-Briey",
    "1DDF-FR-OB" => "Meuse",
    "1DDF-FR-OBA" => "Bar-le-Duc",
    "1DDF-FR-OBB" => "Commercy",
    "1DDF-FR-OBC" => "Verdun",
    "1DDF-FR-OC" => "Moselle",
    "1DDF-FR-OCA" => "Metz",
    "1DDF-FR-OCB" => "Thionville",
    "1DDF-FR-OCC" => "Sarreguemines",
    "1DDF-FR-OCD" => "Sarrebourg",
    "1DDF-FR-OCE" => "Forbach",
    "1DDF-FR-OD" => "Vosges",
    "1DDF-FR-ODA" => "Épinal",
    "1DDF-FR-ODB" => "Neufchâteau",
    "1DDF-FR-ODC" => "Saint-Dié-des-Vosges",
    "1DDF-FR-XEZ" => "Grand-Est: Places of interest",
    "1DDF-FR-XEZC" => "Champagne",
    "1DDF-FR-XEZV" => "Vosges Mountains",
    "1DDF-FR-F" => "Brittany",
    "1DDF-FR-FA" => "Côtes-d’Armor",
    "1DDF-FR-FAA" => "Saint-Brieuc",
    "1DDF-FR-FAB" => "Dinan",
    "1DDF-FR-FAC" => "Guingamp",
    "1DDF-FR-FAD" => "Lannion",
    "1DDF-FR-FB" => "Finistère",
    "1DDF-FR-FBA" => "Quimper",
    "1DDF-FR-FBB" => "Brest",
    "1DDF-FR-FBC" => "Châteaulin",
    "1DDF-FR-FBD" => "Morlaix",
    "1DDF-FR-FC" => "Ille-et-Vilaine",
    "1DDF-FR-FCA" => "Rennes",
    "1DDF-FR-FCB" => "Fougères",
    "1DDF-FR-FCC" => "Redon",
    "1DDF-FR-FCD" => "Saint-Malo",
    "1DDF-FR-FD" => "Morbihan",
    "1DDF-FR-FDA" => "Vannes",
    "1DDF-FR-FDB" => "Lorient",
    "1DDF-FR-FDC" => "Pontivy",
    "1DDF-FR-FDD" => "Carnac",
    "1DDF-FR-FZ" => "Brittany: Places of interest",
    "1DDF-FR-FZC" => "Cornouaille",
    "1DDF-FR-G" => "Centre-Val de Loire",
    "1DDF-FR-GA" => "Cher",
    "1DDF-FR-GAA" => "Saint-Amand-Montrond",
    "1DDF-FR-GAB" => "Bourges",
    "1DDF-FR-GAC" => "Vierzon",
    "1DDF-FR-GAD" => "Sancerre",
    "1DDF-FR-GB" => "Eure-et-Loir",
    "1DDF-FR-GBA" => "Chartres",
    "1DDF-FR-GBB" => "Châteaudun",
    "1DDF-FR-GBC" => "Dreux",
    "1DDF-FR-GBD" => "Nogent-le-Rotrou",
    "1DDF-FR-GC" => "Indre",
    "1DDF-FR-GCA" => "Châteauroux",
    "1DDF-FR-GCB" => "Le Blanc",
    "1DDF-FR-GCC" => "La Châtre",
    "1DDF-FR-GCD" => "Issoudun",
    "1DDF-FR-GD" => "Indre-et-Loire",
    "1DDF-FR-GDA" => "Tours",
    "1DDF-FR-GDB" => "Chinon",
    "1DDF-FR-GDC" => "Loches",
    "1DDF-FR-GE" => "Loir-et-Cher",
    "1DDF-FR-GEA" => "Blois",
    "1DDF-FR-GEB" => "Romorantin-Lanthenay",
    "1DDF-FR-GEC" => "Vendôme",
    "1DDF-FR-GF" => "Loiret",
    "1DDF-FR-GFA" => "Orléans",
    "1DDF-FR-GFB" => "Montargis",
    "1DDF-FR-GFC" => "Pithiviers",
    "1DDF-FR-GZ" => "Centre-Val de Loire: Places of interest",
    "1DDF-FR-GZB" => "Berry",
    "1DDF-FR-GZS" => "Sologne",
    "1DDF-FR-GZT" => "Touraine",
    "1DDF-FR-XH" => "Hauts-de-France",
    "1DDF-FR-Q" => "Nord-Pas-de-Calais",
    "1DDF-FR-QA" => "Nord",
    "1DDF-FR-QAA" => "Lille",
    "1DDF-FR-QAB" => "Avesnes-sur-Helpe",
    "1DDF-FR-QAC" => "Cambrai",
    "1DDF-FR-QAD" => "Douai",
    "1DDF-FR-QAE" => "Dunkirk",
    "1DDF-FR-QAF" => "Valenciennes",
    "1DDF-FR-QB" => "Pas-de-Calais",
    "1DDF-FR-QBA" => "Arras",
    "1DDF-FR-QBB" => "Béthune",
    "1DDF-FR-QBC" => "Boulogne",
    "1DDF-FR-QBD" => "Calais",
    "1DDF-FR-QBE" => "Lens",
    "1DDF-FR-QBF" => "Montreuil",
    "1DDF-FR-QBG" => "Saint-Omer",
    "1DDF-FR-S" => "Picardy",
    "1DDF-FR-SA" => "Aisne",
    "1DDF-FR-SAA" => "Laon",
    "1DDF-FR-SAB" => "Château-Thierry",
    "1DDF-FR-SAC" => "Saint-Quentin",
    "1DDF-FR-SAD" => "Soissons",
    "1DDF-FR-SAE" => "Vervins",
    "1DDF-FR-SB" => "Oise",
    "1DDF-FR-SBA" => "Beauvais",
    "1DDF-FR-SBB" => "Clermont",
    "1DDF-FR-SBC" => "Compiègne",
    "1DDF-FR-SBD" => "Senlis",
    "1DDF-FR-SC" => "Somme",
    "1DDF-FR-SCA" => "Amiens",
    "1DDF-FR-SCB" => "Abbeville",
    "1DDF-FR-SCC" => "Montdidier",
    "1DDF-FR-SCD" => "Péronne",
    "1DDF-FR-XHZ" => "Hauts-de-France: Places of interest",
    "1DDF-FR-XHZA" => "Artois",
    "1DDF-FR-I" => "Corsica",
    "1DDF-FR-IA" => "Corse-du-Sud",
    "1DDF-FR-IAA" => "Ajaccio",
    "1DDF-FR-IAB" => "Sartène",
    "1DDF-FR-IB" => "Haute-Corse",
    "1DDF-FR-IBA" => "Bastia",
    "1DDF-FR-IBB" => "Calvi",
    "1DDF-FR-IBC" => "Corte",
    "1DDF-FR-L" => "Île-de-France",
    "1DDF-FR-LA" => "Paris (75)",
    "1DDF-FR-LAA" => "Paris",
    "1DDF-FR-LB" => "Seine-et-Marne",
    "1DDF-FR-LBA" => "Melun",
    "1DDF-FR-LBB" => "Fontainebleau",
    "1DDF-FR-LBC" => "Meaux",
    "1DDF-FR-LBD" => "Provins",
    "1DDF-FR-LBE" => "Torcy",
    "1DDF-FR-LC" => "Yvelines",
    "1DDF-FR-LCA" => "Versailles",
    "1DDF-FR-LCB" => "Mantes-la-Jolie",
    "1DDF-FR-LCC" => "Rambouillet",
    "1DDF-FR-LCD" => "Saint-Germain-en-Laye",
    "1DDF-FR-LD" => "Essonne",
    "1DDF-FR-LDA" => "Évry",
    "1DDF-FR-LDB" => "Étampes",
    "1DDF-FR-LDC" => "Palaiseau",
    "1DDF-FR-LE" => "Hauts-de-Seine",
    "1DDF-FR-LEA" => "Nanterre",
    "1DDF-FR-LEB" => "Antony",
    "1DDF-FR-LEC" => "Boulogne-Billancourt",
    "1DDF-FR-LF" => "Seine-Saint-Denis",
    "1DDF-FR-LFA" => "Bobigny",
    "1DDF-FR-LFB" => "Le Raincy",
    "1DDF-FR-LFC" => "Saint-Denis",
    "1DDF-FR-LG" => "Val-de-Marne",
    "1DDF-FR-LGA" => "Créteil",
    "1DDF-FR-LGB" => "L’Haÿ-les-Roses",
    "1DDF-FR-LGC" => "Nogent-sur-Marne",
    "1DDF-FR-LH" => "Val-d’Oise",
    "1DDF-FR-LHA" => "Pontoise",
    "1DDF-FR-LHB" => "Argenteuil",
    "1DDF-FR-LHC" => "Sarcelles",
    "1DDF-FR-LZ" => "Î̂le-de-France: Places of interest",
    "1DDF-FR-LZB" => "Brie",
    "1DDF-FR-LZV" => "Vexin",
    "1DDF-FR-XN" => "Normandy",
    "1DDF-FR-D" => "Basse-Normandie",
    "1DDF-FR-DA" => "Calvados",
    "1DDF-FR-DAA" => "Caen",
    "1DDF-FR-DAB" => "Bayeux",
    "1DDF-FR-DAC" => "Lisieux",
    "1DDF-FR-DAD" => "Vire-Normandie",
    "1DDF-FR-DB" => "Manche",
    "1DDF-FR-DBA" => "Saint-Lô",
    "1DDF-FR-DBB" => "Avranches",
    "1DDF-FR-DBC" => "Cherbourg-en-Cotentin",
    "1DDF-FR-DBD" => "Coutances",
    "1DDF-FR-DBE" => "Mont Saint-Michel",
    "1DDF-FR-DC" => "Orne",
    "1DDF-FR-DCA" => "Alençon",
    "1DDF-FR-DCB" => "Argentan",
    "1DDF-FR-DCC" => "Mortagne-au-Perche",
    "1DDF-FR-K" => "Haute-Normandie",
    "1DDF-FR-KA" => "Eure",
    "1DDF-FR-KAA" => "Évreux",
    "1DDF-FR-KAB" => "Les Andelys",
    "1DDF-FR-KAC" => "Bernay",
    "1DDF-FR-KB" => "Seine-Maritime",
    "1DDF-FR-KBA" => "Rouen",
    "1DDF-FR-KBB" => "Dieppe",
    "1DDF-FR-KBC" => "Le Havre",
    "1DDF-FR-XNZ" => "Normandy: Places of interest",
    "1DDF-FR-XNZB" => "Normandy Beaches",
    "1DDF-FR-XNZD" => "Perche",
    "1DDF-FR-XNZF" => "Pays d’Auge",
    "1DDF-FR-XNZH" => "Pays de Caux",
    "1DDF-FR-XQ" => "Nouvelle-Aquitaine",
    "1DDF-FR-B" => "Aquitaine",
    "1DDF-FR-BA" => "Dordogne",
    "1DDF-FR-BAA" => "Périgueux",
    "1DDF-FR-BAB" => "Bergerac",
    "1DDF-FR-BAC" => "Nontron",
    "1DDF-FR-BAD" => "Sarlat-la-Canéda",
    "1DDF-FR-BB" => "Gironde",
    "1DDF-FR-BBA" => "Bordeaux",
    "1DDF-FR-BBB" => "Arcachon",
    "1DDF-FR-BBC" => "Blaye",
    "1DDF-FR-BBD" => "Langon",
    "1DDF-FR-BBE" => "Lesparre-Médoc",
    "1DDF-FR-BBF" => "Libourne",
    "1DDF-FR-BBG" => "Saint-Émilion",
    "1DDF-FR-BC" => "Landes",
    "1DDF-FR-BCA" => "Mont-de-Marsan",
    "1DDF-FR-BCB" => "Dax",
    "1DDF-FR-BD" => "Lot-et-Garonne",
    "1DDF-FR-BDA" => "Agen",
    "1DDF-FR-BDB" => "Marmande",
    "1DDF-FR-BDC" => "Nérac",
    "1DDF-FR-BDD" => "Villeneuve-sur-Lot",
    "1DDF-FR-BE" => "Pyrénées-Atlantiques",
    "1DDF-FR-BEA" => "Pau",
    "1DDF-FR-BEB" => "Bayonne",
    "1DDF-FR-BEC" => "Biarritz",
    "1DDF-FR-BED" => "Oloron-Sainte-Marie",
    "1DDF-FR-N" => "Limousin",
    "1DDF-FR-NA" => "Corrèze",
    "1DDF-FR-NAA" => "Tulle",
    "1DDF-FR-NAB" => "Brive-la-Gaillarde",
    "1DDF-FR-NAC" => "Ussel",
    "1DDF-FR-NB" => "Creuse",
    "1DDF-FR-NBA" => "Guéret",
    "1DDF-FR-NBB" => "Aubusson",
    "1DDF-FR-NC" => "Haute-Vienne",
    "1DDF-FR-NCA" => "Limoges",
    "1DDF-FR-NCB" => "Bellac",
    "1DDF-FR-NCC" => "Rochechouart",
    "1DDF-FR-T" => "Poitou-Charentes",
    "1DDF-FR-TA" => "Charente",
    "1DDF-FR-TAA" => "Angoulême",
    "1DDF-FR-TAB" => "Cognac",
    "1DDF-FR-TAC" => "Confolens",
    "1DDF-FR-TB" => "Charente-Maritime",
    "1DDF-FR-TBA" => "La Rochelle",
    "1DDF-FR-TBB" => "Jonzac",
    "1DDF-FR-TBC" => "Rochefort",
    "1DDF-FR-TBD" => "Saint-Jean-d’Angély",
    "1DDF-FR-TBE" => "Saintes",
    "1DDF-FR-TC" => "Deux-Sèvres",
    "1DDF-FR-TCA" => "Niort",
    "1DDF-FR-TCB" => "Bressuire",
    "1DDF-FR-TCC" => "Parthenay",
    "1DDF-FR-TD" => "Vienne (86)",
    "1DDF-FR-TDA" => "Poitiers",
    "1DDF-FR-TDB" => "Châtellerault",
    "1DDF-FR-TDC" => "Montmorillon",
    "1DDF-FR-XQZ" => "Nouvelle-Aquitaine: Places of interest",
    "1DDF-FR-XQZB" => "Béarn",
    "1DDF-FR-XQZD" => "Gascony",
    "1DDF-FR-XQZG" => "Guyenne",
    "1DDF-FR-XQZH" => "Navarre (Lower)",
    "1DDF-FR-XQZJ" => "Périgord",
    "1DDF-FR-XQZK" => "Poitou",
    "1DDF-FR-XQZL" => "Lascaux",
    "1DDF-FR-XQZM" => "La Marche (Province)",
    "1DDF-FR-R" => "Pays de la Loire",
    "1DDF-FR-RA" => "Loire-Atlantique",
    "1DDF-FR-RAA" => "Saint-Nazaire",
    "1DDF-FR-RAB" => "Nantes",
    "1DDF-FR-RAC" => "Châteaubriant",
    "1DDF-FR-RB" => "Maine-et-Loire",
    "1DDF-FR-RBA" => "Angers",
    "1DDF-FR-RBB" => "Saumur",
    "1DDF-FR-RBC" => "Cholet",
    "1DDF-FR-RBD" => "Segré",
    "1DDF-FR-RC" => "Mayenne",
    "1DDF-FR-RCA" => "Laval",
    "1DDF-FR-RCB" => "Château-Gontier",
    "1DDF-FR-RD" => "Sarthe",
    "1DDF-FR-RDA" => "Le Mans",
    "1DDF-FR-RDB" => "La Flèche",
    "1DDF-FR-RDC" => "Mamers",
    "1DDF-FR-RE" => "Vendée",
    "1DDF-FR-REA" => "La Roche-sur-Yon",
    "1DDF-FR-REB" => "Fontenay-le-Comte",
    "1DDF-FR-REC" => "Les Sables-d’Olonne",
    "1DDF-FR-RZ" => "Pays de la Loire: Places of interest",
    "1DDF-FR-RZA" => "Anjou",
    "1DDF-FR-RZM" => "Maine (province)",
    "1DDF-FR-U" => "Provence-Alpes-Côte d’Azur",
    "1DDF-FR-UA" => "Alpes-de-Haute-Provence",
    "1DDF-FR-UAA" => "Digne-les-Bains",
    "1DDF-FR-UAB" => "Barcelonnette",
    "1DDF-FR-UAC" => "Castellane",
    "1DDF-FR-UAD" => "Forcalquier",
    "1DDF-FR-UB" => "Hautes-Alpes",
    "1DDF-FR-UBA" => "Gap",
    "1DDF-FR-UBB" => "Briançon",
    "1DDF-FR-UC" => "Alpes-Maritimes",
    "1DDF-FR-UCA" => "Nice",
    "1DDF-FR-UCB" => "Grasse",
    "1DDF-FR-UCC" => "Cannes",
    "1DDF-FR-UD" => "Bouches-du-Rhône",
    "1DDF-FR-UDA" => "Marseille",
    "1DDF-FR-UDB" => "Aix-en-Provence",
    "1DDF-FR-UDC" => "Arles",
    "1DDF-FR-UDD" => "Istres",
    "1DDF-FR-UE" => "Var",
    "1DDF-FR-UEA" => "Toulon",
    "1DDF-FR-UEB" => "Brignoles",
    "1DDF-FR-UEC" => "Saint-Tropez",
    "1DDF-FR-UED" => "Draguignan",
    "1DDF-FR-UF" => "Vaucluse",
    "1DDF-FR-UFA" => "Avignon",
    "1DDF-FR-UFB" => "Apt",
    "1DDF-FR-UFC" => "Carpentras",
    "1DDF-FR-UFD" => "Orange",
    "1DDF-FR-UZ" => "Provence-Alpes-Côte d’Azur: Places of interest",
    "1DDF-FR-UZC" => "French Riviera / Côte d’Azur",
    "1DDF-FR-UZD" => "The Luberon",
    "1DDF-FR-UZF" => "Mercantour",
    "1DDF-FR-UZG" => "Camargue",
    "1DDF-FR-UZP" => "Provence",
    "1DDF-FR-Z" => "France: Places of interest",
    "1DDF-FR-ZB" => "The Seine",
    "1DDF-FR-ZD" => "The Dordogne",
    "1DDF-FR-ZL" => "The Loire & the Loire Valley",
    "1DDF-FR-ZR" => "The Rhône",
    "1DDF-FR-ZS" => "Massif Central",
    "1DDL" => "Luxembourg",
    "1DDM" => "Monaco",
    "1DDN" => "Netherlands",
    "1DDN-NL-A" => "Amsterdam",
    "1DDN-NL-B" => "North Brabant",
    "1DDN-NL-BB" => "Breda",
    "1DDN-NL-BE" => "Eindhoven",
    "1DDN-NL-BH" => "s-Hertogenbosch",
    "1DDN-NL-BT" => "Tilburg",
    "1DDN-NL-D" => "Drenthe",
    "1DDN-NL-DA" => "Assen",
    "1DDN-NL-DE" => "Emmen",
    "1DDN-NL-F" => "Flevoland",
    "1DDN-NL-FA" => "Almere",
    "1DDN-NL-FL" => "Lelystad",
    "1DDN-NL-G" => "Gelderland",
    "1DDN-NL-GA" => "Arnhem",
    "1DDN-NL-GD" => "Apeldoorn",
    "1DDN-NL-GE" => "Ede",
    "1DDN-NL-GN" => "Nijmegen",
    "1DDN-NL-H" => "North Holland",
    "1DDN-NL-HH" => "Haarlem",
    "1DDN-NL-HM" => "Alkmaar",
    "1DDN-NL-L" => "Limburg (NL)",
    "1DDN-NL-LM" => "Maastricht",
    "1DDN-NL-LV" => "Venlo",
    "1DDN-NL-N" => "Groningen (province)",
    "1DDN-NL-NG" => "Groningen",
    "1DDN-NL-R" => "Friesland",
    "1DDN-NL-RL" => "Leeuwarden",
    "1DDN-NL-S" => "South Holland",
    "1DDN-NL-SA" => "Alphen aan den Rijn",
    "1DDN-NL-SC" => "Dordrecht",
    "1DDN-NL-SD" => "Delft",
    "1DDN-NL-SH" => "The Hague",
    "1DDN-NL-SL" => "Leiden",
    "1DDN-NL-SR" => "Rotterdam",
    "1DDN-NL-SZ" => "Zoetermeer",
    "1DDN-NL-U" => "Utrecht (province)",
    "1DDN-NL-UA" => "Amersfoort",
    "1DDN-NL-UU" => "Utrecht",
    "1DDN-NL-V" => "Overijssel",
    "1DDN-NL-VE" => "Enschede",
    "1DDN-NL-VZ" => "Zwolle",
    "1DDN-NL-Z" => "Zeeland",
    "1DDN-NL-ZG" => "Goes",
    "1DDN-NL-ZM" => "Middelburg",
    "1DDN-NL-ZV" => "Vlissingen",
    "1DDR" => "Ireland",
    "1DDR-IE-C" => "Connaught",
    "1DDR-IE-CG" => "County Galway",
    "1DDR-IE-CGC" => "Connemara",
    "1DDR-IE-CGD" => "The Twelve Bens",
    "1DDR-IE-CGG" => "Galway",
    "1DDR-IE-CL" => "Leitrim",
    "1DDR-IE-CM" => "Mayo",
    "1DDR-IE-CR" => "Roscommon",
    "1DDR-IE-CS" => "Sligo",
    "1DDR-IE-L" => "Leinster",
    "1DDR-IE-LC" => "Carlow",
    "1DDR-IE-LD" => "County Dublin",
    "1DDR-IE-LDD" => "Dublin",
    "1DDR-IE-LH" => "Louth",
    "1DDR-IE-LI" => "Wicklow",
    "1DDR-IE-LIM" => "The Wicklow Mountains",
    "1DDR-IE-LK" => "Kildare",
    "1DDR-IE-LL" => "Laois",
    "1DDR-IE-LM" => "Meath",
    "1DDR-IE-LMN" => "Newgrange",
    "1DDR-IE-LN" => "Longford",
    "1DDR-IE-LO" => "Offaly",
    "1DDR-IE-LW" => "Westmeath",
    "1DDR-IE-LX" => "Wexford",
    "1DDR-IE-LY" => "Kilkenny",
    "1DDR-IE-M" => "Munster",
    "1DDR-IE-MC" => "County Cork",
    "1DDR-IE-MCC" => "Cork",
    "1DDR-IE-MK" => "Kerry",
    "1DDR-IE-MKD" => "Dingle Peninsula",
    "1DDR-IE-MKK" => "Killarney",
    "1DDR-IE-MKR" => "Ring of Kerry",
    "1DDR-IE-MKS" => "Macgillycuddy’s Reeks",
    "1DDR-IE-ML" => "Clare",
    "1DDR-IE-MLB" => "The Burren",
    "1DDR-IE-MM" => "County Limerick",
    "1DDR-IE-MML" => "Limerick",
    "1DDR-IE-MT" => "Tipperary",
    "1DDR-IE-MW" => "Waterford",
    "1DDR-IE-U" => "Ulster",
    "1DDR-IE-UC" => "Cavan",
    "1DDR-IE-UD" => "Donegal",
    "1DDR-IE-UM" => "Monaghan",
    "1DDR-IE-Z" => "Ireland: Places of interest",
    "1DDR-IE-ZA" => "Atlantic Coast of Ireland",
    "1DDR-IE-ZS" => "The Shannon",
    "1DDU" => "United Kingdom, Great Britain",
    "1DDU-GB-E" => "England",
    "1DDU-GB-EA" => "East Anglia",
    "1DDU-GB-EAC" => "Cambridgeshire",
    "1DDU-GB-EACD" => "Cambridge",
    "1DDU-GB-EAN" => "Norfolk",
    "1DDU-GB-EAS" => "Suffolk",
    "1DDU-GB-EAX" => "Essex",
    "1DDU-GB-EAZ" => "East Anglia: Places of interest",
    "1DDU-GB-EAZF" => "The Fens & the Wash",
    "1DDU-GB-EAZN" => "Norfolk Broads",
    "1DDU-GB-EM" => "Midlands",
    "1DDU-GB-EMD" => "Derbyshire",
    "1DDU-GB-EMDD" => "Derby",
    "1DDU-GB-EMF" => "Herefordshire",
    "1DDU-GB-EMH" => "Leicestershire",
    "1DDU-GB-EMHL" => "Leicester",
    "1DDU-GB-EML" => "Lincolnshire",
    "1DDU-GB-EMLL" => "Lincoln (UK)",
    "1DDU-GB-EMM" => "Northamptonshire",
    "1DDU-GB-EMN" => "Nottinghamshire",
    "1DDU-GB-EMNN" => "Nottingham",
    "1DDU-GB-EMP" => "Shropshire",
    "1DDU-GB-EMR" => "Rutland",
    "1DDU-GB-EMS" => "Staffordshire",
    "1DDU-GB-EMSP" => "Stoke-on-Trent & The Potteries",
    "1DDU-GB-EMT" => "Worcestershire",
    "1DDU-GB-EMW" => "Warwickshire, West Midlands",
    "1DDU-GB-EMWB" => "Birmingham (UK)",
    "1DDU-GB-EMWC" => "Coventry",
    "1DDU-GB-EMWS" => "Stratford-upon-Avon",
    "1DDU-GB-EMWW" => "Wolverhampton & the Black Country",
    "1DDU-GB-EMZ" => "Midlands: Places of interest",
    "1DDU-GB-EMZD" => "The Peak District",
    "1DDU-GB-EMZM" => "Welsh Marches",
    "1DDU-GB-EN" => "North West England",
    "1DDU-GB-ENC" => "Cheshire",
    "1DDU-GB-ENL" => "Lancashire, Greater Manchester, Merseyside",
    "1DDU-GB-ENLB" => "Blackpool",
    "1DDU-GB-ENLL" => "Liverpool",
    "1DDU-GB-ENLM" => "Manchester",
    "1DDU-GB-ENM" => "Cumbria",
    "1DDU-GB-ENZ" => "North West England: Places of interest",
    "1DDU-GB-ENZL" => "The Lake District",
    "1DDU-GB-ES" => "South & South East England",
    "1DDU-GB-ESB" => "Berkshire",
    "1DDU-GB-ESBR" => "Reading",
    "1DDU-GB-ESBW" => "Windsor",
    "1DDU-GB-ESD" => "Bedfordshire",
    "1DDU-GB-ESF" => "Oxfordshire",
    "1DDU-GB-ESFX" => "Oxford",
    "1DDU-GB-ESH" => "Hampshire",
    "1DDU-GB-ESHS" => "Southampton & the Solent",
    "1DDU-GB-ESK" => "Kent",
    "1DDU-GB-ESKC" => "Canterbury",
    "1DDU-GB-ESL" => "London, Greater London",
    "1DDU-GB-ESLC" => "Central London",
    "1DDU-GB-ESLCW" => "Westminster",
    "1DDU-GB-ESLF" => "City of London",
    "1DDU-GB-ESR" => "Surrey",
    "1DDU-GB-EST" => "Hertfordshire",
    "1DDU-GB-ESU" => "Buckinghamshire",
    "1DDU-GB-ESUB" => "Bletchley Park",
    "1DDU-GB-ESW" => "Isle of Wight",
    "1DDU-GB-ESX" => "Sussex",
    "1DDU-GB-ESXB" => "Brighton & Hove",
    "1DDU-GB-ESZ" => "South & South East England: Places of interest",
    "1DDU-GB-ESZD" => "North & South Downs, the Weald",
    "1DDU-GB-ESZF" => "The New Forest",
    "1DDU-GB-ESZT" => "The Thames",
    "1DDU-GB-EW" => "South West England",
    "1DDU-GB-EWC" => "Cornwall",
    "1DDU-GB-EWCS" => "Isles of Scilly",
    "1DDU-GB-EWD" => "Devon",
    "1DDU-GB-EWDP" => "Plymouth",
    "1DDU-GB-EWG" => "Gloucestershire",
    "1DDU-GB-EWS" => "Somerset",
    "1DDU-GB-EWSB" => "Bristol",
    "1DDU-GB-EWSG" => "Glastonbury",
    "1DDU-GB-EWSH" => "Bath",
    "1DDU-GB-EWT" => "Dorset",
    "1DDU-GB-EWTB" => "Bournemouth & Poole",
    "1DDU-GB-EWW" => "Wiltshire",
    "1DDU-GB-EWWS" => "Salisbury",
    "1DDU-GB-EWZ" => "South West England: Places of interest",
    "1DDU-GB-EWZC" => "The Cotswolds",
    "1DDU-GB-EWZD" => "Jurassic Coast & Purbeck",
    "1DDU-GB-EWZM" => "Dartmoor, Exmoor & Bodmin Moor",
    "1DDU-GB-EWZS" => "Stonehenge",
    "1DDU-GB-EWZW" => "Wessex",
    "1DDU-GB-EY" => "North & North East England",
    "1DDU-GB-EYD" => "Durham",
    "1DDU-GB-EYK" => "Yorkshire",
    "1DDU-GB-EYKH" => "Hull",
    "1DDU-GB-EYKK" => "York",
    "1DDU-GB-EYKL" => "Leeds, Bradford",
    "1DDU-GB-EYKM" => "Middlesbrough & Teesside",
    "1DDU-GB-EYKS" => "Sheffield & Rotherham",
    "1DDU-GB-EYN" => "Northumberland, Tyne & Wear",
    "1DDU-GB-EYNC" => "Newcastle",
    "1DDU-GB-EYNS" => "Sunderland & Wearside",
    "1DDU-GB-EYZ" => "North & North East England: Places of interest",
    "1DDU-GB-EYZB" => "The Pennines",
    "1DDU-GB-EYZF" => "North York Moors",
    "1DDU-GB-EYZH" => "Yorkshire Dales",
    "1DDU-GB-EYZL" => "Farne Islands & Lindisfarne (Holy Island)",
    "1DDU-GB-EYZN" => "Northumberland National Park",
    "1DDU-GB-EYZW" => "Hadrian’s Wall",
    "1DDU-GB-N" => "Northern Ireland",
    "1DDU-GB-NB" => "Belfast",
    "1DDU-GB-NC" => "Antrim",
    "1DDU-GB-ND" => "Armagh",
    "1DDU-GB-NE" => "County Derry / County Londonderry",
    "1DDU-GB-NEC" => "Derry / Londonderry",
    "1DDU-GB-NG" => "Down",
    "1DDU-GB-NJ" => "Fermanagh",
    "1DDU-GB-NT" => "Tyrone",
    "1DDU-GB-NZ" => "Northern Ireland: Places of interest",
    "1DDU-GB-NZA" => "Giant’s Causeway, North Antrim Coast & the Glens",
    "1DDU-GB-NZM" => "Mourne Mountains",
    "1DDU-GB-NZS" => "Sperrin Mountains",
    "1DDU-GB-S" => "Scotland",
    "1DDU-GB-SB" => "Lowland Scotland & Borders",
    "1DDU-GB-SBR" => "Rhinn of Kells & Galloway Hills",
    "1DDU-GB-SC" => "Central Scotland",
    "1DDU-GB-SCD" => "Dundee & Fife",
    "1DDU-GB-SCE" => "Edinburgh",
    "1DDU-GB-SCG" => "Glasgow",
    "1DDU-GB-SCS" => "Stirling",
    "1DDU-GB-SH" => "Northern Scotland, Highlands & Islands",
    "1DDU-GB-SHA" => "Aberdeen & Deeside",
    "1DDU-GB-SHG" => "The Grampians",
    "1DDU-GB-SHN" => "Loch Ness & the Great Glen",
    "1DDU-GB-SHV" => "Inverness",
    "1DDU-GB-SHW" => "Northwest Highlands",
    "1DDU-GB-SHF" => "Orkney Islands",
    "1DDU-GB-SHJ" => "Shetland Islands",
    "1DDU-GB-SHL" => "Western Isles, Outer Hebrides",
    "1DDU-GB-SHP" => "Inner Hebrides",
    "1DDU-GB-SHPM" => "Isle of Mull & Iona",
    "1DDU-GB-SHQ" => "Isle of Skye",
    "1DDU-GB-SHR" => "Isle of Arran",
    "1DDU-GB-SHT" => "Loch Lomond & the Trossachs",
    "1DDU-GB-W" => "Wales",
    "1DDU-GB-WC" => "Mid Wales",
    "1DDU-GB-WN" => "North Wales",
    "1DDU-GB-WNS" => "Snowdonia",
    "1DDU-GB-WS" => "South Wales",
    "1DDU-GB-WSC" => "Cardiff",
    "1DDU-GB-WSG" => "Swansea & the Gower",
    "1DDU-GB-WSY" => "Brecon Beacons",
    "1DDU-GB-WV" => "Southwest Wales",
    "1DDU-GB-WVP" => "Pembrokeshire Coast",
    "1DDU-GB-X" => "Channel Islands",
    "1DDU-GB-XG" => "Guernsey",
    "1DDU-GB-XJ" => "Jersey",
    "1DDU-GB-Z" => "Isle of Man",
    "1DF" => "Central Europe",
    "1DFA" => "Austria",
    "1DFA-AT-B" => "Burgenland",
    "1DFA-AT-K" => "Carinthia",
    "1DFA-AT-M" => "Styria",
    "1DFA-AT-N" => "Lower Austria",
    "1DFA-AT-R" => "Upper Austria",
    "1DFA-AT-S" => "Salzburg",
    "1DFA-AT-T" => "Tyrol",
    "1DFA-AT-V" => "Vorarlberg",
    "1DFA-AT-W" => "Vienna",
    "1DFG" => "Germany",
    "1DFG-DE-B" => "Northeast Germany",
    "1DFG-DE-BE" => "Berlin",
    "1DFG-DE-BG" => "Brandenburg",
    "1DFG-DE-BK" => "German Baltic Sea coast & islands",
    "1DFG-DE-BKA" => "Rügen",
    "1DFG-DE-BM" => "Mecklenburg-Western Pomerania",
    "1DFG-DE-BS" => "Saxony-Anhalt",
    "1DFG-DE-F" => "East Germany",
    "1DFG-DE-FS" => "Saxony",
    "1DFG-DE-FSA" => "Leipzig",
    "1DFG-DE-FSB" => "Dresden",
    "1DFG-DE-FT" => "Thuringia",
    "1DFG-DE-T" => "Southeast Germany",
    "1DFG-DE-TB" => "Bavaria",
    "1DFG-DE-TBA" => "Lower Bavaria",
    "1DFG-DE-TBB" => "Upper Bavaria",
    "1DFG-DE-TBC" => "Munich",
    "1DFG-DE-TBD" => "Nuremburg",
    "1DFG-DE-U" => "Southwest Germany",
    "1DFG-DE-UB" => "Baden-Württemberg",
    "1DFG-DE-UBA" => "Stuttgart",
    "1DFG-DE-UH" => "Hesse",
    "1DFG-DE-UHA" => "Frankfurt",
    "1DFG-DE-UR" => "Rhineland-Palatinate",
    "1DFG-DE-URA" => "Palatinate",
    "1DFG-DE-US" => "Saarland",
    "1DFG-DE-V" => "Northwest Germany",
    "1DFG-DE-VA" => "German North Sea coast & islands",
    "1DFG-DE-VB" => "Bremen",
    "1DFG-DE-VH" => "Hamburg",
    "1DFG-DE-VN" => "Lower Saxony",
    "1DFG-DE-VNA" => "Hanover",
    "1DFG-DE-VR" => "North Rhine-Westphalia",
    "1DFG-DE-VRB" => "Düsseldorf",
    "1DFG-DE-VRC" => "Cologne",
    "1DFG-DE-VRD" => "Dortmund",
    "1DFG-DE-VRE" => "Essen",
    "1DFG-DE-VRR" => "Ruhr district",
    "1DFG-DE-VS" => "Schleswig-Holstein",
    "1DFG-DE-X" => "Historical areas within Germany",
    "1DFG-DE-XA" => "Upper Lusatia",
    "1DFG-DE-XB" => "Swabia",
    "1DFG-DE-XC" => "Allgäu",
    "1DFH" => "Switzerland",
    "1DFH-CH-C" => "Espace Mittelland",
    "1DFH-CH-CB" => "Bern",
    "1DFH-CH-CF" => "Freiburg",
    "1DFH-CH-CJ" => "Jura",
    "1DFH-CH-CN" => "Neuchâtel",
    "1DFH-CH-CS" => "Solothurn",
    "1DFH-CH-G" => "Lake Geneva Region",
    "1DFH-CH-GG" => "Geneva",
    "1DFH-CH-GV" => "Vaud",
    "1DFH-CH-GVL" => "Lausanne",
    "1DFH-CH-GW" => "Valais",
    "1DFH-CH-N" => "Northwest Switzerland",
    "1DFH-CH-NA" => "Aargau / Argovie / Argovia",
    "1DFH-CH-NB" => "Basel-Landschaft",
    "1DFH-CH-ND" => "Basel",
    "1DFH-CH-P" => "Eastern Switzerland",
    "1DFH-CH-PC" => "Appenzell Innerrhoden / Appenzell Rhodes-Intérieures / Appenzello Interno /Appenzell dadens",
    "1DFH-CH-PD" => "Appenzell Ausserrhoden / Appenzell Rhodes-Extérieures / Appenzello Esterno / Appenzell dador",
    "1DFH-CH-PG" => "Glarus / Glaris / Glarona / Glaruna",
    "1DFH-CH-PK" => "Graubünden / Grisons / Grigioni / Grischun",
    "1DFH-CH-PN" => "St. Gallen / Saint-Gall / San Gallo / Son Gagl",
    "1DFH-CH-PP" => "Schaffhausen / Schaffhouse / Sciaffusa / Schaffusa",
    "1DFH-CH-PR" => "Thurgau / Thurgovie / Turgovia / Thurgovia",
    "1DFH-CH-R" => "Tessin / Ticino",
    "1DFH-CH-U" => "Central Switzerland",
    "1DFH-CH-UL" => "Lucerne",
    "1DFH-CH-UN" => "Nidwalden / Nidwald / Nidvaldo / Sutsilvania",
    "1DFH-CH-UO" => "Obwalden / Obwald / Obvaldo / Sursilvania",
    "1DFH-CH-US" => "Schwyz / Schwytz / Svitto / Sviz",
    "1DFH-CH-UU" => "Uri",
    "1DFH-CH-UV" => "Zug / Zoug / Zugo",
    "1DFH-CH-X" => "Zurich",
    "1DFL" => "Liechtenstein",
    "1DN" => "Northern Europe, Scandinavia",
    "1DNC" => "Iceland",
    "1DNC-IS-R" => "Reykjavík",
    "1DND" => "Denmark",
    "1DNDF" => "Faroe Islands",
    "1DNDF-FO-T" => "Thorshavn",
    "1DND-DK-B" => "Bornholm",
    "1DND-DK-F" => "Funen and islands",
    "1DND-DK-FO" => "Odense",
    "1DND-DK-J" => "Jutland",
    "1DND-DK-JE" => "Esbjerg",
    "1DND-DK-JL" => "Alborg",
    "1DND-DK-JR" => "Arhus",
    "1DND-DK-L" => "Lolland-Falster",
    "1DND-DK-S" => "Zealand",
    "1DND-DK-SK" => "Copenhagen",
    "1DND-DK-SR" => "Roskilde",
    "1DNF" => "Finland",
    "1DNF-FI-A" => "Southwest Finland",
    "1DNF-FI-AA" => "Turku",
    "1DNF-FI-AB" => "Turku archipelago",
    "1DNF-FI-B" => "Åland",
    "1DNF-FI-BA" => "Mariehamn",
    "1DNF-FI-C" => "Uusimaa",
    "1DNF-FI-CA" => "West Uusimaa",
    "1DNF-FI-CB" => "Helsinki Region",
    "1DNF-FI-CBA" => "Helsinki",
    "1DNF-FI-CBB" => "Espoo",
    "1DNF-FI-CBC" => "Vantaa",
    "1DNF-FI-CC" => "East Uusimaa",
    "1DNF-FI-CCA" => "Porvoo",
    "1DNF-FI-D" => "Häme",
    "1DNF-FI-DA" => "Kanta-Häme",
    "1DNF-FI-DAA" => "Hämeenlinna",
    "1DNF-FI-DB" => "Päijät-Häme",
    "1DNF-FI-DBA" => "Lahti",
    "1DNF-FI-DC" => "Pirkanmaa",
    "1DNF-FI-DCA" => "Tampere",
    "1DNF-FI-DD" => "Central Finland",
    "1DNF-FI-DDA" => "Jyväskylä",
    "1DNF-FI-H" => "Satakunta",
    "1DNF-FI-HA" => "Pori",
    "1DNF-FI-HB" => "Rauma",
    "1DNF-FI-J" => "Savonia",
    "1DNF-FI-JA" => "Southern Savonia",
    "1DNF-FI-JAB" => "Mikkeli",
    "1DNF-FI-JB" => "Northern Savonia",
    "1DNF-FI-JBK" => "Kuopio",
    "1DNF-FI-K" => "Karelia",
    "1DNF-FI-KA" => "South Karelia",
    "1DNF-FI-KAB" => "Lappeenranta",
    "1DNF-FI-KB" => "North Karelia",
    "1DNF-FI-KBA" => "Joensuu",
    "1DNF-FI-L" => "Kymenlaakso",
    "1DNF-FI-LA" => "Kouvola",
    "1DNF-FI-LB" => "Kotka",
    "1DNF-FI-M" => "Ostrobothnia",
    "1DNF-FI-MA" => "Vaasa",
    "1DNF-FI-N" => "North Ostrobothnia",
    "1DNF-FI-NA" => "Oulu",
    "1DNF-FI-P" => "Central Ostrobothnia",
    "1DNF-FI-PA" => "Kokkola",
    "1DNF-FI-Q" => "South Ostrobothnia",
    "1DNF-FI-QA" => "Seinäjoki",
    "1DNF-FI-R" => "Kainuu",
    "1DNF-FI-RA" => "Kajaani",
    "1DNF-FI-S" => "Lappi",
    "1DNF-FI-SA" => "Rovaniemi",
    "1DNF-FI-SB" => "Sámi native region of Finland",
    "1DNN" => "Norway",
    "1DNN-NO-D" => "Northern Norway",
    "1DNN-NO-DF" => "Finnmark",
    "1DNN-NO-DFV" => "Vadsø",
    "1DNN-NO-DL" => "Nordland",
    "1DNN-NO-DLB" => "Bodø",
    "1DNN-NO-DLN" => "Narvik",
    "1DNN-NO-DT" => "Troms",
    "1DNN-NO-DTR" => "Tromsø",
    "1DNN-NO-J" => "Sørlandet",
    "1DNN-NO-JA" => "Aust-Agder",
    "1DNN-NO-JAL" => "Arendal",
    "1DNN-NO-JG" => "Vest-Agder",
    "1DNN-NO-JGF" => "Farsund",
    "1DNN-NO-JGK" => "Kristiansand",
    "1DNN-NO-JGL" => "Lillesand",
    "1DNN-NO-T" => "Trøndelag",
    "1DNN-NO-TD" => "Nord-Trøndelag",
    "1DNN-NO-TDS" => "Steinkjer",
    "1DNN-NO-TR" => "Sør-Trøndelag",
    "1DNN-NO-TRH" => "Trondheim",
    "1DNN-NO-V" => "Vestlandet",
    "1DNN-NO-VH" => "Hordaland",
    "1DNN-NO-VHB" => "Bergen",
    "1DNN-NO-VM" => "Møre og Romsdal",
    "1DNN-NO-VMA" => "Ålesund",
    "1DNN-NO-VMK" => "Kristiansund",
    "1DNN-NO-VML" => "Molde",
    "1DNN-NO-VR" => "Rogaland",
    "1DNN-NO-VRS" => "Stavanger",
    "1DNN-NO-VW" => "Sogn og Fjordane",
    "1DNN-NO-X" => "Østlandet",
    "1DNN-NO-XA" => "Akershus",
    "1DNN-NO-XB" => "Buskerud",
    "1DNN-NO-XBD" => "Drammen",
    "1DNN-NO-XF" => "Oslofjorden",
    "1DNN-NO-XH" => "Hedmark",
    "1DNN-NO-XHR" => "Hamar",
    "1DNN-NO-XP" => "Oppland",
    "1DNN-NO-XPL" => "Lillehammer",
    "1DNN-NO-XS" => "Oslo",
    "1DNN-NO-XT" => "Telemark",
    "1DNN-NO-XTK" => "Skien",
    "1DNN-NO-XV" => "Vestfold",
    "1DNN-NO-XVL" => "Larvik",
    "1DNN-NO-XVN" => "Sandefjord",
    "1DNN-NO-XVR" => "Tønsberg",
    "1DNN-NO-XZ" => "Østfold",
    "1DNN-NO-XZF" => "Fredrikstad",
    "1DNN-NO-XZH" => "Halden",
    "1DNN-NO-XZM" => "Moss",
    "1DNN-NO-XZS" => "Sarpsborg",
    "1DNS" => "Sweden",
    "1DNS-SE-A" => "Svealand",
    "1DNS-SE-AA" => "Stockholm",
    "1DNS-SE-AAA" => "Stockholm archipelago",
    "1DNS-SE-AB" => "Uppland",
    "1DNS-SE-ABA" => "Uppsala",
    "1DNS-SE-AC" => "Södermanland",
    "1DNS-SE-ACA" => "Nyköping",
    "1DNS-SE-AD" => "Närke",
    "1DNS-SE-ADA" => "Örebro",
    "1DNS-SE-AE" => "Västmanland",
    "1DNS-SE-AEA" => "Västerås",
    "1DNS-SE-AF" => "Dalarna",
    "1DNS-SE-AFA" => "Falun",
    "1DNS-SE-AG" => "Värmland",
    "1DNS-SE-AGA" => "Karlstad",
    "1DNS-SE-AH" => "Bergslagen",
    "1DNS-SE-B" => "Götaland",
    "1DNS-SE-BA" => "Skåne",
    "1DNS-SE-BAA" => "Malmö",
    "1DNS-SE-BAB" => "Österlen",
    "1DNS-SE-BB" => "Halland",
    "1DNS-SE-BBA" => "Halmstad",
    "1DNS-SE-BC" => "Blekinge",
    "1DNS-SE-BCA" => "Karlskrona",
    "1DNS-SE-BD" => "Småland",
    "1DNS-SE-BDA" => "Växjö",
    "1DNS-SE-BDB" => "Kalmar",
    "1DNS-SE-BE" => "Öland",
    "1DNS-SE-BF" => "Gotland",
    "1DNS-SE-BFA" => "Visby",
    "1DNS-SE-BG" => "Östergötland",
    "1DNS-SE-BGA" => "Linköping",
    "1DNS-SE-BH" => "Västergötland",
    "1DNS-SE-BJ" => "Gothenburg",
    "1DNS-SE-BJA" => "Gothenburg archipelago",
    "1DNS-SE-BK" => "Bohuslän",
    "1DNS-SE-BL" => "Dalsland",
    "1DNS-SE-C" => "Norrland",
    "1DNS-SE-CA" => "Gästrikland",
    "1DNS-SE-CAA" => "Gävle",
    "1DNS-SE-CB" => "Hälsingland",
    "1DNS-SE-CC" => "Jämtland",
    "1DNS-SE-CCA" => "Östersund",
    "1DNS-SE-CD" => "Härjedalen",
    "1DNS-SE-CE" => "Medelpad",
    "1DNS-SE-CF" => "Ångermanland",
    "1DNS-SE-CFA" => "Härnösand",
    "1DNS-SE-CG" => "Västerbotten",
    "1DNS-SE-CGA" => "Umeå",
    "1DNS-SE-CH" => "Norrbotten",
    "1DNS-SE-CHA" => "Luleå",
    "1DNS-SE-CJ" => "Lapland",
    "1DNS-SE-CK" => "Tornedalen",
    "1DS" => "Southern Europe",
    "1DSE" => "Spain",
    "1DSE-ES-A" => "Andalusia, Autonomous Community of",
    "1DSE-ES-AA" => "Almeria (Province)",
    "1DSE-ES-AAA" => "Almeria (City)",
    "1DSE-ES-AB" => "Cadiz (Province)",
    "1DSE-ES-ABA" => "Cadiz (City)",
    "1DSE-ES-AC" => "Cordoba (Province)",
    "1DSE-ES-ACA" => "Cordoba (City)",
    "1DSE-ES-AD" => "Granada (Province)",
    "1DSE-ES-ADA" => "Granada (City)",
    "1DSE-ES-ADX" => "Granada: Places of interest",
    "1DSE-ES-ADXA" => "Sierra Nevada",
    "1DSE-ES-AE" => "Huelva (Province)",
    "1DSE-ES-AEA" => "Huelva (City)",
    "1DSE-ES-AF" => "Jaen (Province)",
    "1DSE-ES-AFA" => "Jaen (City)",
    "1DSE-ES-AG" => "Malaga (Province)",
    "1DSE-ES-AGA" => "Malaga (City)",
    "1DSE-ES-AGX" => "Malaga: Places of interest",
    "1DSE-ES-AGXA" => "Costa del Sol",
    "1DSE-ES-AH" => "Seville (Province)",
    "1DSE-ES-AHA" => "Seville (City)",
    "1DSE-ES-B" => "Balearic Islands",
    "1DSE-ES-BA" => "Baleares (Province)",
    "1DSE-ES-BAA" => "Mallorca",
    "1DSE-ES-BAAB" => "Palma de Mallorca",
    "1DSE-ES-BAB" => "Menorca",
    "1DSE-ES-BABA" => "Mahon",
    "1DSE-ES-BAC" => "Ibiza (Island)",
    "1DSE-ES-BACA" => "Ibiza (City)",
    "1DSE-ES-BAD" => "Formentera",
    "1DSE-ES-C" => "Aragon, Autonomous Community of",
    "1DSE-ES-CA" => "Huesca (Province)",
    "1DSE-ES-CAA" => "Huesca (City)",
    "1DSE-ES-CB" => "Teruel (Province)",
    "1DSE-ES-CBA" => "Teruel (City)",
    "1DSE-ES-CC" => "Zaragoza (Province)",
    "1DSE-ES-CCA" => "Zaragoza (City)",
    "1DSE-ES-D" => "Asturias, Principality of",
    "1DSE-ES-DA" => "Asturias (Province)",
    "1DSE-ES-DAA" => "Oviedo",
    "1DSE-ES-DAB" => "Gijon",
    "1DSE-ES-E" => "Canary Islands",
    "1DSE-ES-EA" => "Las Palmas (Province)",
    "1DSE-ES-EAA" => "Gran Canaria",
    "1DSE-ES-EAAA" => "Las Palmas de Gran Canaria",
    "1DSE-ES-EAB" => "Fuerteventura",
    "1DSE-ES-EAC" => "Lanzarote",
    "1DSE-ES-EB" => "Santa Cruz de Tenerife (Province)",
    "1DSE-ES-EBA" => "Tenerife",
    "1DSE-ES-EBAA" => "Santa Cruz de Tenerife (City)",
    "1DSE-ES-EBB" => "El Hierro",
    "1DSE-ES-EBC" => "La Gomera",
    "1DSE-ES-EBD" => "La Palma",
    "1DSE-ES-F" => "Cantabria, Autonomous Community of",
    "1DSE-ES-FA" => "Cantabria (Province)",
    "1DSE-ES-FAA" => "Santander",
    "1DSE-ES-G" => "Castile-La Mancha, Autonomous Community of",
    "1DSE-ES-GA" => "Albacete (Province)",
    "1DSE-ES-GAA" => "Albacete (City)",
    "1DSE-ES-GB" => "Ciudad Real (Province)",
    "1DSE-ES-GBA" => "Ciudad Real (City)",
    "1DSE-ES-GC" => "Cuenca (Province)",
    "1DSE-ES-GCA" => "Cuenca (City)",
    "1DSE-ES-GD" => "Guadalajara (Province)",
    "1DSE-ES-GDA" => "Guadalajara (City)",
    "1DSE-ES-GE" => "Toledo (Province)",
    "1DSE-ES-GEA" => "Toledo (City)",
    "1DSE-ES-H" => "Castile and Leon, Autonomous Community of",
    "1DSE-ES-HA" => "Avila (Province)",
    "1DSE-ES-HAA" => "Avila (City)",
    "1DSE-ES-HB" => "Burgos (Province)",
    "1DSE-ES-HBA" => "Burgos (City)",
    "1DSE-ES-HC" => "Leon (Province)",
    "1DSE-ES-HCA" => "Leon (City)",
    "1DSE-ES-HD" => "Palencia (Province)",
    "1DSE-ES-HDA" => "Palencia (City)",
    "1DSE-ES-HE" => "Salamanca (Province)",
    "1DSE-ES-HEA" => "Salamanca (City)",
    "1DSE-ES-HF" => "Segovia (Province)",
    "1DSE-ES-HFA" => "Segovia (City)",
    "1DSE-ES-HG" => "Soria (Province)",
    "1DSE-ES-HGA" => "Soria (City)",
    "1DSE-ES-HH" => "Valladolid (Province)",
    "1DSE-ES-HHA" => "Valladolid (City)",
    "1DSE-ES-HJ" => "Zamora (Province)",
    "1DSE-ES-HJA" => "Zamora (City)",
    "1DSE-ES-J" => "Catalonia",
    "1DSE-ES-JA" => "Barcelona (Province)",
    "1DSE-ES-JAA" => "Barcelona (City)",
    "1DSE-ES-JB" => "Girona (Province)",
    "1DSE-ES-JBA" => "Girona (City)",
    "1DSE-ES-JBX" => "Girona: Places of interest",
    "1DSE-ES-JBXA" => "Costa Brava",
    "1DSE-ES-JC" => "Lerida / Lleida (Province)",
    "1DSE-ES-JCA" => "Lerida / Lleida (City)",
    "1DSE-ES-JD" => "Tarragona (Province)",
    "1DSE-ES-JDA" => "Tarragona (City)",
    "1DSE-ES-K" => "Extremadura, Autonomous Community of",
    "1DSE-ES-KA" => "Caceres (Province)",
    "1DSE-ES-KAA" => "Caceres (City)",
    "1DSE-ES-KB" => "Badajoz (Province)",
    "1DSE-ES-KBA" => "Badajoz (City)",
    "1DSE-ES-L" => "Galicia, Autonomous Community of",
    "1DSE-ES-LA" => "Corunna (Province)",
    "1DSE-ES-LAA" => "Corunna (City)",
    "1DSE-ES-LAB" => "Santiago de Compostela",
    "1DSE-ES-LB" => "Lugo (Province)",
    "1DSE-ES-LBA" => "Lugo (City)",
    "1DSE-ES-LC" => "Orense (Province)",
    "1DSE-ES-LCA" => "Orense (City)",
    "1DSE-ES-LD" => "Pontevedra (Province)",
    "1DSE-ES-LDA" => "Pontevedra (City)",
    "1DSE-ES-M" => "Madrid, Community of",
    "1DSE-ES-MA" => "Madrid (Province)",
    "1DSE-ES-MAA" => "Madrid (City)",
    "1DSE-ES-N" => "Murcia, Region of",
    "1DSE-ES-NA" => "Murcia (Province)",
    "1DSE-ES-NAA" => "Murcia (City)",
    "1DSE-ES-Q" => "Navarre, Chartered Community of",
    "1DSE-ES-QA" => "Navarre",
    "1DSE-ES-QAB" => "Pamplona",
    "1DSE-ES-R" => "Basque Autonomous Community",
    "1DSE-ES-RA" => "Alava",
    "1DSE-ES-RAA" => "Vitoria",
    "1DSE-ES-RB" => "Guipuzcoa",
    "1DSE-ES-RBA" => "San Sebastian",
    "1DSE-ES-RC" => "Biscay",
    "1DSE-ES-RCA" => "Bilbao",
    "1DSE-ES-S" => "La Rioja, Autonomous Community of",
    "1DSE-ES-SA" => "Logroño (Province)",
    "1DSE-ES-SAA" => "Logroño (City)",
    "1DSE-ES-T" => "Valencian Community",
    "1DSE-ES-TA" => "Alicante (Province)",
    "1DSE-ES-TAA" => "Alicante (City)",
    "1DSE-ES-TAX" => "Alicante: Places of interest",
    "1DSE-ES-TAXA" => "Costa Blanca",
    "1DSE-ES-TB" => "Castellon (Province)",
    "1DSE-ES-TBA" => "Castellon (City)",
    "1DSE-ES-TC" => "Valencia (Province)",
    "1DSE-ES-TCA" => "Valencia (City)",
    "1DSE-ES-U" => "Ceuta, Autonomous City of",
    "1DSE-ES-V" => "Melilla, Autonomous City of",
    "1DSE-ES-X" => "Spain: Places of interest",
    "1DSE-ES-XA" => "Way of St. James",
    "1DSE-ES-XB" => "La Mancha",
    "1DSE-ES-XC" => "Cantabrian Mountains",
    "1DSG" => "Gibraltar",
    "1DSM" => "Malta",
    "1DSM-MT-G" => "Gozo",
    "1DSN" => "Andorra",
    "1DSP" => "Portugal",
    "1DSP-PT-B" => "Norte (Northern Portugal)",
    "1DSP-PT-BP" => "Porto",
    "1DSP-PT-C" => "Centro (Central Portugal)",
    "1DSP-PT-L" => "Lisboa (Region)",
    "1DSP-PT-LL" => "Lisbon",
    "1DSP-PT-LS" => "Sintra",
    "1DSP-PT-N" => "Alentejo",
    "1DSP-PT-P" => "Algarve",
    "1DSP-PT-PF" => "Faro",
    "1DSP-PT-R" => "Madeira – Autonomous Region",
    "1DSP-PT-RF" => "Funchal",
    "1DSP-PT-T" => "Azores – Autonomous Region",
    "1DST" => "Italy",
    "1DST-IT-N" => "Northern Italy",
    "1DST-IT-NA" => "Aosta Valley",
    "1DST-IT-NF" => "Friuli Venezia Giulia",
    "1DST-IT-NFG" => "Gorizia",
    "1DST-IT-NFP" => "Pordenone",
    "1DST-IT-NFT" => "Trieste",
    "1DST-IT-NFU" => "Udine",
    "1DST-IT-NG" => "Liguria",
    "1DST-IT-NGA" => "Genoa",
    "1DST-IT-NGM" => "Imperia",
    "1DST-IT-NGS" => "Savona",
    "1DST-IT-NGZ" => "La Spezia",
    "1DST-IT-NL" => "Lombardy",
    "1DST-IT-NLA" => "Varese",
    "1DST-IT-NLB" => "Bergamo",
    "1DST-IT-NLC" => "Como",
    "1DST-IT-NLD" => "Lodi",
    "1DST-IT-NLE" => "Lecco",
    "1DST-IT-NLM" => "Milan",
    "1DST-IT-NLN" => "Sondrio",
    "1DST-IT-NLR" => "Cremona",
    "1DST-IT-NLS" => "Brescia",
    "1DST-IT-NLT" => "Mantua",
    "1DST-IT-NLV" => "Pavia",
    "1DST-IT-NLZ" => "Monza & Brianza",
    "1DST-IT-NP" => "Piedmont",
    "1DST-IT-NPA" => "Alessandria",
    "1DST-IT-NPL" => "Biella",
    "1DST-IT-NPN" => "Novara",
    "1DST-IT-NPR" => "Vercelli",
    "1DST-IT-NPS" => "Asti",
    "1DST-IT-NPT" => "Turin",
    "1DST-IT-NPU" => "Cuneo",
    "1DST-IT-NPV" => "Province of Verbano Cusio Ossola",
    "1DST-IT-NT" => "Trentino Alto Adige",
    "1DST-IT-NTR" => "Trento",
    "1DST-IT-NTZ" => "Bolzano",
    "1DST-IT-NV" => "Veneto",
    "1DST-IT-NVD" => "Padua",
    "1DST-IT-NVE" => "Venice",
    "1DST-IT-NVN" => "Verona",
    "1DST-IT-NVR" => "Rovigo",
    "1DST-IT-NVS" => "Treviso",
    "1DST-IT-NVU" => "Belluno",
    "1DST-IT-NVZ" => "Vicenza",
    "1DST-IT-NZ" => "Northern Italy: Places of interest",
    "1DST-IT-NZB" => "The Northern Apennines",
    "1DST-IT-NZD" => "The Dolomites",
    "1DST-IT-NZL" => "The Italian lakes region",
    "1DST-IT-NZLC" => "Lake Como",
    "1DST-IT-NZLG" => "Lake Garda",
    "1DST-IT-NZLM" => "Lake Maggiore",
    "1DST-IT-NZLQ" => "Lake Iseo",
    "1DST-IT-NZP" => "The Po River & its tributaries",
    "1DST-IT-T" => "Central Italy",
    "1DST-IT-TG" => "Emilia Romagna",
    "1DST-IT-TGB" => "Bologna",
    "1DST-IT-TGC" => "Forlì-Cesena",
    "1DST-IT-TGF" => "Ferrara",
    "1DST-IT-TGM" => "Modena",
    "1DST-IT-TGN" => "Rimini",
    "1DST-IT-TGP" => "Parma",
    "1DST-IT-TGR" => "Reggio Emilia",
    "1DST-IT-TGV" => "Ravenna",
    "1DST-IT-TGZ" => "Piacenza",
    "1DST-IT-TM" => "Marche",
    "1DST-IT-TMA" => "Ancona",
    "1DST-IT-TMF" => "Fermo",
    "1DST-IT-TMP" => "Pesaro & Urbino",
    "1DST-IT-TMS" => "Ascoli Piceno",
    "1DST-IT-TMT" => "Macerata",
    "1DST-IT-TR" => "Umbria",
    "1DST-IT-TRP" => "Perugia",
    "1DST-IT-TRPT" => "Lake Trasimeno",
    "1DST-IT-TRT" => "Terni",
    "1DST-IT-TS" => "Tuscany",
    "1DST-IT-TSA" => "Arezzo",
    "1DST-IT-TSE" => "Siena",
    "1DST-IT-TSEB" => "Val d’Orcia",
    "1DST-IT-TSF" => "Florence",
    "1DST-IT-TSG" => "Grosseto",
    "1DST-IT-TSL" => "Livorno",
    "1DST-IT-TSLB" => "Elba",
    "1DST-IT-TSM" => "Massa-Carrara",
    "1DST-IT-TSP" => "Pisa",
    "1DST-IT-TSR" => "Prato",
    "1DST-IT-TST" => "Pistoia",
    "1DST-IT-TSU" => "Lucca",
    "1DST-IT-TZ" => "Lazio",
    "1DST-IT-TZF" => "Frosinone",
    "1DST-IT-TZL" => "Latina",
    "1DST-IT-TZR" => "Rome",
    "1DST-IT-TZT" => "Rieti",
    "1DST-IT-TZV" => "Viterbo",
    "1DST-IT-TX" => "Central Italy: Places of interest",
    "1DST-IT-TXA" => "The Arno river & tributaries",
    "1DST-IT-TXC" => "The Tiber river & tributaries",
    "1DST-IT-TXF" => "The Central Apennines",
    "1DST-IT-TXM" => "Maremma",
    "1DST-IT-U" => "Southern Italy & Islands",
    "1DST-IT-UA" => "Abruzzo",
    "1DST-IT-UAH" => "Chieti",
    "1DST-IT-UAP" => "Pescara",
    "1DST-IT-UAQ" => "L’Aquila",
    "1DST-IT-UAT" => "Teramo",
    "1DST-IT-UC" => "Calabria",
    "1DST-IT-UCK" => "Crotone",
    "1DST-IT-UCR" => "Reggio Calabria",
    "1DST-IT-UCS" => "Cosenza",
    "1DST-IT-UCV" => "Vibo Valentia",
    "1DST-IT-UCZ" => "Catanzaro",
    "1DST-IT-UD" => "Sardinia",
    "1DST-IT-UDC" => "Cagliari",
    "1DST-IT-UDG" => "Province of Ogliastra",
    "1DST-IT-UDM" => "Province of Medio Campidano",
    "1DST-IT-UDN" => "Carbonia-Iglesias",
    "1DST-IT-UDR" => "Oristano",
    "1DST-IT-UDS" => "Sassari",
    "1DST-IT-UDSD" => "Costa Smeralda",
    "1DST-IT-UDT" => "Olbia Tempio",
    "1DST-IT-UDU" => "Nuoro",
    "1DST-IT-UE" => "Molise",
    "1DST-IT-UEC" => "Campobasso",
    "1DST-IT-UES" => "Isernia",
    "1DST-IT-UL" => "Sicily",
    "1DST-IT-ULA" => "Agrigento",
    "1DST-IT-ULC" => "Caltanissetta",
    "1DST-IT-ULE" => "Enna",
    "1DST-IT-ULM" => "Messina",
    "1DST-IT-ULME" => "Aeolian Islands",
    "1DST-IT-ULN" => "Trapani",
    "1DST-IT-ULP" => "Palermo",
    "1DST-IT-ULR" => "Ragusa",
    "1DST-IT-ULS" => "Syracuse",
    "1DST-IT-ULT" => "Catania",
    "1DST-IT-ULTE" => "Mount Etna",
    "1DST-IT-UM" => "Campania",
    "1DST-IT-UML" => "Avellino",
    "1DST-IT-UMN" => "Naples",
    "1DST-IT-UMNC" => "Capri / Ischia",
    "1DST-IT-UMNP" => "Pompeii / Herculaneum",
    "1DST-IT-UMNV" => "Mount Vesuvius",
    "1DST-IT-UMS" => "Salerno",
    "1DST-IT-UMSC" => "The Amalfi coast",
    "1DST-IT-UMT" => "Caserta",
    "1DST-IT-UMV" => "Benevento",
    "1DST-IT-UP" => "Apulia",
    "1DST-IT-UPA" => "Bari",
    "1DST-IT-UPG" => "Foggia",
    "1DST-IT-UPGB" => "Tavoliere delle Puglie",
    "1DST-IT-UPL" => "Lecce",
    "1DST-IT-UPR" => "Barletta Andria Trani",
    "1DST-IT-UPS" => "Brindisi",
    "1DST-IT-UPT" => "Taranto",
    "1DST-IT-US" => "Basilicata",
    "1DST-IT-USM" => "Matera",
    "1DST-IT-USP" => "Potenza",
    "1DST-IT-UZ" => "Southern Italy: Places of interest",
    "1DST-IT-UZC" => "The Southern Apennines",
    "1DST-IT-UZCE" => "Monte Gran Sasso",
    "1DST-IT-UZCP" => "Monte Pollino",
    "1DST-IT-UZD" => "Sila",
    "1DST-IT-X" => "Historical and cultural areas within Italy",
    "1DST-IT-XN" => "Historical and cultural areas: Northern Italy",
    "1DST-IT-XNA" => "Langhe",
    "1DST-IT-XNC" => "Monferrat",
    "1DST-IT-XNE" => "Canavese",
    "1DST-IT-XNF" => "Cinque Terre",
    "1DST-IT-XNH" => "Tigullio",
    "1DST-IT-XNL" => "Franciacorta",
    "1DST-IT-XNN" => "Lomellina",
    "1DST-IT-XNP" => "Polesine",
    "1DST-IT-XNR" => "Carnia",
    "1DST-IT-XT" => "Historical and cultural areas: Central Italy",
    "1DST-IT-XTA" => "Lunigiana",
    "1DST-IT-XTC" => "Garfagnana",
    "1DST-IT-XTE" => "Chianti",
    "1DST-IT-XTG" => "Mugello",
    "1DST-IT-XTL" => "Versilia",
    "1DST-IT-XTN" => "Ciociaria",
    "1DST-IT-XU" => "Historical and cultural areas: Southern Italy & islands",
    "1DST-IT-XUA" => "Cilento",
    "1DST-IT-XUC" => "Irpinia",
    "1DST-IT-XUE" => "Sannio",
    "1DST-IT-XUG" => "Salento",
    "1DST-IT-XUL" => "Gallura",
    "1DSU" => "San Marino",
    "1DSV" => "Vatican",
    "1DT" => "Eastern Europe",
    "1DTA" => "Russia",
    "1DTA-RU-B" => "Russia: Central District",
    "1DTA-RU-BK" => "Kursk",
    "1DTA-RU-BM" => "Moscow",
    "1DTA-RU-BS" => "Smolensk",
    "1DTA-RU-D" => "Russia: Southern District",
    "1DTA-RU-DB" => "Volgograd",
    "1DTA-RU-DD" => "Rostov-on-Don",
    "1DTA-RU-F" => "Russia: Northwestern District",
    "1DTA-RU-FA" => "Archangel / Arkhangelsk",
    "1DTA-RU-FC" => "Kaliningrad",
    "1DTA-RU-FD" => "Novgorod",
    "1DTA-RU-FP" => "Saint Petersburg",
    "1DTA-RU-H" => "Russia: Far Eastern District",
    "1DTA-RU-J" => "Russia: Siberian District",
    "1DTA-RU-JZ" => "Siberia: places of interest",
    "1DTA-RU-JZB" => "Siberia: Lake Baikal",
    "1DTA-RU-L" => "Russia: Ural District",
    "1DTA-RU-N" => "Russia: Volga District",
    "1DTA-RU-NN" => "Nizhny Novgorod",
    "1DTA-RU-P" => "Russia: North Caucasus District",
    "1DTA-RU-PC" => "Chechen Republic (Chechnya)",
    "1DTB" => "Belarus (Belorussia)",
    "1DTB-BY-M" => "Minsk",
    "1DTD" => "Latvia",
    "1DTD-LV-R" => "Riga",
    "1DTE" => "Estonia",
    "1DTE-EE-T" => "Tallinn",
    "1DTF" => "Lithuania",
    "1DTF-LT-V" => "Vilnius",
    "1DTG" => "Georgia",
    "1DTG-GE-T" => "Tbilisi",
    "1DTH" => "Hungary",
    "1DTH-HU-B" => "Central Hungary",
    "1DTH-HU-BB" => "Budapest",
    "1DTH-HU-D" => "Transdanubia",
    "1DTH-HU-DB" => "Lake Balaton",
    "1DTH-HU-DD" => "Lake Neusiedl / Ferto",
    "1DTH-HU-DF" => "Mecsek Mountains",
    "1DTH-HU-DG" => "Transdanubian Mountains",
    "1DTH-HU-DH" => "Little Hungarian Plain",
    "1DTH-HU-DP" => "Esztergom",
    "1DTH-HU-DQ" => "Győr",
    "1DTH-HU-DR" => "Pécs",
    "1DTH-HU-DS" => "Sopron",
    "1DTH-HU-DT" => "Székesfehérvár",
    "1DTH-HU-DV" => "Veszprém",
    "1DTH-HU-F" => "Great Plain & the North",
    "1DTH-HU-FD" => "North Hungarian Mountains",
    "1DTH-HU-FDE" => "Eger",
    "1DTH-HU-FP" => "Great Hungarian plain",
    "1DTH-HU-FPD" => "Hortobágy National Park",
    "1DTH-HU-FPJ" => "Debrecen",
    "1DTH-HU-FPK" => "Szeged",
    "1DTH-HU-FPW" => "Lake Tisza",
    "1DTH-HU-Z" => "Hungary: Places of interest",
    "1DTH-HU-ZD" => "Danube–Tisza Interfluve",
    "1DTH-HU-ZT" => "Transtisza / Tiszántúl",
    "1DTJ" => "Czechia",
    "1DTJ-CZ-A" => "Prague",
    "1DTJ-CZ-B" => "South Moravian Region",
    "1DTJ-CZ-C" => "South Bohemian Region",
    "1DTJ-CZ-E" => "Pardubice Region",
    "1DTJ-CZ-H" => "Hradec Kralove Region",
    "1DTJ-CZ-J" => "Vysocina Region",
    "1DTJ-CZ-K" => "Karlovy Vary Region",
    "1DTJ-CZ-L" => "Liberec Region",
    "1DTJ-CZ-M" => "Olomouc Region",
    "1DTJ-CZ-P" => "Pilsen Region",
    "1DTJ-CZ-S" => "Central Bohemian Region",
    "1DTJ-CZ-T" => "Moravian-Silesian Region",
    "1DTJ-CZ-U" => "Usti nad Labem Region",
    "1DTJ-CZ-Z" => "Zlin Region",
    "1DTJ-CZ-X" => "Czechia: places of interest",
    "1DTJ-CZ-XB" => "Bohemia",
    "1DTJ-CZ-XBF" => "Bohemian Forest",
    "1DTJ-CZ-XBG" => "Krkonoše / Giant Mountains",
    "1DTJ-CZ-XBV" => "Vltava river & tributaries",
    "1DTJ-CZ-XM" => "Moravia",
    "1DTJ-CZ-XS" => "Czech Silesia",
    "1DTK" => "Slovakia",
    "1DTK-SK-B" => "Bratislava (region)",
    "1DTK-SK-BB" => "Bratislava",
    "1DTK-SK-K" => "Kosice Region",
    "1DTK-SK-N" => "Nitra Region",
    "1DTK-SK-P" => "Presov Region",
    "1DTK-SK-S" => "Banska Bystrica Region",
    "1DTK-SK-T" => "Trencin Region",
    "1DTK-SK-V" => "Trnava Region",
    "1DTK-SK-Y" => "Zilina Region",
    "1DTK-SK-Z" => "Slovakia: places of interest",
    "1DTK-SK-ZV" => "The Vah & tributaries",
    "1DTM" => "Moldova (Moldavia)",
    "1DTN" => "Ukraine",
    "1DTN-UA-K" => "Kiev",
    "1DTP" => "Poland",
    "1DTP-PL-A" => "West Pomerania voivodeship",
    "1DTP-PL-AB" => "Szczecin",
    "1DTP-PL-AP" => "Pomeranian Lake District",
    "1DTP-PL-B" => "East Pomerania",
    "1DTP-PL-BA" => "Kashubia",
    "1DTP-PL-BAA" => "Gdańsk, Gdynia, Sopot – Tri-city",
    "1DTP-PL-BD" => "Hel Peninsula",
    "1DTP-PL-BF" => "Żuławy region",
    "1DTP-PL-BFA" => "Malbork",
    "1DTP-PL-C" => "Kuyavian-Pomeranian",
    "1DTP-PL-CB" => "Bydgoszcz",
    "1DTP-PL-CC" => "Toruń",
    "1DTP-PL-D" => "Lodz / Łódź",
    "1DTP-PL-E" => "Warmia-Masuria Province",
    "1DTP-PL-EA" => "Olsztyn",
    "1DTP-PL-EB" => "Biskupiec",
    "1DTP-PL-H" => "Podlasie / Podlachia",
    "1DTP-PL-HB" => "Białystok",
    "1DTP-PL-HD" => "Suwalki",
    "1DTP-PL-HR" => "Bialowieza National Park",
    "1DTP-PL-HS" => "Biebrza National Park",
    "1DTP-PL-J" => "Lubusz province",
    "1DTP-PL-JA" => "Zielona Góra",
    "1DTP-PL-K" => "Kielce Upland / Holy Cross Province / Świętokrzyskie",
    "1DTP-PL-KA" => "Kielce",
    "1DTP-PL-KS" => "Sandomierz and the Sandomierz basin",
    "1DTP-PL-L" => "Lublin Upland",
    "1DTP-PL-LA" => "Lublin",
    "1DTP-PL-LK" => "Kazimierz Dolny",
    "1DTP-PL-LR" => "Roztocze National Park",
    "1DTP-PL-M" => "Masovian Voivodeship",
    "1DTP-PL-MA" => "Warsaw",
    "1DTP-PL-MP" => "Plock / Płock",
    "1DTP-PL-MR" => "Kampinoski National Park",
    "1DTP-PL-N" => "Greater Poland (Wielkopolska)",
    "1DTP-PL-NB" => "Poznan",
    "1DTP-PL-P" => "Lesser Poland Voivodeship",
    "1DTP-PL-PK" => "Krakow",
    "1DTP-PL-PR" => "Krakow-Częstochowa Upland",
    "1DTP-PL-PT" => "Podhale (Polish highlands)",
    "1DTP-PL-PTZ" => "Zakopane",
    "1DTP-PL-R" => "Silesian Voivodeship",
    "1DTP-PL-RA" => "Katowice",
    "1DTP-PL-RC" => "Częstochowa",
    "1DTP-PL-S" => "Lower Silesian Voivodeship",
    "1DTP-PL-SA" => "Wroclaw",
    "1DTT" => "Turkey",
    "1DTT-TR-A" => "Istanbul",
    "1DTV" => "Armenia",
    "1DTV-AM-Y" => "Yerevan",
    "1DTX" => "Azerbaijan",
    "1DTX-AZ-B" => "Baku",
    "1DTZ" => "Kazakhstan",
    "1DX" => "Southeast Europe",
    "1DXA" => "Albania",
    "1DXA-AL-T" => "Tirana",
    "1DXB" => "Bulgaria",
    "1DXB-BG-S" => "Sofia",
    "1DXC" => "Croatia",
    "1DXC-HR-A" => "Zagreb",
    "1DXC-HR-C" => "Central Croatia",
    "1DXC-HR-D" => "Dalmatia",
    "1DXC-HR-DD" => "Dubrovnik",
    "1DXC-HR-DK" => "Šibenik",
    "1DXC-HR-DS" => "Split",
    "1DXC-HR-DY" => "Zadar",
    "1DXC-HR-J" => "Istria",
    "1DXC-HR-K" => "Kvarner & the Highlands",
    "1DXC-HR-L" => "Lika-Karlovac",
    "1DXC-HR-S" => "Slavonia",
    "1DXD" => "Macedonia (FYR)",
    "1DXD-MK-S" => "Skopje",
    "1DXG" => "Greece",
    "1DXG-GR-E" => "Central Greece",
    "1DXG-GR-EA" => "Attica",
    "1DXG-GR-EAA" => "Athens",
    "1DXG-GR-EAE" => "Eleusis",
    "1DXG-GR-EAP" => "Piraeus",
    "1DXG-GR-EE" => "Euboea",
    "1DXG-GR-EEC" => "Chalcis",
    "1DXG-GR-EF" => "Phocis",
    "1DXG-GR-EFD" => "Delphi",
    "1DXG-GR-EK" => "Aetolia-Acarnania",
    "1DXG-GR-EKM" => "Missolonghi",
    "1DXG-GR-ET" => "Phthiotis",
    "1DXG-GR-ETA" => "Atalanti",
    "1DXG-GR-EV" => "Boeotia",
    "1DXG-GR-EVT" => "Thebes",
    "1DXG-GR-H" => "Epirus",
    "1DXG-GR-L" => "Thessaly",
    "1DXG-GR-M" => "Macedonia",
    "1DXG-GR-MC" => "Chalkidiki",
    "1DXG-GR-ME" => "Pella",
    "1DXG-GR-MP" => "Pieria",
    "1DXG-GR-MT" => "Thessaloniki (region)",
    "1DXG-GR-MTH" => "Thessaloniki",
    "1DXG-GR-P" => "Peloponnese",
    "1DXG-GR-PA" => "Achaea",
    "1DXG-GR-PAP" => "Patras",
    "1DXG-GR-PD" => "Arcadia",
    "1DXG-GR-PH" => "Elis / Ilia",
    "1DXG-GR-PHO" => "Ancient Olympia",
    "1DXG-GR-PK" => "Corinthia",
    "1DXG-GR-PKK" => "Corinth",
    "1DXG-GR-PL" => "Laconia",
    "1DXG-GR-PLS" => "Sparta",
    "1DXG-GR-PLY" => "Mystras",
    "1DXG-GR-PM" => "Messenia",
    "1DXG-GR-PR" => "Argolis",
    "1DXG-GR-PRA" => "Argos",
    "1DXG-GR-PRM" => "Mycenae",
    "1DXG-GR-S" => "Greek Islands",
    "1DXG-GR-SA" => "North Aegean Islands",
    "1DXG-GR-SAC" => "Chios",
    "1DXG-GR-SAH" => "Lemnos",
    "1DXG-GR-SAL" => "Lesbos",
    "1DXG-GR-SAS" => "Samos",
    "1DXG-GR-SC" => "Crete",
    "1DXG-GR-SCH" => "Heraklion",
    "1DXG-GR-SD" => "Dodecanese (Islands)",
    "1DXG-GR-SDH" => "Karpathos",
    "1DXG-GR-SDK" => "Kos",
    "1DXG-GR-SDL" => "Leros",
    "1DXG-GR-SDP" => "Patmos",
    "1DXG-GR-SDR" => "Rhodes",
    "1DXG-GR-SF" => "Ionian Islands",
    "1DXG-GR-SFC" => "Corfu",
    "1DXG-GR-SFF" => "Paxos",
    "1DXG-GR-SFK" => "Cephalonia / Kefalonia",
    "1DXG-GR-SFL" => "Lefkada",
    "1DXG-GR-SFP" => "Ithaca",
    "1DXG-GR-SFR" => "Zakynthos",
    "1DXG-GR-SK" => "Cyclades (Islands)",
    "1DXG-GR-SKK" => "Mykonos",
    "1DXG-GR-SKM" => "Milos",
    "1DXG-GR-SKN" => "Naxos",
    "1DXG-GR-SKP" => "Paros",
    "1DXG-GR-SKS" => "Santorini",
    "1DXG-GR-SKY" => "Syros",
    "1DXG-GR-SR" => "Saronic Islands",
    "1DXG-GR-SRA" => "Aegina",
    "1DXG-GR-SRS" => "Salamis",
    "1DXG-GR-SS" => "Sporades (Islands)",
    "1DXG-GR-SSA" => "Alonnisos",
    "1DXG-GR-SSK" => "Skiathos",
    "1DXG-GR-ST" => "Other Greek Islands",
    "1DXG-GR-STK" => "Kythira",
    "1DXG-GR-STM" => "Samothrace",
    "1DXG-GR-STS" => "Skyros",
    "1DXG-GR-T" => "Thrace",
    "1DXH" => "Bosnia-Herzegovina",
    "1DXH-BA-S" => "Sarajevo",
    "1DXK" => "Kosovo",
    "1DXN" => "Montenegro",
    "1DXN-ME-P" => "Podgorica",
    "1DXR" => "Romania",
    "1DXR-RO-B" => "Bucharest",
    "1DXR-RO-Z" => "Romania: places of interest",
    "1DXR-RO-ZT" => "Transylvania",
    "1DXS" => "Serbia",
    "1DXS-RS-B" => "Belgrade",
    "1DXV" => "Slovenia",
    "1DXV-SI-C" => "Carniola",
    "1DXV-SI-CL" => "Ljubljana",
    "1DXY" => "Cyprus",
    "1DXY-CY-C" => "Nicosia",
    "1DZ" => "Europe: physical features",
    "1DZA" => "Europe: rivers, lakes etc",
    "1DZAD" => "Danube river & tributaries",
    "1DZADT" => "River Tisza & tributaries",
    "1DZAR" => "Rhine river & tributaries",
    "1DZARC" => "Lake Constance",
    "1DZAV" => "Volga river & tributaries",
    "1DZA-DE-E" => "Elbe river & tributaries",
    "1DZA-DE-N" => "Oder and Neisse rivers & tributaries",
    "1DZA-DE-W" => "Weser river & tributaries",
    "1DZA-IT-A" => "Po river & tributaries",
    "1DZA-IT-C" => "Arno river & tributaries",
    "1DZA-IT-E" => "Tiber river and tributaries",
    "1DZA-PL-V" => "Vistula river and tributaries",
    "1DZA-PL-VB" => "Bug River / Western Bug",
    "1DZT" => "Europe: mountains, hills, plains, coastlines etc",
    "1DZTA" => "The Alps",
    "1DZTAP" => "Pennine Alps",
    "1DZTAPM" => "Matterhorn",
    "1DZTAPR" => "Mont Rosa Massif",
    "1DZTA-FR-B" => "Mont Blanc Massif",
    "1DZTA-FR-BM" => "Mont Blanc",
    "1DZTA-SI-C" => "Julian Alps",
    "1DZTB" => "The Caucasus",
    "1DZTC" => "Carpathian mountains",
    "1DZTCT" => "Tatra Mountains",
    "1DZTH" => "The Balkans",
    "1DZTP" => "The Pyrenees",
    "1DZTS" => "Scandinavian Mountains",
    "1DZTU" => "Ural mountains",
    "1DZT-DE-A" => "Harz mountains",
    "1DZT-DE-B" => "Rhön mountains",
    "1DZT-DE-C" => "Eifel region",
    "1DZT-DE-D" => "Black Forest region",
    "1DZT-DE-E" => "Rhineland",
    "1DZT-FR-J" => "Jura Mountains",
    "1DZT-GB-C" => "Cotswolds",
    "1DZT-GB-P" => "Pennines",
    "1DZT-IT-A" => "Northern Apennines",
    "1DZT-IT-B" => "Central Apennines",
    "1DZT-IT-C" => "Southern Apennines",
    "1DZT-IT-G" => "Karst plateau",
    "1DZT-IT-L" => "Maremma",
    "1DZT-IT-N" => "Val d’Orcia",
    "1DZT-IT-P" => "Tavoliere delle Puglie",
    "1DZT-IT-R" => "Amalfi coast",
    "1DZT-IT-T" => "Costa Smeralda",
    "1F" => "Asia",
    "1FB" => "Middle East",
    "1FBG" => "Jerusalem",
    "1FBH" => "Israel",
    "1FBH-IL-A" => "Tel-Aviv",
    "1FBH-IL-H" => "Haifa",
    "1FBJ" => "Jordan",
    "1FBJ-JO-P" => "Petra",
    "1FBL" => "Lebanon",
    "1FBL-LB-B" => "Beirut",
    "1FBN" => "Iran",
    "1FBN-IR-A" => "Tehran",
    "1FBN-IR-S" => "Shiraz",
    "1FBP" => "Palestine",
    "1FBP-PS-G" => "Gaza",
    "1FBQ" => "Iraq",
    "1FBQ-IQ-B" => "Baghdad",
    "1FBS" => "Syria",
    "1FBS-SY-A" => "Aleppo",
    "1FBS-SY-D" => "Damascus",
    "1FBS-SY-P" => "Palmyra",
    "1FBX" => "Arabian peninsula",
    "1FBXB" => "Bahrain",
    "1FBXK" => "Kuwait",
    "1FBXM" => "Oman",
    "1FBXQ" => "Qatar",
    "1FBXS" => "Saudi Arabia",
    "1FBXS-SA-H" => "Hejaz /Hijaz",
    "1FBXS-SA-HJ" => "Jeddah",
    "1FBXS-SA-HM" => "Mecca / Makkah",
    "1FBXS-SA-HN" => "Medina",
    "1FBXS-SA-R" => "Riyadh",
    "1FBXU" => "United Arab Emirates",
    "1FBXU-AE-A" => "Abu Dhabi",
    "1FBXU-AE-D" => "Dubai",
    "1FBXY" => "Yemen",
    "1FBZ" => "Middle East: places of interest",
    "1FBZB" => "Tigris & Euphrates rivers",
    "1FBZJ" => "Jordan River",
    "1FBZJD" => "Dead Sea",
    "1FC" => "Central Asia",
    "1FCA" => "Afghanistan",
    "1FCA-AF-K" => "Kabul",
    "1FCD" => "Tajikistan (Tadzhikistan)",
    "1FCK" => "Kyrgyzstan (Kirghizstan, Kirghizia)",
    "1FCK-KG-B" => "Bishkek",
    "1FCS" => "Siberia",
    "1FCT" => "Turkmenistan",
    "1FCU" => "Uzbekistan",
    "1FK" => "South Asia (Indian sub-continent)",
    "1FKA" => "India",
    "1FKA-IN-A" => "Northern India",
    "1FKA-IN-AB" => "Chandigarh",
    "1FKA-IN-AD" => "National Capital Territory of Delhi",
    "1FKA-IN-ADN" => "New Delhi",
    "1FKA-IN-AG" => "Haryana",
    "1FKA-IN-AH" => "Himachal Pradesh",
    "1FKA-IN-AHS" => "Shimla / Simla",
    "1FKA-IN-AJ" => "Jammu & Kashmir",
    "1FKA-IN-AP" => "Punjab",
    "1FKA-IN-APB" => "Amritsar",
    "1FKA-IN-AR" => "Rajasthan",
    "1FKA-IN-ARB" => "Jaipur",
    "1FKA-IN-ARD" => "Jodhpur",
    "1FKA-IN-ARF" => "Udaipur",
    "1FKA-IN-C" => "Central India",
    "1FKA-IN-CB" => "Chhattisgarh",
    "1FKA-IN-CD" => "Madhya Pradesh",
    "1FKA-IN-CF" => "Uttar Pradesh",
    "1FKA-IN-CFA" => "Agra",
    "1FKA-IN-CFC" => "Varanasi / Benares",
    "1FKA-IN-CH" => "Uttarakhand",
    "1FKA-IN-E" => "Eastern India",
    "1FKA-IN-EB" => "Bihar",
    "1FKA-IN-ED" => "Jharkhand",
    "1FKA-IN-EF" => "Odisha",
    "1FKA-IN-EH" => "West Bengal",
    "1FKA-IN-EHC" => "Kolkata",
    "1FKA-IN-EHD" => "Darjeeling",
    "1FKA-IN-G" => "North East India",
    "1FKA-IN-GA" => "Assam",
    "1FKA-IN-GC" => "Arunachal Pradesh",
    "1FKA-IN-GE" => "Manipur",
    "1FKA-IN-GH" => "Meghalaya",
    "1FKA-IN-GJ" => "Mizoram",
    "1FKA-IN-GL" => "Nagaland",
    "1FKA-IN-GN" => "Tripura",
    "1FKA-IN-GS" => "Sikkim",
    "1FKA-IN-J" => "Western India",
    "1FKA-IN-JB" => "Dadra & Nagar Haveli",
    "1FKA-IN-JD" => "Daman & Diu",
    "1FKA-IN-JF" => "Goa",
    "1FKA-IN-JG" => "Gujarat",
    "1FKA-IN-JM" => "Maharashtra",
    "1FKA-IN-JMM" => "Mumbai",
    "1FKA-IN-L" => "Southern India",
    "1FKA-IN-LA" => "Andhra Pradesh",
    "1FKA-IN-LC" => "Karnataka",
    "1FKA-IN-LCB" => "Bengaluru",
    "1FKA-IN-LE" => "Kerala",
    "1FKA-IN-LEC" => "Kochi",
    "1FKA-IN-LG" => "Puducherry",
    "1FKA-IN-LGB" => "Pondicherry",
    "1FKA-IN-LJ" => "Tamil Nadu",
    "1FKA-IN-LJC" => "Chennai",
    "class here: Madras" => "201710",
    "1FKA-IN-LK" => "Telangana",
    "1FKA-IN-LKH" => "Hyderabad",
    "1FKA-IN-LN" => "Andaman & Nicobar Islands",
    "1FKA-IN-LP" => "Lakshadweep",
    "1FKB" => "Bangladesh",
    "1FKB-BD-D" => "Dhaka",
    "1FKH" => "Bhutan",
    "1FKN" => "Nepal",
    "1FKN-NP-K" => "Kathmandu",
    "1FKP" => "Pakistan",
    "1FKP-PK-B" => "Balochistan",
    "1FKP-PK-D" => "Khyber Pakhtunkhwa",
    "1FKP-PK-F" => "Punjab (PK)",
    "1FKP-PK-FB" => "Lahore",
    "1FKP-PK-H" => "Sindh",
    "1FKP-PK-HB" => "Karachi",
    "1FKP-PK-L" => "Islamabad",
    "1FKS" => "Sri Lanka",
    "1FKS-LK-C" => "Colombo",
    "1FM" => "South East Asia",
    "1FMB" => "Myanmar",
    "1FMC" => "Cambodia",
    "1FMC-KH-A" => "Phnom Penh",
    "1FMC-KH-B" => "Siem Reap",
    "1FMC-KH-BA" => "Angkor",
    "1FML" => "Laos",
    "1FMM" => "Malaysia",
    "1FMM-MY-B" => "Kuala Lumpur",
    "1FMM-MY-M" => "Melaka / Malacca",
    "1FMM-MY-P" => "Penang",
    "1FMM-MY-S" => "Sarawak",
    "1FMM-MY-T" => "Sabah",
    "1FMN" => "Indonesia",
    "1FMNB" => "Bali",
    "1FMN-ID-B" => "Sumatra",
    "1FMN-ID-D" => "Java",
    "1FMN-ID-DJ" => "Jakarta",
    "1FMN-ID-F" => "Kalimantan",
    "1FMN-ID-K" => "Sulawesi",
    "1FMN-ID-M" => "Maluku",
    "1FMN-ID-P" => "Papua",
    "1FMN-ID-S" => "Lesser Sunda Islands",
    "1FMN-ID-SL" => "Lombok",
    "1FMNT" => "East Timor / Timor-Leste",
    "1FMNX" => "Borneo",
    "1FMP" => "Philippines",
    "1FMP-PH-A" => "Manila",
    "1FMR" => "Brunei",
    "1FMS" => "Singapore",
    "1FMT" => "Thailand",
    "1FMT-TH-B" => "Bangkok",
    "1FMT-TH-C" => "Chiang Mai",
    "1FMT-TH-K" => "Krabi",
    "1FMT-TH-KL" => "Ko Lanta",
    "1FMT-TH-P" => "Phuket",
    "1FMT-TH-Q" => "Surat Thani",
    "1FMT-TH-QB" => "Ko Samui / Koh Samui",
    "1FMT-TH-Y" => "Ayutthaya",
    "1FMV" => "Vietnam",
    "1FMV-VN-B" => "Ho Chi Minh City",
    "1FMV-VN-D" => "Hanoi",
    "1FP" => "East Asia, Far East",
    "1FPC" => "China",
    "1FPC-CN-D" => "North China",
    "1FPC-CN-DB" => "Beijing",
    "1FPC-CN-DD" => "Tianjin",
    "1FPC-CN-DF" => "Hebei",
    "1FPC-CN-DH" => "Shanxi",
    "1FPC-CN-DJ" => "Inner Mongolia",
    "1FPC-CN-F" => "Northeast China",
    "1FPC-CN-FB" => "Liaoning",
    "1FPC-CN-FD" => "Jilin",
    "1FPC-CN-FF" => "Heilongjiang",
    "1FPC-CN-H" => "East China",
    "1FPC-CN-HB" => "Shanghai",
    "1FPC-CN-HD" => "Jiangsu",
    "1FPC-CN-HF" => "Zhejiang",
    "1FPC-CN-HH" => "Anhui",
    "1FPC-CN-HJ" => "Fujian",
    "1FPC-CN-HL" => "Jiangxi",
    "1FPC-CN-HN" => "Shandong",
    "1FPC-CN-J" => "Central China",
    "1FPC-CN-JB" => "Henan",
    "1FPC-CN-JD" => "Hubei",
    "1FPC-CN-JF" => "Hunan",
    "1FPC-CN-L" => "South China",
    "1FPC-CN-LB" => "Guangdong",
    "1FPC-CN-LD" => "Guangxi",
    "1FPC-CN-LF" => "Hainan",
    "1FPC-CN-N" => "Southwest China",
    "1FPC-CN-NB" => "Chongqing",
    "1FPC-CN-ND" => "Sichuan",
    "1FPC-CN-NF" => "Guizhou",
    "1FPC-CN-NH" => "Yunnan",
    "1FPCT" => "Tibet",
    "1FPC-CN-P" => "Northwest China",
    "1FPC-CN-PB" => "Shaanxi",
    "1FPC-CN-PD" => "Gansu",
    "1FPC-CN-PF" => "Qinghai",
    "1FPC-CN-PH" => "Ningxia",
    "1FPC-CN-PJ" => "Xinjiang",
    "1FPCW" => "Taiwan",
    "1FPCH" => "Hong Kong",
    "1FPCM" => "Macao",
    "1FPJ" => "Japan",
    "1FPJ-JP-A" => "Hokkaido (region)",
    "1FPJ-JP-AA" => "Hokkaido",
    "1FPJ-JP-B" => "Tohoku",
    "1FPJ-JP-BA" => "Aomori",
    "1FPJ-JP-BB" => "Iwate",
    "1FPJ-JP-BC" => "Miyagi",
    "1FPJ-JP-BD" => "Akita",
    "1FPJ-JP-BE" => "Yamagata",
    "1FPJ-JP-BF" => "Fukushima",
    "1FPJ-JP-C" => "Kanto",
    "1FPJ-JP-CA" => "Ibaraki",
    "1FPJ-JP-CB" => "Tochigi",
    "1FPJ-JP-CC" => "Gunma",
    "1FPJ-JP-CD" => "Saitama",
    "1FPJ-JP-CE" => "Chiba",
    "1FPJ-JP-CF" => "Tokyo",
    "1FPJ-JP-CG" => "Kanagawa",
    "1FPJ-JP-D" => "Chubu",
    "1FPJ-JP-DA" => "Niigata",
    "1FPJ-JP-DB" => "Toyama",
    "1FPJ-JP-DC" => "Ishikawa",
    "1FPJ-JP-DD" => "Fukui",
    "1FPJ-JP-DE" => "Yamanashi",
    "1FPJ-JP-DF" => "Nagano",
    "1FPJ-JP-DG" => "Gifu",
    "1FPJ-JP-DH" => "Shizuoka",
    "1FPJ-JP-DJ" => "Aichi",
    "1FPJ-JP-E" => "Kinki / Kansai",
    "1FPJ-JP-EA" => "Mie",
    "1FPJ-JP-EB" => "Shiga",
    "1FPJ-JP-EC" => "Kyoto",
    "1FPJ-JP-ED" => "Osaka",
    "1FPJ-JP-EE" => "Hyogo",
    "1FPJ-JP-EF" => "Nara",
    "1FPJ-JP-EG" => "Wakayama",
    "1FPJ-JP-F" => "Chugoku",
    "1FPJ-JP-FA" => "Tottori",
    "1FPJ-JP-FB" => "Shimane",
    "1FPJ-JP-FC" => "Okayama",
    "1FPJ-JP-FD" => "Hiroshima",
    "1FPJ-JP-FE" => "Yamaguchi",
    "1FPJ-JP-G" => "Shikoku",
    "1FPJ-JP-GA" => "Tokushima",
    "1FPJ-JP-GB" => "Kagawa",
    "1FPJ-JP-GC" => "Ehime",
    "1FPJ-JP-GD" => "Kochi (JP)",
    "1FPJ-JP-H" => "Kyushu",
    "1FPJ-JP-HA" => "Fukuoka",
    "1FPJ-JP-HB" => "Saga",
    "1FPJ-JP-HC" => "Nagasaki",
    "1FPJ-JP-HD" => "Kumamoto",
    "1FPJ-JP-HE" => "Oita",
    "1FPJ-JP-HF" => "Miyazaki",
    "1FPJ-JP-HG" => "Kagoshima",
    "1FPJ-JP-HH" => "Okinawa",
    "1FPK" => "Korea",
    "1FPKN" => "North Korea",
    "1FPKS" => "South Korea",
    "1FPKS-KR-B" => "Seoul",
    "1FPM" => "Mongolia",
    "1FZ" => "Asia: physical features",
    "1FZA" => "Asia: rivers, lakes etc",
    "1FZAG" => "Ganges river & tributaries",
    "1FZAJ" => "Indus river & tributaries",
    "1FZAM" => "Mekong river & tributaries",
    "1FZAX" => "Yangtze river & tributaries",
    "1FZAY" => "Yellow river & tributaries",
    "1FZT" => "Asia: mountains, hills, plains, coastlines etc",
    "1FZTA" => "Altai mountains",
    "1FZTG" => "Gobi desert",
    "1FZTH" => "The Himalayas",
    "1FZTHA" => "Annapurna",
    "1FZTHK" => "Karakoram",
    "1FZTHKK" => "K2",
    "1FZTHM" => "Mahalangur Himal",
    "1FZTHME" => "Mount Everest",
    "1H" => "Africa",
    "1HB" => "North Africa",
    "1HBA" => "Algeria",
    "1HBA-DZ-A" => "Algiers",
    "1HBC" => "Chad",
    "1HBE" => "Egypt",
    "1HBE-AA-D" => "Nile Valley and Delta",
    "1HBE-AA-DA" => "Alexandria",
    "1HBE-AA-DB" => "Aswan",
    "1HBE-AA-DC" => "Cairo",
    "1HBE-AA-DD" => "Beheira",
    "1HBE-AA-DF" => "Beni Suef",
    "1HBE-AA-DG" => "Dakahlia",
    "1HBE-AA-DH" => "Damietta",
    "1HBE-AA-DJ" => "Gharbia",
    "1HBE-AA-DK" => "Giza",
    "1HBE-AA-DL" => "Kafr el-Sheikh",
    "1HBE-AA-DN" => "Minya",
    "1HBE-AA-DP" => "Monufia",
    "1HBE-AA-DQ" => "Qalyubia",
    "1HBE-AA-DS" => "Sharqia",
    "1HBE-AA-DW" => "Sohag",
    "1HBE-AA-DX" => "Luxor",
    "1HBE-AA-J" => "Egypt: Western Desert",
    "1HBE-AA-JF" => "Faiyum",
    "1HBE-AA-JM" => "Matruh",
    "1HBE-AA-JV" => "New Valley (Governorate of Egypt)",
    "1HBE-AA-M" => "Egypt: Eastern Desert",
    "1HBE-AA-MA" => "Asyut",
    "1HBE-AA-MQ" => "Qena",
    "1HBE-AA-MR" => "Red Sea (Governorate of Egypt)",
    "1HBE-AA-S" => "Sinai Peninsula",
    "1HBE-AA-SL" => "Ismailia",
    "1HBE-AA-SN" => "North Sinai",
    "1HBE-AA-SP" => "Port Said",
    "1HBE-AA-SS" => "South Sinai",
    "1HBE-AA-SZ" => "Suez",
    "1HBL" => "Libya",
    "1HBL-LY-C" => "Cyrenaica",
    "1HBL-LY-CB" => "Benghazi",
    "1HBL-LY-T" => "Tripolitania",
    "1HBL-LY-TT" => "Tripoli",
    "1HBM" => "Morocco",
    "1HBM-MA-B" => "Tanger-Tetouan-Al Hoceima",
    "1HBM-MA-BC" => "Tangier",
    "1HBM-MA-F" => "Fès-Meknès",
    "1HBM-MA-FE" => "Fez",
    "1HBM-MA-H" => "Rabat-Salé-Kenitra",
    "1HBM-MA-HR" => "Rabat",
    "1HBM-MA-L" => "Casablanca-Settat",
    "1HBM-MA-LC" => "Casablanca",
    "1HBM-MA-M" => "Marrakesh-Safi",
    "1HBM-MA-ME" => "Essaouira",
    "1HBM-MA-MM" => "Marrakesh / Marrakech",
    "1HBM-MA-P" => "Drâa-Tafilalet",
    "1HBM-MA-PO" => "Ouarzazate",
    "1HBM-MA-R" => "Souss-Massa",
    "1HBM-MA-RA" => "Agadir",
    "1HBS" => "Sudan",
    "1HBS-SD-B" => "Khartoum",
    "1HBT" => "Tunisia",
    "1HBT-TN-A" => "Tunis",
    "1HBT-TN-D" => "Djerba / Jerba",
    "1HBW" => "Western Sahara",
    "1HBZ" => "South Sudan",
    "1HF" => "Sub-Saharan Africa",
    "1HFD" => "West Africa",
    "1HFDA" => "Mauritania",
    "1HFDB" => "Benin",
    "1HFDE" => "Sierra Leone",
    "1HFDF" => "Burkina Faso",
    "1HFDG" => "Gambia",
    "1HFDH" => "Ghana",
    "1HFDH-GH-A" => "Accra",
    "1HFDL" => "Liberia",
    "1HFDL-LR-A" => "Monrovia",
    "1HFDM" => "Mali",
    "1HFDM-ML-A" => "Timbuktu",
    "1HFDN" => "Nigeria",
    "1HFDN-NG-A" => "Lagos",
    "1HFDR" => "Niger",
    "1HFDS" => "Senegal",
    "1HFDS-SN-A" => "Dakar",
    "1HFDT" => "Togo",
    "1HFDU" => "Guinea",
    "1HFDU-GN-A" => "Conakry",
    "1HFDV" => "Cape Verde",
    "1HFDX" => "Guinea-Bissau",
    "1HFDY" => "Ivory Coast",
    "1HFDY-CI-A" => "Abidjan",
    "1HFG" => "East Africa",
    "1HFGA" => "Ethiopia",
    "1HFGA-ET-A" => "Addis Ababa",
    "1HFGD" => "Djibouti",
    "1HFGE" => "Eritrea",
    "1HFGK" => "Kenya",
    "1HFGK-KE-A" => "Nairobi",
    "1HFGK-KE-M" => "Mombasa",
    "1HFGQ" => "Burundi",
    "1HFGR" => "Rwanda",
    "1HFGR-RW-A" => "Kigali",
    "1HFGS" => "Somalia",
    "1HFGSR" => "Republic of Somaliland",
    "1HFGT" => "Tanzania",
    "1HFGT-TZ-B" => "Dar es Salaam",
    "1HFGT-TZ-C" => "Zanzibar",
    "1HFGT-TZ-E" => "Northern Tanzania",
    "1HFGT-TZ-EB" => "Kilimanjaro",
    "1HFGT-TZ-ED" => "Serengeti",
    "1HFGU" => "Uganda",
    "1HFGU-UG-A" => "Kampala",
    "1HFJ" => "Central Africa",
    "1HFJA" => "Cameroon",
    "1HFJC" => "Congo (Congo-Brazzaville)",
    "1HFJC-CG-A" => "Brazzaville",
    "1HFJG" => "Gabon",
    "1HFJQ" => "Equatorial Guinea",
    "1HFJR" => "Central African Republic",
    "1HFJS" => "Sao Tome & Principe",
    "1HFJZ" => "Democratic Republic of Congo (former Zaire)",
    "1HFJZ-CD-A" => "Kinshasa",
    "1HFM" => "Southern Africa",
    "1HFMA" => "Angola",
    "1HFMB" => "Botswana",
    "1HFMB-BW-A" => "Gaborone",
    "1HFMB-BW-V" => "Okavango River & Delta",
    "1HFMK" => "Swaziland",
    "1HFML" => "Lesotho",
    "1HFMM" => "Malawi",
    "1HFMN" => "Namibia",
    "1HFMQ" => "Mozambique",
    "1HFMQ-MZ-A" => "Maputo",
    "1HFMS" => "Republic of South Africa",
    "1HFMS-ZA-A" => "Eastern Cape",
    "1HFMS-ZA-B" => "Free State",
    "1HFMS-ZA-BB" => "Bloemfontein",
    "1HFMS-ZA-D" => "Gauteng",
    "1HFMS-ZA-DB" => "Johannesburg",
    "1HFMS-ZA-DD" => "Pretoria",
    "1HFMS-ZA-F" => "KwaZulu-Natal",
    "1HFMS-ZA-FB" => "Durban",
    "1HFMS-ZA-H" => "Limpopo",
    "1HFMS-ZA-J" => "Mpumalanga",
    "1HFMS-ZA-K" => "North West Province",
    "1HFMS-ZA-M" => "Northern Cape",
    "1HFMS-ZA-N" => "Western Cape",
    "1HFMS-ZA-NB" => "Cape Town",
    "1HFMS-ZA-Z" => "South Africa: places of interest",
    "1HFMS-ZA-ZD" => "Drakensberg",
    "1HFMS-ZA-ZK" => "Kruger National Park",
    "1HFMW" => "Zimbabwe",
    "1HFMW-ZW-A" => "Harare",
    "1HFMZ" => "Zambia",
    "1HFMZ-ZM-A" => "Lusaka",
    "1HS" => "South Indian Ocean Islands",
    "1HSC" => "Comoros",
    "1HSM" => "Madagascar",
    "1HSU" => "Mauritius",
    "1HSU-MU-B" => "Rodrigues",
    "1HSV" => "Maldives",
    "1HSY" => "Seychelles",
    "1HS-FR-L" => "La Réunion",
    "1HS-FR-LA" => "Saint-Denis (Réunion)",
    "1HS-FR-LB" => "Saint-Benoît",
    "1HS-FR-LC" => "Saint-Paul",
    "1HS-FR-LD" => "Saint-Pierre (Réunion)",
    "1HS-FR-M" => "Mayotte",
    "1HS-FR-MA" => "Dzaoudzi",
    "1HZ" => "Africa: physical features",
    "1HZA" => "Africa: rivers, lakes etc",
    "1HZAC" => "Congo river & tributaries",
    "1HZAG" => "Niger river & tributaries",
    "1HZAM" => "Lake Nyasa / Lake Malawi",
    "1HZAN" => "Nile river & tributaries",
    "1HZAS" => "Suez canal",
    "1HZAT" => "Lake Tanganyika",
    "1HZAV" => "Lake Victoria",
    "1HZAZ" => "Zambesi river & tributaries",
    "1HZAZV" => "Mosi-oa-Tunya / Victoria Falls",
    "1HZT" => "Africa: mountains, hills, plains, coastlines etc",
    "1HZTA" => "Atlas mountains",
    "1HZTK" => "Kalahari desert",
    "1HZTR" => "Great Rift Valley",
    "1HZTS" => "The Sahara",
    "1HZTT" => "The Sahel",
    "1K" => "The Americas",
    "1KB" => "North America (USA & Canada)",
    "1KBB" => "United States of America, USA",
    "1KBB-US-M" => "US Midwest",
    "1KBB-US-ML" => "US Midwest: East North Central (Great Lakes) States",
    "1KBB-US-MLC" => "Illinois",
    "1KBB-US-MLCC" => "Chicago",
    "1KBB-US-MLCS" => "Springfield (IL)",
    "1KBB-US-MLD" => "Indiana",
    "1KBB-US-MLDD" => "Indianapolis",
    "1KBB-US-MLG" => "Michigan",
    "1KBB-US-MLGD" => "Detroit",
    "1KBB-US-MLO" => "Ohio",
    "1KBB-US-MLOL" => "Cleveland",
    "1KBB-US-MLON" => "Cincinnati",
    "1KBB-US-MLOO" => "Columbus",
    "1KBB-US-MLT" => "Minnesota",
    "1KBB-US-MLTM" => "Minneapolis-St. Paul",
    "1KBB-US-MLW" => "Wisconsin",
    "1KBB-US-MLWM" => "Milwaukee",
    "1KBB-US-MLWW" => "Madison",
    "1KBB-US-MP" => "US Midwest: West North Central (Great Plains) States",
    "1KBB-US-MPA" => "Iowa",
    "1KBB-US-MPK" => "Kansas",
    "1KBB-US-MPM" => "Missouri",
    "1KBB-US-MPMK" => "Kansas City (MO)",
    "1KBB-US-MPML" => "St. Louis",
    "1KBB-US-MPN" => "Nebraska",
    "1KBB-US-MPNL" => "Lincoln",
    "1KBB-US-MPNO" => "Omaha",
    "1KBB-US-MPR" => "North Dakota",
    "1KBB-US-MPT" => "South Dakota",
    "1KBB-US-MPTR" => "Mount Rushmore National Memorial",
    "1KBB-US-N" => "US Northeast",
    "1KBB-US-NA" => "US Northeast: Mid-Atlantic States",
    "1KBB-US-NAJ" => "New Jersey",
    "1KBB-US-NAJA" => "Atlantic City",
    "1KBB-US-NAJH" => "Hoboken",
    "1KBB-US-NAJN" => "Newark",
    "1KBB-US-NAJS" => "Jersey Shore",
    "1KBB-US-NAK" => "New York",
    "1KBB-US-NAKA" => "Albany",
    "1KBB-US-NAKB" => "Buffalo",
    "1KBB-US-NAKC" => "New York City",
    "1KBB-US-NAKCB" => "Brooklyn",
    "1KBB-US-NAKCM" => "Manhattan",
    "1KBB-US-NAKCMG" => "Greenwich Village",
    "1KBB-US-NAKCMH" => "Harlem",
    "1KBB-US-NAKL" => "Long Island",
    "1KBB-US-NAKN" => "Niagara Falls (City)",
    "1KBB-US-NAP" => "Pennsylvania",
    "1KBB-US-NAPD" => "Pennsylvania Dutch Country",
    "1KBB-US-NAPG" => "Gettysburg",
    "1KBB-US-NAPH" => "Philadelphia",
    "1KBB-US-NAPT" => "Pittsburgh",
    "1KBB-US-NE" => "US Northeast: New England",
    "1KBB-US-NEC" => "Connecticut",
    "1KBB-US-NECH" => "Hartford",
    "1KBB-US-NEI" => "Maine",
    "1KBB-US-NEIA" => "Acadia National Park",
    "1KBB-US-NEIP" => "Portland (ME)",
    "1KBB-US-NEM" => "Massachusetts",
    "1KBB-US-NEMB" => "Boston",
    "1KBB-US-NEMC" => "Cape Cod",
    "1KBB-US-NEMCM" => "Martha’s Vineyard",
    "1KBB-US-NEMCN" => "Nantucket",
    "1KBB-US-NEMM" => "Cambridge (MA)",
    "1KBB-US-NEMS" => "Salem (MA)",
    "1KBB-US-NEN" => "New Hampshire",
    "1KBB-US-NER" => "Rhode Island",
    "1KBB-US-NERN" => "Newport",
    "1KBB-US-NERP" => "Providence",
    "1KBB-US-NEV" => "Vermont",
    "1KBB-US-S" => "US South",
    "1KBB-US-SC" => "US South: East South Central States",
    "1KBB-US-SCA" => "Alabama",
    "1KBB-US-SCAM" => "Montgomery",
    "1KBB-US-SCK" => "Kentucky",
    "1KBB-US-SCKL" => "Louisville",
    "1KBB-US-SCM" => "Mississippi",
    "1KBB-US-SCT" => "Tennessee",
    "1KBB-US-SCTM" => "Memphis",
    "1KBB-US-SCTN" => "Nashville",
    "1KBB-US-SE" => "US South: South Atlantic States",
    "1KBB-US-SEC" => "District of Columbia (Washington D.C.)",
    "1KBB-US-SED" => "Delaware",
    "1KBB-US-SEF" => "Florida",
    "1KBB-US-SEFA" => "St. Augustine",
    "1KBB-US-SEFE" => "Everglades",
    "1KBB-US-SEFH" => "Tallahassee",
    "1KBB-US-SEFJ" => "Jacksonville",
    "1KBB-US-SEFK" => "Florida Keys",
    "1KBB-US-SEFM" => "Miami",
    "1KBB-US-SEFO" => "Orlando",
    "1KBB-US-SEFP" => "Tampa",
    "1KBB-US-SEG" => "Georgia (US State)",
    "1KBB-US-SEGS" => "Savannah",
    "1KBB-US-SEGT" => "Atlanta",
    "1KBB-US-SEM" => "Maryland",
    "1KBB-US-SEMA" => "Annapolis",
    "1KBB-US-SEMB" => "Baltimore",
    "1KBB-US-SEN" => "North Carolina",
    "1KBB-US-SENA" => "Asheville",
    "1KBB-US-SENB" => "Outer Banks",
    "1KBB-US-SENC" => "Charlotte",
    "1KBB-US-SENR" => "Raleigh",
    "1KBB-US-SES" => "South Carolina",
    "1KBB-US-SESC" => "Charleston (SC)",
    "1KBB-US-SESM" => "Myrtle Beach",
    "1KBB-US-SEV" => "Virginia",
    "1KBB-US-SEVC" => "Charlottesville",
    "1KBB-US-SEVR" => "Richmond",
    "1KBB-US-SEVV" => "Virginia Beach",
    "1KBB-US-SEVW" => "Williamsburg",
    "1KBB-US-SEW" => "West Virginia",
    "1KBB-US-SG" => "Great Smoky Mountains National Park",
    "1KBB-US-SW" => "US South: West South Central States",
    "1KBB-US-SWA" => "Arkansas",
    "1KBB-US-SWAH" => "Hot Springs",
    "1KBB-US-SWAL" => "Little Rock",
    "1KBB-US-SWL" => "Louisiana",
    "1KBB-US-SWLB" => "Baton Rouge",
    "1KBB-US-SWLN" => "New Orleans",
    "1KBB-US-SWO" => "Oklahoma",
    "1KBB-US-SWOC" => "Oklahoma City",
    "1KBB-US-SWOT" => "Tulsa",
    "1KBB-US-SWT" => "Texas",
    "1KBB-US-SWTA" => "Austin",
    "1KBB-US-SWTD" => "Dallas",
    "1KBB-US-SWTH" => "Houston",
    "1KBB-US-SWTN" => "San Antonio",
    "1KBB-US-SWTP" => "El Paso",
    "1KBB-US-SWTW" => "Fort Worth",
    "1KBB-US-W" => "US West",
    "1KBB-US-WM" => "US West: Mountain States",
    "1KBB-US-WMA" => "Arizona",
    "1KBB-US-WMAF" => "Flagstaff",
    "1KBB-US-WMAG" => "Grand Canyon National Park",
    "1KBB-US-WMAP" => "Phoenix",
    "1KBB-US-WMAS" => "Sedona",
    "1KBB-US-WMAT" => "Tucson",
    "1KBB-US-WMC" => "Colorado",
    "1KBB-US-WMCA" => "Aspen",
    "1KBB-US-WMCB" => "Boulder",
    "1KBB-US-WMCD" => "Denver",
    "1KBB-US-WMCR" => "Rocky Mountain National Park",
    "1KBB-US-WMD" => "Idaho",
    "1KBB-US-WMDB" => "Boise",
    "1KBB-US-WMM" => "Montana",
    "1KBB-US-WMMG" => "Glacier National Park",
    "1KBB-US-WMN" => "Nevada",
    "1KBB-US-WMNR" => "Reno",
    "1KBB-US-WMNV" => "Las Vegas",
    "1KBB-US-WMT" => "New Mexico",
    "1KBB-US-WMTA" => "Albuquerque",
    "1KBB-US-WMTF" => "Santa Fe",
    "1KBB-US-WMTT" => "Taos",
    "1KBB-US-WMU" => "Utah",
    "1KBB-US-WMUS" => "Salt Lake City",
    "1KBB-US-WMUZ" => "Zion National Park",
    "1KBB-US-WMW" => "Wyoming",
    "1KBB-US-WMWC" => "Cheyenne",
    "1KBB-US-WMWJ" => "Jackson Hole",
    "1KBB-US-WMWT" => "Grand Teton National Park",
    "1KBB-US-WMY" => "Yellowstone National Park",
    "1KBB-US-WP" => "US West: Pacific States",
    "1KBB-US-WPC" => "California",
    "1KBB-US-WPCA" => "Los Angeles",
    "1KBB-US-WPCAB" => "Beverly Hills",
    "1KBB-US-WPCAH" => "Hollywood",
    "1KBB-US-WPCD" => "San Diego",
    "1KBB-US-WPCF" => "San Francisco",
    "1KBB-US-WPCJ" => "San Jose",
    "1KBB-US-WPCM" => "Monterey",
    "1KBB-US-WPCN" => "Napa & Sonoma",
    "1KBB-US-WPCP" => "Palm Springs",
    "1KBB-US-WPCR" => "Fresno",
    "1KBB-US-WPCS" => "Sacramento",
    "1KBB-US-WPCY" => "Yosemite National Park",
    "1KBB-US-WPH" => "Hawaii",
    "1KBB-US-WPHH" => "Hawaii (Big Island)",
    "1KBB-US-WPHK" => "Kauai",
    "1KBB-US-WPHM" => "Maui",
    "1KBB-US-WPHO" => "Oahu",
    "1KBB-US-WPHOH" => "Honolulu",
    "1KBB-US-WPN" => "US Pacific Northwest",
    "1KBB-US-WPNA" => "Alaska",
    "1KBB-US-WPNAA" => "Anchorage",
    "1KBB-US-WPNAJ" => "Juneau",
    "1KBB-US-WPNR" => "Oregon",
    "1KBB-US-WPNRP" => "Portland (OR)",
    "1KBB-US-WPNW" => "Washington (US State)",
    "1KBB-US-WPNWO" => "Olympic National Park",
    "1KBB-US-WPNWS" => "Seattle",
    "1KBC" => "Canada",
    "1KBC-CA-A" => "Alberta",
    "1KBC-CA-AN" => "Northern Alberta",
    "1KBC-CA-ANB" => "Northern Alberta: Wood Buffalo and Waterton Lakes National Parks",
    "1KBC-CA-AND" => "Northern Alberta: Peace River Country (AB)",
    "1KBC-CA-ANG" => "Northern Alberta: Alberta’s Rockies & Banff and Jasper National Parks",
    "1KBC-CA-AS" => "Southern Alberta",
    "1KBC-CA-ASC" => "Southern Alberta: Calgary Region",
    "1KBC-CA-ASF" => "Southern Alberta: Edmonton Capital Region",
    "1KBC-CA-ASJ" => "Southern Alberta: Elk Island National Park",
    "1KBC-CA-ASN" => "Southern Alberta: Waterton Lakes National Park",
    "1KBC-CA-B" => "British Columbia",
    "1KBC-CA-BD" => "British Columbia Interior",
    "1KBC-CA-BDA" => "British Columbia Interior: Atlin District",
    "1KBC-CA-BDB" => "British Columbia Interior: Stikine Country",
    "1KBC-CA-BDC" => "British Columbia Interior: Peace River Country",
    "1KBC-CA-BDD" => "British Columbia Interior: Nechako",
    "1KBC-CA-BDE" => "British Columbia Interior: Bulkley",
    "1KBC-CA-BDF" => "British Columbia Interior: Cariboo",
    "1KBC-CA-BDG" => "British Columbia Interior: Chilcotin",
    "1KBC-CA-BDH" => "British Columbia Interior: Omineca-Prince George",
    "1KBC-CA-BDJ" => "British Columbia Interior: Robson Valley",
    "1KBC-CA-BDK" => "British Columbia Interior: Kootenays",
    "1KBC-CA-BDKA" => "British Columbia Interior: Kootenays National Parks (Mount Revelstoke, Kootenay, Glacier and Yoho)",
    "1KBC-CA-BDL" => "British Columbia Interior: Okanagan",
    "1KBC-CA-BDM" => "British Columbia Interior: Boundary",
    "1KBC-CA-BDN" => "British Columbia Interior: Similkameen",
    "1KBC-CA-BDP" => "British Columbia Interior: Thompson",
    "1KBC-CA-BDQ" => "British Columbia Interior: Shuswap",
    "1KBC-CA-BDR" => "British Columbia Interior: Lillooet-Fraser Canyon",
    "1KBC-CA-BF" => "British Columbia South Coast",
    "1KBC-CA-BFB" => "British Columbia South Coast: Lower Mainland",
    "1KBC-CA-BFD" => "British Columbia South Coast: Greater Vancouver",
    "1KBC-CA-BFF" => "British Columbia South Coast: Fraser Valley",
    "1KBC-CA-BFJ" => "British Columbia South Coast: Sea-to-Sky Corridor",
    "1KBC-CA-BFM" => "British Columbia South Coast: Gulf Islands & Gulf Islands National Park Reserve",
    "1KBC-CA-BFR" => "British Columbia South Coast: Sunshine Coast",
    "1KBC-CA-BL" => "British Columbia Vancouver Island",
    "1KBC-CA-BLC" => "British Columbia Vancouver Island: Greater Victoria",
    "1KBC-CA-BLK" => "British Columbia Vancouver Island: Mid-Island",
    "1KBC-CA-BLN" => "British Columbia Vancouver Island: North Island",
    "1KBC-CA-BLS" => "British Columbia Vancouver Island: West Coast",
    "1KBC-CA-BLW" => "British Columbia Vancouver Island: Juan de Fuca region & Pacific Rim National Park Reserve",
    "1KBC-CA-BP" => "British Columbia Central Coast",
    "1KBC-CA-BPD" => "British Columbia Central Coast: Queen Charlotte Strait",
    "1KBC-CA-BPL" => "British Columbia Central Coast: Bella Coola Valley",
    "1KBC-CA-BT" => "British Columbia North Coast",
    "1KBC-CA-BTE" => "British Columbia North Coast: Haida Gwaii & Gwaii Haanas National Park Reserve and Haida Heritage Site",
    "1KBC-CA-BTM" => "British Columbia North Coast: Skeena",
    "1KBC-CA-BTR" => "British Columbia North Coast: Nass",
    "1KBC-CA-BTY" => "British Columbia North Coast: Stewart Country",
    "1KBC-CA-C" => "Manitoba",
    "1KBC-CA-CN" => "Northern Manitoba",
    "1KBC-CA-CNB" => "Northern Manitoba: Wapusk National Park",
    "1KBC-CA-CP" => "Interlake and Central Manitoba",
    "1KBC-CA-CPR" => "Interlake and Central Manitoba: Riding Mountain National Park",
    "1KBC-CA-CS" => "Southern Manitoba",
    "1KBC-CA-CSW" => "Southern Manitoba: Winnipeg Capital Region",
    "1KBC-CA-D" => "New Brunswick",
    "1KBC-CA-DF" => "New Brunswick: Fundy National Park",
    "1KBC-CA-DK" => "New Brunswick: Greater Saint John",
    "1KBC-CA-DN" => "New Brunswick: Greater Fredericton",
    "1KBC-CA-F" => "Newfoundland & Labrador",
    "1KBC-CA-FL" => "Labrador",
    "1KBC-CA-FLT" => "Labrador: Torngat Mountains National Park",
    "1KBC-CA-FN" => "Newfoundland",
    "1KBC-CA-FNA" => "Newfoundland: Avalon Peninsula",
    "1KBC-CA-FNAJ" => "Newfoundland: Avalon Peninsula: St. John’s",
    "1KBC-CA-FNC" => "Newfoundland: Burin Peninsula",
    "1KBC-CA-FNE" => "Newfoundland: Bonavista Peninsula & Terra Nova National Park",
    "1KBC-CA-FNH" => "Newfoundland: South Coast",
    "1KBC-CA-FNK" => "Newfoundland: West Coast & Gros Morne National Park",
    "1KBC-CA-FNM" => "Newfoundland: Great Northern Peninsula",
    "1KBC-CA-FNR" => "Newfoundland: Northeast Coast",
    "1KBC-CA-H" => "Northwest Territories",
    "1KBC-CA-HL" => "Northwest Territories: Inuvik Region & Tuktut Nogait National Park",
    "1KBC-CA-HP" => "Northwest Territories: Sahtu Region",
    "1KBC-CA-HT" => "Northwest Territories: Dehcho Region & Nahanni and Naats’ihch’oh National Park Reserves",
    "1KBC-CA-HV" => "Northwest Territories: North Slave Region",
    "1KBC-CA-HW" => "Northwest Territories: Yellowknife",
    "1KBC-CA-HX" => "Northwest Territories: South Slave Region",
    "1KBC-CA-J" => "Nova Scotia",
    "1KBC-CA-JA" => "Nova Scotia: Annapolis Valley",
    "1KBC-CA-JB" => "Nova Scotia: Cape Breton Island & Cape Breton Highlands National Park",
    "1KBC-CA-JC" => "Central Nova Scotia",
    "1KBC-CA-JD" => "Nova Scotia: Eastern Shore & Sable Island National Park Reserve",
    "1KBC-CA-JH" => "Nova Scotia: Halifax Regional Municipality (HRM)",
    "1KBC-CA-JK" => "Nova Scotia: North Shore",
    "1KBC-CA-JM" => "Nova Scotia: South Shore & Kejimkujik National Park",
    "1KBC-CA-K" => "Nunavut",
    "1KBC-CA-KC" => "Nunavut: Kitikmeot Region",
    "1KBC-CA-KN" => "Nunavut: Kivalliq Region & Ukkusiksalik National Park",
    "1KBC-CA-KQ" => "Nunavut: Qikiqtaaluk Region & Auyuittuq, Sirmilik and Quttinirpaaq National Parks",
    "1KBC-CA-KQT" => "Nunavut: Qikiqtaaluk Region: Iqaluit",
    "1KBC-CA-O" => "Ontario",
    "1KBC-CA-OB" => "Northwestern Ontario",
    "1KBC-CA-OBP" => "Northwestern Ontario: Pukaskwa National Park",
    "1KBC-CA-OD" => "Northeastern Ontario",
    "1KBC-CA-OG" => "Central Ontario",
    "1KBC-CA-OGC" => "Central Ontario: Haliburton and Algonquin Park",
    "1KBC-CA-OGF" => "Central Ontario: Kawartha Lakes",
    "1KBC-CA-OGJ" => "Central Ontario: Muskoka",
    "1KBC-CA-OGQ" => "Central Ontario: Bay of Quinte",
    "1KBC-CA-OM" => "Eastern Ontario",
    "1KBC-CA-OMC" => "Eastern Ontario: Ottawa / National Capital Region",
    "1KBC-CA-OML" => "Eastern Ontario: Ottawa Valley",
    "1KBC-CA-OMT" => "Eastern Ontario: Thousand Islands & St. Lawrence Islands National Park",
    "1KBC-CA-OS" => "Southwestern Ontario",
    "1KBC-CA-OSB" => "Southwestern Ontario: Bruce Peninsula & National Park",
    "1KBC-CA-OSF" => "Southwestern Ontario: Georgian Triangle & Georgian Bay Islands National Park",
    "1KBC-CA-OSM" => "Southwestern Ontario: Greater Toronto Area",
    "1KBC-CA-OSR" => "Southwestern Ontario: Niagara Peninsula & Point Pelee National Park",
    "1KBC-CA-P" => "Prince Edward Island",
    "1KBC-CA-PM" => "Prince Edward Island: North Shore & Prince Edward Island National Park",
    "1KBC-CA-PR" => "Prince Edward Island: South Shore",
    "1KBC-CA-PT" => "Prince Edward Island: Summerside Area",
    "1KBC-CA-PV" => "Prince Edward Island: Charlottetown Area",
    "1KBC-CA-Q" => "Quebec",
    "1KBC-CA-QB" => "Quebec: Bas-Saint-Laurent",
    "1KBC-CA-QBB" => "Rimouski",
    "1KBC-CA-QBG" => "Kamouraska",
    "1KBC-CA-QBK" => "Reford Gardens",
    "1KBC-CA-QD" => "Quebec: Saguenay–Lac-Saint-Jean",
    "1KBC-CA-QDC" => "Saguenay (city)",
    "1KBC-CA-QDF" => "Saguenay River",
    "1KBC-CA-QDK" => "Lac Saint-Jean",
    "1KBC-CA-QF" => "Quebec, National Capital Region",
    "1KBC-CA-QFC" => "Quebec City",
    "1KBC-CA-QFF" => "Orleans Island",
    "1KBC-CA-QFG" => "Charlevoix",
    "1KBC-CA-QH" => "Quebec: Mauricie",
    "1KBC-CA-QHD" => "Trois-Rivières",
    "1KBC-CA-QHH" => "Shawanigan",
    "1KBC-CA-QJ" => "Quebec: Estrie / Eastern Townships",
    "1KBC-CA-QJS" => "Sherbrooke",
    "1KBC-CA-QL" => "Quebec: Outaouais",
    "1KBC-CA-QLG" => "Gatineau",
    "1KBC-CA-QM" => "Quebec: Montréal (region)",
    "1KBC-CA-QMM" => "Montreal",
    "1KBC-CA-QN" => "Quebec: Abitibi-Témiscamingue",
    "1KBC-CA-QP" => "Quebec: Côte-Nord",
    "1KBC-CA-QPC" => "Mingan Archipelago",
    "1KBC-CA-QPD" => "Anticosti Island",
    "1KBC-CA-QR" => "Quebec: Nord-du-Québec",
    "1KBC-CA-QRK" => "James Bay",
    "1KBC-CA-QRN" => "Nunavik",
    "1KBC-CA-QRU" => "Ungava Bay",
    "1KBC-CA-QS" => "Quebec: Gaspésie",
    "1KBC-CA-QSJ" => "Challeur Bay",
    "1KBC-CA-QT" => "Quebec: Chaudière-Appalaches",
    "1KBC-CA-QU" => "Quebec: Laval",
    "1KBC-CA-QV" => "Quebec: Lanaudière",
    "1KBC-CA-QW" => "Quebec: Laurentides",
    "1KBC-CA-QX" => "Quebec: Montérégie",
    "1KBC-CA-QY" => "Quebec: Centre-du-Québec",
    "1KBC-CA-S" => "Saskatchewan",
    "1KBC-CA-SD" => "Northern Saskatchewan",
    "1KBC-CA-SG" => "Central Saskatchewan",
    "1KBC-CA-SGA" => "Central Saskatchewan: Saskatoon",
    "1KBC-CA-SGP" => "Central Saskatchewan: Prince Albert National Park",
    "1KBC-CA-SS" => "Southern Saskatchewan",
    "1KBC-CA-SSA" => "Central Saskatchewan: Regina",
    "1KBC-CA-SSP" => "Central Saskatchewan: Grasslands National Park",
    "1KBC-CA-U" => "Yukon Territory",
    "1KBC-CA-UD" => "Yukon Territory: Northern Yukon, Vuntut & Ivvavik National Parks",
    "1KBC-CA-UF" => "Yukon Territory: Silver Trail Region",
    "1KBC-CA-UK" => "Yukon Territory: Klondike Region",
    "1KBC-CA-UL" => "Yukon Territory: Kluane Region & Kluane National Park & Reserve",
    "1KBC-CA-UO" => "Yukon Territory: Campbell & Watson Lakes Regions",
    "1KBC-CA-UW" => "Yukon Territory: Whitehorse & Southern Lakes Regions",
    "1KBC-CA-Z" => "Canada: Places of interest",
    "1KBC-CA-ZH" => "Hudson Bay",
    "1KBZ" => "North America: physical features",
    "1KBZA" => "North America: rivers, lakes etc",
    "1KBZAA" => "Great Lakes",
    "1KBZAAN" => "Niagara Falls",
    "1KBZAC" => "Colorado river & tributaries",
    "1KBZAG" => "Rio Grande & tributaries",
    "1KBZAK" => "Mackenzie river & tributaries",
    "1KBZAM" => "Mississippi-Missouri river & tributaries",
    "1KBZAS" => "St Lawrence river & tributaries",
    "1KBZAS-CA-L" => "Gulf of St Lawrence",
    "1KBZAY" => "Yukon river & tributaries",
    "1KBZA-US-H" => "Hudson river & tributaries",
    "1KBZA-US-L" => "Great Salt Lake",
    "1KBZA-US-O" => "Columbia river & tributaries",
    "1KBZA-US-P" => "Potomac river & Chesapeake Bay",
    "1KBZT" => "North America: mountains, hills, plains, coastlines etc",
    "1KBZTA" => "Appalachian Mountains",
    "1KBZTG" => "Grand Canyon",
    "1KBZTP" => "North America: Great Plains",
    "1KBZTR" => "Rocky Mountains",
    "1KBZT-US-D" => "Denali",
    "1KJ" => "Caribbean islands",
    "1KJC" => "Cuba",
    "1KJC-CU-A" => "Cuba: Western Region",
    "1KJC-CU-B" => "Cuba: Central Region",
    "1KJC-CU-C" => "Cuba: Eastern Region",
    "1KJC-CU-D" => "Havana",
    "1KJC-CU-V" => "Guantánamo",
    "1KJD" => "Dominican Republic",
    "1KJD-DO-A" => "Norte – Cilbao",
    "1KJD-DO-B" => "Dominican Republic: South Region",
    "1KJD-DO-C" => "Dominican Republic: Southeast / East Region",
    "1KJD-DO-D" => "Santo Domingo",
    "1KJH" => "Haiti",
    "1KJH-HT-P" => "Port-au-Prince",
    "1KJM" => "Cayman Islands",
    "1KJP" => "Puerto Rico",
    "1KJP-PR-C" => "Spanish Virgin Islands",
    "1KJP-PR-CC" => "Culebra",
    "1KJP-PR-CD" => "Vieques",
    "1KJP-PR-J" => "San Juan",
    "1KJW" => "West Indies",
    "1KJWB" => "Bahamas",
    "1KJWB-BS-A" => "Nassau",
    "1KJWJ" => "Jamaica",
    "1KJWJ-JM-B" => "Kingston",
    "1KJWT" => "Turks & Caicos Islands",
    "1KJWV" => "Leeward Islands",
    "1KJWVA" => "Anguilla",
    "1KJWVB" => "Antigua & Barbuda",
    "1KJWVG" => "Guadeloupe",
    "1KJWVG-FR-A" => "Basse Terre",
    "1KJWVG-FR-B" => "Pointe-à-Pitre",
    "1KJWVK" => "Saint Kitts & Nevis",
    "1KJWVM" => "Montserrat",
    "1KJWVV" => "Virgin Islands",
    "1KJWVVK" => "Virgin Islands (UK)",
    "1KJWVVS" => "Virgin Islands (USA)",
    "1KJWW" => "Windward Islands",
    "1KJWWB" => "Barbados",
    "1KJWWD" => "Dominica",
    "1KJWWG" => "Grenada",
    "1KJWWL" => "Saint Lucia",
    "1KJWWM" => "Martinique",
    "1KJWWM-FR-A" => "Fort-De-France",
    "1KJWWM-FR-B" => "La Trinité",
    "1KJWWM-FR-C" => "Le Marin",
    "1KJWWM-FR-D" => "Saint-Pierre",
    "1KJWWT" => "Trinidad & Tobago",
    "1KJWWT-TT-P" => "Port of Spain",
    "1KJWWV" => "Saint Vincent & the Grenadines",
    "1KJX" => "Lesser Antilles",
    "1KJXA" => "Aruba",
    "1KJXN" => "Dutch Caribbean",
    "1KJX-BL-B" => "Saint Barthélemy",
    "1KJX-BQ-B" => "Bonaire",
    "1KJX-BQ-E" => "Sint Eustatius",
    "1KJX-BQ-S" => "Saba",
    "1KJX-CW-C" => "Curaçao",
    "1KJX-MF-M" => "Saint Martin",
    "1KJX-SX-M" => "Sint Maarten",
    "1KL" => "Latin America – Mexico, Central America, South America",
    "1KLC" => "Mexico & Central America",
    "1KLCB" => "Belize",
    "1KLCG" => "Guatemala",
    "1KLCG-GT-A" => "Guatemala department",
    "1KLCG-GT-AC" => "Guatemala City",
    "1KLCG-GT-E" => "Guatemala: Central region",
    "1KLCG-GT-EB" => "Sacatepéquez",
    "1KLCG-GT-EBA" => "Antigua Guatemala",
    "1KLCG-GT-F" => "Guatemala: South western region",
    "1KLCG-GT-FB" => "Sololá",
    "1KLCG-GT-H" => "Petan department",
    "1KLCG-GT-HF" => "Flores (El Petén)",
    "1KLCH" => "Honduras",
    "1KLCH-HN-A" => "Honduras: Western region",
    "1KLCH-HN-AC" => "Copan",
    "1KLCH-HN-C" => "Honduras: North Eastern Region",
    "1KLCH-HN-CJ" => "Bay Islands",
    "1KLCH-HN-E" => "Honduras: Central Eastern Region",
    "1KLCH-HN-EA" => "Francisco Morazán (Department)",
    "1KLCH-HN-EAB" => "Tegucigalpa",
    "1KLCM" => "Mexico",
    "1KLCM-MX-A" => "Northwest Mexico",
    "1KLCM-MX-AA" => "Baja California",
    "1KLCM-MX-AAB" => "Tijuana",
    "1KLCM-MX-AB" => "Baja California Sur",
    "1KLCM-MX-ABB" => "Los Cabos",
    "1KLCM-MX-AC" => "Chihuahua",
    "1KLCM-MX-AD" => "Durango",
    "1KLCM-MX-AE" => "Sinaloa",
    "1KLCM-MX-AEB" => "Mazatlan",
    "1KLCM-MX-AF" => "Sonora",
    "1KLCM-MX-B" => "Northeast Mexico",
    "1KLCM-MX-BA" => "Coahuila de Zaragoza",
    "1KLCM-MX-BB" => "Nuevo Leon",
    "1KLCM-MX-BC" => "Tamaulipas",
    "1KLCM-MX-C" => "West Mexico",
    "1KLCM-MX-CA" => "Colima",
    "1KLCM-MX-CB" => "Jalisco",
    "1KLCM-MX-CBA" => "Guadalajara",
    "1KLCM-MX-CBD" => "Puerto Vallarta",
    "1KLCM-MX-CC" => "Michoacán de Ocampo",
    "1KLCM-MX-CD" => "Nayarit",
    "1KLCM-MX-D" => "East Mexico",
    "1KLCM-MX-DA" => "Hidalgo",
    "1KLCM-MX-DB" => "Puebla",
    "1KLCM-MX-DC" => "Tlaxcala",
    "1KLCM-MX-DD" => "Veracruz",
    "1KLCM-MX-E" => "North-Central Mexico",
    "1KLCM-MX-EA" => "Aguascalientes",
    "1KLCM-MX-EB" => "Guanajuato",
    "1KLCM-MX-EBB" => "San Miguel de Allende",
    "1KLCM-MX-EC" => "Queretaro",
    "1KLCM-MX-ED" => "San Luis Potosi",
    "1KLCM-MX-EE" => "Zacatecas",
    "1KLCM-MX-F" => "South-Central Mexico",
    "1KLCM-MX-FA" => "Mexico City",
    "1KLCM-MX-FB" => "Mexico State",
    "1KLCM-MX-FBM" => "Teotihuacan",
    "1KLCM-MX-FC" => "Morelos",
    "1KLCM-MX-G" => "Southwest Mexico",
    "1KLCM-MX-GA" => "Chiapas",
    "1KLCM-MX-GB" => "Guerrero",
    "1KLCM-MX-GBB" => "Acapulco",
    "1KLCM-MX-GBE" => "Ixtapa-Zihuatanejo",
    "1KLCM-MX-GC" => "Oaxaca",
    "1KLCM-MX-GCA" => "Oaxaca de Juarez",
    "1KLCM-MX-H" => "Southeast Mexico",
    "1KLCM-MX-HA" => "Campeche",
    "1KLCM-MX-HB" => "Quintana Roo",
    "1KLCM-MX-HBB" => "Cancun",
    "1KLCM-MX-HBC" => "Cozumel",
    "1KLCM-MX-HBD" => "Playa del Carmen",
    "1KLCM-MX-HBM" => "Tulum",
    "1KLCM-MX-HBN" => "Riviera Maya",
    "1KLCM-MX-HC" => "Tabasco",
    "1KLCM-MX-HD" => "Yucatán",
    "1KLCM-MX-HDA" => "Merida",
    "1KLCM-MX-HDM" => "Chichen Itza",
    "1KLCM-MX-HX" => "Southeast Mexico: Places of interest",
    "1KLCM-MX-HXP" => "Yucatan Peninsula",
    "1KLCM-MX-Z" => "Mexico: places of interest",
    "1KLCM-MX-ZC" => "Gulf of California / Sea of Cortes",
    "1KLCN" => "Nicaragua",
    "1KLCN-NI-A" => "Nicaragua: Pacific Region",
    "1KLCN-NI-B" => "Nicaragua: Central Region",
    "1KLCN-NI-C" => "Nicaragua: Caribbean Region",
    "1KLCN-NI-M" => "Managua",
    "1KLCP" => "Panama",
    "1KLCP-PA-A" => "Panamá",
    "1KLCP-PA-C" => "Colón",
    "1KLCP-PA-D" => "Darien",
    "1KLCR" => "Costa Rica",
    "1KLCR-CR-A" => "San José",
    "1KLCS" => "El Salvador",
    "1KLCS-SV-A" => "El Salvador: Western",
    "1KLCS-SV-B" => "El Salvador: Central",
    "1KLCS-SV-BA" => "San Salvador",
    "1KLCS-SV-C" => "El Salvador: Eastern",
    "1KLS" => "South America",
    "1KLSA" => "Argentina",
    "1KLSA-AR-A" => "Northwest Argentina (NOA)",
    "1KLSA-AR-AA" => "Catamarca",
    "1KLSA-AR-AB" => "Jujuy",
    "1KLSA-AR-AC" => "La Rioja",
    "1KLSA-AR-AD" => "Salta",
    "1KLSA-AR-AE" => "Santiago del Estero",
    "1KLSA-AR-AF" => "Tucuman",
    "1KLSA-AR-B" => "Northeast Argentina (NEA)",
    "1KLSA-AR-BA" => "Corrientes",
    "1KLSA-AR-BB" => "Chaco",
    "1KLSA-AR-BC" => "Formosa (AR)",
    "1KLSA-AR-BD" => "Misiones",
    "1KLSA-AR-C" => "Cuyo",
    "1KLSA-AR-CA" => "Mendoza",
    "1KLSA-AR-CAM" => "Aconcagua",
    "1KLSA-AR-CB" => "San Juan (AR)",
    "1KLSA-AR-CC" => "San Luis (AR)",
    "1KLSA-AR-D" => "Centro",
    "1KLSA-AR-DA" => "Buenos Aires",
    "1KLSA-AR-DB" => "Córdoba (AR)",
    "1KLSA-AR-DC" => "Entre Rios (Mesopotamia)",
    "1KLSA-AR-DD" => "La Pampa",
    "1KLSA-AR-DE" => "Santa Fe (AR)",
    "1KLSA-AR-E" => "Patagonia",
    "1KLSA-AR-EA" => "Chubut",
    "1KLSA-AR-EB" => "Neuquén",
    "1KLSA-AR-EC" => "Rio Negro (AR)",
    "1KLSA-AR-ED" => "Santa Cruz (AR)",
    "1KLSA-AR-EDM" => "Parque Nacional de los Glaciares",
    "1KLSA-AR-EE" => "Tierra del Fuego",
    "1KLSA-AR-EEA" => "Ushuaia",
    "1KLSB" => "Brazil",
    "1KLSB-BR-A" => "Brazil: North Region",
    "1KLSB-BR-AA" => "Acre (state)",
    "1KLSB-BR-AB" => "Amapa",
    "1KLSB-BR-AC" => "Amazonas (state)",
    "1KLSB-BR-AD" => "Para",
    "1KLSB-BR-AE" => "Rondônia",
    "1KLSB-BR-AF" => "Roraima",
    "1KLSB-BR-AG" => "Tocantins",
    "1KLSB-BR-B" => "Brazil: Northeast Region",
    "1KLSB-BR-BA" => "Alagoas",
    "1KLSB-BR-BB" => "Bahia",
    "1KLSB-BR-BBB" => "Salvador de Bahia",
    "1KLSB-BR-BC" => "Ceara",
    "1KLSB-BR-BD" => "Maranhão",
    "1KLSB-BR-BE" => "Paraíba",
    "1KLSB-BR-BF" => "Pernambuco",
    "1KLSB-BR-BFB" => "Recife",
    "1KLSB-BR-BG" => "Piaui",
    "1KLSB-BR-BH" => "Rio Grande do Norte",
    "1KLSB-BR-BJ" => "Sergipe",
    "1KLSB-BR-C" => "Brazil: Central-West Region",
    "1KLSB-BR-CA" => "Distrito Federal",
    "1KLSB-BR-CAB" => "Brasilia",
    "1KLSB-BR-CB" => "Goias",
    "1KLSB-BR-CC" => "Mato Grosso",
    "1KLSB-BR-CD" => "Mato Grosso do Sul",
    "1KLSB-BR-CZ" => "Brazil: Central-West Region: places of interest",
    "1KLSB-BR-CZP" => "Pantanal",
    "1KLSB-BR-D" => "Brazil: Southeast Region",
    "1KLSB-BR-DA" => "Espirito Santo",
    "1KLSB-BR-DB" => "Minas Gerais",
    "1KLSB-BR-DC" => "Rio de Janeiro (State)",
    "1KLSB-BR-DCA" => "Rio de Janeiro",
    "1KLSB-BR-DD" => "São Paulo",
    "1KLSB-BR-E" => "Brazil: South Region",
    "1KLSB-BR-EA" => "Parana",
    "1KLSB-BR-EB" => "Santa Catarina",
    "1KLSB-BR-EC" => "Rio Grande do Sul",
    "1KLSC" => "Colombia",
    "1KLSC-CO-A" => "Colombia: Amazonian Region",
    "1KLSC-CO-B" => "Colombia: Andean Region",
    "1KLSC-CO-BA" => "Antioquia",
    "1KLSC-CO-BAA" => "Medellin",
    "1KLSC-CO-BB" => "Boyaca",
    "1KLSC-CO-BD" => "Cundinamarca",
    "1KLSC-CO-BDA" => "Bogota",
    "1KLSC-CO-BF" => "Norte de Santander",
    "1KLSC-CO-BJ" => "Santander (department)",
    "1KLSC-CO-C" => "Colombia: Caribbean Region",
    "1KLSC-CO-CB" => "Bolivar (department)",
    "1KLSC-CO-CBA" => "Cartagena",
    "1KLSC-CO-CG" => "San Andres, Providencia & Santa Catalina",
    "1KLSC-CO-D" => "Colombia: Orinoco Region",
    "1KLSC-CO-E" => "Colombia: Pacific Region",
    "1KLSC-CO-ED" => "Valle del Cauca",
    "1KLSC-CO-EDA" => "Cali",
    "1KLSE" => "Ecuador",
    "1KLSE-EC-A" => "Ecuador: Coastal region",
    "1KLSE-EC-B" => "Ecuador: Andean region",
    "1KLSE-EC-BA" => "Azuay",
    "1KLSE-EC-BAA" => "Cuenca",
    "1KLSE-EC-BE" => "Chimborazo",
    "1KLSE-EC-BF" => "Cotopaxi",
    "1KLSE-EC-BJ" => "Pichincha",
    "1KLSE-EC-BJA" => "Quito",
    "1KLSE-EC-C" => "Ecuador: Amazonian region",
    "1KLSF" => "French Guiana",
    "1KLSF-FR-A" => "Cayenne",
    "1KLSF-FR-B" => "Saint-Laurent-du-Maroni",
    "1KLSG" => "Guyana",
    "1KLSG-GY-G" => "Georgetown",
    "1KLSH" => "Chile",
    "1KLSH-CL-A" => "Norte Grande",
    "1KLSH-CL-B" => "Norte Chico",
    "1KLSH-CL-C" => "Chile: Zona Central",
    "1KLSH-CL-CD" => "Santiago Metropolitan Region",
    "1KLSH-CL-CV" => "Valparaíso",
    "1KLSH-CL-D" => "Zona Sur",
    "1KLSH-CL-DA" => "Biobío Region",
    "1KLSH-CL-DAA" => "Concepción",
    "1KLSH-CL-DC" => "Los Ríos Region",
    "1KLSH-CL-DCA" => "Valdivia",
    "1KLSH-CL-DD" => "Los Lagos Region",
    "1KLSH-CL-DDA" => "Chiloé Archipelago",
    "1KLSH-CL-E" => "Zona Austral",
    "1KLSH-CL-EA" => "Magallanes & Chilean Antarctica Region",
    "1KLSL" => "Bolivia",
    "1KLSL-BO-A" => "Pando",
    "1KLSL-BO-B" => "La Paz",
    "1KLSL-BO-C" => "Beni",
    "1KLSL-BO-D" => "Oruro",
    "1KLSL-BO-E" => "Cochabamba",
    "1KLSL-BO-F" => "Santa Cruz",
    "1KLSL-BO-G" => "Potosi",
    "1KLSL-BO-H" => "Chuquisaca",
    "1KLSL-BO-HA" => "Sucre",
    "1KLSL-BO-J" => "Tarija",
    "1KLSP" => "Paraguay",
    "1KLSP-PY-A" => "Asunción",
    "1KLSP-PY-B" => "Paraguay: Western Region",
    "1KLSP-PY-C" => "Paraguay: Eastern Region",
    "1KLSR" => "Peru",
    "1KLSR-PE-A" => "Peru: Amazon Region",
    "1KLSR-PE-AA" => "Amazonas region",
    "1KLSR-PE-AAB" => "Chachapoyas",
    "1KLSR-PE-AC" => "Madre de Dios region",
    "1KLSR-PE-ACT" => "Tambopata",
    "1KLSR-PE-B" => "Peru: Andean Region",
    "1KLSR-PE-BD" => "Cusco region",
    "1KLSR-PE-BDC" => "Cusco / Cuzco",
    "1KLSR-PE-BDD" => "La Convención",
    "1KLSR-PE-BDM" => "Machu Picchu",
    "1KLSR-PE-BDV" => "Ausangate & the Cordillera Vilcanota",
    "1KLSR-PE-C" => "Peru: Northern coastal region",
    "1KLSR-PE-D" => "Peru: Central coastal region",
    "1KLSR-PE-DA" => "Ancash region",
    "1KLSR-PE-DAB" => "Huaraz",
    "1KLSR-PE-DAS" => "Cordillera Blanca & Huascaran National Park",
    "1KLSR-PE-DAY" => "Yerupaja & Huayhuash",
    "1KLSR-PE-DC" => "La Libertad region",
    "1KLSR-PE-DD" => "Lima region",
    "1KLSR-PE-DDL" => "Lima",
    "1KLSR-PE-E" => "Peru: Southern coastal region",
    "1KLSR-PE-EA" => "Arequipa region",
    "1KLSR-PE-EB" => "Ica region",
    "1KLSR-PE-EBN" => "Nazca",
    "1KLSS" => "Suriname",
    "1KLSS-SR-P" => "Paramaribo",
    "1KLSU" => "Uruguay",
    "1KLSU-UY-A" => "Uruguay: North",
    "1KLSU-UY-B" => "Uruguay: North West",
    "1KLSU-UY-C" => "Uruguay: South West",
    "1KLSU-UY-D" => "Uruguay: East",
    "1KLSU-UY-E" => "Uruguay: Southern central",
    "1KLSU-UY-EF" => "Montevideo",
    "1KLSV" => "Venezuela",
    "1KLSV-VE-A" => "Venezuela: Andes Region",
    "1KLSV-VE-AA" => "Mérida (Venezuela)",
    "1KLSV-VE-B" => "Venezuela: Central Region",
    "1KLSV-VE-C" => "Capital Region and Caracas",
    "1KLSV-VE-D" => "Venezuela: Guayana Region",
    "1KLSV-VE-E" => "Venezuela: Insular Region",
    "1KLSV-VE-EA" => "Margarita Island",
    "1KLSV-VE-F" => "Los Llanos Region",
    "1KLSV-VE-G" => "Venezuela: Northeast Region",
    "1KLSV-VE-H" => "Venezuela: Central-western Region",
    "1KLSV-VE-J" => "Zuliana Region",
    "1KLZ" => "South & Central America: physical features",
    "1KLZA" => "South & Central America: rivers, lakes etc",
    "1KLZAA" => "Amazon river & tributaries",
    "1KLZAC" => "Panama canal",
    "1KLZAO" => "Orinoco River",
    "1KLZAP" => "Paraná-Río de la Plata & tributaries",
    "1KLZAPF" => "Iguazu Falls & river",
    "1KLZAT" => "Lake Titicaca",
    "1KLZT" => "South & Central America: mountains, hills, plains, coastlines etc",
    "1KLZTA" => "Andes mountains",
    "1KLZTAB" => "Altiplano / Andean plateau",
    "1KLZTG" => "Galapagos Islands",
    "1KLZTM" => "Sierra Madre mountains",
    "1M" => "Australasia, Oceania, Pacific Islands, Atlantic Islands",
    "1MB" => "Australasia",
    "1MBF" => "Australia",
    "1MBF-AU-C" => "Australian Capital Territory (ACT)",
    "1MBF-AU-CA" => "Canberra",
    "1MBF-AU-N" => "New South Wales",
    "1MBF-AU-NS" => "Sydney",
    "1MBF-AU-Q" => "Queensland",
    "1MBF-AU-QB" => "Brisbane",
    "1MBF-AU-S" => "South Australia",
    "1MBF-AU-SA" => "Adelaide",
    "1MBF-AU-T" => "Tasmania",
    "1MBF-AU-TH" => "Hobart",
    "1MBF-AU-V" => "Victoria",
    "1MBF-AU-VM" => "Melbourne",
    "1MBF-AU-W" => "Western Australia",
    "1MBF-AU-WP" => "Perth",
    "1MBF-AU-X" => "Northern Territory",
    "1MBF-AU-XD" => "Darwin",
    "1MBN" => "New Zealand",
    "1MBZ" => "Australasia: physical features",
    "1MBZA" => "Australasia: rivers, lakes etc",
    "1MBZAD" => "Murray-Darling river & tributaries",
    "1MBZT" => "Australasia: mountains, hills, plains, coastlines etc",
    "1MBZTB" => "Great Dividing Range mountains",
    "1MBZTD" => "Great Barrier Reef",
    "1MBZTU" => "Uluru & The Outback",
    "1MK" => "Oceania",
    "1MKC" => "Micronesia",
    "1MKCB" => "Palau",
    "1MKCC" => "Caroline Islands",
    "1MKCF" => "Federated States of Micronesia",
    "1MKCG" => "Gilbert Islands",
    "1MKCM" => "Marshall Islands",
    "1MKCN" => "Nauru",
    "1MKCU" => "Guam",
    "1MKCV" => "Northern Marianas",
    "1MKL" => "Melanesia",
    "1MKLF" => "Fiji",
    "1MKLN" => "New Caledonia",
    "1MKLN-FR-N" => "Nouméa",
    "1MKLP" => "New Guinea",
    "1MKLPN" => "Papua New Guinea",
    "1MKLS" => "Solomon Islands",
    "1MKLV" => "Vanuatu",
    "1MKP" => "Polynesia",
    "1MKPC" => "Cook Islands",
    "1MKPCR" => "Raratonga",
    "1MKPE" => "Easter Island",
    "1MKPF" => "French Polynesia",
    "1MKPFT" => "Tahiti",
    "1MKPFT-FR-P" => "Papeete",
    "1MKPH" => "Hawaiian Islands",
    "1MKPK" => "Kiribati",
    "1MKPN" => "Niue",
    "1MKPP" => "Pitcairn Island",
    "1MKPR" => "Samoan Islands",
    "1MKPRA" => "American Samoa",
    "1MKPRW" => "Western Samoa",
    "1MKPT" => "Tonga",
    "1MKPU" => "Tokelau",
    "1MKPV" => "Tuvalu",
    "1MKPW" => "Wallis & Futuna",
    "1MKPW-FR-M" => "Mata-Utu",
    "1MT" => "Atlantic Ocean islands / Polar regions",
    "1MTA" => "Atlantic Ocean islands",
    "1MTAN" => "North Atlantic islands",
    "1MTANB" => "Bermuda",
    "1MTANC" => "The Canary Islands",
    "1MTANM" => "Madeira",
    "1MTANZ" => "Azores",
    "1MTAN-FR-P" => "Saint Pierre & Miquelon",
    "1MTAS" => "South Atlantic islands",
    "1MTASC" => "Ascension Island",
    "1MTASF" => "Falklands",
    "1MTASG" => "South Georgia",
    "1MTASH" => "Saint Helena",
    "1MTAST" => "Tristan da Cunha",
    "1MTN" => "Arctic regions",
    "1MTNG" => "Greenland",
    "1MTNG-GL-A" => "North-east Greenland (National park)",
    "1MTNG-GL-D" => "Kommune Kujalleq",
    "1MTNG-GL-G" => "Kommuneqarfik Sermersooq",
    "1MTNG-GL-GN" => "Nuuk",
    "1MTNG-GL-J" => "Qeqqata Kommunia",
    "1MTNG-GL-JK" => "Kangerlussuaq (Søndre Strømfjord)",
    "1MTNG-GL-M" => "Qaasuitsup Kommunia",
    "1MTNG-GL-MP" => "Thule Air Base (Pituffik)",
    "1MTN-NO-J" => "Jan Mayen",
    "1MTN-NO-S" => "Svalbard",
    "1MTS" => "Antarctica",
    "1Q" => "Other geographical groupings: Oceans & seas, historical, political etc",
    "1QB" => "Historical states, empires & regions",
    "1QBA" => "Ancient World",
    "1QBAA" => "Assyrian Empires",
    "1QBAB" => "Babylonia",
    "1QBAE" => "Ancient Egypt",
    "1QBAG" => "Ancient Greece",
    "1QBAG-IT-A" => "Magna Grecia (Hellenic Italy)",
    "1QBAH" => "Hittite Empire",
    "1QBAL" => "Ancient / Biblical Israel",
    "1QBAM" => "Mesopotamia",
    "1QBAP" => "Persian Empire",
    "1QBAR" => "Ancient Rome",
    "1QBAS" => "Sumer",
    "1QBAT" => "Etruria",
    "1QBC" => "Historical states & empires: multi-continental",
    "1QBCB" => "Byzantine Empire",
    "1QBCE" => "Islamic Caliphate",
    "1QBCL" => "Mongol Empire",
    "1QBCS" => "Ottoman Empire",
    "1QBCU" => "British Empire",
    "1QBC-FR-C" => "French Colonial Empire",
    "1QBD" => "Historical states & empires: Europe",
    "1QBDA" => "Austro-Hungarian Empire",
    "1QBDF" => "Holy Roman Empire",
    "1QBDK" => "Czechoslovakia",
    "1QBDL" => "East Germany, DDR",
    "1QBDN" => "West Germany",
    "1QBDP" => "Prussia",
    "1QBDR" => "USSR, Soviet Union",
    "1QBDT" => "Russian tsarist empire",
    "1QBDY" => "Yugoslavia",
    "1QBD-FR-G" => "Gaul",
    "1QBD-FR-L" => "Carolingian Empire",
    "1QBD-FR-N" => "Napoleonic Empire",
    "1QBD-FR-Z" => "France: Historical & cultural regions",
    "1QBF" => "Historical states & empires: Asia",
    "1QBH" => "Historical states & empires: Africa",
    "1QBHK" => "Ashanti Kingdoms",
    "1QBK" => "Historical states & empires: Americas",
    "1QBKC" => "Confederate States of America",
    "1QBKL" => "Inca Empire / Incas",
    "1QBKM" => "Mesoamerican civilisations",
    "1QBKMA" => "Aztec Empire",
    "1QBKMM" => "Mayan states",
    "1QBK-CA-Q" => "New France",
    "1QBK-CA-QA" => "New France: Acadia",
    "1QBK-CA-QL" => "New France: French Louisiana",
    "1QBM" => "Historical states & empires: Australasia, Oceania & other land areas",
    "1QF" => "Political, socio-economic, cultural & strategic groupings",
    "1QFA" => "Arab world / Arab League",
    "1QFAM" => "Maghreb",
    "1QFC" => "Commonwealth of Nations",
    "1QFE" => "EU (European Union)",
    "1QFG" => "Developing countries",
    "1QFH" => "Industrialized / developed countries",
    "1QFL" => "Sápmi",
    "1QFM" => "Islamic countries",
    "1QFN" => "NATO",
    "1QFP" => "OPEC",
    "1QFS" => "ASEAN",
    "1QFU" => "United Nations",
    "1QFW" => "Warsaw Pact, Eastern bloc",
    "1QF-CA-A" => "Atlantic Canada (NB, PE, NS, NL)",
    "1QF-CA-C" => "Central Canada (ON, QC)",
    "1QF-CA-E" => "Eastern Canada (ON, QC, NB, PE, NS, NL)",
    "1QF-CA-M" => "Canada Maritimes (NB, PE, NS)",
    "1QF-CA-P" => "Canadian Prairies (AB, SK, MB)",
    "1QF-CA-T" => "Canadian Territories (YT, NT, NU)",
    "1QF-CA-W" => "Western Canada (BC, AB, SK, MB)",
    "1QM" => "Climatic regions",
    "1QMP" => "Polar regions",
    "1QMT" => "Tropics",
    "1QR" => "Groupings linked by seas",
    "1QRM" => "Mediterranean countries",
    "1QRP" => "Pacific Rim countries",
    "1QS" => "Oceans & seas",
    "1QSA" => "Atlantic Ocean",
    "1QSAN" => "North Atlantic",
    "1QSAS" => "South Atlantic",
    "1QSB" => "Baltic Sea",
    "1QSC" => "Caribbean Sea",
    "1QSD" => "Gulf of Mexico",
    "1QSE" => "Irish Sea",
    "1QSF" => "North Sea",
    "1QSG" => "English Channel",
    "1QSJ" => "Caspian Sea",
    "1QSK" => "Black Sea",
    "1QSL" => "Red Sea",
    "1QSM" => "Mediterranean Sea",
    "1QSMA" => "Ligurian Sea",
    "1QSMB" => "Tyrrhenian Sea",
    "1QSMC" => "Adriatic Sea",
    "1QSMD" => "Ionian Sea",
    "1QSN" => "Indian Ocean",
    "1QSNP" => "Persian Gulf",
    "1QSP" => "Pacific Ocean",
    "1QSPN" => "North Pacific",
    "1QSPS" => "South Pacific",
    "1QSR" => "Arctic Ocean",
    "1QSS" => "Southern Ocean",
    "1QST" => "Tasman Sea",
    "1Z" => "Space, planets & extraterrestrial locations",
    "1ZM" => "The Solar System",
    "1ZMA" => "The Sun",
    "1ZMC" => "The Planets",
    "1ZMCB" => "Mercury",
    "1ZMCD" => "Venus",
    "1ZMCE" => "Earth",
    "1ZMCEL" => "The Moon",
    "1ZMCF" => "Mars",
    "1ZMCH" => "Jupiter",
    "1ZMCK" => "Saturn",
    "1ZMCM" => "Uranus",
    "1ZMCN" => "Neptune",
    "1ZMG" => "Other entities in the Solar System",
    "1ZMGP" => "Pluto & dwarf planets",
    "1ZMGR" => "Comets",
    "1ZMGT" => "Asteroids, the Asteroid belt",
    "2A" => "Indo-European languages",
    "2AC" => "Germanic & Scandinavian languages",
    "2ACB" => "English",
    "2ACBA" => "Anglo-Saxon / Old English",
    "2ACBC" => "Middle English",
    "2ACBK" => "American English",
    "2ACBM" => "Australian English",
    "2ACBR" => "Canadian English",
    "2ACC" => "Scots (Lallans, the Doric)",
    "2ACCU" => "Ulster Scots (Ullans)",
    "2ACD" => "Dutch",
    "2ACF" => "Flemish",
    "2ACG" => "German",
    "2ACGH" => "Swiss German (Alemannic)",
    "2ACGM" => "German, Middle High",
    "2ACGP" => "German, Old High",
    "2ACK" => "Afrikaans",
    "2ACS" => "Scandinavian languages",
    "2ACSC" => "Icelandic",
    "2ACSD" => "Danish",
    "2ACSF" => "Faroese",
    "2ACSJ" => "Jutish",
    "2ACSN" => "Norwegian",
    "2ACSNB" => "Norwegian, bokmål",
    "2ACSNK" => "Norwegian, nynorsk",
    "2ACSW" => "Swedish",
    "2ACSX" => "Old Norse",
    "2ACY" => "Yiddish",
    "2ACZ" => "Other Germanic languages & dialects",
    "2ACZF" => "Frisian",
    "2AD" => "Romance, Italic & Rhaeto-Romanic languages",
    "2ADC" => "Catalan",
    "2ADD" => "Valencian",
    "2ADF" => "French",
    "2ADFP" => "Provencal",
    "2ADFQ" => "Canadian French",
    "2ADFQ-CA-A" => "Acadian French",
    "2ADFQ-CA-C" => "Quebec French (Quebecois)",
    "2ADH" => "Corsican",
    "2ADL" => "Latin",
    "2ADP" => "Portuguese",
    "2ADPB" => "Brazilian Portuguese",
    "2ADQ" => "Galician (Gallego, Galego)",
    "2ADR" => "Romanian",
    "2ADS" => "Spanish",
    "2ADSL" => "Latin-American Spanish",
    "2ADT" => "Italian",
    "2ADTX" => "Italian dialects",
    "2ADV" => "Sardinian",
    "2ADW" => "Ladin languages",
    "2AD-ES-G" => "Aragonese",
    "2AD-ES-N" => "Aranese",
    "2AD-ES-T" => "Asturian",
    "2AD-FR-C" => "Occitan (lenga d’òc)",
    "2AF" => "Celtic languages",
    "2AFB" => "Breton",
    "2AFC" => "Cornish",
    "2AFG" => "Gaulish",
    "2AFM" => "Manx",
    "2AFR" => "Irish Gaelic",
    "2AFS" => "Scottish Gaelic",
    "2AFW" => "Welsh",
    "2AG" => "Slavic (Slavonic) languages",
    "2AGB" => "Bulgarian",
    "2AGC" => "Church Slavic",
    "2AGK" => "Slovak",
    "2AGL" => "Belarusian (Belorussian)",
    "2AGM" => "Macedonian",
    "2AGP" => "Polish",
    "2AGR" => "Russian",
    "2AGS" => "Serbo-Croatian",
    "2AGSC" => "Croatian",
    "2AGSS" => "Serbian",
    "2AGU" => "Ukrainian",
    "2AGV" => "Slovenian",
    "2AGW" => "Wendish (Lusatian, Sorbian)",
    "2AGZ" => "Czech",
    "2AH" => "Hellenic languages",
    "2AHA" => "Ancient (Classical) Greek",
    "2AHB" => "Biblical Greek",
    "2AHM" => "Modern Greek",
    "2AJ" => "Baltic & other Indo-European languages",
    "2AJB" => "Baltic languages",
    "2AJBL" => "Lithuanian",
    "2AJBV" => "Latvian (Lettish)",
    "2AJK" => "Other Indo-European languages",
    "2AJKL" => "Albanian",
    "2AJKR" => "Armenian",
    "2B" => "Indic, East Indo-European & Dravidian languages",
    "2BB" => "Early Indic languages",
    "2BBA" => "Sanskrit",
    "2BBP" => "Pali",
    "2BM" => "Modern Indic languages",
    "2BMB" => "Bengali",
    "2BMD" => "Marathi",
    "2BMG" => "Gujarati",
    "2BMH" => "Hindi",
    "2BMJ" => "Rajasthani",
    "2BMK" => "Kashmiri",
    "2BMN" => "Nepali",
    "2BMP" => "Punjabi",
    "2BMR" => "Romany",
    "2BMS" => "Sinhalese",
    "2BMSM" => "Maldivian",
    "2BMU" => "Urdu",
    "2BR" => "Dravidian languages",
    "2BRB" => "Brahui",
    "2BRK" => "Kannada (Kanarese)",
    "2BRL" => "Telugu",
    "2BRM" => "Malayalam",
    "2BRT" => "Tamil",
    "2BX" => "Indo-Iranian languages",
    "2BXF" => "Persian (Farsi)",
    "2BXK" => "Kurdish",
    "2BXL" => "Pashto (Pushto, Afghan)",
    "2BXZ" => "Zend Avestan",
    "2C" => "Afro-Asiatic languages",
    "2CS" => "Semitic languages",
    "2CSA" => "Aramaic",
    "2CSB" => "Assyro-Babylonian (Akkadian) languages",
    "2CSJ" => "Hebrew",
    "2CSM" => "Maltese",
    "2CSR" => "Arabic",
    "2CSS" => "Syriac",
    "2CST" => "Ethiopic",
    "2CSTA" => "Amharic",
    "2CSTT" => "Tigrinya",
    "2CX" => "Non-Semitic Afro-Asiatic languages",
    "2CXB" => "Berber (Tuareg)",
    "2CXC" => "Coptic",
    "2CXG" => "Egyptian",
    "2CXH" => "Hausa",
    "2CXS" => "Somali",
    "2CXSR" => "Oromo",
    "2F" => "Ural-Altaic & Hyperborean languages",
    "2FC" => "Finno-Ugric languages",
    "2FCD" => "Estonian",
    "2FCF" => "Finnish (Suomi)",
    "2FCL" => "Sami",
    "2FCLD" => "Southern Sami",
    "2FCLF" => "Northern Sami",
    "2FCLL" => "Lule Sami",
    "2FCLN" => "Inari Sami",
    "2FCLS" => "Skolt Sami",
    "2FCLX" => "Sami languages (other)",
    "2FCM" => "Hungarian (Magyar)",
    "2FM" => "Turkic languages",
    "2FMC" => "Turkish",
    "2FMH" => "Kirghiz",
    "2FMK" => "Kazakh",
    "2FMN" => "Turkmen",
    "2FMU" => "Uzbek",
    "2FMZ" => "Azerbaijani",
    "2FV" => "Mongolian",
    "2FW" => "Tungusic languages",
    "2FWK" => "Evenki",
    "2FWM" => "Manchu",
    "2FX" => "Hyperborean & Palaeosiberian languages",
    "2G" => "East & Southeast Asian languages",
    "2GD" => "Sino-Tibetan languages",
    "2GDB" => "Burmese",
    "2GDC" => "Chinese",
    "2GDCC" => "Cantonese",
    "2GDCK" => "Hokkien",
    "2GDCM" => "Mandarin",
    "2GDCW" => "Wu",
    "2GDCY" => "Amoy",
    "2GDK" => "Karen",
    "2GDT" => "Tibetan",
    "2GJ" => "Japanese",
    "2GK" => "Korean",
    "2GR" => "Other Southeast Asian languages, Austroasiatic languages",
    "2GRH" => "Cambodian (Khmer)",
    "2GRL" => "Lao",
    "2GRM" => "Hmong (Miao)",
    "2GRS" => "Thai (Siamese)",
    "2GRV" => "Vietnamese",
    "2H" => "African languages",
    "2HC" => "Niger-Congo languages",
    "2HCB" => "Bantu languages",
    "2HCBA" => "Bantu proper (Narrow Bantu)",
    "2HCBB" => "Central Bantu languages",
    "2HCBBC" => "Chichewa (Chewa)",
    "2HCBBF" => "Chilomwe (Lomwe)",
    "2HCBBH" => "Chinyanja (Cinyanja, Nyanja)",
    "2HCBBJ" => "Chitonga (Tonga)",
    "2HCBBL" => "Chitumbuka (Tumbuka)",
    "2HCBBN" => "Chiyao (Yao)",
    "2HCBBP" => "Icibemba (Bemba)",
    "2HCBBQ" => "Kiikaonde (Kaonde)",
    "2HCBBR" => "Kongo",
    "2HCBBS" => "Lunda",
    "2HCBBU" => "Luvale",
    "2HCBD" => "kiSwahili (Swahili)",
    "2HCBH" => "OtjiHerero (Herero)",
    "2HCBK" => "Kikuyu",
    "2HCBL" => "Nyoro-Ganda group",
    "2HCBLG" => "Luganda (Ganda)",
    "2HCBLR" => "Nyankore (Runyankore-Rukiga)",
    "2HCBM" => "Fang (Yaunde-Fang)",
    "2HCBN" => "Duala",
    "2HCBP" => "Tshivenda & Venda group",
    "2HCBQ" => "Shona",
    "2HCBS" => "Sotho-Tswana group",
    "2HCBSA" => "Sesotho (Sotho, Sesotho sa Leboa, Southern Sotho)",
    "2HCBSB" => "Sepedi (Northern Sotho)",
    "2HCBSD" => "Setswana (Tswana)",
    "2HCBSF" => "Silozi",
    "2HCBV" => "XiTsonga (Tsonga)",
    "2HCBW" => "Siswati (Swazi)",
    "2HCBX" => "isiXhosa (Xhosa)",
    "2HCBY" => "isiNdebele (Ndebele)",
    "2HCBZ" => "isiZulu (Zulu)",
    "2HCW" => "West Atlantic & Volta Congo languages",
    "2HCWF" => "Fulani (Fulah)",
    "2HCWV" => "Volta-Congo languages",
    "2HCWVB" => "Ibo (Igbo)",
    "2HCWVD" => "Dagbani (Dagomba)",
    "2HCWVE" => "Ewe",
    "2HCWVG" => "Ga",
    "2HCWVN" => "Fante",
    "2HCWVS" => "Asante Twi",
    "2HCWVT" => "Akwapim Twi",
    "2HCWVY" => "Yoruba",
    "2HK" => "Khoisan languages",
    "2HN" => "Nilo-Saharan & Chari-Nile (Macrosudanic) languages",
    "2HND" => "Dinka",
    "2HNM" => "Masai",
    "2HNR" => "Nubian",
    "2HNT" => "Teso (Ateso)",
    "2HX" => "Other African languages",
    "2J" => "American indigenous languages",
    "2JN" => "North & Central American indigenous languages",
    "2JNA" => "Aleut",
    "2JNB" => "Inuit",
    "2JNBK" => "Inuktitut",
    "2JNC" => "Algonkian (Algonquin) languages",
    "2JNCE" => "Cree",
    "2JNCJ" => "Ojibway",
    "2JND" => "Na-Dene & Athapascan (Athabascan) languages",
    "2JNG" => "Iroquoian & Siouan languages",
    "2JNM" => "Mayan",
    "2JNN" => "Uto-Aztecan languages",
    "2JNZ" => "Zuni",
    "2JS" => "South American & Caribbean indigenous languages",
    "2JSC" => "Carib (Cariban)",
    "2JSG" => "Guarani",
    "2JSQ" => "Quechuan",
    "2P" => "Oceanic & Austronesian languages",
    "2PB" => "Australian Aboriginal languages",
    "2PC" => "Papuan languages",
    "2PCS" => "Susuami",
    "2PG" => "Austronesian & Malayo-Polynesian languages",
    "2PGB" => "Formosan (Taiwanese)",
    "2PGG" => "Malagasy",
    "2PGJ" => "Tagalog (Filipino)",
    "2PGN" => "Indonesian languages",
    "2PGNA" => "Indonesian (Bahasa Indonesia)",
    "2PGNC" => "Balinese",
    "2PGND" => "Javanese",
    "2PGNM" => "Malay (Bahasa Malaysia)",
    "2PGP" => "Oceanic & Polynesian languages",
    "2PGPA" => "Maori language",
    "2PGPF" => "Fijian",
    "2PGPG" => "Tongan",
    "2PGPH" => "Tahitian",
    "2PGPR" => "Rarotongan",
    "2PGPS" => "Samoan",
    "2PGPW" => "Hawaiian",
    "2PGPX" => "Other Oceanic languages",
    "2PGPXK" => "Mokilese",
    "2PGPXM" => "Marshallese",
    "2PGPXN" => "Ponapean",
    "2PGPXP" => "Palauan",
    "2PGPXT" => "Tokelauan",
    "2Z" => "Other languages",
    "2ZB" => "Basque",
    "2ZC" => "Caucasian languages",
    "2ZCG" => "Georgian",
    "2ZM" => "Sumerian",
    "2ZP" => "Pidgins & Creoles",
    "2ZPT" => "Tok Pisin",
    "2ZX" => "Artificial languages",
    "2ZXA" => "Afrihili",
    "2ZXC" => "Occidental",
    "2ZXP" => "Esperanto",
    "2ZXT" => "Interlingua",
    "3B" => "Prehistory",
    "3BD" => "Stone Age",
    "3BDF" => "Stone Age: Palaeolithic period",
    "3BDK" => "Stone Age: Mesolithic period",
    "3BDQ" => "Stone Age: Neolithic period",
    "3BD-JP-J" => "c 16500 to c 1000 BCE (Japanese Jomon period)",
    "3BL" => "Bronze Age",
    "3BR" => "Iron Age",
    "3B-AA-E" => "Egypt: Predynastic & Early Dynastic periods (c 5500 to c 2700 BCE)",
    "3C" => "BCE period – Protohistory",
    "3CD" => "c 4000 to c 3000 BCE",
    "3CG" => "c 3000 to c 2000 BCE",
    "3CJ" => "c 2000 to c 1000 BCE",
    "3CT" => "c 1000 BCE to start of CE period",
    "3CT-DE-A" => "Germany: the ancient / classical world (c 800 BCE to c 500 CE)",
    "3CT-ES-A" => "Spain: Ancient History (up to c 200 BCE)",
    "3CT-ES-B" => "Spain: Roman History (c 200 BCE to c 400 CE)",
    "3CT-IT-A" => "Ancient Italy (c 1000 to c 500 BCE)",
    "3CT-JP-Y" => "c 1000 BCE to 300 CE (Japanese Yayoi period)",
    "3C-AA-E" => "Ancient Egypt (c 2686 BCE to c 323 BCE)",
    "3K" => "CE period up to c 1500",
    "3KB" => "c 1 CE to c 500 CE",
    "3KBF" => "1st century, c 1 to c 99",
    "3KBK" => "2nd century, c 100 to c 199",
    "3KBN" => "3rd century, c 200 to c 299",
    "3KBW" => "4th century, c 300 to c 399",
    "3KBY" => "5th century, c 400 to c 499",
    "3KB-AA-E" => "Egypt: Classical Antiquity (c 332 BCE to c 630 CE)",
    "3KB-GB-A" => "Roman Britain (c 43 BCE to c 410 CE)",
    "3KB-JP-K" => "c 300 CE to 591 (Japanese Kofun period)",
    "3KH" => "c 500 CE to c 1000 CE",
    "3KHF" => "6th century, c 500 to c 599",
    "3KHK" => "7th century, c 600 to c 699",
    "3KHK-JP-A" => "592 CE to 710 CE (Japanese Asuka period)",
    "3KHN" => "8th century, c 700 to c 799",
    "3KHN-JP-N" => "710 to 784 (Japanese Nara period)",
    "3KHW" => "9th century, c 800 to c 899",
    "3KHY" => "10th century, c 900 to c 999",
    "3KH-AA-E" => "Mediaeval Egypt (c 630 to c 1517)",
    "3KH-DK-H" => "Denmark: the Viking Age (c 800 to c 1050)",
    "3KH-ES-A" => "Spain: Germanic and visigothic invasions (c 400 to c 600)",
    "3KH-GB-B" => "Anglo-Saxon period (c 400 to c 1066)",
    "3KH-IE-S" => "Early Christian Ireland (c 400 to c 800)",
    "3KH-IE-V" => "Viking Ireland (c 800 to c 1014)",
    "3KH-IT-C" => "Italy: from Germanic Kingdoms to Franks (c 500 to c 1000)",
    "3KH-JP-H" => "785 to 1068 (Japanese Early and Middle Heian period)",
    "3KH-SE-H" => "Sweden: the Viking Age (c 800 to c 1050)",
    "3KL" => "c 1000 CE to c 1500",
    "3KLF" => "11th century, c 1000 to c 1099",
    "3KLK" => "12th century, c 1100 to c 1199",
    "3KLK-JP-H" => "1068 to 1185 (Japanese Late Heian period)",
    "3KLN" => "13th century, c 1200 to c 1299",
    "3KLN-GB-E" => "English conquest of Wales (c 1277 to c 1283)",
    "3KLN-JP-K" => "1185 to 1333 (Japanese Kamakura period)",
    "3KLW" => "14th century, c 1300 to c 1399",
    "3KLW-JP-C" => "1333 to 1392 (Japanese Northern and Southern Court period)",
    "3KLY" => "15th century, c 1400 to c 1499",
    "3KLY-GB-F" => "Wars of the Roses (c 1455 to c 1487)",
    "3KLY-IT-E" => "Italy: Renaissance (c 1400 to c 1499)",
    "3KLY-JP-M" => "1392 to 1573 (Japanese Muromachi period)",
    "3KLY-PL-A" => "Period of the Jagiellonian dynasty 1386–1572",
    "3KL-GB-C" => "Norman Conquest & Norman period (1066–1154)",
    "3KL-GB-D" => "The Plantagenet & mediaeval period (1154–1485)",
    "3KL-IE-N" => "Norman Ireland (1169 to c 1350)",
    "3KL-IT-D" => "Italy: Communes, ‘Signorie’ (c 1000 to c 1400)",
    "3KL-PL-A" => "Period of the Piast dynasty 960–1370",
    "3KL-SE-J" => "Sweden: Middle Ages (c 1050 to c 1520)",
    "3K-ES-A" => "Spain: Middle Ages (c 400 to c 1492)",
    "3K-ES-B" => "Spain: Arab presence (711–1492)",
    "3K-ES-C" => "Spain: ‘Reconquista’ (711–1492)",
    "3K-IT-B" => "Italy: c 500 BCE to c 1500 CE",
    "3M" => "c 1500 onwards to present day",
    "3MD" => "16th century, c 1500 to c 1599",
    "3MDB" => "Early 16th century c 1500 to c 1550",
    "3MDBA" => "c 1500 to c 1509",
    "3MDBF" => "c 1510 to c 1519",
    "3MDBH" => "c 1520 to c 1529",
    "3MDBJ" => "c 1530 to c 1539",
    "3MDBL" => "c 1540 to c 1549",
    "3MDQ" => "Later 16th century c 1550 to c 1599",
    "3MDQM" => "c 1550 to c 1559",
    "3MDQS" => "c 1560 to c 1569",
    "3MDQV" => "c 1570 to c 1579",
    "3MDQX" => "c 1580 to c 1589",
    "3MDQZ" => "c 1590 to c 1599",
    "3MDQ-JP-A" => "1573 to 1600 (Japanese Azuchi Momoyama period)",
    "3MD-CA-A" => "North America: New France (1534–1763)",
    "3MD-GB-G" => "Tudor period (1485–1603)",
    "3MD-GB-GE" => "Elizabethan era (1558–1603)",
    "3MD-IE-P" => "Plantations of Ireland (1556–1663)",
    "3MD-SE-L" => "Sweden: the Vasa era (c 1520 to c 1611)",
    "3MG" => "17th century, c 1600 to c 1699",
    "3MGB" => "Early 17th century c 1600 to c 1650",
    "3MGBA" => "c 1600 to c 1609",
    "3MGBF" => "c 1610 to c 1619",
    "3MGBH" => "c 1620 to c 1629",
    "3MGBJ" => "c 1630 to c 1639",
    "3MGBL" => "c 1640 to c 1649",
    "3MGB-GB-H" => "Jacobean & Early Stuart era (1603–1649)",
    "3MGQ" => "Later 17th century c 1650 to c 1699",
    "3MGQM" => "c 1650 to c 1659",
    "3MGQM-GB-J" => "British Civil Wars & Interregnum (c 1639 to 1660)",
    "3MGQM-IE-C" => "Cromwellian conquest of Ireland (1649–1653)",
    "3MGQS" => "c 1660 to c 1669",
    "3MGQS-GB-K" => "The Restoration & Later Stuart era (1660–1714)",
    "3MGQV" => "c 1670 to c 1679",
    "3MGQX" => "c 1680 to c 1689",
    "3MGQX-GB-M" => "The Glorious Revolution (1688–1689)",
    "3MGQZ" => "c 1690 to c 1699",
    "3MG-IT-G" => "Italy: Spanish domination (1559–1714)",
    "3MG-PL-A" => "Period of the Polish-Lithuanian Commonwealth 1569–1795",
    "3MG-SE-N" => "The Swedish Empire (c 1611 to c 1718)",
    "3MG-US-A" => "USA: Colonization and Settlement ( c 1600 to c 1775)",
    "3ML" => "18th century, c 1700 to c 1799",
    "3MLB" => "Early 18th century c 1700 to c 1750",
    "3MLBA" => "c 1700 to c 1709",
    "3MLBF" => "c 1710 to c 1719",
    "3MLBH" => "c 1720 to c 1729",
    "3MLBJ" => "c 1730 to c 1739",
    "3MLBL" => "c 1740 to c 1749",
    "3MLQ" => "Later 18th century c 1750 to c 1799",
    "3MLQM" => "c 1750 to c 1759",
    "3MLQS" => "c 1760 to c 1769",
    "3MLQV" => "c 1770 to c 1779",
    "3MLQX" => "c 1780 to c 1789",
    "3MLQZ" => "c 1790 to c 1799",
    "3MLQZ-FR-A" => "The French Revolution (c 1789 to c 1799)",
    "3MLQZ-IE-R" => "Irish Rebellion of 1798",
    "3MLQ-PL-A" => "Period of the Partitions of Poland 1772–1795",
    "3MLQ-SE-R" => "Sweden: the Gustavian Era (1772–1809)",
    "3MLQ-US-B" => "American Revolution (1775–1783)",
    "3MLQ-US-C" => "USA: The New Nation (c 1783 to c 1800)",
    "3ML-DE-B" => "Germany: the age of Absolutism & Enlightenment (1648–1779)",
    "3ML-GB-P" => "Georgian era (1714–1837)",
    "3ML-GB-PR" => "Regency Period (c 1811 to c 1820)",
    "3ML-IT-H" => "Italy: Austrian domination (1701–1796)",
    "3ML-SE-Q" => "Sweden: the Age of Liberty (c 1718 to c 1772)",
    "3MN" => "19th century, c 1800 to c 1899",
    "3MNB" => "Early 19th century c 1800 to c 1850",
    "3MNBA" => "c 1800 to c 1809",
    "3MNBF" => "c 1810 to c 1819",
    "3MNBH" => "c 1820 to c 1829",
    "3MNBJ" => "c 1830 to c 1839",
    "3MNBJ-CA-D" => "Lower Canada Rebellion / Patriots War (1837–1838)",
    "3MNBL" => "c 1840 to c 1849",
    "3MNBL-IE-F" => "Ireland: The Great Famine (1845–1852)",
    "3MNB-DE-C" => "Germany: the age of the European Revolutions (1780–1848)",
    "3MNB-ES-A" => "Spain: Spanish War of Independence (1808–1813)",
    "3MNB-GB-T" => "Industrial revolution (c 1760 to c 1840)",
    "3MNB-IT-M" => "Italy: Napoleonic era, Restoration, Risorgimento uprisings (1796–1848)",
    "3MNB-US-D" => "USA: Exploration and Expansion (c 1800 to c 1861)",
    "3MNQ" => "Later 19th century c 1850 to c 1899",
    "3MNQM" => "c 1850 to c 1859",
    "3MNQS" => "c 1860 to c 1869",
    "3MNQV" => "c 1870 to c 1879",
    "3MNQX" => "c 1880 to c 1889",
    "3MNQZ" => "c 1890 to c 1899",
    "3MNQZ-DE-D" => "Germany: the age of Imperialism (1890–1914)",
    "3MNQ-AR-D" => "Argentina: period of the Generation of ’80 & the Republica Conservadora 1880–1916",
    "3MNQ-GB-V" => "Victorian period (1837–1901)",
    "3MNQ-IE-G" => "Ireland: The Gaelic Revival (c 1850 to 1916)",
    "3MNQ-IT-N" => "Italy: National Independence & Risorgimento (1850–1861)",
    "3MNQ-IT-P" => "Italy: National Unification & first decades of the Kingdom of Italy (1861–1900)",
    "3MNQ-JP-M" => "1868 to 1912 (Japanese Meiji period)",
    "3MNQ-US-E" => "American Civil War and Reconstruction (1861–1877)",
    "3MNQ-US-F" => "USA: The Gilded Age (c 1877 to c 1893)",
    "3MN-DK-G" => "Denmark: Golden Age (c 1800 to c 1850)",
    "3MN-ES-A" => "Spain: Contemporary history (1808–2000)",
    "3MN-FI-A" => "Finland: period of Autonomy 1809–1917",
    "3MN-PA-A" => "Period of the Union of Columbia & Panama 1821–1903",
    "3MP" => "20th century, c 1900 to c 1999",
    "3MPB" => "Early 20th century c 1900 to c 1950",
    "3MPBA" => "c 1900 to c 1909",
    "3MPBF" => "c 1910 to c 1919",
    "3MPBFB" => "World War One period (1914–1918)",
    "3MPBF-FI-A" => "Period of Finnish Civil War 1918",
    "3MPBF-IE-R" => "Ireland: The Revolutionary Period (1916–1922)",
    "3MPBG" => "Inter-war period c 1919 to c 1939",
    "3MPBGH" => "c 1920 to c 1929",
    "3MPBGH-ES-A" => "Spain: Dictatorship of Primo de Rivera (1923–1930)",
    "3MPBGH-IE-C" => "The Irish Civil War (1922–1923)",
    "3MPBGH-US-J" => "USA: The Jazz Age (1919–1929)",
    "3MPBGJ" => "c 1930 to c 1939",
    "3MPBGJ-AR-A" => "Infamous Decade 1930–1943 (Argentina)",
    "3MPBGJ-DE-H" => "Germany: National Socialist period (1933–1945)",
    "3MPBGJ-ES-A" => "Spain: Second Republic (1931–1936)",
    "3MPBGJ-ES-B" => "Spain: Civil war (1936–1939)",
    "3MPBGJ-US-K" => "USA: The Great Depression (1929–1939)",
    "3MPBG-DE-G" => "Germany: Weimar Republic (1918–1933)",
    "3MPBG-IE-S" => "Irish Free State (1922–1937)",
    "3MPBG-IT-S" => "Italy: post First World War period & Fascism (1918–1943)",
    "3MPBL" => "c 1940 to c 1949",
    "3MPBLB" => "World War Two period (c 1939 to c 1945)",
    "3MPBLB-FI-A" => "Period of The Winter War 1939–1940 & the Continuation War 1941 to 1944",
    "3MPBLB-PL-A" => "Period of the Warsaw Ghetto uprising of 1943",
    "3MPBLB-PL-B" => "Period of the Warsaw Rising of 1944",
    "3MPBL-AR-C" => "Argentina: period of Peronism & the Peron presidencies 1943–1955",
    "3MPBL-DK-B" => "Denmark: German occupation (1940–1945)",
    "3MPBL-ES-A" => "Spain: Postwar period (1940–1949)",
    "3MPBL-IT-T" => "Italy: Liberation from Fascism & Resistance (1943–1945)",
    "3MPBL-IT-U" => "Italy: post Second World War period & Foundation of Italian Republic (1946–1968)",
    "3MPB-AR-B" => "Argentina: period of the Saenz Peña Law & First democratic governments 1916–1930",
    "3MPB-ES-A" => "Spain: End of the Monarchy (c 1900 to c 1931)",
    "3MPB-FI-A" => "Finland: period of Russification of 1899–1917",
    "3MPB-IT-R" => "Italy: Giolittian period (1900–1914)",
    "3MPB-JP-B" => "1912 to 1926 (Japanese Taisho period)",
    "3MPB-JP-D" => "1926 to 1945 (Japanese pre-war Showa period)",
    "3MPB-US-H" => "USA: The Progressive Era (c 1890 to c 1929)",
    "3MPQ" => "Later 20th century c 1950 to c 1999",
    "3MPQM" => "c 1950 to c 1959",
    "3MPQM-US-N" => "USA: Korean War period (1950–1953)",
    "3MPQS" => "c 1960 to c 1969",
    "3MPQS-CA-Q" => "Quebec: The Quiet Revolution (1960–1968)",
    "3MPQS-DE-K" => "Germany: Protest of 1968",
    "3MPQS-US-P" => "USA: Era of Civil Rights Movement (c 1954 to c 1968)",
    "3MPQS-US-Q" => "USA: Vietnam War period (c 1955 to c 1975)",
    "3MPQV" => "c 1970 to c 1979",
    "3MPQV-AR-C" => "Argentina: period of Military dictatorship 1976–1983",
    "3MPQV-DE-L" => "German Autumn, 1977",
    "3MPQV-IT-W" => "Italy: protest movement & ‘Anni di Piombo’ (1969–1980)",
    "3MPQX" => "c 1980 to c 1989",
    "3MPQZ" => "c 1990 to c 1999",
    "3MPQZ-IT-X" => "Italy: crisis of the Nineties & so-called Second Republic (1990–1999)",
    "3MPQ-DE-J" => "Germany: the Cold War era (1945–1990)",
    "3MPQ-ES-A" => "Spain: Franco´s dictatorship (c 1940 to 1975)",
    "3MPQ-ES-B" => "Spain: Democratic transition (c 1975 to c 1982)",
    "3MPQ-ES-C" => "Spain: Democracy (c 1982 to present)",
    "3MPQ-IE-T" => "Ireland: The Troubles (1968–1999)",
    "3MPQ-IT-V" => "Italy: reconstruction, economic miracle, social & political transformations (1950–1968)",
    "3MPQ-JP-B" => "1945 to 1989 (Japanese post-war Showa period)",
    "3MPQ-PL-A" => "Period of the Polish People’s Republic 1947–1989",
    "3MP-AA-E" => "Modern Egypt (c 1882 to present)",
    "3MP-JP-S" => "1926 to 1989 (Japanese Showa period)",
    "3MP-PA-B" => "Panama: the republican period 1903–1968",
    "3MPQ-PA-A" => "Panama: the Military Dictatorship period 1968–1989",
    "3MP-SE-A" => "Sweden: Folkhemmet (c 1930 to 1965)",
    "3MR" => "21st century, c 2000 to c 2100",
    "3MRB" => "Early 21st century c 2000 to c 2050",
    "3MRBA" => "c 2000 to c 2009",
    "3MRBF" => "c 2010 to c 2019",
    "3MRBH" => "c 2020 to c 2029",
    "3MRBJ" => "c 2030 to c 2039",
    "3MRBL" => "c 2040 to c 2049",
    "3MRB-JP-D" => "1989 to 2019 (Japanese Heisei period)",
    "3MRB-JP-R" => "2019 onwards (Japanese Reiwa period)",
    "3M-AA-E" => "Early Modern Egypt (c 1517 to c 1914)",
    "3M-ES-A" => "Spain: Modern history (1492–1808)",
    "3M-ES-AB" => "Spain: ‘Siglo de oro’ (1492–1690)",
    "3M-JP-E" => "1600 to 1867 (Japanese Edo period)",
    "4C" => "For all educational levels",
    "4CA" => "For pre-school learning",
    "4CD" => "For primary education",
    "4CF" => "For middle / preparatory school education",
    "4CL" => "For mandatory secondary education",
    "4CN" => "For optional / advanced secondary education",
    "4CP" => "For vocational / professional education / training",
    "4CPC" => "For vocational / professional certification / qualifications",
    "4CT" => "For higher / tertiary / university education",
    "4CTB" => "For undergraduate education & equivalents",
    "4CTM" => "For graduate / post-graduate & equivalents",
    "4CX" => "For adult education",
    "4G" => "For international curricula & examinations",
    "4GA" => "For International Baccalaureate (IB) pre-diploma level programmes",
    "4GAJ" => "For International Baccalaureate (IB) Early Years programme",
    "4GAS" => "For International Baccalaureate (IB) Middle Years programme",
    "4GB" => "For International Baccalaureate (IB) Diploma",
    "4GC" => "For International Baccalaureate (IB) Career-related Certificate",
    "4GH" => "For International GCSE (IGCSE)",
    "4L" => "For language learning courses & examinations",
    "4LB" => "For language proficiency tests / exams",
    "4LE" => "ELT examinations & certificates",
    "4LEA" => "Cambridge English Exams",
    "4LEC" => "International English Language Testing System (IELTS)",
    "4LEF" => "Test of English as a Foreign Language (TOEFL)",
    "4LEH" => "Test of English for International Communication (TOEIC)",
    "4LEP" => "ELT: Exams and tests of English for specific purposes",
    "4LZ" => "For specific language learning & courses other than ELT",
    "4LZ-ES-D" => "Diplomas of Spanish as a Foreign Language (DELE)",
    "4LZ-FR-D" => "Diplomas of French as a Foreign Language (DELF / DALF / DILF / TCF / TEF)",
    "4LZ-IT-H" => "Certification of Italian language learning",
    "4LZ-IT-HB" => "For Italian language learning: CELI Certificate",
    "4LZ-IT-HD" => "For Italian language learning: CIC Certificate",
    "4LZ-IT-HF" => "For Italian language learning: PLIDA Certificate",
    "4LZ-IT-HH" => "For Italian language learning: CILS Certificate",
    "4T" => "For specific educational purposes",
    "4TC" => "Textbook, coursework",
    "4TM" => "Revision & study guide",
    "4TN" => "For examinations / tests / assessments",
    "4TNC" => "For citizenship exams / tests",
    "4TP" => "Content and language integrated learning (CLIL)",
    "4TV" => "For supplementary education programmes (compensatory / complementary education)",
    "4TW" => "For specific learning difficulties",
    "4TY" => "For home learning",
    "4Z" => "For specific national or regional educational curricula",
    "4Z-AA-" => "For Arab world educational systems",
    "4Z-AA-E" => "For Egyptian educational systems",
    "4Z-AA-EA" => "For Al-Azhar Education System (Egypt)",
    "4Z-AR-" => "For the educational curriculum of Argentina",
    "4Z-AR-A" => "For pre-school education (Argentina)",
    "4Z-AR-B" => "For primary education (Argentina)",
    "4Z-AR-BA" => "Primary Education 1st Cycle (Argentina)",
    "4Z-AR-BC" => "Primary Education 2nd Cycle (Argentina)",
    "4Z-AR-BD" => "7th Grade Primary Education (Argentina)",
    "4Z-AR-C" => "For secondary education (Argentina)",
    "4Z-AR-CA" => "For basic secondary education (Argentina)",
    "4Z-AR-CB" => "For higher secondary education (Argentina)",
    "4Z-AR-CC" => "For technical secondary education (Argentina)",
    "4Z-BO-" => "For the educational curriculum of Bolivia",
    "4Z-CA-" => "For Canadian educational curricula",
    "4Z-CA-A" => "For Elementary Education (Canada)",
    "4Z-CA-C" => "For Secondary Education (Canada)",
    "4Z-CA-F" => "For College, Pre-University Programs (Canada)",
    "4Z-CA-H" => "For College, Technical Programs (Canada)",
    "4Z-CA-J" => "For University, Bachelor’s Degree (Canada)",
    "4Z-CA-L" => "For University, Master’s Degree (Canada)",
    "4Z-CA-M" => "For University, Doctorate (Canada)",
    "4Z-CA-Q" => "For Quebec educational curricula",
    "4Z-CA-QA" => "Quebec: for Elementary education",
    "4Z-CA-QC" => "Quebec: for Secondary education",
    "4Z-CA-QF" => "Quebec: CEGEP pre-university programme",
    "4Z-CA-QH" => "Quebec: CEGEP technical programme",
    "4Z-CA-QJ" => "Quebec: for university Batchelor’s degree",
    "4Z-CA-QK" => "Quebec: for university Master’s degree",
    "4Z-CA-QL" => "Quebec: for university Doctorate",
    "4Z-CB-" => "For educational curricula in the Caribbean",
    "4Z-CL-" => "For the educational curriculum of Chile",
    "4Z-CO-" => "For the educational curriculum of Colombia",
    "4Z-CR-" => "For the educational curriculum of Costa Rica",
    "4Z-CU-" => "For the educational curriculum of Cuba",
    "4Z-DE-" => "For German educational curricula",
    "4Z-DE-A" => "For pre-school learning (Germany)",
    "4Z-DE-B" => "For primary education (Germany)",
    "4Z-DE-BA" => "For German elementary school",
    "4Z-DE-C" => "For German common school",
    "4Z-DE-D" => "For secondary education (Germany)",
    "4Z-DE-DA" => "For German academic high school add on education",
    "4Z-DE-DAB" => "For German integrated secondary school",
    "4Z-DE-DAD" => "For German cooperative comprehensive school",
    "4Z-DE-DAE" => "For German laboratory school",
    "4Z-DE-DAF" => "For German intermediate school",
    "4Z-DE-DAG" => "For German pre-intermediate school",
    "4Z-DE-DAH" => "For German ten-class secondary school",
    "4Z-DE-DAJ" => "For German upper school college",
    "4Z-DE-DAK" => "For German junior high school",
    "4Z-DE-DAL" => "For German combined middle & secondary school",
    "4Z-DE-DB" => "For German middle school add on education",
    "4Z-DE-DBA" => "For German regular school",
    "4Z-DE-DBB" => "For German regional school",
    "4Z-DE-DBC" => "For German orientation classes",
    "4Z-DE-DBD" => "For German schools of a special kind",
    "4Z-DE-DBE" => "For German secondary school",
    "4Z-DE-DBF" => "For German municipality school",
    "4Z-DE-DBG" => "For German craft related junior high or main school",
    "4Z-DE-DC" => "For German comprehensive school",
    "4Z-DE-DD" => "For German academic high school",
    "4Z-DE-DDA" => "For German academic high school – eight year",
    "4Z-DE-DDB" => "For German academic high school – nine year",
    "4Z-DE-DJ" => "For German general school",
    "4Z-DE-DL" => "For German integrated comprehensive school",
    "4Z-DE-F" => "For vocational education (Germany)",
    "4Z-DE-FA" => "For German vocational high school",
    "4Z-DE-FAB" => "For German vocational professional school, two-year course",
    "4Z-DE-FAD" => "For occupational training one year basic course or for German vocational elementary school",
    "4Z-DE-FAF" => "For German vocational college",
    "4Z-DE-FAH" => "For German vocational secondary school",
    "4Z-DE-FAJ" => "For German vocational professional school qualifying for a certain profession",
    "4Z-DE-FAL" => "For German vocational school",
    "4Z-DE-FAM" => "For German preliminary vocational training",
    "4Z-DE-FAN" => "For German build-up year for vocational training",
    "4Z-DE-FAP" => "For German courses of education – with double qualifications",
    "4Z-DE-FB" => "For German vocational upper secondary school",
    "4Z-DE-FBB" => "For German dual vocational school",
    "4Z-DE-FBD" => "For German professional academy",
    "4Z-DE-FBF" => "For German professional high school",
    "4Z-DE-FBH" => "For German university of applied sciences",
    "4Z-DE-FBJ" => "For German specialist classes of the dual system of vocational training",
    "4Z-DE-FBL" => "For German upper secondary vocational school",
    "4Z-DE-FBM" => "For German secondary vocational school",
    "4Z-DE-FBN" => "For German upper secondary professional school",
    "4Z-DE-FBP" => "For German commercial college",
    "4Z-DE-FBR" => "For German technical college",
    "4Z-DE-FC" => "For German vocational academy",
    "4Z-DE-FCB" => "For German integrated vocational training preparation",
    "4Z-DE-FCD" => "For German independent vocational schools",
    "4Z-DE-FCF" => "For German occupational training one year prep classes",
    "4Z-DE-FCH" => "For German independent vocational schools with focus on crafts",
    "4Z-DE-FCJ" => "For German commercial school",
    "4Z-DE-FD" => "For German vocational buildup school",
    "4Z-DE-FF" => "For preparation of entry into professional life – one year school (Germany)",
    "4Z-DE-FH" => "For preparation of entry into professional life – class (Germany)",
    "4Z-DE-FJ" => "For preparation of entry into professional life – school (Germany)",
    "4Z-DE-FL" => "For German vocational professional school",
    "4Z-DE-FN" => "For German vocational professional school, one year course",
    "4Z-DE-G" => "For special needs schools (Germany)",
    "4Z-DE-GA" => "For German special-needs school (with focus on assistance with learning disabilities)",
    "4Z-DE-GC" => "For German special-needs school (with focus on assistance with mental development)",
    "4Z-DE-GE" => "For German special-needs school (with focus on assistance with emotional & social development)",
    "4Z-DE-GH" => "For German special-needs school (with focus on assistance with language learning)",
    "4Z-DE-GJ" => "For German special-needs school (with focus on assistance with physical & motor development)",
    "4Z-DE-GL" => "For German special-needs school (with focus on assistance with hearing)",
    "4Z-DE-GN" => "For German special-needs school (with focus on assistance with vision)",
    "4Z-DE-H" => "For German College or University Education",
    "4Z-DE-J" => "For adult education (Germany)",
    "4Z-DE-JB" => "For German three-year school of adult education",
    "4Z-DE-L" => "For learning years (Germany)",
    "4Z-DE-LA" => "For learning year 1 (Germany)",
    "4Z-DE-LB" => "For learning year 2 (Germany)",
    "4Z-DE-LC" => "For learning year 3 (Germany)",
    "4Z-DE-LD" => "For learning year 4 (Germany)",
    "4Z-DE-LE" => "For learning year 5 (Germany)",
    "4Z-DE-LF" => "For learning year 6 (Germany)",
    "4Z-DE-LG" => "For learning year 7 (Germany)",
    "4Z-DE-LH" => "For learning year 8 (Germany)",
    "4Z-DE-LJ" => "For learning year 9 (Germany)",
    "4Z-DE-LK" => "For learning year 10 (Germany)",
    "4Z-DE-LL" => "For learning year 11 (Germany)",
    "4Z-DE-LM" => "For learning year 12 (Germany)",
    "4Z-DE-LN" => "For learning year 13 (Germany)",
    "4Z-DE-U" => "For specific German vocational, professional or university qualifications",
    "4Z-DE-UD" => "For specific German professional qualifications & degrees",
    "4Z-DE-UDA" => "For German law qualifications (bachelors & other undergraduate)",
    "4Z-DE-UDB" => "For German law qualifications (masters, postgraduate & doctoral)",
    "4Z-DE-UDC" => "For German first state exam in licensed professions (Erste Staatsexamen)",
    "4Z-DE-UDD" => "For German training placements in state-licensed professions (Referendariat / Stationen)",
    "4Z-DE-UDE" => "For German second state exam for licensed professions (Erste Staatsexamen)",
    "4Z-DE-UDF" => "For German lawyers, paralegals & legal secretaries (professional development & reference)",
    "4Z-DE-UDG" => "For German tax consulting (professional development & reference)",
    "4Z-DE-UDH" => "For German curricula leading to certificatied legal specialisms",
    "4Z-DE-UDI" => "For German tax advisors’ exams",
    "4Z-DE-UDJ" => "For German civil law notaries’ exams",
    "4Z-DE-UDK" => "For German auditors’ exams",
    "4Z-DE-UH" => "For specific German professional/vocational qualifications & degrees (dual education system)",
    "4Z-DE-UHA" => "For German vocational qualifications working in the land sector",
    "4Z-DE-UHAA" => "For German vocational qualifications in agriculture, husbandry, forestry, landscaping & horticulture",
    "4Z-DE-UHAB" => "For German vocational qualifications in land surveying",
    "4Z-DE-UHB" => "For German vocational qualifications in the food industries",
    "4Z-DE-UHBA" => "For German vocational qualifications in baking, pastry making & confectionary",
    "4Z-DE-UHBB" => "For German vocational qualifications as a butcher",
    "4Z-DE-UHBC" => "For German vocational qualifications as a chef",
    "4Z-DE-UHBD" => "For German vocational qualifications as a food & beverage specialist",
    "4Z-DE-UHD" => "For German vocational qualifications in metal production & metal working industries",
    "4Z-DE-UHDA" => "For German vocational qualifications in precision engineering & related professions",
    "4Z-DE-UHDB" => "For German vocational qualifications in metal production & processing",
    "4Z-DE-UHDC" => "For German vocational qualifications in metalworking, plant construction, sheet metalwork, casting, & fitting",
    "4Z-DE-UHDD" => "For German vocational qualifications as an industrial mechanic or toolmaker",
    "4Z-DE-UHE" => "For German vocational qualifications in stone, glass & ceramic production & related industries",
    "4Z-DE-UHEA" => "For German vocational qualifications in stone, glass or ceramics processing & building materials",
    "4Z-DE-UHEB" => "For German vocational qualifications in mining & quarrying",
    "4Z-DE-UHF" => "For German vocational qualifications in the cloth & leather industries",
    "4Z-DE-UHFA" => "For German vocational qualifications in spinning, weaving, textile finishing",
    "4Z-DE-UHFB" => "For German vocational qualifications in textile processing & leatherworking",
    "4Z-DE-UHH" => "For German vocational qualifications in engineering, manufacturing & construction",
    "4Z-DE-UHHA" => "For German vocational qualifications in electrical trades",
    "4Z-DE-UHHB" => "For German vocational qualifications as technicians or mechanical engineer",
    "4Z-DE-UHHC" => "For German vocational qualifications as a drafter or drafting technician",
    "4Z-DE-UHHD" => "For German vocational qualifications in vehicle or aircraft manufacture & maintenance",
    "4Z-DE-UHHE" => "For German vocational qualifications in construction, wood & plastic processing",
    "4Z-DE-UHHF" => "For German vocational qualifications in the chemical & plastics industries",
    "4Z-DE-UHHG" => "For German vocational qualifications in paper manufacture, processing & printing",
    "4Z-DE-UHJ" => "For German vocational qualifications in scientific, geographical and IT related professions",
    "4Z-DE-UHJA" => "For German vocational qualifications in chemistry, physics or natural sciences",
    "4Z-DE-UHJB" => "For German vocational qualifications in IT",
    "4Z-DE-UHL" => "For German vocational qualifications in transport, logistics, security & safety",
    "4Z-DE-UHLA" => "For German vocational qualifications in the transport sector",
    "4Z-DE-UHLB" => "For German vocational qualifications in aviation or seafaring",
    "4Z-DE-UHLC" => "For German vocational qualifications in quality control & inspection",
    "4Z-DE-UHLD" => "For German vocational qualifications as packers, warehouse or transport workers",
    "4Z-DE-UHLE" => "For German vocational qualifications in personal protection & security",
    "4Z-DE-UHLF" => "For German vocational qualifications in the safety & security professions",
    "4Z-DE-UHLG" => "For German vocational qualifications in cleansing & waste disposal",
    "4Z-DE-UHM" => "For German vocational qualifications in commercial services, retail, distribution, hospitality and tourism",
    "4Z-DE-UHMA" => "For German vocational qualifications in the retail sector",
    "4Z-DE-UHMB" => "For German vocational qualifications in the wholesale sector",
    "4Z-DE-UHMC" => "For German vocational qualifications as caretakers & property management",
    "4Z-DE-UHMD" => "For German vocational qualifications in the hospitality industry",
    "4Z-DE-UHP" => "For German vocational qualifications in the finance, business & administration sectors",
    "4Z-DE-UHPA" => "For German vocational qualifications in banking or insurance",
    "4Z-DE-UHPB" => "For German vocational qualifications in commercial office skills",
    "4Z-DE-UHPC" => "For German vocational qualifications in management, accounting & business consulting",
    "4Z-DE-UHPD" => "For German vocational qualifications in public administration",
    "4Z-DE-UHPE" => "For German vocational qualifications in finance & bookkeeping",
    "4Z-DE-UHPF" => "For German vocational qualifications in secretarial & office skills",
    "4Z-DE-UHPG" => "For German vocational qualifications in the legal sector",
    "4Z-DE-UHQ" => "For German vocational qualifications in the health, social care & educational sectors",
    "4Z-DE-UHQA" => "For German vocational qualifications in personal care",
    "4Z-DE-UHQB" => "For German vocational qualifications in health care (licenced)",
    "4Z-DE-UHQC" => "For German vocational qualifications in health care (without a licence)",
    "4Z-DE-UHQD" => "For German vocational qualifications in social work",
    "4Z-DE-UHQE" => "For German vocational qualifications in teaching",
    "4Z-DE-UHS" => "For German vocational qualifications in the cultural sector, creative industries & the media",
    "4Z-DE-UHSA" => "For German vocational qualifications in advertising",
    "4Z-DE-UHSB" => "For German vocational qualifications in art or music",
    "4Z-DE-UHSC" => "For German vocational qualifications in design or photography",
    "4Z-DE-UHSD" => "For German vocational qualifications in publishing, librarianship, translation & related sectors",
    "4Z-DK-" => "For Danish educational curricula",
    "4Z-DK-A" => "For early education (Denmark)",
    "4Z-DK-F" => "For elementary school (Denmark)",
    "4Z-DK-FA" => "For pre-school (Denmark)",
    "4Z-DK-FB" => "For Grade 0 (Denmark)",
    "4Z-DK-FC" => "For Grade 1 (Denmark)",
    "4Z-DK-FD" => "For Grade 2 (Denmark)",
    "4Z-DK-FE" => "For Grade 3 (Denmark)",
    "4Z-DK-FF" => "For Grade 4 (Denmark)",
    "4Z-DK-FG" => "For Grade 5 (Denmark)",
    "4Z-DK-FH" => "For Grade 6 (Denmark)",
    "4Z-DK-FI" => "For Grade 7 (Denmark)",
    "4Z-DK-FJ" => "For Grade 8 (Denmark)",
    "4Z-DK-FK" => "For Grade 9 (Denmark)",
    "4Z-DK-FL" => "For Grade 10 (Denmark)",
    "4Z-DK-G" => "For secondary school (Denmark)",
    "4Z-DK-GA" => "For HF (Higher Preparatory Exam -Denmark)",
    "4Z-DK-GB" => "For HHX (Higher Commercial Exam -Denmark)",
    "4Z-DK-GC" => "For HTX (Higher Technical Exam -Denmark)",
    "4Z-DK-GD" => "For STX (Students’ Exam -Denmark)",
    "4Z-DK-H" => "For vocational education and training (Denmark)",
    "4Z-DK-K" => "For college and professional training (Denmark)",
    "4Z-DK-N" => "For higher education, universities (Denmark)",
    "4Z-DK-V" => "For adult vocational education and training (Denmark)",
    "4Z-DK-X" => "For continuing education (Denmark)",
    "4Z-DO-" => "For the educational curriculum of the Dominican Republic",
    "4Z-EC-" => "For the educational curriculum of Ecuador",
    "4Z-EC-A" => "For pre-school education (Ecuador)",
    "4Z-EC-B" => "Basic General Education (Ecuador)",
    "4Z-EC-C" => "Unified General Baccalaureate (Ecuador)",
    "4Z-ES-" => "For Spanish educational curricula",
    "4Z-ES-A" => "For general education (Spain)",
    "4Z-ES-AA" => "For pre-school learning (Spain)",
    "4Z-ES-AB" => "For primary education (Spain)",
    "4Z-ES-AC" => "For mandatory secondary education (Spain)",
    "4Z-ES-AD" => "For optional / advanced secondary education (Spain)",
    "4Z-ES-AE" => "For vocational / professional education (Spain)",
    "4Z-ES-AF" => "For higher / tertiary / university education (Spain)",
    "4Z-ES-B" => "For languages education (Spain)",
    "4Z-ES-C" => "For music education (Spain)",
    "4Z-ES-D" => "For dance education (Spain)",
    "4Z-ES-E" => "For dramatic arts education (Spain)",
    "4Z-ES-F" => "For arts and design education (Spain)",
    "4Z-ES-G" => "For sports education (Spain)",
    "4Z-ES-H" => "For adult education (Spain)",
    "4Z-ES-J" => "For special education (Spain)",
    "4Z-ES-K" => "For compensatory education (Spain)",
    "4Z-ES-L" => "For social guarantee programs (Spain)",
    "4Z-ES-X" => "For other educational levels or types (Spain)",
    "4Z-FI-" => "For the educational curriculum of Finland",
    "4Z-FI-A" => "Pre-primary education (Finland)",
    "4Z-FI-B" => "Basic education (Finland)",
    "4Z-FI-BA" => "Basic Education Grades 1–6 (Finland)",
    "4Z-FI-BB" => "Basic Education Grades 7–9 (Finland)",
    "4Z-FI-C" => "General upper secondary education (Finland)",
    "4Z-FI-D" => "Vocational upper secondary education (Finland)",
    "4Z-FR-" => "For French educational curricula",
    "4Z-GB-" => "For UK educational curricula",
    "4Z-GB-A" => "For England & Wales educational curricula",
    "4Z-GB-AC" => "For National Curriculum (England & Wales)",
    "4Z-GB-ACA" => "For National Curriculum Early Years (England & Wales)",
    "4Z-GB-ACF" => "For National Curriculum Key Stage 1 (England & Wales)",
    "4Z-GB-ACJ" => "For National Curriculum Key Stage 2 (England & Wales)",
    "4Z-GB-ACL" => "Eleven Plus (11+) exam",
    "4Z-GB-ACN" => "For National Curriculum Key Stage 3 (England & Wales)",
    "4Z-GB-ACT" => "For National Curriculum Key Stage 4 & GCSE (England & Wales)",
    "4Z-GB-AL" => "Designed / suitable for A & AS Level (England & Wales)",
    "4Z-GB-E" => "For U.K. Exam boards",
    "4Z-GB-EA" => "AQA – Assessment and Qualifications Alliance",
    "4Z-GB-EC" => "CCEA – Council for the Curriculum, Examinations & Assessment",
    "4Z-GB-ED" => "ICAAE – International Curriculum and Assessment Agency Examinations",
    "4Z-GB-EE" => "Edexcel",
    "4Z-GB-EF" => "CIE – Cambridge International Examinations",
    "4Z-GB-ER" => "OCR – Oxford, Cambridge and RSA Examinations",
    "4Z-GB-ES" => "SQA – Scottish Qualifications Authority",
    "4Z-GB-EW" => "WJEC (& Educas) – Welsh Joint Education Committee",
    "4Z-GB-N" => "For Northern Irish educational curricula",
    "4Z-GB-NC" => "For National Curriculum (Northern Ireland)",
    "4Z-GB-NCA" => "For National Curriculum Early Years (Northern Ireland)",
    "4Z-GB-NCF" => "For National Curriculum Key Stage 1 (Northern Ireland)",
    "4Z-GB-NCJ" => "For National Curriculum Key Stage 2 (Northern Ireland)",
    "4Z-GB-NCN" => "For National Curriculum Key Stage 3 (Northern Ireland)",
    "4Z-GB-NCT" => "For National Curriculum Key Stage 4 & GCSE (Northern Ireland)",
    "4Z-GB-NL" => "Designed / suitable for A & AS Level (Northern Ireland)",
    "4Z-GB-S" => "For Scottish Curriculum",
    "4Z-GB-SB" => "For Scottish Curriculum National 4",
    "4Z-GB-SD" => "For Scottish Curriculum National 5",
    "4Z-GB-SE" => "For Scottish Curriculum Intermediate 1",
    "4Z-GB-SG" => "For Scottish Curriculum Intermediate 2",
    "4Z-GB-SK" => "For Scottish Curriculum Higher",
    "4Z-GB-SL" => "For Scottish Curriculum Advanced Higher",
    "4Z-GB-V" => "For UK vocational courses",
    "4Z-GB-VC" => "For NVQ / SVQ (National / Scottish Vocational Qualification)",
    "4Z-GB-VN" => "For GNVQ (General National Vocational Qualification)",
    "4Z-GB-VS" => "For GSVQ (General Scottish Vocational Qualification)",
    "4Z-GB-VT" => "For BTEC (Business And Technology Education Council)",
    "4Z-GT-" => "For the educational curriculum of Guatemala",
    "4Z-HN-" => "For the educational curriculum of Honduras",
    "4Z-IE-" => "For Irish educational curricula",
    "4Z-IE-P" => "For Irish primary level curriculum",
    "4Z-IE-S" => "For Irish secondary level curriculum",
    "4Z-IE-SJ" => "For Irish Junior Certificate curriculum",
    "4Z-IE-SL" => "For Irish Leaving Certificate curriculum",
    "4Z-IN-" => "For the educational curriculum of India",
    "4Z-IN-A" => "For Primary education (India)",
    "4Z-IN-AA" => "For Class 1 (India)",
    "4Z-IN-AB" => "For Class 2 (India)",
    "4Z-IN-AC" => "For Class 3 (India)",
    "4Z-IN-AD" => "For Class 4 (India)",
    "4Z-IN-AE" => "For Class 5 (India)",
    "4Z-IN-B" => "For Upper Primary education (India)",
    "4Z-IN-BA" => "For Class 6 (India)",
    "4Z-IN-BB" => "For Class 7 (India)",
    "4Z-IN-BC" => "For Class 8 (India)",
    "4Z-IN-C" => "For Secondary education (India)",
    "4Z-IN-CA" => "For Class 9 (India)",
    "4Z-IN-CB" => "For Class 10 (India)",
    "4Z-IN-D" => "For Senior Secondary education (India)",
    "4Z-IN-DA" => "For Class 11 (India)",
    "4Z-IN-DB" => "For Class 12 (India)",
    "4Z-IN-E" => "For School Exam Boards (India)",
    "4Z-IN-EB" => "Central Board of Secondary Education (CBSE) Curriculum",
    "4Z-IN-ED" => "Indian School Certificate(ISC) and Indian Certificate of Secondary education(ICSE) Books",
    "4Z-IN-EG" => "National Talent Search Examination(NTSE)",
    "4Z-IN-EJ" => "For Olympiad Exams",
    "4Z-IN-EN" => "National Council of Educational Research and Training(NCERT)",
    "4Z-IN-F" => "For Indian State level education, exams and qualifications",
    "4Z-IN-FB" => "For Indian State Level School Boards",
    "4Z-IN-FD" => "For Indian State Level Public Service Exams",
    "4Z-IN-FF" => "For Indian State Level Vocational / Professional Exams and qualifications",
    "4Z-IN-FH" => "For Indian State level Recruitment tests or exams",
    "4Z-IN-G" => "For Engineering Qualifications / Entrance Exams (India)",
    "4Z-IN-GB" => "For National Engineering Entrance Exams (India)",
    "4Z-IN-GBB" => "Joint Entrance Examination (JEE) Main and JEE Advanced",
    "4Z-IN-GBD" => "For Graduate Aptitude Test in Engineering (GATE)",
    "4Z-IN-GD" => "For Regional Engineering Entrance Exams (India)",
    "4Z-IN-H" => "For Medical Qualifications / Entrance Exams (India)",
    "4Z-IN-HB" => "National Eligibility cum Entrance Test (NEET-UG)",
    "4Z-IN-HD" => "All India Institute of Medical Science(AIIMS) and Jawaharlal Institute of Postgraduate Medical Education and Research (JIPMER)",
    "4Z-IN-HF" => "Bachelor of Pharmacy (B. Pharma) and Nursing Entrance exam",
    "4Z-IN-K" => "For Accounting, banking, finance and Insurance Qualifications / Exams (India)",
    "4Z-IN-KA" => "For Chartered Accountant (CA) Exam (India)",
    "4Z-IN-KB" => "Chartered Financial Accountant(CFA) Exam (India)",
    "4Z-IN-KC" => "For Actuaries Qualifications / Exams (India)",
    "4Z-IN-KF" => "For Banking Qualifications / Exams (India)",
    "4Z-IN-L" => "For Law / Legal Professions Exams and qualifications (India)",
    "4Z-IN-M" => "For Management / Business Administration Exams / tests (India)",
    "4Z-IN-N" => "For Vocational, technical and professional Qualifications / Exams (India)",
    "4Z-IN-NA" => "For Agriculture Entrance Exams/ Pre Veterinary and Fisheries Test (PVT)",
    "4Z-IN-P" => "For Indian Defence Service Exams",
    "4Z-IN-PB" => "National Defence Academy/ Combined Defence Services (NDA/CDS)",
    "4Z-IN-PD" => "Indian Airforce Recruitment tests",
    "4Z-IN-PE" => "Indian Army Recruitment tests",
    "4Z-IN-PF" => "Indian Navy Recruitment tests",
    "4Z-IN-Q" => "For Civil Service Examinations (India)",
    "4Z-IN-QB" => "Civil Services Examination(CSE)/Indian Foreign Services(IFS)",
    "4Z-IN-QD" => "Engineering Services Examination (ESE)",
    "4Z-IN-QF" => "For Staff Selection Commission (SSC) Exams",
    "4Z-IN-QT" => "For Indian Teaching professions and research tests and exams",
    "4Z-IN-QTB" => "Central Teacher Eligibility Test (CTET)",
    "4Z-IN-QTD" => "Post- Graduate Teacher / Trained Graduate Teacher( PGT/TGT) Tests",
    "4Z-IN-QTF" => "National Eligibility Tests (NET)",
    "4Z-IN-QTH" => "State Eligibility Tests (SET)",
    "4Z-IN-R" => "For Indian Central government recruitment tests or entrance exams",
    "4Z-IN-RB" => "For Indian Railways Board Recruitment Exams",
    "4Z-IN-RD" => "For Public Sector Undertakings (PSU) Recruitment exams",
    "4Z-IN-RE" => "For Indian Postal Service Recruitment Exams",
    "4Z-IN-RF" => "Life Insurance Corporation (LIC) recruitment exams",
    "4Z-IN-RH" => "For Ordnance Trade Apprentice recruitment tests",
    "4Z-IN-RJ" => "For Intelligence Bureau (IB) Exams",
    "4Z-IN-RK" => "For Food Corporation of India (FCI) recruitment exams",
    "4Z-IN-T" => "For School Entrance Exams / Admission tests(India)",
    "4Z-IN-TC" => "Central Hindu School (CHS) Entrance Exam",
    "4Z-IN-TD" => "Jawahar Navodya Vidyalya schools entrance exams",
    "4Z-IN-TN" => "For Military Academies and Schools Entrance Exams /Admissions tests (India)",
    "4Z-IN-U" => "For University Entrance Exams and material (India)",
    "4Z-IN-UB" => "For Aligarh Muslim university (AMU)",
    "4Z-IN-UC" => "For Allahabad Central University",
    "4Z-IN-UD" => "For Banaras Hindu University (BHU)",
    "4Z-IN-UE" => "For University of Delhi (DU)",
    "4Z-IN-UF" => "For IP University",
    "4Z-IN-UG" => "For Jamia Millia Islamia (JMI)",
    "4Z-IN-UH" => "For Jawaharlal Nehru University (JNU)",
    "4Z-IN-V" => "For Technical institutions and education (India)",
    "4Z-IN-VB" => "For Institutes of Technology qualifications and exams (India)",
    "4Z-IN-VBT" => "For Indian Institute of Technology Joint Admission Test (IIT JAM)",
    "4Z-IN-VD" => "For Industrial Training Institutes (ITI) qualifications and exams",
    "4Z-IN-VF" => "For Polytechnic qualifications and exams (India)",
    "4Z-IT-" => "For Italian educational curricula",
    "4Z-IT-A" => "For Italian high school & teacher training education",
    "4Z-IT-AC" => "For Italian high school (with Classics specialism)",
    "4Z-IT-AD" => "For Italian high school (with Science specialism)",
    "4Z-IT-AG" => "For Italian high school (with Languages specialism)",
    "4Z-IT-AH" => "For Italian high school (aimed at developing European values and identity)",
    "4Z-IT-AL" => "For Italian high school (aimed at developing international language skills specific to the specialism chosen)",
    "4Z-IT-AN" => "For Italian high school (with Humanities and Social science specialism)",
    "4Z-IT-AP" => "For other Italian high schools & educational curricula",
    "4Z-IT-AR" => "For Italian teacher training (for former Italian primary school teacher training)",
    "4Z-IT-AS" => "For Italian teacher training (for former Italian nursery school teacher training)",
    "4Z-IT-C" => "For artistic education (Italy)",
    "4Z-IT-CB" => "For Italian high school (with Arts specialism)",
    "4Z-IT-CE" => "For Italian school of art / art college",
    "4Z-IT-E" => "For professional education (Italy)",
    "4Z-IT-EA" => "For Italian professional institute of agriculture & environment",
    "4Z-IT-EC" => "For Italian professional institute of industry & handicraft",
    "4Z-IT-EF" => "For Italian professional institute of commerce & tourism",
    "4Z-IT-EH" => "For Italian professional institute of advertising",
    "4Z-IT-EL" => "For Italian professional institute of hotel management",
    "4Z-IT-EN" => "For Italian professional institute of social services",
    "4Z-IT-EQ" => "For Italian professional institute of auxiliary health services",
    "4Z-IT-ER" => "For Italian professional institute of maritime activities",
    "4Z-IT-ES" => "For other Italian professional institutes",
    "4Z-IT-G" => "For technical education (Italy)",
    "4Z-IT-GB" => "For Italian technical institute of commerce (chartered accounting)",
    "4Z-IT-GD" => "For Italian technical institute of business & foreign languages",
    "4Z-IT-GF" => "For Italian technical institute of Industry",
    "4Z-IT-GH" => "For Italian technical institute of agriculture",
    "4Z-IT-GL" => "For Italian technical institute of surveying",
    "4Z-IT-GM" => "For Italian technical institute of nautical studies",
    "4Z-IT-GP" => "For Italian technical institute of aeronautics",
    "4Z-IT-GT" => "For Italian technical institute of tourism",
    "4Z-IT-GZ" => "For other Italian technical institutes",
    "4Z-JP-" => "For the educational curricula of Japan",
    "4Z-JP-A" => "For pre-school learning (Japan)",
    "4Z-JP-AA" => "For nursery education (Japan)",
    "4Z-JP-AB" => "For ECEC - Early Childhood Education and Care centres (Japan)",
    "4Z-JP-AC" => "For kindergarten (Japan)",
    "4Z-JP-ACA" => "For the first year of kindergarten (Japan)",
    "4Z-JP-ACB" => "For the second year of kindergarten (Japan)",
    "4Z-JP-ACC" => "For the third year of kindergarten (Japan)",
    "4Z-JP-B" => "For primary school learning (Japan)",
    "4Z-JP-BA" => "For primary school learning year 1 (Japan)",
    "4Z-JP-BB" => "For primary school learning year 2 (Japan)",
    "4Z-JP-BC" => "For primary school learning year 3 (Japan)",
    "4Z-JP-BD" => "For primary school learning year 4 (Japan)",
    "4Z-JP-BE" => "For primary school learning year 5 (Japan)",
    "4Z-JP-BF" => "For primary school learning year 6 (Japan)",
    "4Z-JP-C" => "For junior high school learning (Japan)",
    "4Z-JP-CA" => "For junior high school learning year 1 (Japan)",
    "4Z-JP-CB" => "For junior high school learning year 2 (Japan)",
    "4Z-JP-CC" => "For junior high school learning year 3 (Japan)",
    "4Z-JP-D" => "For high school / technical college learning (Japan)",
    "4Z-JP-DA" => "For high school learning - general course (Japan)",
    "4Z-JP-DAA" => "For high school learning - general course year 1 (Japan)",
    "4Z-JP-DAB" => "For high school learning - general course year 2 (Japan)",
    "4Z-JP-DAC" => "For high school learning - general course year 3 (Japan)",
    "4Z-JP-DB" => "For high school learning - specialised course (Japan)",
    "4Z-JP-DBA" => "For high school learning - specialised course year 1 (Japan)",
    "4Z-JP-DBB" => "For high school learning - specialised course year 2 (Japan)",
    "4Z-JP-DBC" => "For high school learning - specialised course year 3 (Japan)",
    "4Z-JP-DC" => "For technical college learning (Japan)",
    "4Z-JP-E" => "For special needs education (Japan)",
    "4Z-JP-EA" => "For special needs education - pre-school section (Japan)",
    "4Z-JP-EB" => "For special needs education - elementary school section (Japan)",
    "4Z-JP-EC" => "For special needs education - junior high school section (Japan)",
    "4Z-JP-ED" => "For special needs education - senior high school section (Japan)",
    "4Z-JP-F" => "For Institution under the control of the government (Japan)",
    "4Z-JP-G" => "For university / college learning (Japan)",
    "4Z-JP-H" => "For graduate school learning (Japan)",
    "4Z-JP-K" => "For Japanese Entrance and other exams",
    "4Z-JP-KA" => "For kindergarten entrance examination (Japan)",
    "4Z-JP-KB" => "For primary school entrance examination (Japan)",
    "4Z-JP-KC" => "For junior high school entrance examination (Japan)",
    "4Z-JP-KD" => "For Test of Lower Secondary School Graduation Certificate (Japan)",
    "4Z-JP-KE" => "For high school / technical entrance examination (Japan)",
    "4Z-JP-KF" => "For Test of Upper Secondary School Graduation Certificate examination (Japan)",
    "4Z-JP-KH" => "For Institution under the control of the government entrance examination (Japan)",
    "4Z-JP-KJ" => "For university / college entrance examination (Japan)",
    "4Z-JP-KJA" => "For National Centre Test for University Admissions (Japan)",
    "4Z-JP-KK" => "For graduate school entrance examination (Japan)",
    "4Z-MX-" => "For the educational curriculum of Mexico",
    "4Z-NI-" => "For the educational curriculum of Nicaragua",
    "4Z-NO-" => "For the educational curriculum of Norway",
    "4Z-NO-A" => "KL06 Kunnskapsløftet",
    "4Z-NO-B" => "LK20 Fagfornyelsen",
    "4Z-NO-C" => "LK20S Fagfornyelsen (sami curricula)",
    "4Z-PA-" => "For the educational curriculum of Panama",
    "4Z-PA-A" => "Primary Education (Panama)",
    "4Z-PA-B" => "Pre-secondary or secondary education (Panama)",
    "4Z-PA-C" => "Secondary education or Bachillerato (Panama)",
    "4Z-PE-" => "For the educational curriculum of Peru",
    "4Z-PL-" => "For the educational curriculum of Poland",
    "4Z-PL-A" => "For Primary / elementary education (Poland)",
    "4Z-PL-B" => "For Eighth grade exams (Poland)",
    "4Z-PL-C" => "For secondary education (Poland)",
    "4Z-PL-CA" => "For Polish general secondary schools (liceum)",
    "4Z-PL-CB" => "For Polish technical secondary schools (technikum)",
    "4Z-PL-CD" => "For Polish basic vocational schools",
    "4Z-PL-D" => "Polish vocational or professional exams",
    "4Z-PL-E" => "Polish secondary school leaving exams (Matura)",
    "4Z-PY-" => "For the educational curriculum of Paraguay",
    "4Z-SV-" => "For the educational curriculum of El Salvador",
    "4Z-US-" => "For US educational curricula",
    "4Z-US-A" => "For SAT (Scholastic Assessment Test) (USA)",
    "4Z-US-B" => "For ACT (American College Testing) (USA)",
    "4Z-US-C" => "For GED (General Educational Development Tests) (USA)",
    "4Z-US-D" => "For GMAT (Graduate Management Admission Test) (USA)",
    "4Z-US-E" => "For GRE (Graduate Record Examination) (USA)",
    "4Z-US-F" => "For LSAT (Law School Admission Test) (USA)",
    "4Z-US-G" => "For MCAT (Medical College Admission Test) (USA)",
    "4Z-US-H" => "For PSAT & NMSQT (National Merit Scholarship Qualifying Test) (USA)",
    "4Z-US-I" => "For NTE (National Teacher Examinations) (USA)",
    "4Z-US-J" => "For NCLEX (National Council Licensure Examination) (USA)",
    "4Z-US-L" => "For Legal Bar (USA)",
    "4Z-US-M" => "For High School Entrance (USA)",
    "4Z-US-N" => "For College Entrance (USA)",
    "4Z-US-O" => "For Advance Placement (USA)",
    "4Z-US-P" => "For Armed Forces (USA)",
    "4Z-UY-" => "For the educational curriculum of Uruguay",
    "4Z-VE-" => "For the educational curriculum of Venezuela",
    "5A" => "Interest age / level",
    "5AB" => "For children c 0–36 months",
    "5ABB" => "For babies from birth",
    "5ABD" => "For babies from 3 months",
    "5ABF" => "For babies from 6 months",
    "5ABH" => "For infants from c 12 months",
    "5ABK" => "Interest age: from c 24 months",
    "5AC" => "Interest age: from c 3 years",
    "5AD" => "Interest age: from c 4 years",
    "5AF" => "Interest age: from c 5 years",
    "5AG" => "Interest age: from c 6 years",
    "5AH" => "Interest age: from c 7 years",
    "5AJ" => "Interest age: from c 8 years",
    "5AK" => "Interest age: from c 9 years",
    "5AL" => "Interest age: from c 10 years",
    "5AM" => "Interest age: from c 11 years",
    "5AN" => "Interest age: from c 12 years",
    "5AP" => "Interest age: from c 13 years",
    "5AQ" => "Interest age: from c 14 years",
    "5AR" => "For reluctant or struggling readers (children / teenagers)",
    "5AS" => "Interest age: from c 15 years",
    "5AT" => "Interest age: from c 16 years",
    "5AU" => "Interest age: from c 17 years",
    "5AX" => "For adult emergent readers",
    "5AZ" => "For people with learning / communication difficulties",
    "5H" => "Holidays, events & seasonal interest",
    "5HC" => "Holidays & celebrations",
    "5HCA" => "New Year",
    "5HCC" => "Chinese New Year",
    "5HCE" => "Valentine’s Day",
    "5HCG" => "Carnival / Mardi Gras",
    "5HCJ" => "Mother’s Day",
    "5HCL" => "Father’s Day",
    "5HCM" => "Midsummer",
    "5HCN" => "Mid-Autumn festival",
    "5HCP" => "Hallowe’en",
    "5HCR" => "Harvest Festivals",
    "5HCS" => "Thanksgiving",
    "5HCV" => "Midwinter",
    "5HCW" => "International Workers Day (Labour Day)",
    "5HC-CN-D" => "Dragon Boat Festival",
    "5HC-CN-G" => "Chinese National Day",
    "5HC-CN-Q" => "Ancestors’ Day",
    "5HC-IE-B" => "St Brigid’s Day",
    "5HC-IE-P" => "St Patrick’s Day",
    "5HC-MX-D" => "Day of the Dead / Día de Muertos",
    "5HC-US-A" => "US Independence Day",
    "5HK" => "Special events",
    "5HKA" => "Birthdays",
    "5HKB" => "Back to School",
    "5HKC" => "Graduation",
    "5HKF" => "Baptism",
    "5HKM" => "First Communion, Holy Communion",
    "5HKQ" => "Confirmation",
    "5HKT" => "Bar Mitzvah, Bat Mitzvah",
    "5HKU" => "Engagement / Wedding / Marriage",
    "5HKV" => "Coming of age celebrations / festivals / rituals",
    "5HP" => "Religious holidays",
    "5HP-NL-N" => "Saint Nicholas Day",
    "5HPD" => "Christmas",
    "5HPDA" => "Advent",
    "5HPF" => "Easter",
    "5HPG" => "Holi (Festival of Colours)",
    "5HPH" => "Diwali",
    "5HPK" => "Ramadan",
    "5HPKE" => "Eid al-Fitr",
    "5HPL" => "Eid al-Adha",
    "5HPU" => "Hanukkah",
    "5HPV" => "Passover (Pesach)",
    "5HPW" => "Rosh Hashanah",
    "5HPWY" => "Yom Kippur",
    "5HR" => "Seasonal interest",
    "5HRA" => "Seasonal interest: Spring",
    "5HRB" => "Seasonal interest: Summer",
    "5HRB-FI-P" => "Midnight sun",
    "5HRC" => "Seasonal interest: Autumn, Fall",
    "5HRD" => "Seasonal interest: Winter",
    "5HRD-FI-P" => "Polar night",
    "5J" => "Intended for specific groups",
    "5JA" => "Intended specifically for women and/or girls",
    "5JB" => "Intended specifically for men and/or boys",
    "5L" => "Relating to the stages of life",
    "5LB" => "Relating to infancy",
    "5LC" => "Relating to childhood",
    "5LD" => "Relating to preteen / tween years",
    "5LF" => "Relating to adolescence / teenage years",
    "5LK" => "Relating to adulthood",
    "5LKE" => "Relating to early adulthood",
    "5LKM" => "Relating to middle adulthood",
    "5LKS" => "Relating to late adulthood / old age",
    "5P" => "Relating to specific groups & cultures or social & cultural interests",
    "5PB" => "Relating to peoples: ethnic groups, indigenous peoples, cultures, tribes & other groupings of people",
    "5PBR" => "Relating to Romani people & Travellers",
    "5PBR-IE-T" => "Relating to Irish Travellers",
    "5PBS" => "Relating to Sami people",
    "5PB-AU-A" => "Relating to Australian Aboriginal & Torres Strait Islanders",
    "5PB-GB-A" => "Relating to British Asian people",
    "5PB-GB-AE" => "Relating to British East Asian people",
    "5PB-GB-AS" => "Relating to British South Asian people",
    "5PB-GB-B" => "Relating to Black British people",
    "5PB-GB-BC" => "Relating to Black British Caribbean people",
    "5PB-GB-BF" => "Relating to Black British African people",
    "5PB-GB-N" => "Relating to Ulster-Scots (or Scots-Irish) people",
    "5PB-NO-K" => "Relating to Kven people",
    "5PB-NZ-A" => "Relating to Maori people",
    "5PB-US-B" => "Relating to Amish / Mennonite people",
    "5PB-US-C" => "Relating to African American people",
    "5PB-US-D" => "Relating to Asian American people",
    "5PB-US-E" => "Relating to Native American people",
    "5PB-US-F" => "Relating to Creole people",
    "5PB-US-G" => "Relating to Cajun people",
    "5PB-US-H" => "Relating to Latin / Hispanic American people",
    "5PG" => "Relating to religious groups",
    "5PGC" => "Relating to Confucian people & groups",
    "5PGD" => "Relating to Hindu people & groups",
    "5PGF" => "Relating to Buddhist people & groups",
    "5PGJ" => "Relating to Jewish people & groups",
    "5PGM" => "Relating to Christian people & groups",
    "5PGP" => "Relating to Islamic people & groups",
    "5PGS" => "Relating to Shinto people & groups",
    "5PGT" => "Relating to Taoist people & groups",
    "5PS" => "Relating to Gay, Lesbian & bisexual people",
    "5PSB" => "Relating to bisexuals",
    "5PSG" => "Relating to gay people",
    "5PSL" => "Relating to lesbians",
    "5PT" => "Relating to transgender people",
    "5PX" => "Relating to specific and significant cultural interests",
    "5PX-GB-S" => "Shakespeare",
    "5X" => "Contains explicit material",
    "6A" => "Styles (A)",
    "6AA" => "Abstractism",
    "6AB" => "Abstract Expressionism",
    "6AC" => "Art Deco",
    "6AD" => "Art Nouveau",
    "6AF" => "Arts & Crafts",
    "6AG" => "Academic style, Academism, Academicism",
    "6AH" => "Aestheticism",
    "6AJ" => "Altermodernism",
    "6AK" => "Analytic Cubism",
    "6AL" => "Arbeitsrat für Kunst",
    "6AM" => "Art Informel",
    "6AN" => "Arte Povera",
    "6AP" => "Assemblage",
    "6AQ" => "Avant-garde",
    "6B" => "Styles (B)",
    "6BA" => "Baroque",
    "6BB" => "Barbizon school",
    "6BC" => "Bauhaus",
    "6BD" => "Berliner Sezession",
    "6BF" => "Biedermeier",
    "6BG" => "Beat style",
    "6BH" => "Bebop",
    "6BJ" => "Der Blaue Reiter",
    "6BK" => "Bloomsbury Group style",
    "6BL" => "Bluegrass",
    "6BM" => "Blues",
    "6BN" => "Die Brücke",
    "6BP" => "Byzantine style",
    "6C" => "Styles (C)",
    "6CA" => "Classical style",
    "6CB" => "Cubism",
    "6CC" => "Celtic style",
    "6CD" => "Camden Town Group",
    "6CF" => "Cloisonnism",
    "6CG" => "CoBrA",
    "6CH" => "Color Field painting",
    "6CJ" => "Computer art",
    "6CK" => "Conceptualism",
    "6CL" => "Constructivism",
    "6CM" => "Country & Western",
    "6CN" => "Cubo-Futurism",
    "6D" => "Styles (D)",
    "6DA" => "Dada",
    "6DB" => "Divisionism",
    "6DC" => "Düsseldorf School",
    "6E" => "Styles (E)",
    "6EA" => "Empire style",
    "6EB" => "Easy listening",
    "6EC" => "The Eight",
    "6ED" => "Ancient Etruscan style",
    "6EF" => "Expressionism",
    "6EG" => "Ancient Egyptian style",
    "6EH" => "Epic",
    "6EJ" => "Elegy",
    "6F" => "Styles (F)",
    "6FA" => "Fauvism",
    "6FB" => "Fado",
    "6FC" => "Flamenco",
    "6FD" => "Folk style",
    "6FF" => "Futurism",
    "6FG" => "Fantasy art",
    "6G" => "Styles (G)",
    "6GA" => "Gothic",
    "6GB" => "Georgian style",
    "6GC" => "Ancient Greek style",
    "6H" => "Styles (H)",
    "6HA" => "Metal, Heavy Metal",
    "6HB" => "Hague School",
    "6HC" => "Heidelberg School",
    "6J" => "Styles (IJ)",
    "6JA" => "Impressionism",
    "6JB" => "Iberian style",
    "6JC" => "Indie",
    "6JD" => "Jazz",
    "6JF" => "Jack of Diamonds",
    "6JG" => "Jugendstil",
    "6K" => "Styles (K)",
    "6L" => "Styles (L)",
    "6LA" => "Lettrism",
    "6LB" => "Lyric",
    "6M" => "Styles (M)",
    "6MA" => "Mannerism",
    "6MB" => "Mediaeval style",
    "6MC" => "Modernism",
    "6MD" => "Macchiaioli",
    "6MF" => "Minimalism",
    "6MG" => "Ancient Minoan style",
    "6MH" => "Mir iskusstva",
    "6MJ" => "Mozarabic style",
    "6MK" => "Ancient Mycenaean style",
    "6N" => "Styles (NO)",
    "6NA" => "Naive style",
    "6NB" => "Naturalism",
    "6NC" => "Op art",
    "6ND" => "Outsider art, Art brut",
    "6NE" => "Orientalism",
    "6NF" => "Les Nabis",
    "6NG" => "Nazarene",
    "6NH" => "Neo-Classicism",
    "6NJ" => "Neo-impressionism",
    "6NK" => "New age",
    "6NL" => "Norwich School",
    "6NM" => "Orphism",
    "6NW" => "New Wave",
    "6P" => "Styles (P)",
    "6PA" => "Pop art",
    "6PB" => "Pop music",
    "6PC" => "Post-Impressionism",
    "6PD" => "Postmodernism",
    "6PF" => "Peredvizhniki",
    "6PG" => "Pittura Metafisica",
    "6PH" => "Pointillism",
    "6PJ" => "Prehistoric styles",
    "6PK" => "Prog Rock",
    "6PL" => "Pre-Raphaelite",
    "6PM" => "Psychedelic",
    "6PN" => "Punk",
    "6PP" => "Purism",
    "6Q" => "Styles (Q)",
    "6QA" => "Queen Anne style",
    "6R" => "Styles (R)",
    "6RA" => "Romanticism",
    "6RB" => "Romanesque",
    "6RC" => "Renaissance style",
    "6RD" => "Rococo",
    "6RE" => "Regency",
    "6RF" => "Rock",
    "6RG" => "Rock & Roll",
    "6RH" => "Rhythm & blues, R’n’B",
    "6RJ" => "Rap & Hip Hop",
    "6RK" => "Reggae & Ska",
    "6RL" => "Rayonism",
    "6RM" => "Realism",
    "6RN" => "Relational art",
    "6RP" => "Retro art",
    "6RQ" => "Return to order",
    "6RR" => "Ancient Roman style",
    "6S" => "Styles (S)",
    "6SA" => "Surrealism",
    "6SB" => "Soul & Funk",
    "6SC" => "Samba & Bossa Nova",
    "6SD" => "Schweizerischer Werkbund",
    "6SF" => "Scuola Romana",
    "6SG" => "Secession Groups",
    "6SH" => "Section d’Or",
    "6SJ" => "Shaker style",
    "6SK" => "Situationist International",
    "6SL" => "Soviet style",
    "6SM" => "Spanish Eclecticism",
    "6SN" => "De Stijl, Neoplasticism",
    "6SP" => "Stuckism International",
    "6SQ" => "Sturm und Drang",
    "6SR" => "Suprematism",
    "6SS" => "Swing",
    "6ST" => "Symbolist / symbolism",
    "6SU" => "Synthetic Cubism",
    "6SV" => "Synthetism",
    "6SW" => "Satirical",
    "6T" => "Styles (T)",
    "6TA" => "Tango",
    "6TB" => "Tachism",
    "6TC" => "Tartessian style",
    "6TE" => "Transavanguardia",
    "6U" => "Styles (U)",
    "6V" => "Styles (V)",
    "6VA" => "Vienna Secession",
    "6VB" => "Viking style",
    "6VC" => "Visigoth style",
    "6VD" => "Vorticism",
    "6VE" => "Vernacular",
    "6W" => "Styles (W)",
    "6X" => "Styles (XYZ)",
    "6XZ" => "Zydeco"
};
